/* Copyright (C) 2007-2017 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

Under Section 7 of GPL version 3, you are granted additional
permissions described in the GCC Runtime Library Exception, version
3.1, as published by the Free Software Foundation.

You should have received a copy of the GNU General Public License and
a copy of the GCC Runtime Library Exception along with this program;
see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
<http://www.gnu.org/licenses/>.  */

#include "bid_internal.h"

// Counting leading zeros in an unsigned 32-bit word
// The "_nz" version will return the wrong answer (31) for zero inputs

#define CLZ32_MASK16 0xFFFF0000ul
#define CLZ32_MASK8  0xFF00FF00ul
#define CLZ32_MASK4  0xF0F0F0F0ul
#define CLZ32_MASK2  0xCCCCCCCCul
#define CLZ32_MASK1  0xAAAAAAAAul

#define clz32_nz(n)                                             \
 (((((n) & CLZ32_MASK16) <= ((n) & ~CLZ32_MASK16)) ? 16 : 0) +  \
  ((((n) & CLZ32_MASK8) <= ((n) & ~CLZ32_MASK8)) ? 8 : 0) +     \
  ((((n) & CLZ32_MASK4) <= ((n) & ~CLZ32_MASK4)) ? 4 : 0) +     \
  ((((n) & CLZ32_MASK2) <= ((n) & ~CLZ32_MASK2)) ? 2 : 0) +     \
  ((((n) & CLZ32_MASK1) <= ((n) & ~CLZ32_MASK1)) ? 1 : 0))

#define clz32(n) (((n)==0) ? 32 : clz32_nz(n))

// Counting trailing zeros in an unsigned 32-bit word
// The ctz32_1bit version is for a single bit

#define ctz32_1bit(n)                                           \
 ((((n) & ~CLZ32_MASK16) ? 0 : 16) +                            \
  (((n) & ~CLZ32_MASK8) ? 0 : 8) +                              \
  (((n) & ~CLZ32_MASK4) ? 0 : 4) +                              \
  (((n) & ~CLZ32_MASK2) ? 0 : 2) +                              \
  (((n) & ~CLZ32_MASK1) ? 0 : 1))

#define ctz32(n) (((n) == 0) ? 32 : ctz32_1bit((n) & -(n)))

// Counting leading zeros in an unsigned 64-bit word
// The "_nz" version will return the wrong answer (63) for zero inputs

#define CLZ64_MASK32 0xFFFFFFFF00000000ull
#define CLZ64_MASK16 0xFFFF0000FFFF0000ull
#define CLZ64_MASK8  0xFF00FF00FF00FF00ull
#define CLZ64_MASK4  0xF0F0F0F0F0F0F0F0ull
#define CLZ64_MASK2  0xCCCCCCCCCCCCCCCCull
#define CLZ64_MASK1  0xAAAAAAAAAAAAAAAAull

#define clz64_nz(n)                                             \
 (((((n) & CLZ64_MASK32) <= ((n) & ~CLZ64_MASK32)) ? 32 : 0) +  \
  ((((n) & CLZ64_MASK16) <= ((n) & ~CLZ64_MASK16)) ? 16 : 0) +  \
  ((((n) & CLZ64_MASK8) <= ((n) & ~CLZ64_MASK8)) ? 8 : 0) +     \
  ((((n) & CLZ64_MASK4) <= ((n) & ~CLZ64_MASK4)) ? 4 : 0) +     \
  ((((n) & CLZ64_MASK2) <= ((n) & ~CLZ64_MASK2)) ? 2 : 0) +     \
  ((((n) & CLZ64_MASK1) <= ((n) & ~CLZ64_MASK1)) ? 1 : 0))      \

#define clz64(n) (((n)==0) ? 64 : clz64_nz(n))

// Counting trailing zeros in an unsigned 64-bit word
// The ctz64_1bit version is for a single bit

#define ctz64_1bit(n)                                           \
 ((((n) & ~CLZ64_MASK32) ? 0 : 32) +                            \
  (((n) & ~CLZ64_MASK16) ? 0 : 16) +                            \
  (((n) & ~CLZ64_MASK8) ? 0 : 8) +                              \
  (((n) & ~CLZ64_MASK4) ? 0 : 4) +                              \
  (((n) & ~CLZ64_MASK2) ? 0 : 2) +                              \
  (((n) & ~CLZ64_MASK1) ? 0 : 1))

#define ctz64(n) (((n) == 0) ? 64 : ctz64_1bit((n) & -(n)))

// Counting leading zeros in an unsigned 2-part 128-bit word

#define clz128(n_hi,n_lo) (((n_hi) == 0) ? 64 + clz64(n_lo) : clz64_nz(n_hi))

// Counting trailing zeros in a 2-part 128-bit word

#define ctz128(hi,lo) (((lo) == 0) ? 64 + ctz64(hi) : ctz64(lo))

// Shift 2-part 2^64 * hi + lo left by "c" bits
// The "short" form requires a shift 0 < c < 64 and will be faster
// Note that shifts of 64 can't be relied on as ANSI

#define sll128_short(hi,lo,c)                                   \
  ((hi) = ((hi) << (c)) + ((lo)>>(64-(c))),                     \
   (lo) = (lo) << (c)                                           \
  )

#define sll128(hi,lo,c)                                         \
  (((c) == 0) ? hi = hi, lo = lo :                              \
  (((c) >= 64) ? hi = lo << ((c) - 64), lo = 0 : sll128_short(hi,lo,c)))

// Shift 2-part 2^64 * hi + lo right by "c" bits
// The "short" form requires a shift 0 < c < 64 and will be faster
// Note that shifts of 64 can't be relied on as ANSI

#define srl128_short(hi,lo,c)                                   \
  ((lo) = ((hi) << (64 - (c))) + ((lo) >> (c)),                 \
   (hi) = (hi) >> (c)                                           \
  )

#define srl128(hi,lo,c)                                         \
  (((c) == 0) ? hi = hi, lo = lo :                              \
  (((c) >= 64) ? lo = hi >> ((c) - 64), hi = 0 : srl128_short(hi,lo,c)))

// Shift 4-part 2^196 * x3 + 2^128 * x2 + 2^64 * x1 + x0
// right by "c" bits (must have c < 64)

#define srl256(x3,x2,x1,x0,c)                                   \
  ((x0) = ((x1) << (64 - (c))) + ((x0) >> (c)),                 \
   (x1) = ((x2) << (64 - (c))) + ((x1) >> (c)),                 \
   (x2) = ((x3) << (64 - (c))) + ((x2) >> (c)),                 \
   (x3) = (x3) >> (c)                                           \
  )

// Compare "<" two 2-part unsigned integers

#define lt128(x_hi,x_lo,y_hi,y_lo)                              \
  (((x_hi) < (y_hi)) || (((x_hi) == (y_hi)) && ((x_lo) < (y_lo))))

// Likewise "<="

#define le128(x_hi,x_lo,y_hi,y_lo)                              \
  (((x_hi) < (y_hi)) || (((x_hi) == (y_hi)) && ((x_lo) <= (y_lo))))

// 128x256->384 bit multiplication (missing from existing macros)
// I derived this by propagating (A).w[2] = 0 in __mul_192x256_to_448

#define __mul_128x256_to_384(P, A, B)                           \
{                                                               \
UINT512 P0,P1;                                                  \
UINT64 CY;                                                      \
        __mul_64x256_to_320(P0, (A).w[0], B);                   \
        __mul_64x256_to_320(P1, (A).w[1], B);                   \
        (P).w[0] = P0.w[0];                                     \
        __add_carry_out((P).w[1],CY,P1.w[0],P0.w[1]);           \
        __add_carry_in_out((P).w[2],CY,P1.w[1],P0.w[2],CY);     \
        __add_carry_in_out((P).w[3],CY,P1.w[2],P0.w[3],CY);     \
        __add_carry_in_out((P).w[4],CY,P1.w[3],P0.w[4],CY);     \
        (P).w[5] = P1.w[4] + CY;                                \
}

// Multiply a 64-bit number by 10, getting "carry" and "sum"

#define __mul_10x64(sum,carryout,input,carryin)                         \
{ unsigned long long s3 = (input) + ((input) >> 2);                     \
  (carryout) = ((s3 < (unsigned long long)(input))<<3) + (s3>>61);      \
  s3 = (s3<<3) + ((input&3)<<1);                                        \
  (sum) = s3 + (carryin);                                               \
  if ((unsigned long long)(sum) < s3) ++(carryout);                     \
}

// Multiply a 256-bit number by 10, assuming no overflow

#define __mul_10x256_to_256(p3,p2,p1,p0,a3,a2,a1,a0)            \
{ unsigned long long c0,c1,c2,c3;                               \
  __mul_10x64(p0,c0,a0,0ull);                                   \
  __mul_10x64(p1,c1,a1,c0);                                     \
  __mul_10x64(p2,c2,a2,c1);                                     \
  __mul_10x64(p3,c3,a3,c2);                                     \
}

// Set up indices for low and high parts, depending on the endian-ness.
// Note that this only affects 128-bit input and output operands, not any
// of the internal workings, where w[0] is always the low-order part.

#if BID_BIG_ENDIAN
typedef union {
  struct {
    unsigned short hi;
    unsigned short lo1;
    unsigned short lo2;
    unsigned short lo3;
    unsigned short lo4;
    unsigned short pad;
    unsigned pad128;
  } i;
  BINARY80 f;
}
BID_BINARY80LDOUBLE;
#else
typedef union {
  struct {
    unsigned short lo4;
    unsigned short lo3;
    unsigned short lo2;
    unsigned short lo1;
    unsigned short hi;
    unsigned short pad;
    unsigned pad128;
  } i;
  BINARY80 f;
}
BID_BINARY80LDOUBLE;
#endif

// Pack and return binary floating-point numbers from raw fields

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary32(s,e,c)                  \
 { union {UINT32 i; float f; } x_out;           \
   x_out.i = (((UINT32)(s)) << 31) +            \
           (((UINT32)(e)) << 23) +              \
           (c);                                 \
   return x_out.f;                              \
}
#else
#define return_binary32(s,e,c)                  \
 { union {UINT32 i; float f; } x_out;           \
   x_out.i = (((UINT32)(s)) << 31) +            \
           (((UINT32)(e)) << 23) +              \
           (c);                                 \
   *pres = x_out.f;                             \
   return;                                      \
}
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary64(s,e,c)                  \
 { union {UINT64 i; double f; } x_out;          \
   x_out.i = (((UINT64)(s)) << 63) +            \
           (((UINT64)(e)) << 52) +              \
           (c);                                 \
   return x_out.f;                              \
 }
#else
#define return_binary64(s,e,c)                  \
 { union {UINT64 i; double f; } x_out;          \
   x_out.i = (((UINT64)(s)) << 63) +            \
           (((UINT64)(e)) << 52) +              \
           (c);                                 \
   *pres = x_out.f;                             \
   return;                                      \
 }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary80(s,e,c)                      \
 { BID_BINARY80LDOUBLE x_out;                       \
   x_out.i.pad128 = 0;                              \
   x_out.i.pad = 0;                                 \
   x_out.i.lo4 =  (c)&0xffff;                       \
   x_out.i.lo3 = ((c)&0xffff0000) >> 16;            \
   x_out.i.lo2 = ((c)&0xffff00000000ull) >> 32;     \
   x_out.i.lo1 = ((c)&0xffff000000000000ull) >> 48; \
   x_out.i.hi = (((UINT64)(s)) << 15) +             \
                (e);                                \
   return x_out.f;                                  \
 }
#else
#define return_binary80(s,e,c)                      \
 { BID_BINARY80LDOUBLE x_out;                       \
   x_out.i.pad128 = 0;                              \
   x_out.i.pad = 0;                                 \
   x_out.i.lo4 =  (c)&0xffff;                       \
   x_out.i.lo3 = ((c)&0xffff0000) >> 16;            \
   x_out.i.lo2 = ((c)&0xffff00000000ull) >> 32;     \
   x_out.i.lo1 = ((c)&0xffff000000000000ull) >> 48; \
   x_out.i.hi = ((s) << 15) +                       \
                (e);                                \
   *pres = x_out.f;                                 \
   return;                                          \
 }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary128(s,e,c_hi,c_lo)                 \
 { union {UINT128 i; BINARY128 f; } x_out;             \
   x_out.i.w[LOW_128W] = (c_lo);                   \
   x_out.i.w[HIGH_128W] = (((UINT64)(s)) << 63) +   \
                (((UINT64)(e)) << 48) +                 \
                (c_hi);                                 \
   return x_out.f;                                      \
 }
#else
#define return_binary128(s,e,c_hi,c_lo)                 \
 { union {UINT128 i; BINARY128 f; } x_out;             \
   x_out.i.w[LOW_128W] = (c_lo);                   \
   x_out.i.w[HIGH_128W] = (((UINT64)(s)) << 63) +   \
                (((UINT64)(e)) << 48) +                 \
                (c_hi);                                 \
   *pres = x_out.f;                                     \
   return;                                              \
 }
#endif

// Special cases of returning zero, infinity, NaN as binary FP
// Take parameters for the sign, and for NaN the significand

#define return_binary32_zero(s) return_binary32(s,0,0)
#define return_binary32_inf(s) return_binary32(s,255,0)
#define return_binary32_nan(s,c_hi,c_lo) \
  return_binary32(s,255,(c_hi>>42)+(1ul<<22))

#define return_binary64_zero(s) return_binary64(s,0,0)
#define return_binary64_inf(s) return_binary64(s,2047,0)
#define return_binary64_nan(s,c_hi,c_lo) \
  return_binary64(s,2047,(c_hi>>13)+(1ull<<51))

#define return_binary80_zero(s) return_binary80(s,0,0)
#define return_binary80_inf(s) return_binary80(s,32767,(1ull<<63))
#define return_binary80_nan(s,c_hi,c_lo) \
  return_binary80(s,32767,(c_hi>>2)+(3ull<<62))

#define return_binary128_zero(s) return_binary128(s,0,0,0)
#define return_binary128_inf(s) return_binary128(s,32767,0,0)
#define return_binary128_nan(s,c_hi,c_lo) \
  return_binary128(s,32767,(c_hi>>17)+(1ull<<47),((c_lo>>17)+(c_hi<<47)))

// Return finite values of maximal magnitude in the various formats

#define return_binary32_max(s) return_binary32(s,254,((1ul<<23)-1ul))
#define return_binary64_max(s) return_binary64(s,2046,((1ull<<52)-1ull))
#define return_binary80_max(s) return_binary80(s,32766,0xFFFFFFFFFFFFFFFFull)
#define return_binary128_max(s) \
  return_binary128(s,32766,((1ull<<48)-1ull),0xFFFFFFFFFFFFFFFFull)

#define return_bid32_max(s) return_bid32(s,191,9999999ul)
#define return_bid64_max(s) return_bid64(s,767,9999999999999999ull)
#define return_bid128_max(s)    \
  return_bid128(s,12287,542101086242752ull,4003012203950112767ull)

// Handle overflow by either infinity or maximal value as appropriate

#define return_binary32_ovf(s)                                               \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary32_max(s)                                                   \
  else return_binary32_inf(s)                                                \
}

#define return_binary64_ovf(s)                                               \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary64_max(s)                                                   \
  else return_binary64_inf(s)                                                \
}

#define return_binary80_ovf(s)                                               \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary80_max(s)                                                   \
  else return_binary80_inf(s)                                                \
}

#define return_binary128_ovf(s)                                              \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary128_max(s)                                                  \
  else return_binary128_inf(s)                                               \
}

#define return_bid32_ovf(s)                                                  \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_bid32_max(s)                                                      \
  else return_bid32_inf(s)                                                   \
}

#define return_bid64_ovf(s)                                                  \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_bid64_max(s)                                                      \
  else return_bid64_inf(s)                                                   \
}

#define return_bid128_ovf(s)                                                 \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_bid128_max(s)                                                     \
  else return_bid128_inf(s)                                                  \
}

// Unpack binary floating-point number x into
//
// int    s (sign in the LSB)
// int    e (true "integer" exponent)
//        c (normalized coefficient with explicit 1 bit)
//        t (trailing zero count, valid in normalized case only)
//        [c_hi,c_lo in the case of quad]
//
// Call the given zero, infinity or nan macros if appropriate

#define unpack_binary32(x,s,e,c,t,zero,inf,nan)                             \
{ union { UINT32 i; float f; } x_in;                                        \
  x_in.f = x;                                                               \
  c = x_in.i;                                                               \
  e = (c >> 23) & ((1ull<<8)-1);                                            \
  s = c >> 31;                                                              \
  c = c & ((1ull<<23)-1);                                                   \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if (c == 0) zero;                                                      \
     l = clz32(c) - (32 - 24);                                              \
     c = c << l;                                                            \
     e = -(l + 149);                                                        \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
   }                                                                        \
  else if (e == ((1ull<<8)-1))                                              \
   { if (c == 0) inf;                                                       \
     if ((c&(1ul<<22))==0) *pfpsf |= INVALID_EXCEPTION;                     \
     nan(s,(((unsigned long long) c)) << 42,0ull)                           \
   }                                                                        \
  else                                                                      \
   { c += 1ull<<23;                                                         \
     t = ctz32(c);                                                          \
     e -= 150;                                                              \
   }                                                                        \
}

#define unpack_binary64(x,s,e,c,t,zero,inf,nan)                             \
{ union { UINT64 i; double f; } x_in;                                       \
  x_in.f = x;                                                               \
  c = x_in.i;                                                               \
  e = (c >> 52) & ((1ull<<11)-1);                                           \
  s = c >> 63;                                                              \
  c = c & ((1ull<<52)-1);                                                   \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if (c == 0) zero;                                                      \
     l = clz64(c) - (64 - 53);                                              \
     c = c << l;                                                            \
     e = -(l + 1074);                                                       \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
   }                                                                        \
  else if (e == ((1ull<<11)-1))                                             \
   { if (c == 0) inf;                                                       \
     if ((c&(1ull<<51))==0) *pfpsf |= INVALID_EXCEPTION;                    \
     nan(s,(((unsigned long long) c) << 13),0ull)                           \
   }                                                                        \
  else                                                                      \
   { c += 1ull<<52;                                                         \
     t = ctz64(c);                                                          \
     e -= 1075;                                                             \
   }                                                                        \
}

#define unpack_binary80(x,s,e,c,t,zero,inf,nan)                             \
{ BID_BINARY80LDOUBLE x_in;                                                 \
  x_in.f = x;                                                               \
  c = x_in.i.lo4 + ((UINT64)x_in.i.lo3 << 16) +                             \
      ((UINT64)x_in.i.lo2 << 32) + ((UINT64)x_in.i.lo1 << 48);              \
  e = x_in.i.hi;                                                            \
  s = e >> 15;                                                              \
  e = (e & ((1<<15)-1));                                                    \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if (c == 0) zero;                                                      \
     l = clz64(c);                                                          \
     c = c << l;                                                            \
     e -= (l + 16445);                                                      \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
    }                                                                       \
  else if (e == ((1ull<<15)-1))                                             \
   { if ((c & ((1ull<<63)-1)) == 0) inf;                                    \
     if ((c&(1ull<<62))==0) *pfpsf |= INVALID_EXCEPTION;                    \
     nan(s,(((unsigned long long) c) << 2),0ull)                            \
   }                                                                        \
  else                                                                      \
   { t = ctz64(c);                                                          \
     e -= 16446;                                                            \
   }                                                                        \
}

#define unpack_binary128(x,s,e,c_hi,c_lo,t,zero,inf,nan)                    \
{ union { UINT128 i; BINARY128 f; } x_in;                                  \
  x_in.f = x;                                                               \
  c_lo = x_in.i.w[LOW_128W];                                           \
  c_hi = x_in.i.w[HIGH_128W];                                           \
  e = (c_hi >> 48) & ((1ull<<15)-1);                                        \
  s = c_hi >> 63;                                                           \
  c_hi = c_hi & ((1ull<<48)-1);                                             \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if ((c_hi == 0) && (c_lo == 0)) zero;                                  \
     l = clz128(c_hi,c_lo) - (128 - 113);                                   \
     sll128(c_hi,c_lo,l);                                                   \
     e = -(l + 16494);                                                      \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
   }                                                                        \
  else if (e == ((1ull<<15)-1))                                             \
   { if ((c_hi == 0) && (c_lo == 0)) inf;                                   \
     if ((c_hi&(1ull<<47))==0) *pfpsf |= INVALID_EXCEPTION;                 \
     nan(s,((((unsigned long long) c_hi) << 17) +                           \
            (((unsigned long long) c_lo) >> 47)),                           \
           (((unsigned long long) c_lo) << 17))                             \
   }                                                                        \
  else                                                                      \
   { c_hi += 1ull<<48;                                                      \
     t = ctz128(c_hi,c_lo);                                                 \
     e -= 16495;                                                            \
   }                                                                        \
}

// Pack and return decimal number from raw fields

#if !DECIMAL_CALL_BY_REFERENCE
#define return_bid32(s,e,c)                                                 \
  { if ((UINT32) (c) < (1ul<<23))                                           \
      return (((UINT32) (s) << 31) + ((UINT32) (e) << 23) + (UINT32) (c));  \
    else                                                                    \
      return (((UINT32) (s) << 31) + ((0x3ull<<29) - (1ull<<23)) +          \
             ((UINT32) (e) << 21) + (UINT32) (c));                          \
  }
#else
#define return_bid32(s,e,c)                                                 \
  { if ((UINT32) (c) < (1ul<<23))                                           \
      *pres = (((UINT32) (s) << 31) + ((UINT32) (e) << 23) + (UINT32) (c)); \
    else                                                                    \
      *pres = (((UINT32) (s) << 31) + ((0x3ull<<29) - (1ull<<23)) +         \
             ((UINT32) (e) << 21) + (UINT32) (c));                          \
    return;                                                                 \
  }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_bid64(s,e,c)                                                 \
  { if ((c) < (1ull<<53))                                                   \
      return (((UINT64) (s) << 63) + ((UINT64) (e) << 53) + (c));           \
    else                                                                    \
      return (((UINT64) (s) << 63) + ((0x3ull<<61) - (1ull<<53)) +          \
             ((UINT64) (e) << 51) + (c));                                   \
  }
#else
#define return_bid64(s,e,c)                                                 \
  { if ((c) < (1ull<<53))                                                   \
      *pres = (((UINT64) (s) << 63) + ((UINT64) (e) << 53) + (c));          \
    else                                                                    \
      *pres = (((UINT64) (s) << 63) + ((0x3ull<<61) - (1ull<<53)) +         \
             ((UINT64) (e) << 51) + (c));                                   \
    return;                                                                 \
  }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_bid128(s,e,c_hi,c_lo)                                        \
  { UINT128 x_out;                                                          \
    x_out.w[LOW_128W] = c_lo;                                          \
    x_out.w[HIGH_128W] = ((UINT64) (s) << 63) + ((UINT64) (e) << 49) +  \
                             (c_hi);                                        \
    return x_out;                                                           \
  }
#else
#define return_bid128(s,e,c_hi,c_lo)                                                    \
  { UINT128 x_out;                                                                      \
    x_out.w[LOW_128W] = c_lo;                                                      \
    x_out.w[HIGH_128W] = ((UINT64) (s) << 63) + ((UINT64) (e) << 49) + (c_hi);      \
    *pres = x_out;                                                                      \
    return;                                                                             \
  }
#endif

// Special cases of returning zero, infinity, NaN as decimal FP
// Take parameters for the sign, and for NaN the significand

#define return_bid32_zero(s) return_bid32(s,101,0)
#define return_bid32_inf(s) return_bid32(s,(0xF<<4),0)
#define return_bid32_nan(s,c_hi,c_lo)                                       \
  return_bid32(s,(0x1F<<3),(((c_hi>>44) > 999999ul) ? 0 : (c_hi>>44)));

#define return_bid64_zero(s) return_bid64(s,398,0)
#define return_bid64_inf(s) return_bid64(s,(0xF<<6),0)
#define return_bid64_nan(s,c_hi,c_lo)                                       \
  return_bid64(s,(0x1F<<5),                                                 \
               (((c_hi>>14) > 999999999999999ull) ? 0 : (c_hi>>14)));

#define return_bid128_zero(s) return_bid128(s,6176,0,0)
#define return_bid128_inf(s) return_bid128(s,(0xF<<10),0,0)
#define return_bid128_nan(s,c_hi,c_lo)                                      \
 { if (lt128(54210108624275ull,4089650035136921599ull,                      \
             (c_hi>>18),((c_lo>>18)+(c_hi<<46))))                           \
   return_bid128(s,(0x1F<<9),0ull,0ull)                                     \
   else return_bid128(s,(0x1F<<9),(c_hi>>18),((c_lo>>18)+(c_hi<<46)))       \
 }

// Unpack decimal floating-point number x into sign,exponent,coefficient
// In special cases, call the macros provided
// Coefficient is normalized in the binary sense with postcorrection k,
// so that x = 10^e * c / 2^k and the range of c is:
//
// 2^23 <= c < 2^24   (decimal32)
// 2^53 <= c < 2^54   (decimal64)
// 2^112 <= c < 2^113 (decimal128)

#define unpack_bid32(x,s,e,k,c,zero,inf,nan)                                \
{ s = x >> 31;                                                              \
  if ((x & (3ull<<29)) == (3ull<<29))                                       \
   { if ((x & (0xFull<<27)) == (0xFull<<27))                                \
      { if ((x & (0x1Full<<26)) != (0x1Full<<26)) inf;                      \
        if ((x & (1ul<<25))!=0) *pfpsf |= INVALID_EXCEPTION;                \
        nan(s,((((x) & 0xFFFFul) > 999999ul) ? 0 :                          \
               (((unsigned long long) x) << 44)),0ull);                     \
      }                                                                     \
     e = ((x >> 21) & ((1ull<<8)-1)) - 101;                                 \
     c = (1ull<<23) + (x & ((1ull<<21)-1));                                 \
     if ((unsigned long)(c) > 9999999ul) c = 0;                             \
     k = 0;                                                                 \
   }                                                                        \
  else                                                                      \
   { e = ((x >> 23) & ((1ull<<8)-1)) - 101;                                 \
     c = x & ((1ull<<23)-1);                                                \
     if (c == 0) zero;                                                      \
     k = clz32(c) - 8;                                                      \
     c = c << k;                                                            \
   }                                                                        \
}

#define unpack_bid64(x,s,e,k,c,zero,inf,nan)                                \
{ s = x >> 63;                                                              \
  if ((x & (3ull<<61)) == (3ull<<61))                                       \
   { if ((x & (0xFull<<59)) == (0xFull<<59))                                \
      { if ((x & (0x1Full<<58)) != (0x1Full<<58)) inf;                      \
        if ((x & (1ull<<57))!=0) *pfpsf |= INVALID_EXCEPTION;               \
        nan(s,((((x) & 0x3FFFFFFFFFFFFull) > 999999999999999ull) ? 0 :      \
               (((unsigned long long) x) << 14)),0ull);                     \
      }                                                                     \
     e = ((x >> 51) & ((1ull<<10)-1)) - 398;                                \
     c = (1ull<<53) + (x & ((1ull<<51)-1));                                 \
     if ((unsigned long long)(c) > 9999999999999999ull) c = 0;              \
     k = 0;                                                                 \
   }                                                                        \
  else                                                                      \
   { e = ((x >> 53) & ((1ull<<10)-1)) - 398;                                \
     c = x & ((1ull<<53)-1);                                                \
     if (c == 0) zero;                                                      \
     k = clz64(c) - 10;                                                     \
     c = c << k;                                                            \
   }                                                                        \
}

#define unpack_bid128(x,s,e,k,c,zero,inf,nan)                               \
{ s = x.w[HIGH_128W] >> 63;                                             \
  if ((x.w[HIGH_128W] & (3ull<<61)) == (3ull<<61))                      \
   { if ((x.w[HIGH_128W] & (0xFull<<59)) == (0xFull<<59))               \
      { if ((x.w[HIGH_128W] & (0x1Full<<58)) != (0x1Full<<58)) inf;     \
        if ((x.w[HIGH_128W] & (1ull<<57))!=0)                           \
           *pfpsf |= INVALID_EXCEPTION;                                     \
        if (lt128(54210108624275ull,4089650035136921599ull,                 \
            (x.w[HIGH_128W] & 0x3FFFFFFFFFFFull),x.w[LOW_128W]))   \
          nan(s,0ull,0ull);                                                 \
        nan(s,((((unsigned long long) x.w[HIGH_128W]) << 18) +          \
               (((unsigned long long) x.w[LOW_128W]) >> 46)),          \
              (((unsigned long long) x.w[LOW_128W]) << 18));           \
      }                                                                     \
     zero;                                                                  \
   }                                                                        \
  else                                                                      \
   { e = ((x.w[HIGH_128W] >> 49) & ((1ull<<14)-1)) - 6176;              \
     c.w[1] = x.w[HIGH_128W] & ((1ull<<49)-1);                          \
     c.w[0] = x.w[LOW_128W];                                           \
     if (lt128(542101086242752ull,4003012203950112767ull,                   \
               c.w[1],c.w[0]))                                              \
      { c.w[1] = 0ull; c.w[0] = 0ull; }                                     \
     if ((c.w[1] == 0) && (c.w[0] == 0)) zero;                              \
     k = clz128(c.w[1],c.w[0]) - 15;                                        \
     sll128(c.w[1],c.w[0],k);                                               \
   }                                                                        \
}

// Rounding boundaries table, indexed by
// 4 * rounding_mode + 2 * sign + lsb of truncation
// We round up if the round/sticky data is strictly > this boundary
//
// NB: This depends on the particular values of the rounding mode
// numbers, which are supposed to be defined as here:
//
// #define ROUNDING_TO_NEAREST     0x00000
// #define ROUNDING_DOWN           0x00001
// #define ROUNDING_UP             0x00002
// #define ROUNDING_TO_ZERO        0x00003
// #define ROUNDING_TIES_AWAY      0x00004
//
// Some of the shortcuts below in "underflow after rounding" also use
// the concrete values.
//
// So we add a directive here to double-check that this is the case

#if ((ROUNDING_TO_NEAREST!=0) || (ROUNDING_DOWN!=1) ||          \
     (ROUNDING_UP!=2) || (ROUNDING_TO_ZERO!=3) ||               \
     (ROUNDING_TIES_AWAY!=4))
#error "Rounding mode numbers don't match tables for binary/decimal conversion"
#endif

static const UINT128 roundbound_128[] = { {{0ull, (1ull << 63)}},       // ROUNDING_TO_NEAREST | positive | even
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TO_NEAREST | positive | odd
{{0ull, (1ull << 63)}}, // ROUNDING_TO_NEAREST | negative | even
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TO_NEAREST | negative | odd

{{~0ull, ~0ull}},       // ROUNDING_DOWN       | positive | even
{{~0ull, ~0ull}},       // ROUNDING_DOWN       | positive | odd
{{0ull, 0ull}}, // ROUNDING_DOWN       | negative | even
{{0ull, 0ull}}, // ROUNDING_DOWN       | negative | odd

{{0ull, 0ull}}, // ROUNDING_UP         | positive | even
{{0ull, 0ull}}, // ROUNDING_UP         | positive | odd
{{~0ull, ~0ull}},       // ROUNDING_UP         | negative | even
{{~0ull, ~0ull}},       // ROUNDING_UP         | negative | odd

{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | positive | even
{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | positive | odd
{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | negative | even
{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | negative | odd

{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TIES_AWAY  | positive | even
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TIES_AWAY  | positive | odd
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TIES_AWAY  | negative | even
{{~0ull, (1ull << 63) - 1}}     // ROUNDING_TIES_AWAY  | negative | odd
};

// Table of powers of 5

static const UINT128 power_five[] = { {{1ull, 0ull}},
{{5ull, 0ull}},
{{25ull, 0ull}},
{{125ull, 0ull}},
{{625ull, 0ull}},
{{3125ull, 0ull}},
{{15625ull, 0ull}},
{{78125ull, 0ull}},
{{390625ull, 0ull}},
{{1953125ull, 0ull}},
{{9765625ull, 0ull}},
{{48828125ull, 0ull}},
{{244140625ull, 0ull}},
{{1220703125ull, 0ull}},
{{6103515625ull, 0ull}},
{{30517578125ull, 0ull}},
{{152587890625ull, 0ull}},
{{762939453125ull, 0ull}},
{{3814697265625ull, 0ull}},
{{19073486328125ull, 0ull}},
{{95367431640625ull, 0ull}},
{{476837158203125ull, 0ull}},
{{2384185791015625ull, 0ull}},
{{11920928955078125ull, 0ull}},
{{59604644775390625ull, 0ull}},
{{298023223876953125ull, 0ull}},
{{1490116119384765625ull, 0ull}},
{{7450580596923828125ull, 0ull}},
{{359414837200037393ull, 2ull}},
{{1797074186000186965ull, 10ull}},
{{8985370930000934825ull, 50ull}},
{{8033366502585570893ull, 252ull}},
{{3273344365508751233ull, 1262ull}},
{{16366721827543756165ull, 6310ull}},
{{8046632842880574361ull, 31554ull}},
{{3339676066983768573ull, 157772ull}},
{{16698380334918842865ull, 788860ull}},
{{9704925379756007861ull, 3944304ull}},
{{11631138751360936073ull, 19721522ull}},
{{2815461535676025517ull, 98607613ull}},
{{14077307678380127585ull, 493038065ull}},
{{15046306170771983077ull, 2465190328ull}},
{{1444554559021708921ull, 12325951644ull}},
{{7222772795108544605ull, 61629758220ull}},
{{17667119901833171409ull, 308148791101ull}},
{{14548623214327650581ull, 1540743955509ull}},
{{17402883850509598057ull, 7703719777548ull}},
{{13227442957709783821ull, 38518598887744ull}},
{{10796982567420264257ull, 192592994438723ull}}
};


// Tables of values for the various conversions:
//
// exponents: table of output exponents
// breakpoints: test values to decide between two possible exponents
// multipliers1/multipliers2: corresponding reciprocal multipliers
// coefflimits: used in exactness checks
//

static const UINT128 breakpoints_binary32[] =
  { {{17291492046443221751ull, 474778387287989ull}},
{{17522542451896487724ull, 379822709830391ull}},
{{10328685146775279856ull, 303858167864313ull}},
{{12836547420098537447ull, 486173068582901ull}},
{{6579889121336919634ull, 388938454866321ull}},
{{1574562482327625384ull, 311150763893057ull}},
{{6208648786466110938ull, 497841222228891ull}},
{{1277570214430978427ull, 398272977783113ull}},
{{8400753801028603388ull, 318618382226490ull}},
{{13441206081645765421ull, 509789411562384ull}},
{{14442313680058522660ull, 407831529249907ull}},
{{4175153314562997481ull, 326265223399926ull}},
{{17748291747526526940ull, 522024357439881ull}},
{{10509284583279311229ull, 417619485951905ull}},
{{8407427666623448983ull, 334095588761524ull}},
{{2383837822371787403ull, 534552942018439ull}},
{{5596419072639340246ull, 427642353614751ull}},
{{787786443369561873ull, 342113882891801ull}},
{{12328504753617029967ull, 547382212626881ull}},
{{6173454988151713650ull, 437905770101505ull}},
{{4938763990521370920ull, 350324616081204ull}},
{{15280720014318014119ull, 560519385729926ull}},
{{8535227196712500972ull, 448415508583941ull}},
{{3138832942628090454ull, 358732406867153ull}},
{{9889763983586293010ull, 286985925493722ull}},
{{1066227114770427523ull, 459177480789956ull}},
{{15610376950783983311ull, 367341984631964ull}},
{{16177650375369096972ull, 293873587705571ull}},
{{58798897397182893ull, 470197740328915ull}},
{{47039117917746314ull, 376158192263132ull}},
{{11105677738559928021ull, 300926553810505ull}},
{{17769084381695884834ull, 481482486096808ull}},
{{3147221061130976897ull, 385185988877447ull}},
{{13585823293130512487ull, 308148791101957ull}},
{{6979922010041178687ull, 493038065763132ull}},
{{16651984052258673919ull, 394430452610505ull}},
{{13321587241806939135ull, 315544362088404ull}},
{{10246493142665371647ull, 504870979341447ull}},
{{818496884648476671ull, 403896783473158ull}},
{{8033495137202601983ull, 323117426778526ull}},
{{5474894590040342527ull, 516987882845642ull}},
{{15447962116258004991ull, 413590306276513ull}},
{{1290323248780673023ull, 330872245021211ull}},
{{13132563642274807807ull, 529395592033937ull}},
{{3127353284336025599ull, 423516473627150ull}},
{{2501882627468820479ull, 338813178901720ull}},
{{4003012203950112767ull, 542101086242752ull}},
{{14270456207385821183ull, 433680868994201ull}},
{{7727016151166746623ull, 346944695195361ull}},
{{4984528212382973951ull, 555111512312578ull}},
{{11366320199390199807ull, 444089209850062ull}},
{{1714358530028339199ull, 355271367880050ull}},
{{1371486824022671359ull, 284217094304040ull}},
{{2194378918436274175ull, 454747350886464ull}},
{{5444851949490929663ull, 363797880709171ull}},
{{666532744850833407ull, 291038304567337ull}},
{{4755801206503243775ull, 465661287307739ull}},
{{7493989779944505343ull, 372529029846191ull}},
{{2305843009213693951ull, 298023223876953ull}},
{{18446744073709551615ull, 476837158203124ull}},
{{18446744073709551615ull, 381469726562499ull}},
{{18446744073709551615ull, 305175781249999ull}},
{{18446744073709551615ull, 488281249999999ull}},
{{18446744073709551615ull, 390624999999999ull}},
{{18446744073709551615ull, 312499999999999ull}},
{{18446744073709551615ull, 499999999999999ull}},
{{18446744073709551615ull, 399999999999999ull}},
{{18446744073709551615ull, 319999999999999ull}},
{{18446744073709551615ull, 511999999999999ull}},
{{18446744073709551615ull, 409599999999999ull}},
{{18446744073709551615ull, 327679999999999ull}},
{{18446744073709551615ull, 524287999999999ull}},
{{18446744073709551615ull, 419430399999999ull}},
{{18446744073709551615ull, 335544319999999ull}},
{{18446744073709551615ull, 536870911999999ull}},
{{18446744073709551615ull, 429496729599999ull}},
{{18446744073709551615ull, 343597383679999ull}},
{{18446744073709551615ull, 549755813887999ull}},
{{18446744073709551615ull, 439804651110399ull}},
{{18446744073709551615ull, 351843720888319ull}},
{{18446744073709551615ull, 281474976710655ull}},
{{11068046444225730969ull, 450359962737049ull}},
{{12543785970122495098ull, 360287970189639ull}},
{{13724377590839906402ull, 288230376151711ull}},
{{14580306515860029597ull, 461168601842738ull}},
{{596198768462292708ull, 368934881474191ull}},
{{15234354273737475459ull, 295147905179352ull}},
{{9617571579012319442ull, 472236648286964ull}},
{{11383406077951765876ull, 377789318629571ull}},
{{5417376047619502378ull, 302231454903657ull}},
{{12357150490933114128ull, 483570327845851ull}},
{{6196371578004580979ull, 386856262276681ull}},
{{1267748447661754460ull, 309485009821345ull}},
{{2028397516258807136ull, 495176015714152ull}},
{{12690764457232776679ull, 396140812571321ull}},
{{6463262751044311020ull, 316912650057057ull}},
{{14030569216412807955ull, 507060240091291ull}},
{{7535106558388336041ull, 405648192073033ull}},
{{13406782876194489479ull, 324518553658426ull}},
{{14072154972427362520ull, 519229685853482ull}},
{{3879026348458069369ull, 415383748682786ull}},
{{17860616337734096788ull, 332306998946228ull}},
{{6440893251923092922ull, 531691198313966ull}},
{{1463365786796564015ull, 425352958651173ull}},
{{8549390258921071858ull, 340282366920938ull}},
{{9989675599531804650ull, 544451787073501ull}},
{{4302391664883533397ull, 435561429658801ull}},
{{18199308590874468010ull, 348449143727040ull}},
{{10672149671689597200ull, 557518629963265ull}},
{{8537719737351677760ull, 446014903970612ull}},
{{17898222234107073178ull, 356811923176489ull}},
{{18007926602027568865ull, 285449538541191ull}},
{{2987240860050737922ull, 456719261665907ull}},
{{13457839132266321307ull, 365375409332725ull}},
{{10766271305813057046ull, 292300327466180ull}},
{{17226034089300891273ull, 467680523945888ull}},
{{2712780827214982049ull, 374144419156711ull}},
{{16927619920739626932ull, 299315535325368ull}},
{{4948098984731941152ull, 478904856520590ull}},
{{3958479187785552922ull, 383123885216472ull}}
};

static const int exponents_binary32[] = { -27,
  -24,
  -21,
  -17,
  -14,
  -11,
  -7,
  -4,
  -1,
  3,
  6,
  9,
  13,
  16,
  19,
  23,
  26,
  29,
  33,
  36,
  39,
  43,
  46,
  49,
  52,
  56,
  59,
  62,
  66,
  69,
  72,
  76,
  79,
  82,
  86,
  89,
  92,
  96,
  99,
  102,
  106,
  109,
  112,
  116,
  119,
  122,
  126,
  129,
  132,
  136,
  139,
  142,
  145,
  149,
  152,
  155,
  159,
  162,
  165,
  169,
  172,
  175,
  179,
  182,
  185,
  189,
  192,
  195,
  199,
  202,
  205,
  209,
  212,
  215,
  219,
  222,
  225,
  229,
  232,
  235,
  238,
  242,
  245,
  248,
  252,
  255,
  258,
  262,
  265,
  268,
  272,
  275,
  278,
  282,
  285,
  288,
  292,
  295,
  298,
  302,
  305,
  308,
  312,
  315,
  318,
  322,
  325,
  328,
  332,
  335,
  338,
  341,
  345,
  348,
  351,
  355,
  358,
  361,
  365,
  368,
};

static const UINT256 multipliers1_binary32[] =
  { {{6013890151484785128ull, 7481633477359093489ull,
      655737588518723529ull, 651851512427ull}},
{{12129048707783369314ull, 13963727865126254765ull,
  14654730040930568123ull, 814814390533ull}},
{{1326252829447047930ull, 12842973812980430553ull,
  4483354495881046442ull, 1018517988167ull}},
{{12358123064472874716ull, 12638544651540156999ull,
  9719625587566735882ull, 636573742604ull}},
{{10835967812163705491ull, 6574808777570420441ull,
  12149531984458419853ull, 795717178255ull}},
{{18156645783632019768ull, 12830196990390413455ull,
  10575228962145636912ull, 994646472819ull}},
{{18265432642411094211ull, 8018873118994008409ull,
  4303675092127329118ull, 621654045512ull}},
{{8996732747731704052ull, 800219361887734704ull, 5379593865159161398ull,
  777067556890ull}},
{{11245915934664630065ull, 10223646239214444188ull,
  15947864368303727555ull, 971334446112ull}},
{{16252069496020169599ull, 4083935890295333665ull,
  9967415230189829722ull, 607084028820ull}},
{{6480028814743048286ull, 14328291899723942890ull,
  12459269037737287152ull, 758855036025ull}},
{{17323408055283586166ull, 17910364874654928612ull,
  1739028241889445228ull, 948568795032ull}},
{{1603757997697465546ull, 1970606009804554575ull,
  1086892651180903268ull, 592855496895ull}},
{{15839755552403995644ull, 2463257512255693218ull,
  15193673869258292797ull, 741069371118ull}},
{{10576322403650218747ull, 7690757908747004427ull,
  9768720299718090188ull, 926336713898ull}},
{{4304358493067692765ull, 14030095729821653575ull,
  10717136205751194271ull, 578960446186ull}},
{{768762097907228052ull, 12925933643849679065ull,
  4173048220334217031ull, 723700557733ull}},
{{5572638640811422969ull, 11545731036384710927ull,
  9827996293845159193ull, 904625697166ull}},
{{10400428178148221212ull, 298552870099362473ull,
  1530811665225836592ull, 565391060729ull}},
{{17612221241112664419ull, 373191087624203091ull,
  6525200599959683644ull, 706738825911ull}},
{{17403590532963442619ull, 466488859530253864ull,
  3544814731522216651ull, 883423532389ull}},
{{10877244083102151637ull, 16432456601702266329ull,
  4521352216415079358ull, 552139707743ull}},
{{18208241122305077450ull, 11317198715273057103ull,
  1040004252091461294ull, 690174634679ull}},
{{18148615384453958909ull, 4923126357236545571ull,
  15135063370396490330ull, 862718293348ull}},
{{18074083212140060732ull, 15377279983400457772ull,
  472085139286061296ull, 1078397866686ull}},
{{2072929970732762150ull, 9610799989625286108ull,
  14130111267335952022ull, 673998666678ull}},
{{2591162463415952687ull, 2790127950176831827ull,
  8439267047315164220ull, 842498333348ull}},
{{17074011134552104570ull, 3487659937721039783ull,
  10549083809143955275ull, 1053122916685ull}},
{{17588785986736147213ull, 18320688525571507528ull,
  8899020389928665998ull, 658201822928ull}},
{{3539238409710632400ull, 13677488620109608603ull,
  11123775487410832498ull, 822752278660ull}},
{{18259106067420454212ull, 7873488738282234945ull,
  13904719359263540623ull, 1028440348325ull}},
{{4494412264496702026ull, 11838459489067478697ull,
  10996292608753406841ull, 642775217703ull}},
{{10229701349048265437ull, 963016306052184659ull,
  9133679742514370648ull, 803469022129ull}},
{{8175440667882943892ull, 1203770382565230824ull,
  16028785696570351214ull, 1004336277661ull}},
{{5109650417426839933ull, 14587414544385432977ull,
  12323834069570163460ull, 627710173538ull}},
{{10998749040210937820ull, 18234268180481791221ull,
  6181420550107928517ull, 784637716923ull}},
{{18360122318691060179ull, 8957777170320075314ull,
  3115089669207522743ull, 980797146154ull}},
{{16086762467609300516ull, 12516139759091128927ull,
  6558617061682089618ull, 612998216346ull}},
{{15496767066084237741ull, 6421802662009135351ull,
  17421643363957387831ull, 766247770432ull}},
{{14759272814177909272ull, 3415567309084031285ull,
  3330310131237183173ull, 957809713041ull}},
{{11530388518074887247ull, 4440572577391213505ull,
  13610658878091709243ull, 598631070650ull}},
{{577927592311445347ull, 939029703311628978ull, 7789951560759860746ull,
  748288838313ull}},
{{9945781527244082491ull, 10397159165994312030ull,
  14349125469377213836ull, 935361047891ull}},
{{1604427436100163653ull, 15721596515601220827ull,
  6662360409147064695ull, 584600654932ull}},
{{15840592350407368278ull, 15040309626074138129ull,
  8327950511433830869ull, 730750818665ull}},
{{5965682382727046636ull, 4965328977310508950ull,
  15021624157719676491ull, 913438523331ull}},
{{17563609544486567859ull, 797487601605374141ull,
  7082672089361103855ull, 570899077082ull}},
{{8119453875326046112ull, 14831917557288881389ull,
  18076712148556155626ull, 713623846352ull}},
{{14761003362584945544ull, 9316524909756325928ull,
  4149146111985642917ull, 892029807941ull}},
{{9225627101615590965ull, 8128671077811397657ull,
  4899059329204720775ull, 557518629963ull}},
{{16143719895446876610ull, 5549152828836859167ull,
  1512138143078513065ull, 696898287454ull}},
{{15567963850881207859ull, 11548127054473461863ull,
  11113544715702917139ull, 871122859317ull}},
{{14848268795174121920ull, 9823472799664439425ull, 56872839346482712ull,
  1088903574147ull}},
{{2362638969342744344ull, 6139670499790274641ull,
  16176446589087409359ull, 680564733841ull}},
{{7564984730105818334ull, 3062902106310455397ull,
  6385500181077097987ull, 850705917302ull}},
{{14067916931059660821ull, 17663685688170232958ull,
  17205247263201148291ull, 1063382396627ull}},
{{4180762063484900109ull, 8733960545892701647ull,
  8447436530287023730ull, 664613997892ull}},
{{614266560928737233ull, 1694078645511101251ull,
  10559295662858779663ull, 830767497365ull}},
{{14602891256443085253ull, 15952656362171040275ull,
  17810805597000862482ull, 1038459371706ull}},
{{6820964026063234331ull, 14582096244784288076ull,
  15743439516552926955ull, 649037107316ull}},
{{8526205032579042914ull, 13615934287552972191ull,
  1232555321981607078ull, 811296384146ull}},
{{6046070272296415738ull, 7796545822586439431ull,
  10764066189331784656ull, 1014120480182ull}},
{{10696322947826341692ull, 4872841139116524644ull,
  2115855349904977506ull, 633825300114ull}},
{{13370403684782927115ull, 15314423460750431613ull,
  11868191224235997690ull, 792281625142ull}},
{{2877946550696495182ull, 9919657289083263709ull,
  5611866993440221305ull, 990352031428ull}},
{{4104559603399003441ull, 17729000851745509578ull,
  12730788907754914123ull, 618970019642ull}},
{{14354071541103530109ull, 17549565046254499068ull,
  6690114097838866846ull, 773712524553ull}},
{{17942589426379412636ull, 12713584270963348027ull,
  12974328640725971462ull, 967140655691ull}},
{{8908275382273438946ull, 3334304150924704613ull,
  5803112391240038212ull, 604462909807ull}},
{{15747030246269186586ull, 4167880188655880766ull,
  2642204470622659861ull, 755578637259ull}},
{{10460415770981707425ull, 9821536254247238862ull,
  17137813643560488538ull, 944473296573ull}},
{{1926073838436179237ull, 10750146177331912193ull,
  13016976536438999288ull, 590295810358ull}},
{{7019278316472611950ull, 13437682721664890241ull,
  7047848633693973302ull, 737869762948ull}},
{{13385783914018152841ull, 7573731365226336993ull,
  8809810792117466628ull, 922337203685ull}},
{{1448585918620263670ull, 13956954140121236429ull,
  7811974754287110594ull, 576460752303ull}},
{{6422418416702717491ull, 8222820638296769728ull,
  5153282424431500339ull, 720575940379ull}},
{{8028023020878396864ull, 5666839779443574256ull,
  1829917012111987520ull, 900719925474ull}},
{{5017514388048998040ull, 3541774862152233910ull,
  5755384150997380104ull, 562949953421ull}},
{{15495265021916023358ull, 4427218577690292387ull,
  11805916207174113034ull, 703687441776ull}},
{{14757395258967641293ull, 14757395258967641292ull,
  14757395258967641292ull, 879609302220ull}},
{{0ull, 0ull, 0ull, 1099511627776ull}},
{{0ull, 0ull, 0ull, 687194767360ull}},
{{0ull, 0ull, 0ull, 858993459200ull}},
{{0ull, 0ull, 0ull, 1073741824000ull}},
{{0ull, 0ull, 0ull, 671088640000ull}},
{{0ull, 0ull, 0ull, 838860800000ull}},
{{0ull, 0ull, 0ull, 1048576000000ull}},
{{0ull, 0ull, 0ull, 655360000000ull}},
{{0ull, 0ull, 0ull, 819200000000ull}},
{{0ull, 0ull, 0ull, 1024000000000ull}},
{{0ull, 0ull, 0ull, 640000000000ull}},
{{0ull, 0ull, 0ull, 800000000000ull}},
{{0ull, 0ull, 0ull, 1000000000000ull}},
{{0ull, 0ull, 0ull, 625000000000ull}},
{{0ull, 0ull, 0ull, 781250000000ull}},
{{0ull, 0ull, 0ull, 976562500000ull}},
{{0ull, 0ull, 0ull, 610351562500ull}},
{{0ull, 0ull, 0ull, 762939453125ull}},
{{0ull, 0ull, 4611686018427387904ull, 953674316406ull}},
{{0ull, 0ull, 16717361816799281152ull, 596046447753ull}},
{{0ull, 0ull, 7061644215716937728ull, 745058059692ull}},
{{0ull, 0ull, 8827055269646172160ull, 931322574615ull}},
{{0ull, 0ull, 12434438571169939456ull, 582076609134ull}},
{{0ull, 0ull, 6319676177107648512ull, 727595761418ull}},
{{0ull, 0ull, 17122967258239336448ull, 909494701772ull}},
{{0ull, 0ull, 1478482499544809472ull, 568434188608ull}},
{{0ull, 0ull, 1848103124431011840ull, 710542735760ull}},
{{0ull, 0ull, 2310128905538764800ull, 888178419700ull}},
{{0ull, 0ull, 10667202602816503808ull, 555111512312ull}},
{{0ull, 0ull, 13334003253520629760ull, 693889390390ull}},
{{0ull, 0ull, 7444132030046011392ull, 867361737988ull}},
{{0ull, 0ull, 9305165037557514240ull, 1084202172485ull}},
{{0ull, 0ull, 8121571157687140352ull, 677626357803ull}},
{{0ull, 0ull, 5540277928681537536ull, 847032947254ull}},
{{0ull, 0ull, 16148719447706697728ull, 1058791184067ull}},
{{0ull, 0ull, 7787106645602992128ull, 661744490042ull}},
{{0ull, 0ull, 510511270148964352ull, 827180612553ull}},
{{0ull, 0ull, 5249825106113593344ull, 1033975765691ull}},
{{0ull, 0ull, 975297682107301888ull, 646234853557ull}},
{{0ull, 0ull, 5830808121061515264ull, 807793566946ull}}
};

static const UINT256 multipliers2_binary32[] =
  { {{12230317112597168372ull, 12964188775534322552ull,
      9551240831114137572ull, 325925756213ull}},
{{15287896390746460465ull, 16205235969417903190ull,
  16550737057320059869ull, 407407195266ull}},
{{9886498451578299773ull, 6421486906490215276ull,
  11465049284795299029ull, 509258994083ull}},
{{15402433569091213166ull, 6319272325770078499ull,
  4859812793783367941ull, 318286871302ull}},
{{14641355942936628554ull, 12510776425639986028ull,
  15298138029083985734ull, 397858589127ull}},
{{18301694928670785692ull, 6415098495195206727ull,
  14510986517927594264ull, 497323236409ull}},
{{18356088358060322914ull, 4009436559497004204ull,
  2151837546063664559ull, 310827022756ull}},
{{4498366373865852026ull, 400109680943867352ull, 2689796932579580699ull,
  388533778445ull}},
{{5622957967332315033ull, 14335195156461997902ull,
  7973932184151863777ull, 485667223056ull}},
{{17349406784864860608ull, 2041967945147666832ull,
  4983707615094914861ull, 303542014410ull}},
{{3240014407371524143ull, 7164145949861971445ull,
  15453006555723419384ull, 379427518012ull}},
{{8661704027641793083ull, 8955182437327464306ull, 869514120944722614ull,
  474284397516ull}},
{{10025251035703508581ull, 985303004902277287ull,
  9766818362445227442ull, 296427748447ull}},
{{7919877776201997822ull, 10455000792982622417ull,
  7596836934629146398ull, 370534685559ull}},
{{14511533238679885182ull, 3845378954373502213ull,
  4884360149859045094ull, 463168356949ull}},
{{11375551283388622191ull, 16238419901765602595ull,
  5358568102875597135ull, 289480223093ull}},
{{9607753085808389834ull, 15686338858779615340ull,
  11309896147021884323ull, 361850278866ull}},
{{12009691357260487293ull, 14996237555047131271ull,
  4913998146922579596ull, 452312848583ull}},
{{14423586125928886414ull, 149276435049681236ull,
  9988777869467694104ull, 282695530364ull}},
{{18029482657411108018ull, 186595543812101545ull,
  12485972336834617630ull, 353369412955ull}},
{{8701795266481721310ull, 9456616466619902740ull,
  10995779402615884133ull, 441711766194ull}},
{{14661994078405851627ull, 8216228300851133164ull,
  11484048145062315487ull, 276069853871ull}},
{{18327492598007314533ull, 5658599357636528551ull,
  9743374162900506455ull, 345087317339ull}},
{{18297679729081755263ull, 2461563178618272785ull,
  7567531685198245165ull, 431359146674ull}},
{{9037041606070030366ull, 7688639991700228886ull, 236042569643030648ull,
  539198933343ull}},
{{1036464985366381075ull, 4805399994812643054ull,
  7065055633667976011ull, 336999333339ull}},
{{10518953268562752152ull, 1395063975088415913ull,
  4219633523657582110ull, 421249166674ull}},
{{17760377604130828093ull, 10967202005715295699ull,
  14497913941426753445ull, 526561458342ull}},
{{8794392993368073607ull, 9160344262785753764ull,
  4449510194964332999ull, 329100911464ull}},
{{10992991241710092008ull, 6838744310054804301ull,
  5561887743705416249ull, 411376139330ull}},
{{18352925070565002914ull, 13160116405995893280ull,
  16175731716486546119ull, 514220174162ull}},
{{11470578169103126821ull, 15142601781388515156ull,
  14721518341231479228ull, 321387608851ull}},
{{14338222711378908527ull, 481508153026092329ull,
  13790211908111961132ull, 401734511064ull}},
{{4087720333941471946ull, 601885191282615412ull,
  17237764885139951415ull, 502168138830ull}},
{{11778197245568195775ull, 7293707272192716488ull,
  6161917034785081730ull, 313855086769ull}},
{{14722746556960244718ull, 18340506127095671418ull,
  12314082311908740066ull, 392318858461ull}},
{{9180061159345530090ull, 13702260622014813465ull,
  1557544834603761371ull, 490398573077ull}},
{{17266753270659426066ull, 6258069879545564463ull,
  3279308530841044809ull, 306499108173ull}},
{{16971755569896894679ull, 12434273367859343483ull,
  8710821681978693915ull, 383123885216ull}},
{{16603008443943730444ull, 10931155691396791450ull,
  10888527102473367394ull, 478904856520ull}},
{{14988566295892219432ull, 11443658325550382560ull,
  6805329439045854621ull, 299315535325ull}},
{{288963796155722674ull, 469514851655814489ull, 13118347817234706181ull,
  374144419156ull}},
{{4972890763622041246ull, 5198579582997156015ull,
  16397934771543382726ull, 467680523945ull}},
{{10025585754904857635ull, 17084170294655386221ull,
  3331180204573532347ull, 292300327466ull}},
{{17143668212058459947ull, 16743526849891844872ull,
  13387347292571691242ull, 365375409332ull}},
{{2982841191363523318ull, 11706036525510030283ull,
  16734184115714614053ull, 456719261665ull}},
{{18005176809098059738ull, 9622115837657462878ull,
  3541336044680551927ull, 285449538541ull}},
{{13283098974517798864ull, 7415958778644440694ull,
  9038356074278077813ull, 356811923176ull}},
{{7380501681292472772ull, 13881634491732938772ull,
  11297945092847597266ull, 446014903970ull}},
{{13836185587662571291ull, 13287707575760474636ull,
  11672901701457136195ull, 278759314981ull}},
{{17295231984578214113ull, 11997948451273205391ull,
  756069071539256532ull, 348449143727ull}},
{{17007353962295379738ull, 14997435564091506739ull,
  14780144394706234377ull, 435561429658ull}},
{{16647506434441836768ull, 4911736399832219712ull,
  9251808456528017164ull, 544451787073ull}},
{{10404691521526147980ull, 12293207286749913128ull,
  17311595331398480487ull, 340282366920ull}},
{{13005864401907684975ull, 10754823090010003506ull,
  3192750090538548993ull, 425352958651ull}},
{{7033958465529830411ull, 18055214880939892287ull,
  17825995668455349953ull, 531691198313ull}},
{{11313753068597225863ull, 4366980272946350823ull,
  4223718265143511865ull, 332306998946ull}},
{{9530505317319144425ull, 10070411359610326433ull,
  14503019868284165639ull, 415383748682ull}},
{{16524817665076318435ull, 7976328181085520137ull,
  8905402798500431241ull, 519229685853ull}},
{{3410482013031617166ull, 16514420159246919846ull,
  7871719758276463477ull, 324518553658ull}},
{{13486474553144297265ull, 6807967143776486095ull,
  616277660990803539ull, 405648192073ull}},
{{12246407173002983677ull, 3898272911293219715ull,
  5382033094665892328ull, 507060240091ull}},
{{5348161473913170846ull, 2436420569558262322ull,
  1057927674952488753ull, 316912650057ull}},
{{15908573879246239366ull, 7657211730375215806ull,
  5934095612117998845ull, 396140812571ull}},
{{10662345312203023399ull, 14183200681396407662ull,
  2805933496720110652ull, 495176015714ull}},
{{2052279801699501721ull, 18087872462727530597ull,
  6365394453877457061ull, 309485009821ull}},
{{7177035770551765055ull, 8774782523127249534ull,
  12568429085774209231ull, 386856262276ull}},
{{18194666750044482126ull, 6356792135481674013ull,
  15710536357217761539ull, 483570327845ull}},
{{13677509727991495281ull, 1667152075462352306ull,
  12124928232474794914ull, 302231454903ull}},
{{7873515123134593293ull, 11307312131182716191ull,
  10544474272166105738ull, 377789318629ull}},
{{5230207885490853713ull, 4910768127123619431ull,
  17792278858635020077ull, 472236648286ull}},
{{10186408956072865427ull, 5375073088665956096ull,
  6508488268219499644ull, 295147905179ull}},
{{12733011195091081783ull, 6718841360832445120ull,
  3523924316846986651ull, 368934881474ull}},
{{15916263993863852229ull, 3786865682613168496ull,
  13628277432913509122ull, 461168601842ull}},
{{9947664996164907643ull, 6978477070060618214ull,
  13129359413998331105ull, 288230376151ull}},
{{3211209208351358746ull, 13334782356003160672ull,
  11800013249070525977ull, 360287970189ull}},
{{4014011510439198432ull, 2833419889721787128ull, 914958506055993760ull,
  450359962737ull}},
{{2508757194024499020ull, 1770887431076116955ull,
  12101064112353465860ull, 281474976710ull}},
{{16971004547812787487ull, 2213609288845146193ull,
  5902958103587056517ull, 351843720888ull}},
{{7378697629483820647ull, 7378697629483820646ull,
  7378697629483820646ull, 439804651110ull}},
{{0ull, 0ull, 0ull, 549755813888ull}},
{{0ull, 0ull, 0ull, 343597383680ull}},
{{0ull, 0ull, 0ull, 429496729600ull}},
{{0ull, 0ull, 0ull, 536870912000ull}},
{{0ull, 0ull, 0ull, 335544320000ull}},
{{0ull, 0ull, 0ull, 419430400000ull}},
{{0ull, 0ull, 0ull, 524288000000ull}},
{{0ull, 0ull, 0ull, 327680000000ull}},
{{0ull, 0ull, 0ull, 409600000000ull}},
{{0ull, 0ull, 0ull, 512000000000ull}},
{{0ull, 0ull, 0ull, 320000000000ull}},
{{0ull, 0ull, 0ull, 400000000000ull}},
{{0ull, 0ull, 0ull, 500000000000ull}},
{{0ull, 0ull, 0ull, 312500000000ull}},
{{0ull, 0ull, 0ull, 390625000000ull}},
{{0ull, 0ull, 0ull, 488281250000ull}},
{{0ull, 0ull, 0ull, 305175781250ull}},
{{0ull, 0ull, 9223372036854775808ull, 381469726562ull}},
{{0ull, 0ull, 2305843009213693952ull, 476837158203ull}},
{{0ull, 0ull, 17582052945254416384ull, 298023223876ull}},
{{0ull, 0ull, 3530822107858468864ull, 372529029846ull}},
{{0ull, 0ull, 13636899671677861888ull, 465661287307ull}},
{{0ull, 0ull, 6217219285584969728ull, 291038304567ull}},
{{0ull, 0ull, 3159838088553824256ull, 363797880709ull}},
{{0ull, 0ull, 8561483629119668224ull, 454747350886ull}},
{{0ull, 0ull, 739241249772404736ull, 284217094304ull}},
{{0ull, 0ull, 924051562215505920ull, 355271367880ull}},
{{0ull, 0ull, 1155064452769382400ull, 444089209850ull}},
{{0ull, 0ull, 5333601301408251904ull, 277555756156ull}},
{{0ull, 0ull, 6667001626760314880ull, 346944695195ull}},
{{0ull, 0ull, 3722066015023005696ull, 433680868994ull}},
{{0ull, 0ull, 13875954555633532928ull, 542101086242ull}},
{{0ull, 0ull, 13284157615698345984ull, 338813178901ull}},
{{0ull, 0ull, 2770138964340768768ull, 423516473627ull}},
{{0ull, 0ull, 17297731760708124672ull, 529395592033ull}},
{{0ull, 0ull, 3893553322801496064ull, 330872245021ull}},
{{0ull, 0ull, 9478627671929257984ull, 413590306276ull}},
{{0ull, 0ull, 11848284589911572480ull, 516987882845ull}},
{{0ull, 0ull, 9711020877908426752ull, 323117426778ull}},
{{0ull, 0ull, 2915404060530757632ull, 403896783473ull}}
};

// **********************************************************************

static const UINT128 breakpoints_binary64[] =
  { {{5261314576080512960ull, 21426681862861333ull}},
{{4728754506986910400ull, 34282690980578133ull}},
{{11161701235073348928ull, 27426152784462506ull}},
{{5240012173316768832ull, 21940922227570005ull}},
{{8384019477306830144ull, 35105475564112008ull}},
{{14085913211329284736ull, 28084380451289606ull}},
{{7579381754321517504ull, 22467504361031685ull}},
{{12127010806914427968ull, 35948006977650696ull}},
{{6012259830789632064ull, 28758405582120557ull}},
{{15877854308857436608ull, 23006724465696445ull}},
{{12702283447085949312ull, 18405379572557156ull}},
{{12944955885853698240ull, 29448607316091450ull}},
{{10355964708682958592ull, 23558885852873160ull}},
{{8284771766946366848ull, 18847108682298528ull}},
{{9566286012372276672ull, 30155373891677645ull}},
{{7653028809897821312ull, 24124299113342116ull}},
{{2433074233176346752ull, 19299439290673693ull}},
{{203569958340244480ull, 30879102865077909ull}},
{{3852204781414105920ull, 24703282292062327ull}},
{{14149810269357015680ull, 19762625833649861ull}},
{{15260998801487404480ull, 31620201333839778ull}},
{{1140752596964192576ull, 25296161067071823ull}},
{{8291299707055174720ull, 20236928853657458ull}},
{{9576730716546369216ull, 32379086165851933ull}},
{{15040082202720916032ull, 25903268932681546ull}},
{{8342716947434822464ull, 20722615146145237ull}},
{{17037695930637626304ull, 33156184233832379ull}},
{{17319505559252011392ull, 26524947387065903ull}},
{{2787558003175878144ull, 21219957909652723ull}},
{{770743990339494720ull, 33951932655444357ull}},
{{11684641636497326720ull, 27161546124355485ull}},
{{9347713309197861376ull, 21729236899484388ull}},
{{11266992479974667904ull, 34766779039175021ull}},
{{5324245169237824000ull, 27813423231340017ull}},
{{15327442579615990144ull, 22250738585072013ull}},
{{2387815238934122304ull, 35601181736115222ull}},
{{12978298635373028800ull, 28480945388892177ull}},
{{3003941278814602368ull, 22784756311113742ull}},
{{13471199467277412864ull, 18227805048890993ull}},
{{17864570332901950336ull, 29164488078225589ull}},
{{17981005081063470592ull, 23331590462580471ull}},
{{10695455250108866112ull, 18665272370064377ull}},
{{2355333141206544512ull, 29864435792103004ull}},
{{5573615327707145920ull, 23891548633682403ull}},
{{11837589891649537408ull, 19113238906945922ull}},
{{4182748567671618560ull, 30581182251113476ull}},
{{18103594113104936128ull, 24464945800890780ull}},
{{14482875290483948864ull, 19571956640712624ull}},
{{12104554020548587264ull, 31315130625140199ull}},
{{13372992031180780160ull, 25052104500112159ull}},
{{14387742439686534400ull, 20041683600089727ull}},
{{8262992644530813824ull, 32066693760143564ull}},
{{10299742930366561344ull, 25653355008114851ull}},
{{4550445529551338752ull, 20522684006491881ull}},
{{18348759291507873024ull, 32836294410387009ull}},
{{18368356247948208704ull, 26269035528309607ull}},
{{7315987368874746304ull, 21015228422647686ull}},
{{4326882160715773504ull, 33624365476236298ull}},
{{10840203358056439424ull, 26899492380989038ull}},
{{16050860315928972160ull, 21519593904791230ull}},
{{7234632431776803904ull, 34431350247665969ull}},
{{9477054760163353472ull, 27545080198132775ull}},
{{7581643808130682752ull, 22036064158506220ull}},
{{12130630093009092416ull, 35257702653609952ull}},
{{2325806444923453248ull, 28206162122887962ull}},
{{12928691600164493568ull, 22564929698310369ull}},
{{14032302094873505216ull, 18051943758648295ull}},
{{4004939278088056704ull, 28883110013837273ull}},
{{10582649051954265984ull, 23106488011069818ull}},
{{15844816871047233408ull, 18485190408855854ull}},
{{14283660549449842560ull, 29576304654169367ull}},
{{4048230810076053376ull, 23661043723335494ull}},
{{6927933462802753024ull, 18928834978668395ull}},
{{11084693540484404864ull, 30286135965869432ull}},
{{1489057202903703232ull, 24228908772695546ull}},
{{15948641021290603904ull, 19383127018156436ull}},
{{18139128004581145600ull, 31013003229050298ull}},
{{3443255959439185472ull, 24810402583240239ull}},
{{6443953582293258688ull, 19848322066592191ull}},
{{2931628102185393280ull, 31757315306547506ull}},
{{17102697740715955904ull, 25405852245238004ull}},
{{17371507007314675072ull, 20324681796190403ull}},
{{5658318323252018176ull, 32519490873904646ull}},
{{837305843859704192ull, 26015592699123717ull}},
{{11737891119313494336ull, 20812474159298973ull}},
{{15091276976159680640ull, 33299958654878357ull}},
{{4694323951443923840ull, 26639966923902686ull}},
{{66110346413228736ull, 21311973539122149ull}},
{{7484474183744986688ull, 34099157662595438ull}},
{{13366276976479809984ull, 27279326130076350ull}},
{{10693021581183848000ull, 21823460904061080ull}},
{{17108834529894156800ull, 34917537446497728ull}},
{{2619021179689594432ull, 27934029957198183ull}},
{{9473914573235496192ull, 22347223965758546ull}},
{{7779565687692973312ull, 35755558345213674ull}},
{{9913001364896288960ull, 28604446676170939ull}},
{{11619749906658941440ull, 22883557340936751ull}},
{{5606451110585242816ull, 18306845872749401ull}},
{{1591624147452567936ull, 29290953396399042ull}},
{{12341345762187785280ull, 23432762717119233ull}},
{{17251774239234048896ull, 18746210173695386ull}},
{{1777397079581105984ull, 29993936277912619ull}},
{{5111266478406795072ull, 23995149022330095ull}},
{{4089013182725436096ull, 19196119217864076ull}},
{{17610467536586428672ull, 30713790748582521ull}},
{{10399025214527232640ull, 24571032598866017ull}},
{{940522542137965440ull, 19656826079092814ull}},
{{8883533696904565376ull, 31450921726548502ull}},
{{18174873401749383296ull, 25160737381238801ull}},
{{10850549906657596288ull, 20128589904991041ull}},
{{9982182221168333440ull, 32205743847985666ull}},
{{4296396962192756416ull, 25764595078388533ull}},
{{10815815199238025792ull, 20611676062710826ull}},
{{9926606689297020608ull, 32978681700337322ull}},
{{562587721953795840ull, 26382945360269858ull}},
{{7828767807046857280ull, 21106356288215886ull}},
{{5147330861791151040ull, 33770170061145418ull}},
{{11496562318916741504ull, 27016136048916334ull}},
{{12886598669875303488ull, 21612908839133067ull}},
{{5861162612832844352ull, 34580654142612908ull}},
{{12067627719750096128ull, 27664523314090326ull}},
{{5964753361058166592ull, 22131618651272261ull}},
{{2164907748209245888ull, 35410589842035618ull}},
{{9110623828051217344ull, 28328471873628494ull}},
{{10977847877182884160ull, 22662777498902795ull}},
{{8782278301746307328ull, 18130221999122236ull}},
{{6672947653310271104ull, 29008355198595578ull}},
{{12717055752132037568ull, 23206684158876462ull}},
{{2794946972221809408ull, 18565347327101170ull}},
{{4471915155554895040ull, 29704555723361872ull}},
{{14645578568669646976ull, 23763644578689497ull}},
{{4337765225451896960ull, 19010915662951598ull}},
{{3251075545981124800ull, 30417465060722557ull}},
{{13668906881010630784ull, 24333972048578045ull}},
{{10935125504808504640ull, 19467177638862436ull}},
{{10117503178209786752ull, 31147484222179898ull}},
{{15472700172051650048ull, 24917987377743918ull}},
{{1310113693415589056ull, 19934389902195135ull}},
{{2096181909464942528ull, 31895023843512216ull}},
{{16434340786539595328ull, 25516019074809772ull}},
{{5768774999747855616ull, 20412815259847818ull}},
{{5540691184854658688ull, 32660504415756509ull}},
{{8121901762625637248ull, 26128403532605207ull}},
{{17565567854326240768ull, 20902722826084165ull}},
{{9658164493212433600ull, 33444356521734665ull}},
{{7726531594569946880ull, 26755485217387732ull}},
{{17249271719881688448ull, 21404388173910185ull}},
{{9152090678101149952ull, 34247021078256297ull}},
{{18389718986706650944ull, 27397616862605037ull}},
{{7333077559881500096ull, 21918093490084030ull}},
{{11732924095810400192ull, 35068949584134448ull}},
{{16765036906132140800ull, 28055159667307558ull}},
{{2343983080679981632ull, 22444127733846047ull}},
{{7439721743829880960ull, 35910604374153675ull}},
{{5951777395063904768ull, 28728483499322940ull}},
{{4761421916051123840ull, 22982786799458352ull}},
{{14877183977066630016ull, 18386229439566681ull}},
{{16424796733822787392ull, 29417967103306690ull}},
{{13139837387058229888ull, 23534373682645352ull}},
{{3133172280162763264ull, 18827498946116282ull}},
{{8702424463002331584ull, 30123998313786051ull}},
{{3272590755659954944ull, 24099198651028841ull}},
{{17375467863495605248ull, 19279358920823072ull}},
{{13043353322625327104ull, 30846974273316916ull}},
{{6745333843358351360ull, 24677579418653533ull}},
{{12774964704170501696ull, 19742063534922826ull}},
{{13061245897188982144ull, 31587301655876522ull}},
{{3070299088267365056ull, 25269841324701218ull}},
{{9834936900097712704ull, 20215873059760974ull}},
{{4667852595930609344ull, 32345396895617559ull}},
{{7423630891486397760ull, 25876317516494047ull}},
{{17006951157414849216ull, 20701054013195237ull}},
{{12453726592896117440ull, 33121686421112380ull}},
{{9962981274316893952ull, 26497349136889904ull}},
{{11659733834195425472ull, 21197879309511923ull}},
{{14966225319970770432ull, 33916606895219077ull}},
{{4594282626492795712ull, 27133285516175262ull}},
{{14743472545419967552ull, 21706628412940209ull}},
{{12521509628446217088ull, 34730605460704335ull}},
{{10017207702756973632ull, 27784484368563468ull}},
{{15392463791689399552ull, 22227587494850774ull}},
{{13559895622477308352ull, 35564139991761239ull}},
{{14537265312723756992ull, 28451311993408991ull}},
{{7940463435437095296ull, 22761049594727193ull}},
{{13731068377833496832ull, 18208839675781754ull}},
{{10901662960307864000ull, 29134143481250807ull}},
{{1342632738762470592ull, 23307314785000646ull}},
{{15831501449977617728ull, 18645851828000516ull}},
{{17951704690480367744ull, 29833362924800826ull}},
{{10672014937642383872ull, 23866690339840661ull}},
{{4848263135371996800ull, 19093352271872529ull}},
{{15135918646079015488ull, 30549363634996046ull}},
{{8419386102121302080ull, 24439490907996837ull}},
{{17803555325922772608ull, 19551592726397469ull}},
{{17417642077250705216ull, 31282548362235951ull}},
{{10244764847058653888ull, 25026038689788761ull}},
{{4506463062905012736ull, 20020830951831009ull}},
{{14589038530131841088ull, 32033329522929614ull}},
{{15360579638847383168ull, 25626663618343691ull}},
{{8599114896335996224ull, 20501330894674953ull}},
{{10069235019395683648ull, 32802129431479925ull}},
{{8055388015516546880ull, 26241703545183940ull}},
{{6444310412413237504ull, 20993362836147152ull}},
{{14000245474603090368ull, 33589380537835443ull}},
{{132149935456741312ull, 26871504430268355ull}},
{{105719948365393024ull, 21497203544214684ull}},
{{7547849546868449536ull, 34395525670743494ull}},
{{9727628452236669952ull, 27516420536594795ull}},
{{7782102761789335936ull, 22013136429275836ull}},
{{5072666789379116928ull, 35221018286841338ull}},
{{11436831060987114176ull, 28176814629473070ull}},
{{9149464848789691328ull, 22541451703578456ull}},
{{3630223064289842752ull, 18033161362862765ull}},
{{5808356902863748416ull, 28853058180580424ull}},
{{8336034337032909056ull, 23082446544464339ull}},
{{10358176284368237568ull, 18465957235571471ull}},
{{9194384425505359424ull, 29545531576914354ull}},
{{11044856355146197888ull, 23636425261531483ull}},
{{16214582713600778944ull, 18909140209225186ull}},
{{117890638567874048ull, 30254624334760299ull}},
{{3783661325596209536ull, 24203699467808239ull}},
{{6716277875218877952ull, 19362959574246591ull}},
{{3367346970866384128ull, 30980735318794546ull}},
{{17451272835660748544ull, 24784588255035636ull}},
{{10271669453786688512ull, 19827670604028509ull}},
{{5366624681832970688ull, 31724272966445615ull}},
{{4293299745466376576ull, 25379418373156492ull}},
{{14502686240598832192ull, 20303534698525193ull}},
{{1068205096506669632ull, 32485655517640310ull}},
{{854564077205335680ull, 25988524414112248ull}},
{{8062348891248089216ull, 20790819531289798ull}},
{{9210409411255032384ull, 33265311250063677ull}},
{{18436373973229756864ull, 26612249000050941ull}},
{{11059750363841895168ull, 21289799200040753ull}},
{{14006251767405121984ull, 34063678720065205ull}},
{{11205001413924097600ull, 27250942976052164ull}},
{{12653349945881188352ull, 21800754380841731ull}},
{{12866662283926080768ull, 34881207009346770ull}},
{{10293329827140864640ull, 27904965607477416ull}},
{{4545315046970781376ull, 22323972485981933ull}},
{{3583155260411339840ull, 35718355977571093ull}},
{{10245221837812892544ull, 28574684782056874ull}},
{{11885526284992224320ull, 22859747825645499ull}},
{{13197769842735689792ull, 18287798260516399ull}},
{{10048385304151372736ull, 29260477216826239ull}},
{{11728057058063008512ull, 23408381773460991ull}},
{{5693096831708496448ull, 18726705418768793ull}},
{{5419606115991684032ull, 29962728670030069ull}},
{{8025033707535257536ull, 23970182936024055ull}},
{{6420026966028206016ull, 19176146348819244ull}},
{{17650740775128950336ull, 30681834158110790ull}},
{{14120592620103160256ull, 24545467326488632ull}},
{{3917776466598707520ull, 19636373861190906ull}},
{{17336488790783663040ull, 31418198177905449ull}},
{{17558539847368840768ull, 25134558542324359ull}},
{{17736180692636982912ull, 20107646833859487ull}},
{{13620493849251531392ull, 32172234934175180ull}},
{{10896395079401225152ull, 25737787947340144ull}},
{{12406464878262890432ull, 20590230357872115ull}},
{{1403599731511073088ull, 32944368572595385ull}},
{{1122879785208858432ull, 26355494858076308ull}},
{{8277001457650907392ull, 21084395886461046ull}},
{{5864504702757631232ull, 33735033418337674ull}},
{{8380952576948015296ull, 26988026734670139ull}},
{{10394110876300322560ull, 21590421387736111ull}},
{{9251879772596695424ull, 34544674220377778ull}},
{{14780201447561177024ull, 27635739376302222ull}},
{{4445463528565120960ull, 22108591501041778ull}},
{{3423392830962283200ull, 35373746401666845ull}},
{{2738714264769826560ull, 28298997121333476ull}},
{{16948366670783502528ull, 22639197697066780ull}},
{{13558693336626802048ull, 18111358157653424ull}},
{{10625862894377152256ull, 28978173052245479ull}},
{{12190039130243632128ull, 23182538441796383ull}},
{{17130728933678726336ull, 18546030753437106ull}},
{{1583724590692589952ull, 29673649205499371ull}},
{{16024374931521713216ull, 23738919364399496ull}},
{{9130151130475460224ull, 18991135491519597ull}},
{{18297590623502646720ull, 30385816786431355ull}},
{{14638072498802117376ull, 24308653429145084ull}},
{{15399806813783604224ull, 19446922743316067ull}},
{{9882295643086125504ull, 31115076389305708ull}},
{{15284534143952721024ull, 24892061111444566ull}},
{{8538278500420266496ull, 19913648889155653ull}},
{{9971896785930516096ull, 31861838222649045ull}},
{{7977517428744412864ull, 25489470578119236ull}},
{{2692665128253619968ull, 20391576462495389ull}},
{{11686961834689612608ull, 32626522339992622ull}},
{{1970871838267869440ull, 26101217871994098ull}},
{{8955395100098116160ull, 20880974297595278ull}},
{{10639283345415075584ull, 33409558876152445ull}},
{{8511426676332060480ull, 26727647100921956ull}},
{{3119792526323738048ull, 21382117680737565ull}},
{{4991668042117980864ull, 34211388289180104ull}},
{{7682683248436295040ull, 27369110631344083ull}},
{{13524844228232856640ull, 21895288505075266ull}},
{{14261053135688750016ull, 35032461608120426ull}},
{{7719493693809089664ull, 28025969286496341ull}},
{{2486246140305361408ull, 22420775429197073ull}},
{{288645009746667968ull, 35873240686715317ull}},
{{11298962452023065344ull, 28698592549372253ull}},
{{16417867591102272896ull, 22958874039497802ull}},
{{5755596443397997696ull, 18367099231598242ull}},
{{12898303124178706624ull, 29387358770557187ull}},
{{2939944869859144640ull, 23509887016445750ull}},
{{2351955895887315712ull, 18807909613156600ull}},
{{3763129433419705152ull, 30092655381050560ull}},
{{3010503546735764096ull, 24074124304840448ull}},
{{9787100466872431936ull, 19259299443872358ull}},
{{11970011932253980800ull, 30814879110195773ull}},
{{16954707175287005248ull, 24651903288156618ull}},
{{2495719296003873216ull, 19721522630525295ull}},
{{3993150873606197184ull, 31554436208840472ull}},
{{14262567143110688704ull, 25243548967072377ull}},
{{4031356085004730304ull, 20194839173657902ull}},
{{10139518550749478848ull, 32311742677852643ull}},
{{15490312470083403712ull, 25849394142282114ull}},
{{16081598790808633280ull, 20679515313825691ull}},
{{18351860435809992640ull, 33087224502121106ull}},
{{10992139533906083776ull, 26469779601696885ull}},
{{8793711627124867008ull, 21175823681357508ull}},
{{10380589788657876928ull, 33881317890172013ull}},
{{15683169460410122176ull, 27105054312137610ull}},
{{12546535568328097728ull, 21684043449710088ull}},
{{16385108094583046080ull, 34694469519536141ull}},
{{9418737660924526528ull, 27755575615628913ull}},
{{14913687758223441856ull, 22204460492503130ull}},
{{5415156339447955392ull, 35527136788005009ull}},
{{8021473886300274624ull, 28421709430404007ull}},
{{17485225553265950656ull, 22737367544323205ull}},
{{13988180442612760512ull, 18189894035458564ull}},
{{11313042263954685888ull, 29103830456733703ull}},
{{16429131440647569344ull, 23283064365386962ull}},
{{5764607523034234816ull, 18626451492309570ull}},
{{9223372036854775744ull, 29802322387695312ull}},
{{18446744073709551552ull, 23841857910156249ull}},
{{18446744073709551552ull, 19073486328124999ull}},
{{18446744073709551552ull, 30517578124999999ull}},
{{18446744073709551552ull, 24414062499999999ull}},
{{18446744073709551552ull, 19531249999999999ull}},
{{18446744073709551552ull, 31249999999999999ull}},
{{18446744073709551552ull, 24999999999999999ull}},
{{18446744073709551552ull, 19999999999999999ull}},
{{18446744073709551552ull, 31999999999999999ull}},
{{18446744073709551552ull, 25599999999999999ull}},
{{18446744073709551552ull, 20479999999999999ull}},
{{18446744073709551552ull, 32767999999999999ull}},
{{18446744073709551552ull, 26214399999999999ull}},
{{18446744073709551552ull, 20971519999999999ull}},
{{18446744073709551552ull, 33554431999999999ull}},
{{18446744073709551552ull, 26843545599999999ull}},
{{18446744073709551552ull, 21474836479999999ull}},
{{18446744073709551552ull, 34359738367999999ull}},
{{18446744073709551552ull, 27487790694399999ull}},
{{18446744073709551552ull, 21990232555519999ull}},
{{18446744073709551552ull, 35184372088831999ull}},
{{18446744073709551552ull, 28147497671065599ull}},
{{18446744073709551552ull, 22517998136852479ull}},
{{18446744073709551552ull, 18014398509481983ull}},
{{7378697629483820608ull, 28823037615171174ull}},
{{9592306918328966784ull, 23058430092136939ull}},
{{11363194349405083776ull, 18446744073709551ull}},
{{10802413329564313408ull, 29514790517935282ull}},
{{1263233034167630080ull, 23611832414348226ull}},
{{15767981686301745344ull, 18889465931478580ull}},
{{6782026624373240960ull, 30223145490365729ull}},
{{9114970114240503040ull, 24178516392292583ull}},
{{14670673720876223104ull, 19342813113834066ull}},
{{16094380323918136320ull, 30948500982134506ull}},
{{9186155444392598720ull, 24758800785707605ull}},
{{7348924355514078976ull, 19807040628566084ull}},
{{690232524596795392ull, 31691265005705735ull}},
{{552186019677436352ull, 25353012004564588ull}},
{{7820446445225769728ull, 20282409603651670ull}},
{{12512714312361231552ull, 32451855365842672ull}},
{{2631473820405164608ull, 25961484292674138ull}},
{{9483876685807952320ull, 20769187434139310ull}},
{{15174202697292723712ull, 33230699894622896ull}},
{{8450013343092268608ull, 26584559915698317ull}},
{{17828057118699545856ull, 21267647932558653ull}},
{{6388798501467811456ull, 34028236692093846ull}},
{{1421689986432338880ull, 27222589353675077ull}},
{{12205398433371602048ull, 21778071482940061ull}},
{{12149939863910742656ull, 34844914372704098ull}},
{{17098649520612414784ull, 27875931498163278ull}},
{{2610873172264200832ull, 22300745198530623ull}},
{{488048260880811008ull, 35681192317648997ull}},
{{11458485052930379776ull, 28544953854119197ull}},
{{1788090412860483200ull, 22835963083295358ull}},
{{8809169959772207168ull, 18268770466636286ull}},
{{6715974306151710848ull, 29230032746618058ull}},
{{12751477074405189312ull, 23384026197294446ull}},
{{6511832844782241152ull, 18707220957835557ull}},
{{14108281366393496128ull, 29931553532536891ull}},
{{7597276278372886592ull, 23945242826029513ull}},
{{13456518652182129920ull, 19156194260823610ull}},
{{3083685769781856256ull, 30649910817317777ull}},
{{13534995060051216000ull, 24519928653854221ull}},
{{7138647233299062464ull, 19615942923083377ull}},
{{15111184388020410240ull, 31385508676933403ull}},
{{1020901066190597248ull, 25108406941546723ull}},
{{8195418482436298432ull, 20086725553237378ull}},
{{9423320757156167168ull, 32138760885179805ull}},
{{7538656605724933760ull, 25711008708143844ull}},
{{9720274099321857280ull, 20568806966515075ull}},
{{15552438558914971712ull, 32910091146424120ull}},
{{12441950847131977344ull, 26328072917139296ull}},
{{6264211862963671552ull, 21062458333711437ull}},
{{13712087795483784832ull, 33699933333938299ull}},
{{14659019051128938176ull, 26959946667150639ull}},
{{15416564055645060864ull, 21567957333720511ull}},
{{17287804859548276736ull, 34508731733952818ull}},
{{2762197443412890432ull, 27606985387162255ull}},
{{2209757954730312320ull, 22085588309729804ull}},
{{10914310357052320384ull, 35336941295567686ull}},
{{5042099470899945984ull, 28269553036454149ull}},
{{7723028391461867136ull, 22615642429163319ull}},
{{9867771527911404032ull, 18092513943330655ull}},
{{15788434444658246400ull, 28948022309329048ull}},
{{1562701111500866176ull, 23158417847463239ull}},
{{4939509703942603264ull, 18526734277970591ull}},
{{524517896824344576ull, 29642774844752946ull}},
{{15177009576427116928ull, 23714219875802356ull}},
{{8452258846399783232ull, 18971375900641885ull}},
{{13523614154239653184ull, 30354201441027016ull}},
{{7129542508649812224ull, 24283361152821613ull}},
{{13082331636403670400ull, 19426688922257290ull}},
{{2484986544536321088ull, 31082702275611665ull}},
{{1987989235629056832ull, 24866161820489332ull}},
{{12658437832728976448ull, 19892929456391465ull}},
{{1806756458656810688ull, 31828687130226345ull}},
{{1445405166925448576ull, 25462949704181076ull}},
{{15913719392508000128ull, 20370359763344860ull}},
{{7015206954303248640ull, 32592575621351777ull}},
{{16680212007668329856ull, 26074060497081421ull}},
{{9654820791392753536ull, 20859248397665137ull}},
{{690318007260764416ull, 33374797436264220ull}},
{{552254405808611520ull, 26699837949011376ull}},
{{15199198783614530496ull, 21359870359209100ull}},
{{5871973980073697216ull, 34175792574734561ull}},
{{1008230369317047424ull, 27340634059787649ull}},
{{4495933110195548288ull, 21872507247830119ull}},
{{14572190605796697920ull, 34996011596528190ull}},
{{11657752484637358336ull, 27996809277222552ull}},
{{1947504358226065984ull, 22397447421778042ull}},
{{6805355787903615936ull, 35835915874844867ull}},
{{16512331074548623680ull, 28668732699875893ull}},
{{2141818415413168000ull, 22934986159900715ull}},
{{1713454732330534400ull, 18347988927920572ull}},
{{6430876386470765376ull, 29356782284672915ull}},
{{5144701109176612288ull, 23485425827738332ull}},
{{15183807331567020800ull, 18788340662190665ull}},
{{5847347656797681664ull, 30061345059505065ull}},
{{4677878125438145344ull, 24049076047604052ull}},
{{14810348944576247232ull, 19239260838083241ull}},
{{16317860681838174912ull, 30782817340933186ull}},
{{9364939730728629632ull, 24626253872746549ull}},
{{11181300599324814016ull, 19701003098197239ull}},
{{6822034514693971456ull, 31521604957115583ull}},
{{12836325241238997824ull, 25217283965692466ull}},
{{6579711378249287936ull, 20173827172553973ull}},
{{6838189390456950400ull, 32278123476086357ull}},
{{16538597956591291264ull, 25822498780869085ull}},
{{13230878365273033024ull, 20657999024695268ull}},
{{17480056569694942528ull, 33052798439512429ull}},
{{17673394070497864320ull, 26442238751609943ull}},
{{3070668812172560448ull, 21153791001287955ull}},
{{4913070099476096768ull, 33846065602060728ull}},
{{11309153709064698048ull, 27076852481648582ull}},
{{1668625337767937792ull, 21661481985318866ull}},
{{13737846984654431488ull, 34658371176510185ull}},
{{10990277587723545152ull, 27726696941208148ull}},
{{16170919699662656768ull, 22181357552966518ull}},
{{3737378631008788928ull, 35490172084746430ull}},
{{2989902904807031104ull, 28392137667797144ull}},
{{6081271138587535232ull, 22713710134237715ull}},
{{4865016910870028160ull, 18170968107390172ull}},
{{11473375872133955392ull, 29073548971824275ull}},
{{9178700697707164352ull, 23258839177459420ull}},
{{7342960558165731456ull, 18607071341967536ull}},
{{4370039263581349696ull, 29771314147148058ull}},
{{10874729040348900416ull, 23817051317718446ull}},
{{5010434417537209984ull, 19053641054174757ull}},
{{11706043882801446336ull, 30485825686679611ull}},
{{5675486291499246720ull, 24388660549343689ull}},
{{8229737847941307712ull, 19510928439474951ull}},
{{5788882927222271680ull, 31217485503159922ull}},
{{15699152786003548288ull, 24973988402527937ull}},
{{5180624599319017984ull, 19979190722022350ull}},
{{8288999358910428800ull, 31966705155235760ull}},
{{6631199487128343040ull, 25573364124188608ull}},
{{12683657219186495104ull, 20458691299350886ull}},
{{12915153921214571520ull, 32733906078961418ull}},
{{17710820766455477824ull, 26187124863169134ull}},
{{17858005427906292608ull, 20949699890535307ull}},
{{13815413425682426880ull, 33519519824856492ull}},
{{3673633111062120832ull, 26815615859885194ull}},
{{6628255303591606976ull, 21452492687908155ull}},
{{10605208485746571200ull, 34323988300653048ull}},
{{15862864418081077632ull, 27459190640522438ull}},
{{1622245090239131136ull, 21967352512417951ull}},
{{13663638588608340736ull, 35147764019868721ull}},
{{7241562056144762304ull, 28118211215894977ull}},
{{16861296089141540800ull, 22494568972715981ull}},
{{1152632039433092992ull, 35991310356345571ull}},
{{15679500890514115712ull, 28793048285076456ull}},
{{8854251897669382208ull, 23034438628061165ull}},
{{7083401518135505792ull, 18427550902448932ull}},
{{15022791243758719616ull, 29484081443918291ull}},
{{8328884180265065344ull, 23587265155134633ull}},
{{14041804973695872896ull, 18869812124107706ull}},
{{15088190328429576000ull, 30191699398572330ull}},
{{12070552262743660800ull, 24153359518857864ull}},
{{13345790624936838976ull, 19322687615086291ull}},
{{13974567370415121728ull, 30916300184138066ull}},
{{7490305081590187072ull, 24733040147310453ull}},
{{13370941694755970304ull, 19786432117848362ull}},
{{6636111452641911168ull, 31658291388557380ull}},
{{5308889162113528960ull, 25326633110845904ull}},
{{7936460144432733440ull, 20261306488676723ull}},
{{9008987416350463232ull, 32418090381882757ull}},
{{18275236377306101568ull, 25934472305506205ull}},
{{14620189101844881216ull, 20747577844404964ull}},
{{12324256118726079040ull, 33196124551047943ull}},
{{17238102524464683840ull, 26556899640838354ull}},
{{17479830834313657408ull, 21245519712670683ull}},
{{5831636446450389952ull, 33992831540273094ull}},
{{8354657971902222272ull, 27194265232218475ull}},
{{6683726377521777792ull, 21755412185774780ull}},
{{10693962204034844480ull, 34808659497239648ull}},
{{15933867392711696256ull, 27846927597791718ull}},
{{1679047469943626048ull, 22277542078233375ull}},
{{2686475951909801664ull, 35644067325173400ull}},
{{2149180761527841344ull, 28515253860138720ull}},
{{1719344609222273024ull, 22812203088110976ull}},
{{16132870946345459712ull, 18249762470488780ull}},
{{7365849440443183936ull, 29199619952782049ull}},
{{9582028367096457472ull, 23359695962225639ull}},
{{11354971508419076288ull, 18687756769780511ull}},
{{10789256783986701440ull, 29900410831648818ull}},
{{16010103056673181824ull, 23920328665319054ull}},
{{16497431260080455744ull, 19136262932255243ull}},
{{4259797127677267328ull, 30618020691608390ull}},
{{3407837702141813824ull, 24494416553286712ull}},
{{13794316605939182016ull, 19595533242629369ull}},
{{11002860125276960320ull, 31352853188206991ull}},
{{5112939285479657920ull, 25082282550565593ull}},
{{11469049057867546944ull, 20065826040452474ull}},
{{7282432048362344192ull, 32105321664723959ull}},
{{9515294453431785664ull, 25684257331779167ull}},
{{233537933261607872ull, 20547405865423334ull}},
{{7752358322702393280ull, 32875849384677334ull}},
{{9891235472903824960ull, 26300679507741867ull}},
{{534290748839239296ull, 21040543606193494ull}},
{{8233562827626603520ull, 33664869769909590ull}},
{{6586850262101282816ull, 26931895815927672ull}},
{{16337526653906757248ull, 21545516652742137ull}},
{{11382647387283170304ull, 34472826644387420ull}},
{{9106117909826536256ull, 27578261315509936ull}},
{{3595545513119318656ull, 22062609052407949ull}},
{{13131570450474730496ull, 35300174483852718ull}},
{{17883953989863605056ull, 28240139587082174ull}},
{{17996512006632794368ull, 22592111669665739ull}},
{{18086558420048145792ull, 18073689335732591ull}},
{{3113051768883661056ull, 28917902937172147ull}},
{{13558487859332659776ull, 23134322349737717ull}},
{{3468092657982307200ull, 18507457879790174ull}},
{{12927645882255512128ull, 29611932607664278ull}},
{{17720814335288230336ull, 23689546086131422ull}},
{{6797953838746763648ull, 18951636868905138ull}},
{{7187377327252911552ull, 30322618990248221ull}},
{{2060553047060418880ull, 24258095192198577ull}},
{{12716488881874066048ull, 19406476153758861ull}},
{{12967684581514685120ull, 31050361846014178ull}},
{{17752845294695568704ull, 24840289476811342ull}},
{{6823578606272634304ull, 19872231581449074ull}},
{{18296423399520035584ull, 31795570530318518ull}},
{{3569092275390297472ull, 25436456424254815ull}},
{{2855273820312237952ull, 20349165139403852ull}},
{{8257786927241491136ull, 32558664223046163ull}},
{{13984927171277013504ull, 26046931378436930ull}},
{{11187941737021610816ull, 20837545102749544ull}},
{{6832660335008846336ull, 33340072164399271ull}},
{{1776779453265166784ull, 26672057731519417ull}},
{{12489470006837864384ull, 21337646185215533ull}},
{{16293803196198672704ull, 34140233896344853ull}},
{{1966996112733207168ull, 27312187117075883ull}},
{{8952294519670386368ull, 21849749693660706ull}},
{{6944973601988797568ull, 34959599509857130ull}},
{{5555978881591038080ull, 27967679607885704ull}},
{{8134131920014740736ull, 22374143686308563ull}},
{{9325262257281674880ull, 35798629898093701ull}},
{{3770860991083429568ull, 28638903918474961ull}},
{{17774084051834384960ull, 22911123134779968ull}},
{{3151220797241777024ull, 18328898507823975ull}},
{{5041953275586843200ull, 29326237612518360ull}},
{{4033562620469474560ull, 23460990090014688ull}},
{{10605547725859400320ull, 18768792072011750ull}},
{{16968876361375040512ull, 30030067315218800ull}},
{{13575101089100032384ull, 24024053852175040ull}},
{{10860080871280025920ull, 19219243081740032ull}},
{{2618734135080400192ull, 30750788930784052ull}},
{{13163033752290051072ull, 24600631144627241ull}},
{{6841078187090130560ull, 19680504915701793ull}},
{{7256376284602298560ull, 31488807865122869ull}},
{{9494449842423749184ull, 25191046292098295ull}},
{{7595559873938999360ull, 20152837033678636ull}},
{{4774198168818578304ull, 32244539253885818ull}},
{{11198056164538683264ull, 25795631403108654ull}},
{{12647793746372856960ull, 20636505122486923ull}},
{{16547121179454660800ull, 33018408195979077ull}},
{{5858999314079907968ull, 26414726556783262ull}},
{{15755245895489657344ull, 21131781245426609ull}},
{{14140346988557720832ull, 33810849992682575ull}},
{{11312277590846176640ull, 27048679994146060ull}},
{{9049822072676941312ull, 21638943995316848ull}},
{{10790366501541195776ull, 34622310392506957ull}},
{{1253595571749136000ull, 27697848314005566ull}},
{{15760271716366950080ull, 22158278651204452ull}},
{{10459039487219478848ull, 35453245841927124ull}},
{{12056580404517493376ull, 28362596673541699ull}},
{{13334613138355905024ull, 22690077338833359ull}},
{{14357039325426634368ull, 18152061871066687ull}},
{{8213867661714973696ull, 29043298993706700ull}},
{{6571094129371978944ull, 23234639194965360ull}},
{{5256875303497583168ull, 18587711355972288ull}},
{{4721651670854222720ull, 29740338169555661ull}},
{{87972521941467840ull, 23792270535644529ull}},
{{3759726832295084608ull, 19033816428515623ull}},
{{2326214116930225024ull, 30454106285624997ull}},
{{12929017737769910976ull, 24363285028499997ull}},
{{2964516560732108160ull, 19490628022799998ull}},
{{1053877682429462720ull, 31185004836479997ull}},
{{11911148590169301120ull, 24948003869183997ull}},
{{2150221242651620288ull, 19958403095347198ull}},
{{18197749247210233728ull, 31933444952555516ull}},
{{10868850583026276672ull, 25546755962044413ull}},
{{16073778095904841984ull, 20437404769635530ull}},
{{7271300879738195520ull, 32699847631416849ull}},
{{9506389518532466752ull, 26159878105133479ull}},
{{11294460429567883712ull, 20927902484106783ull}},
{{14381787872566703680ull, 33484643974570853ull}},
{{437383853827631936ull, 26787715179656683ull}},
{{7728604712545926208ull, 21430172143725346ull}},
{{4987069910589661312ull, 34288275429960554ull}},
{{7679004743213639360ull, 27430620343968443ull}},
{{13521901424054732096ull, 21944496275174754ull}},
{{10566995834261840448ull, 35111194040279607ull}},
{{1074899037925651712ull, 28088955232223686ull}},
{{15617314489308162624ull, 22471164185778948ull}},
{{2851610294441598336ull, 35953862697246318ull}},
{{9659985865037099264ull, 28763090157797054ull}},
{{11417337506771589760ull, 23010472126237643ull}},
{{16512567634901092416ull, 18408377700990114ull}},
{{15352061771616016960ull, 29453404321584183ull}},
{{1213602973067082560ull, 23562723457267347ull}},
{{12038928822679397056ull, 18850178765813877ull}},
{{4504890857319393984ull, 30160286025302204ull}},
{{7293261500597425472ull, 24128228820241763ull}},
{{13213306829961761024ull, 19302583056193410ull}},
{{2694546854229266048ull, 30884132889909457ull}},
{{13223683927609143808ull, 24707306311927565ull}},
{{10578947142087315072ull, 19765845049542052ull}},
{{2168920168372062784ull, 31625352079267284ull}},
{{5424484949439560576ull, 25300281663413827ull}},
{{15407634403777379392ull, 20240225330731061ull}},
{{17273517416559986432ull, 32384360529169698ull}},
{{2750767489022258176ull, 25907488423335759ull}}
};

static const int exponents_binary64[] = { -55,
  -51,
  -48,
  -45,
  -41,
  -38,
  -35,
  -31,
  -28,
  -25,
  -22,
  -18,
  -15,
  -12,
  -8,
  -5,
  -2,
  2,
  5,
  8,
  12,
  15,
  18,
  22,
  25,
  28,
  32,
  35,
  38,
  42,
  45,
  48,
  52,
  55,
  58,
  62,
  65,
  68,
  71,
  75,
  78,
  81,
  85,
  88,
  91,
  95,
  98,
  101,
  105,
  108,
  111,
  115,
  118,
  121,
  125,
  128,
  131,
  135,
  138,
  141,
  145,
  148,
  151,
  155,
  158,
  161,
  164,
  168,
  171,
  174,
  178,
  181,
  184,
  188,
  191,
  194,
  198,
  201,
  204,
  208,
  211,
  214,
  218,
  221,
  224,
  228,
  231,
  234,
  238,
  241,
  244,
  248,
  251,
  254,
  258,
  261,
  264,
  267,
  271,
  274,
  277,
  281,
  284,
  287,
  291,
  294,
  297,
  301,
  304,
  307,
  311,
  314,
  317,
  321,
  324,
  327,
  331,
  334,
  337,
  341,
  344,
  347,
  351,
  354,
  357,
  360,
  364,
  367,
  370,
  374,
  377,
  380,
  384,
  387,
  390,
  394,
  397,
  400,
  404,
  407,
  410,
  414,
  417,
  420,
  424,
  427,
  430,
  434,
  437,
  440,
  444,
  447,
  450,
  454,
  457,
  460,
  463,
  467,
  470,
  473,
  477,
  480,
  483,
  487,
  490,
  493,
  497,
  500,
  503,
  507,
  510,
  513,
  517,
  520,
  523,
  527,
  530,
  533,
  537,
  540,
  543,
  547,
  550,
  553,
  556,
  560,
  563,
  566,
  570,
  573,
  576,
  580,
  583,
  586,
  590,
  593,
  596,
  600,
  603,
  606,
  610,
  613,
  616,
  620,
  623,
  626,
  630,
  633,
  636,
  640,
  643,
  646,
  649,
  653,
  656,
  659,
  663,
  666,
  669,
  673,
  676,
  679,
  683,
  686,
  689,
  693,
  696,
  699,
  703,
  706,
  709,
  713,
  716,
  719,
  723,
  726,
  729,
  733,
  736,
  739,
  743,
  746,
  749,
  752,
  756,
  759,
  762,
  766,
  769,
  772,
  776,
  779,
  782,
  786,
  789,
  792,
  796,
  799,
  802,
  806,
  809,
  812,
  816,
  819,
  822,
  826,
  829,
  832,
  836,
  839,
  842,
  845,
  849,
  852,
  855,
  859,
  862,
  865,
  869,
  872,
  875,
  879,
  882,
  885,
  889,
  892,
  895,
  899,
  902,
  905,
  909,
  912,
  915,
  919,
  922,
  925,
  929,
  932,
  935,
  939,
  942,
  945,
  948,
  952,
  955,
  958,
  962,
  965,
  968,
  972,
  975,
  978,
  982,
  985,
  988,
  992,
  995,
  998,
  1002,
  1005,
  1008,
  1012,
  1015,
  1018,
  1022,
  1025,
  1028,
  1032,
  1035,
  1038,
  1041,
  1045,
  1048,
  1051,
  1055,
  1058,
  1061,
  1065,
  1068,
  1071,
  1075,
  1078,
  1081,
  1085,
  1088,
  1091,
  1095,
  1098,
  1101,
  1105,
  1108,
  1111,
  1115,
  1118,
  1121,
  1125,
  1128,
  1131,
  1134,
  1138,
  1141,
  1144,
  1148,
  1151,
  1154,
  1158,
  1161,
  1164,
  1168,
  1171,
  1174,
  1178,
  1181,
  1184,
  1188,
  1191,
  1194,
  1198,
  1201,
  1204,
  1208,
  1211,
  1214,
  1218,
  1221,
  1224,
  1228,
  1231,
  1234,
  1237,
  1241,
  1244,
  1247,
  1251,
  1254,
  1257,
  1261,
  1264,
  1267,
  1271,
  1274,
  1277,
  1281,
  1284,
  1287,
  1291,
  1294,
  1297,
  1301,
  1304,
  1307,
  1311,
  1314,
  1317,
  1321,
  1324,
  1327,
  1330,
  1334,
  1337,
  1340,
  1344,
  1347,
  1350,
  1354,
  1357,
  1360,
  1364,
  1367,
  1370,
  1374,
  1377,
  1380,
  1384,
  1387,
  1390,
  1394,
  1397,
  1400,
  1404,
  1407,
  1410,
  1414,
  1417,
  1420,
  1424,
  1427,
  1430,
  1433,
  1437,
  1440,
  1443,
  1447,
  1450,
  1453,
  1457,
  1460,
  1463,
  1467,
  1470,
  1473,
  1477,
  1480,
  1483,
  1487,
  1490,
  1493,
  1497,
  1500,
  1503,
  1507,
  1510,
  1513,
  1517,
  1520,
  1523,
  1526,
  1530,
  1533,
  1536,
  1540,
  1543,
  1546,
  1550,
  1553,
  1556,
  1560,
  1563,
  1566,
  1570,
  1573,
  1576,
  1580,
  1583,
  1586,
  1590,
  1593,
  1596,
  1600,
  1603,
  1606,
  1610,
  1613,
  1616,
  1620,
  1623,
  1626,
  1629,
  1633,
  1636,
  1639,
  1643,
  1646,
  1649,
  1653,
  1656,
  1659,
  1663,
  1666,
  1669,
  1673,
  1676,
  1679,
  1683,
  1686,
  1689,
  1693,
  1696,
  1699,
  1703,
  1706,
  1709,
  1713,
  1716,
  1719,
  1722,
  1726,
  1729,
  1732,
  1736,
  1739,
  1742,
  1746,
  1749,
  1752,
  1756,
  1759,
  1762,
  1766,
  1769,
  1772,
  1776,
  1779,
  1782,
  1786,
  1789,
  1792,
  1796,
  1799,
  1802,
  1806,
  1809,
  1812,
  1815,
  1819,
  1822,
  1825,
  1829,
  1832,
  1835,
  1839,
  1842,
  1845,
  1849,
  1852,
  1855,
  1859,
  1862,
  1865,
  1869,
  1872,
  1875,
  1879,
  1882,
  1885,
  1889,
  1892,
  1895,
  1899,
  1902,
  1905,
  1909,
  1912,
  1915,
  1918,
  1922,
  1925,
  1928,
  1932,
  1935,
  1938,
  1942,
  1945,
  1948,
  1952,
  1955,
  1958,
  1962,
  1965,
  1968,
  1972,
  1975,
  1978,
  1982,
  1985,
  1988,
  1992,
  1995,
  1998,
  2002,
  2005,
  2008,
  2011,
  2015,
  2018,
  2021,
  2025,
  2028,
  2031,
  2035,
  2038,
  2041,
  2045,
  2048,
  2051,
  2055,
  2058,
  2061,
  2065,
  2068,
  2071,
  2075,
  2078,
  2081,
  2085,
  2088,
  2091,
  2095,
  2098,
  2101,
  2105,
  2108,
  2111,
  2114,
  2118,
  2121,
  2124,
  2128,
  2131,
  2134,
  2138,
  2141,
  2144,
  2148,
  2151,
  2154,
  2158,
  2161,
};

static const UINT256 multipliers1_binary64[] =
  { {{1837554224478941466ull, 10276842184138466546ull,
      11651621577776737258ull, 7754513766366540701ull}},
{{5760157408726726321ull, 11034712383513929495ull,
  9588106495324154738ull, 4846571103979087938ull}},
{{2588510742481019997ull, 4570018442537636061ull,
  2761761082300417615ull, 6058213879973859923ull}},
{{7847324446528662900ull, 1100837034744657172ull,
  17287259408157685731ull, 7572767349967324903ull}},
{{14127949815935190120ull, 16828924211211268396ull,
  17722066157739635437ull, 4732979593729578064ull}},
{{17659937269918987650ull, 7201097208731921783ull,
  3705838623464992681ull, 5916224492161972581ull}},
{{17463235568971346659ull, 13613057529342290133ull,
  9243984297758628755ull, 7395280615202465726ull}},
{{13220365239820785614ull, 6202317946625237381ull,
  1165804167671755068ull, 4622050384501541079ull}},
{{2690398494493818305ull, 7752897433281546727ull,
  15292313264871857547ull, 5777562980626926348ull}},
{{17198056173399436594ull, 5079435773174545504ull,
  668647507380270318ull, 7221953725783657936ull}},
{{3050826143039744126ull, 15572666753322957689ull,
  835809384225337897ull, 9027442157229572420ull}},
{{13435981385468309839ull, 2815387693185766699ull,
  9745752901995611994ull, 5642151348268482762ull}},
{{12183290713407999394ull, 12742606653336984182ull,
  2958819090639739184ull, 7052689185335603453ull}},
{{6005741354905223435ull, 15928258316671230228ull,
  8310209881727061884ull, 8815861481669504316ull}},
{{12976960383670540455ull, 731789411064743084ull,
  14417253212934189486ull, 5509913426043440197ull}},
{{16221200479588175569ull, 10138108800685704663ull,
  4186508460885573145ull, 6887391782554300247ull}},
{{15664814581057831557ull, 17284322019284518733ull,
  621449557679578527ull, 8609239728192875309ull}},
{{12096352122374838675ull, 17720230289693906064ull,
  2694248982763430531ull, 5380774830120547068ull}},
{{15120440152968548344ull, 17538601843689994676ull,
  3367811228454288164ull, 6725968537650683835ull}},
{{453806117501133814ull, 3476508230902941730ull,
  18044822090850023918ull, 8407460672063354793ull}},
{{4895314841865596538ull, 16007875699596502293ull,
  4360484779140183092ull, 5254662920039596746ull}},
{{10730829570759383576ull, 1563100550786076250ull,
  14673978010780004674ull, 6568328650049495932ull}},
{{4190164926594453662ull, 11177247725337371121ull,
  18342472513475005842ull, 8210410812561869915ull}},
{{14148068125190003299ull, 11597465846763244854ull,
  9158202311708184699ull, 5131506757851168697ull}},
{{8461713119632728315ull, 9885146290026668164ull,
  16059438908062618778ull, 6414383447313960871ull}},
{{10577141399540910394ull, 3133060825678559397ull,
  15462612616650885569ull, 8017979309142451089ull}},
{{8916556383926762949ull, 13487378062117569383ull,
  2746603857765721624ull, 5011237068214031931ull}},
{{6534009461481065782ull, 16859222577646961729ull,
  17268312877489315742ull, 6264046335267539913ull}},
{{12779197845278720131ull, 11850656185203926353ull,
  7750333041579480966ull, 7830057919084424892ull}},
{{1069469625658118226ull, 2794974097325066067ull,
  14067330187841951412ull, 4893786199427765557ull}},
{{15171895087354811494ull, 3493717621656332583ull,
  3749104679520275553ull, 6117232749284706947ull}},
{{14353182840766126464ull, 8978833045497803633ull, 74694830972956537ull,
  7646540936605883684ull}},
{{2053210247837747184ull, 17140985699504597031ull,
  9270056306212873643ull, 4779088085378677302ull}},
{{16401570865079347692ull, 16814546105953358384ull,
  2364198345911316246ull, 5973860106723346628ull}},
{{2055219507639632999ull, 11794810595586922173ull,
  2955247932389145308ull, 7467325133404183285ull}},
{{3590355201488464576ull, 16595128659096602166ull,
  4152872966956909769ull, 4667078208377614553ull}},
{{13711316038715356528ull, 6908852768588588995ull,
  9802777227123525116ull, 5833847760472018191ull}},
{{12527459029966807756ull, 8636065960735736244ull,
  7641785515477018491ull, 7292309700590022739ull}},
{{15659323787458509695ull, 6183396432492282401ull,
  4940545875918885210ull, 9115387125737528424ull}},
{{2869548339520486704ull, 8476308788735064405ull,
  3087841172449303256ull, 5697116953585955265ull}},
{{8198621442827996284ull, 10595385985918830506ull,
  8471487483989016974ull, 7121396191982444081ull}},
{{1024904766680219546ull, 4020860445543762325ull,
  15201045373413659122ull, 8901745239978055101ull}},
{{2946408488388831169ull, 7124723796892239357ull,
  11806496367597230903ull, 5563590774986284438ull}},
{{8294696628913426865ull, 4294218727687911292ull,
  5534748422641762821ull, 6954488468732855548ull}},
{{10368370786141783581ull, 9979459428037277019ull,
  6918435528302203526ull, 8693110585916069435ull}},
{{4174388732124920786ull, 1625476124095910233ull,
  2018179195975183252ull, 5433194116197543397ull}},
{{9829671933583538887ull, 2031845155119887791ull,
  7134410013396366969ull, 6791492645246929246ull}},
{{7675403898552035704ull, 7151492462327247643ull,
  18141384553600234519ull, 8489365806558661557ull}},
{{2491284427381328363ull, 11387211816595611633ull,
  13644208355213840526ull, 5305853629099163473ull}},
{{7725791552654048358ull, 5010642733889738733ull,
  3220202388735136946ull, 6632317036373954342ull}},
{{14268925459244948351ull, 15486675454216949224ull,
  13248625022773696990ull, 8290396295467442927ull}},
{{8918078412028092720ull, 5067486140458205361ull,
  15197919666874642475ull, 5181497684667151829ull}},
{{15759284033462503804ull, 1722671657145368797ull,
  5162341528311139382ull, 6476872105833939787ull}},
{{5864046986545966042ull, 11376711608286486805ull,
  1841240891961536323ull, 8096090132292424734ull}},
{{5970872375804922729ull, 4804601745965360301ull,
  14985833612758123914ull, 5060056332682765458ull}},
{{12075276488183541315ull, 15229124219311476184ull,
  9508919979092879084ull, 6325070415853456823ull}},
{{15094095610229426643ull, 589661200429793614ull,
  7274463955438710952ull, 7906338019816821029ull}},
{{4822123737966003748ull, 368538250268621009ull, 6852382981362888297ull,
  4941461262385513143ull}},
{{10639340690884892589ull, 5072358831263164165ull,
  3953792708276222467ull, 6176826577981891429ull}},
{{17910861882033503640ull, 1728762520651567302ull,
  9553926903772665988ull, 7721033222477364286ull}},
{{6582602657843551871ull, 10303848612262005372ull,
  1359518296430528338ull, 4825645764048352679ull}},
{{8228253322304439839ull, 3656438728472730907ull,
  15534455925820324135ull, 6032057205060440848ull}},
{{5673630634453161895ull, 18405606465873077346ull,
  971325833565853552ull, 7540071506325551061ull}},
{{8157705164960614088ull, 11503504041170673341ull,
  2912921655192352422ull, 4712544691453469413ull}},
{{14808817474628155514ull, 5156008014608565868ull,
  8252838087417828432ull, 5890680864316836766ull}},
{{64277769575642777ull, 6445010018260707336ull, 1092675572417509732ull,
  7363351080396045958ull}},
{{80347211969553471ull, 8056262522825884170ull, 10589216502376662973ull,
  9204188850495057447ull}},
{{4661903025908358824ull, 7341007085979871558ull,
  13535789341626496214ull, 5752618031559410904ull}},
{{15050750819240224337ull, 18399630894329615255ull,
  16919736677033120267ull, 7190772539449263630ull}},
{{14201752505622892517ull, 18387852599484631165ull,
  11926298809436624526ull, 8988465674311579538ull}},
{{11181938325228001776ull, 6880721856250506574ull,
  12065622774325278233ull, 5617791046444737211ull}},
{{4754050869680226411ull, 13212588338740521122ull,
  10470342449479209887ull, 7022238808055921514ull}},
{{15165935623955058822ull, 11904049404998263498ull,
  3864556024994236551ull, 8777798510069901893ull}},
{{14090395783399299668ull, 14357559905764996542ull,
  4721190524835091796ull, 5486124068793688683ull}},
{{8389622692394348777ull, 17946949882206245678ull,
  1289802137616476841ull, 6857655085992110854ull}},
{{1263656328638160163ull, 8598629297475643386ull,
  10835624708875371860ull, 8572068857490138567ull}},
{{5401471223826238006ull, 14597515347777052924ull,
  13689794470688189268ull, 5357543035931336604ull}},
{{6751839029782797507ull, 18246894184721316155ull,
  17112243088360236585ull, 6696928794914170755ull}},
{{3828112768801108980ull, 8973559675619481482ull,
  16778617842022907828ull, 8371160993642713444ull}},
{{7004256498928081017ull, 14831846834116951734ull,
  1263264114409541584ull, 5231975621026695903ull}},
{{17978692660514877079ull, 93064468936638051ull,
  15414138198294090693ull, 6539969526283369878ull}},
{{17861679807216208444ull, 4728016604598185468ull,
  10044300711012837558ull, 8174961907854212348ull}},
{{1940177842655354470ull, 16790068433156029630ull,
  15501059981237799281ull, 5109351192408882717ull}},
{{11648594340173968895ull, 7152527486162873325ull,
  5541266921265085390ull, 6386688990511103397ull}},
{{725684869935297407ull, 18164031394558367465ull,
  11538269670008744641ull, 7983361238138879246ull}},
{{11982768089778030640ull, 4434990593957897809ull,
  2599732525328077497ull, 4989600773836799529ull}},
{{1143402056940374587ull, 10155424260874760166ull,
  7861351675087484775ull, 6237000967295999411ull}},
{{10652624608030244042ull, 8082594307666062303ull,
  5215003575431968065ull, 7796251209119999264ull}},
{{13575419407659984382ull, 16580836488359758699ull,
  3259377234644980040ull, 4872657005699999540ull}},
{{12357588241147592574ull, 2279301536740146758ull,
  4074221543306225051ull, 6090821257124999425ull}},
{{6223613264579714909ull, 16684184976207347160ull,
  9704462947560169217ull, 7613526571406249281ull}},
{{3889758290362321819ull, 3510086582488510119ull,
  17594504388293575521ull, 4758454107128905800ull}},
{{250511844525514369ull, 8999294246538025553ull, 3546386411657417785ull,
  5948067633911132251ull}},
{{4924825824084280865ull, 15860803826599919845ull,
  18268041069853935943ull, 7435084542388915313ull}},
{{5383859149266369493ull, 16830531419266031759ull,
  4499996641017628108ull, 4646927838993072071ull}},
{{2118137918155573962ull, 2591420200372988083ull,
  1013309782844647232ull, 5808659798741340089ull}},
{{16482730452976631164ull, 3239275250466235103ull,
  5878323246983196944ull, 7260824748426675111ull}},
{{15991727047793401051ull, 4049094063082793879ull,
  2736218040301608276ull, 9076030935533343889ull}},
{{16912358432511957513ull, 11754055826281521982ull,
  13239351321256974932ull, 5672519334708339930ull}},
{{11917076003785171083ull, 14692569782851902478ull,
  7325817114716442857ull, 7090649168385424913ull}},
{{5672972967876688046ull, 4530654173282714386ull,
  13768957411822941476ull, 8863311460481781141ull}},
{{8157294123350317933ull, 12055030895156472299ull,
  10911441391603032374ull, 5539569662801113213ull}},
{{5584931635760509512ull, 5845416582090814566ull,
  18250987757931178372ull, 6924462078501391516ull}},
{{16204536581555412698ull, 7306770727613518207ull,
  4366990623704421349ull, 8655577598126739396ull}},
{{17045364391113214793ull, 6872574713972142831ull,
  11952741176670039151ull, 5409735998829212122ull}},
{{16695019470464130587ull, 3979032374037790635ull,
  5717554433982773131ull, 6762169998536515153ull}},
{{16257088319652775329ull, 362104449119850390ull,
  11758629060905854318ull, 8452712498170643941ull}},
{{5548994181355596677ull, 14061373335982070206ull,
  9654986172279852900ull, 5282945311356652463ull}},
{{16159614763549271654ull, 17576716669977587757ull,
  7457046696922428221ull, 6603681639195815579ull}},
{{6364460399154425855ull, 8135837782189820985ull,
  4709622352725647373ull, 8254602048994769474ull}},
{{15507002795539985920ull, 7390741623082332067ull,
  7555199988880917512ull, 5159126280621730921ull}},
{{14772067475997594496ull, 9238427028852915084ull,
  14055686004528534794ull, 6448907850777163651ull}},
{{18340271287441503ull, 2324661749211368048ull, 12957921487233280589ull,
  8061134813471454564ull}},
{{11462669554650940ull, 3758756602470798982ull, 17322072966375576176ull,
  5038209258419659102ull}},
{{9237700373798089483ull, 4698445753088498727ull,
  12429219171114694412ull, 6297761573024573878ull}},
{{6935439448820223949ull, 5873057191360623409ull,
  6313151927038592207ull, 7872201966280717348ull}},
{{15863864701581109728ull, 10588189772241471486ull,
  13169091991253895937ull, 4920126228925448342ull}},
{{10606458840121611352ull, 17846923233729227262ull,
  7237992952212594113ull, 6150157786156810428ull}},
{{4034701513297238382ull, 8473595986879370366ull,
  9047491190265742642ull, 7687697232696013035ull}},
{{16356746501092937701ull, 9907683510226994382ull,
  3348838984702395199ull, 4804810770435008147ull}},
{{11222561089511396318ull, 7772918369356355074ull,
  18021106786160157711ull, 6006013463043760183ull}},
{{4804829325034469590ull, 5104461943268055939ull,
  17914697464272809235ull, 7507516828804700229ull}},
{{697175318932849542ull, 884445705328841010ull, 13502528924384199724ull,
  4692198018002937643ull}},
{{10094841185520837735ull, 1105557131661051262ull,
  12266475137052861751ull, 5865247522503672054ull}},
{{3395179445046271361ull, 15217004469858477790ull,
  6109721884461301380ull, 7331559403129590068ull}},
{{13467346343162615009ull, 574511513613545621ull,
  7637152355576626726ull, 9164449253911987585ull}},
{{10722934473690328333ull, 14194127751290629725ull,
  16302435268303861463ull, 5727780783694992240ull}},
{{18015354110540298320ull, 13130973670685899252ull,
  1931300011670275213ull, 7159725979618740301ull}},
{{4072448564465821284ull, 2578659033075210354ull,
  7025811033015231921ull, 8949657474523425376ull}},
{{7156966371218526206ull, 13140876941740476231ull,
  4391131895634519950ull, 5593535921577140860ull}},
{{4334521945595769854ull, 7202724140320819481ull,
  5488914869543149938ull, 6991919901971426075ull}},
{{10029838450422100221ull, 18226777212255800159ull,
  2249457568501549518ull, 8739899877464282594ull}},
{{13186178059154894494ull, 6780049739232487195ull,
  6017596998740856353ull, 5462437423415176621ull}},
{{11871036555516230214ull, 13086748192467996898ull,
  12133682266853458345ull, 6828046779268970776ull}},
{{5615423657540511959ull, 2523377185302832411ull,
  15167102833566822932ull, 8535058474086213470ull}},
{{1203796776749126023ull, 10800482777669046065ull,
  4867753252551876428ull, 5334411546303883419ull}},
{{6116431989363795432ull, 13500603472086307581ull,
  1473005547262457631ull, 6668014432879854274ull}},
{{12257226005132132194ull, 12264068321680496572ull,
  11064628970932847847ull, 8335018041099817842ull}},
{{16884138290062358430ull, 14582571728691392213ull,
  11527079125260417808ull, 5209386275687386151ull}},
{{7270114807295784325ull, 18228214660864240267ull,
  9797162888148134356ull, 6511732844609232689ull}},
{{4475957490692342502ull, 4338524252370748718ull,
  16858139628612555850ull, 8139666055761540861ull}},
{{16632531486964877776ull, 7323263676159105852ull,
  12842180277096541358ull, 5087291284850963038ull}},
{{2343920284996545604ull, 18377451632053658124ull,
  6829353309515900889ull, 6359114106063703798ull}},
{{2929900356245682005ull, 9136756484784908943ull,
  17760063673749651920ull, 7948892632579629747ull}},
{{8748716750294633109ull, 5710472802990568089ull,
  8794196786879838498ull, 4968057895362268592ull}},
{{15547581956295679290ull, 16361463040592985919ull,
  10992745983599798122ull, 6210072369202835740ull}},
{{14822791426942211209ull, 11228456763886456591ull,
  13740932479499747653ull, 7762590461503544675ull}},
{{16181773669479963862ull, 9323628486642729321ull,
  6282239790473648331ull, 4851619038439715422ull}},
{{6392159031567791115ull, 7042849589876023748ull,
  17076171774946836222ull, 6064523798049644277ull}},
{{7990198789459738893ull, 18026934024199805493ull,
  7510156663401381565ull, 7580654747562055347ull}},
{{7299717252626030761ull, 13572676774338572385ull,
  2388004905412169526ull, 4737909217226284592ull}},
{{13736332584209926355ull, 7742473931068439673ull,
  2985006131765211908ull, 5922386521532855740ull}},
{{3335357674980244231ull, 9678092413835549592ull,
  3731257664706514885ull, 7402983151916069675ull}},
{{2084598546862652645ull, 8354650767860912447ull, 26193031227877851ull,
  4626864469947543547ull}},
{{16440806238860479518ull, 5831627441398752654ull,
  13867799344317011026ull, 5783580587434429433ull}},
{{11327635761720823589ull, 16512906338603216626ull,
  3499691125114100070ull, 7229475734293036792ull}},
{{4936172665296253678ull, 11417760886399244975ull,
  4374613906392625088ull, 9036844667866295990ull}},
{{10002636943451240405ull, 7136100553999528109ull,
  16569191746777554392ull, 5648027917416434993ull}},
{{17114982197741438410ull, 8920125692499410136ull,
  6876431628189779278ull, 7060034896770543742ull}},
{{2946983673467246397ull, 1926785078769486863ull,
  17818911572091999906ull, 8825043620963179677ull}},
{{8759393823558110854ull, 5815926692658317193ull,
  13442662741771193893ull, 5515652263101987298ull}},
{{15560928297875026471ull, 11881594384250284395ull,
  7579956390359216558ull, 6894565328877484123ull}},
{{14839474353916395185ull, 5628620943458079686ull,
  4863259469521632794ull, 8618206661096855154ull}},
{{4662985452770359087ull, 8129574108088687708ull,
  7651223186878408400ull, 5386379163185534471ull}},
{{5828731815962948858ull, 10161967635110859635ull,
  4952342965170622596ull, 6732973953981918089ull}},
{{2674228751526298169ull, 12702459543888574544ull,
  10802114724890666149ull, 8416217442477397611ull}},
{{1671392969703936356ull, 10244880224144053042ull,
  4445478693842972391ull, 5260135901548373507ull}},
{{11312613248984696253ull, 8194414261752678398ull,
  945162348876327585ull, 6575169876935466884ull}},
{{4917394524376094508ull, 14854703845618235902ull,
  1181452936095409481ull, 8218962346169333605ull}},
{{16908429633017222779ull, 2366660875870315582ull,
  3044251094273324878ull, 5136851466355833503ull}},
{{11912165004416752666ull, 12181698131692670286ull,
  17640371923123819809ull, 6421064332944791878ull}},
{{5666834218666165025ull, 1392064609333674146ull,
  12827092867049998954ull, 8026330416180989848ull}},
{{8153457405093741045ull, 5481726399260934245ull,
  8016933041906249346ull, 5016456510113118655ull}},
{{14803507774794564210ull, 16075530035930943614ull,
  5409480283955423778ull, 6270570637641398319ull}},
{{9281012681638429454ull, 10871040508058903710ull,
  2150164336516891819ull, 7838213297051747899ull}},
{{1188946907596630505ull, 4488557308323120867ull,
  17484753774818915051ull, 4898883310657342436ull}},
{{15321241689777951843ull, 999010616976513179ull,
  3409198144814092198ull, 6123604138321678046ull}},
{{14539866093795051900ull, 10472135308075417282ull,
  13484869717872391055ull, 7654505172902097557ull}},
{{13699102327049295341ull, 13462613595188217657ull,
  10733886582883938361ull, 4784065733063810973ull}},
{{3288819853529455465ull, 2993208938703108360ull,
  18029044247032310856ull, 5980082166329763716ull}},
{{4111024816911819331ull, 3741511173378885450ull,
  4089561235080836954ull, 7475102707912204646ull}},
{{7181076528997274986ull, 6950130501789191310ull,
  16391033827207686808ull, 4671939192445127903ull}},
{{18199717698101369540ull, 8687663127236489137ull,
  15877106265582220606ull, 5839923990556409879ull}},
{{8914589067344548213ull, 1636206872190835614ull,
  15234696813550387854ull, 7299904988195512349ull}},
{{1919864297325909458ull, 11268630627093320326ull,
  5208312961655821105ull, 9124881235244390437ull}},
{{15034973241110857124ull, 125365114292243347ull,
  5561038610248582143ull, 5703050772027744023ull}},
{{14182030532961183500ull, 13991764448147467896ull,
  2339612244383339774ull, 7128813465034680029ull}},
{{17727538166201479375ull, 8266333523329559062ull,
  7536201323906562622ull, 8911016831293350036ull}},
{{6468025335448536706ull, 554772433653586510ull,
  13933497864296377447ull, 5569385519558343772ull}},
{{17308403706165446690ull, 14528523597349146849ull,
  17416872330370471808ull, 6961731899447929715ull}},
{{7800446577424644651ull, 18160654496686433562ull,
  17159404394535701856ull, 8702164874309912144ull}},
{{9486965129317790811ull, 11350409060429020976ull,
  10724627746584813660ull, 5438853046443695090ull}},
{{11858706411647238513ull, 14188011325536276220ull,
  4182412646376241267ull, 6798566308054618863ull}},
{{14823383014559048142ull, 13123328138492957371ull,
  616329789542913680ull, 8498207885068273579ull}},
{{6958771374885711137ull, 8202080086558098357ull,
  16526107182960178714ull, 5311379928167670986ull}},
{{13310150237034526825ull, 1029228071342847138ull,
  11434261941845447585ull, 6639224910209588733ull}},
{{7414315759438382723ull, 5898221107605946827ull, 457769372024645769ull,
  8299031137761985917ull}},
{{2328104340435295250ull, 15215603238322186527ull,
  2591948866729097557ull, 5186894461101241198ull}},
{{16745188480826282774ull, 5184445992620569446ull,
  12463308120266147755ull, 6483618076376551497ull}},
{{11708113564178077660ull, 1868871472348323904ull,
  1744077095050520982ull, 8104522595470689372ull}},
{{7317570977611298537ull, 15003102725499866152ull,
  10313420221261351421ull, 5065326622169180857ull}},
{{9146963722014123172ull, 4918820351592668978ull,
  17503461295004077181ull, 6331658277711476071ull}},
{{2210332615662878157ull, 10760211457918224127ull,
  17267640600327708572ull, 7914572847139345089ull}},
{{8298986912430380704ull, 15948504198053665887ull,
  3874746347563736001ull, 4946608029462090681ull}},
{{5762047622110587976ull, 6100572192284918647ull,
  9455118952882057906ull, 6183260036827613351ull}},
{{2590873509210847066ull, 16849087277210924117ull,
  7207212672675184478ull, 7729075046034516689ull}},
{{3925138952470473368ull, 5918993529829439669ull,
  16033722966490460059ull, 4830671903771572930ull}},
{{9518109709015479614ull, 2787055893859411682ull,
  10818781671258299266ull, 6038339879714466163ull}},
{{2674265099414573710ull, 12707191904179040411ull,
  8911791070645486178ull, 7547924849643082704ull}},
{{17812316751629966233ull, 12553680958539288160ull,
  5569869419153428861ull, 4717453031026926690ull}},
{{3818651865827906175ull, 1857043142891946489ull,
  16185708810796561885ull, 5896816288783658362ull}},
{{9385000850712270622ull, 6932989947042321015ull,
  11008763976640926548ull, 7371020360979572953ull}},
{{7119565044962950374ull, 8666237433802901269ull,
  18372640989228546089ull, 9213775451224466191ull}},
{{6755571162315537936ull, 16945613442195283053ull,
  18400429645908923161ull, 5758609657015291369ull}},
{{13056149971321810324ull, 7346958747461940104ull,
  9165479002103990240ull, 7198262071269114212ull}},
{{16320187464152262904ull, 9183698434327425130ull,
  11456848752629987800ull, 8997827589086392765ull}},
{{14811803183522552219ull, 5739811521454640706ull,
  9466373479607436327ull, 5623642243178995478ull}},
{{9291381942548414466ull, 2563078383390912979ull,
  2609594812654519601ull, 7029552803973744348ull}},
{{7002541409758130179ull, 7815533997666029128ull,
  3261993515818149501ull, 8786941004967180435ull}},
{{4376588381098831362ull, 7190551757754962157ull,
  18179647011882201102ull, 5491838128104487771ull}},
{{10082421494800927106ull, 18211561734048478504ull,
  18112872746425363473ull, 6864797660130609714ull}},
{{12603026868501158883ull, 8929394112278434418ull,
  13417718896176928534ull, 8580997075163262143ull}},
{{12488577811240612206ull, 969185301746633607ull,
  15303603337751662190ull, 5363123171977038839ull}},
{{10999036245623377353ull, 10434853664038067817ull,
  14517818153762189833ull, 6703903964971298549ull}},
{{18360481325456609595ull, 17655253098474972675ull,
  4312214636920573579ull, 8379879956214123187ull}},
{{9169457819196687045ull, 8728690177333163970ull, 389291138861664535ull,
  5237424972633826992ull}},
{{2238450237141082998ull, 6299176703239067059ull, 486613923577080669ull,
  6546781215792283740ull}},
{{16633120851708517460ull, 12485656897476221727ull,
  608267404471350836ull, 8183476519740354675ull}},
{{17313229559958905269ull, 17026907597777414387ull,
  16521068192290451936ull, 5114672824837721671ull}},
{{17029850931521243682ull, 2836890423512216368ull,
  16039649221935677017ull, 6393341031047152089ull}},
{{2840569590692002986ull, 8157799047817658365ull,
  6214503472137432559ull, 7991676288808940112ull}},
{{4081199003396195818ull, 12016153432527118334ull,
  3884064670085895349ull, 4994797680505587570ull}},
{{14324870791100020581ull, 1185133735376734205ull,
  14078452874462144995ull, 6243497100631984462ull}},
{{4071030433592862014ull, 15316475224503081469ull,
  8374694056222905435ull, 7804371375789980578ull}},
{{4850237030209232711ull, 7266954006100731966ull,
  9845869803566703801ull, 4877732109868737861ull}},
{{15286168324616316697ull, 13695378526053302861ull,
  16919023272885767655ull, 6097165137335922326ull}},
{{5272652350488232159ull, 12507537139139240673ull,
  11925407054252433761ull, 7621456421669902908ull}},
{{14824622765123614859ull, 899681684320943564ull,
  16676751445762546909ull, 4763410263543689317ull}},
{{84034382694966958ull, 5736288123828567360ull, 7010881251921019924ull,
  5954262829429611647ull}},
{{105042978368708697ull, 7170360154785709200ull, 4151915546473887001ull,
  7442828536787014559ull}},
{{65651861480442936ull, 16010690142809538010ull, 9512476244187261231ull,
  4651767835491884099ull}},
{{9305436863705329478ull, 15401676660084534608ull,
  7278909286806688635ull, 5814709794364855124ull}},
{{11631796079631661847ull, 14640409806678280356ull,
  9098636608508360794ull, 7268387242956068905ull}},
{{14539745099539577309ull, 9077140221493074637ull,
  15984981779062838897ull, 9085484053695086131ull}},
{{11393183696425929770ull, 17202427684501641408ull,
  7684770602700580358ull, 5678427533559428832ull}},
{{14241479620532412213ull, 12279662568772275952ull,
  9605963253375725448ull, 7098034416949286040ull}},
{{17801849525665515266ull, 15349578210965344940ull,
  12007454066719656810ull, 8872543021186607550ull}},
{{1902783916686171233ull, 14205172400280728492ull,
  2892972773272397602ull, 5545339388241629719ull}},
{{2378479895857714042ull, 8533093463496134807ull,
  17451274021872660715ull, 6931674235302037148ull}},
{{16808157925104306264ull, 6054680810942780604ull,
  3367348453631274278ull, 8664592794127546436ull}},
{{1281726666335415607ull, 17619233562121401590ull,
  11327964820374322231ull, 5415370496329716522ull}},
{{10825530369774045317ull, 17412355934224364083ull,
  4936583988613126981ull, 6769213120412145653ull}},
{{8920226943790168742ull, 7930386862498291392ull,
  10782416004193796631ull, 8461516400515182066ull}},
{{5575141839868855464ull, 11874020816702513976ull,
  11350696021048510798ull, 5288447750321988791ull}},
{{6968927299836069330ull, 5619153984023366662ull,
  9576684007883250594ull, 6610559687902485989ull}},
{{17934531161649862470ull, 16247314516883984135ull,
  16582541028281451146ull, 8263199609878107486ull}},
{{18126611003672245900ull, 14766257591479877988ull,
  5752402124248519062ull, 5164499756173817179ull}},
{{4211519680880755759ull, 9234449952495071678ull,
  2578816636883260924ull, 6455624695217271474ull}},
{{14487771637955720506ull, 11543062440618839597ull,
  12446892832958851963ull, 8069530869021589342ull}},
{{11360700282936019269ull, 4908571016173080796ull,
  3167622002171894573ull, 5043456793138493339ull}},
{{14200875353670024086ull, 10747399788643738899ull,
  17794585557997031928ull, 6304320991423116673ull}},
{{13139408173660142203ull, 13434249735804673624ull,
  8408173892214126198ull, 7880401239278895842ull}},
{{8212130108537588877ull, 3784720066450533111ull,
  9866794701061216778ull, 4925250774549309901ull}},
{{5653476617244598192ull, 13954272119917942197ull,
  16945179394753908876ull, 6156563468186637376ull}},
{{11678531789983135644ull, 17442840149897427746ull,
  2734730169732834479ull, 7695704335233296721ull}},
{{11910768387166847682ull, 17819304121326974197ull,
  13238421402151491309ull, 4809815209520810450ull}},
{{1053402428676395890ull, 8439072096376554035ull,
  7324654715834588329ull, 6012269011901013063ull}},
{{15151811091127658574ull, 15160526138898080447ull,
  4544132376365847507ull, 7515336264876266329ull}},
{{16387410959595868465ull, 7169485827597606327ull,
  14369297781297124452ull, 4697085165547666455ull}},
{{15872577681067447677ull, 8961857284497007909ull,
  13349936208194017661ull, 5871356456934583069ull}},
{{6005664046052145885ull, 15814007624048647791ull,
  2852362204960358364ull, 7339195571168228837ull}},
{{2895394039137794452ull, 1320765456351258123ull,
  8177138774627835860ull, 9173994463960286046ull}},
{{17950522338956979196ull, 10048850447074312134ull,
  499025715715009508ull, 5733746539975178779ull}},
{{13214780886841448187ull, 12561063058842890168ull,
  14458840199925925597ull, 7167183174968973473ull}},
{{16518476108551810234ull, 1866270768271448998ull,
  4238492194625243285ull, 8958978968711216842ull}},
{{5712361549417493492ull, 3472262239383349576ull,
  7260743640068164957ull, 5599361855444510526ull}},
{{7140451936771866865ull, 8952013817656574874ull,
  18299301586939982004ull, 6999202319305638157ull}},
{{18148936957819609390ull, 11190017272070718592ull,
  9039068928392813793ull, 8749002899132047697ull}},
{{11343085598637255869ull, 76231767403117264ull,
  17178633126313978381ull, 5468126811957529810ull}},
{{14178856998296569836ull, 4706975727681284484ull,
  12249919371037697168ull, 6835158514946912263ull}},
{{17723571247870712295ull, 5883719659601605605ull,
  10700713195369733556ull, 8543948143683640329ull}},
{{13383075039132889136ull, 12900696824105779311ull,
  18217160793174553232ull, 5339967589802275205ull}},
{{12117157780488723516ull, 16125871030132224139ull,
  8936392936186027828ull, 6674959487252844007ull}},
{{10534761207183516491ull, 1710594713955728558ull,
  6558805151805146882ull, 8343699359066055009ull}},
{{1972539736062309903ull, 5680807714649718253ull,
  15628468265946686561ull, 5214812099416284380ull}},
{{7077360688505275283ull, 11712695661739535720ull,
  1088841258723806585ull, 6518515124270355476ull}},
{{8846700860631594104ull, 805811521892255938ull, 1361051573404758232ull,
  8148143905337944345ull}},
{{10140874056322134219ull, 503632201182659961ull,
  12379872279446443655ull, 5092589940836215215ull}},
{{17287778588830055677ull, 14464598306760488663ull,
  10863154330880666664ull, 6365737426045269019ull}},
{{16998037217610181693ull, 18080747883450610829ull,
  8967256895173445426ull, 7957171782556586274ull}},
{{12929616270220057510ull, 15912153445584019672ull,
  10216221577910791295ull, 4973232364097866421ull}},
{{16162020337775071888ull, 15278505788552636686ull,
  17381962990815877023ull, 6216540455122333026ull}},
{{10979153385364064051ull, 14486446217263407954ull,
  12504081701665070471ull, 7770675568902916283ull}},
{{11473656884279927936ull, 15971557913430711827ull,
  5509208054326975092ull, 4856672230564322677ull}},
{{9730385086922522016ull, 1517703318078838168ull,
  11498196086336106770ull, 6070840288205403346ull}},
{{12162981358653152520ull, 11120501184453323518ull,
  5149373071065357654ull, 7588550360256754183ull}},
{{2990177330730832421ull, 2338627221855939295ull,
  10135887197056930390ull, 4742843975160471364ull}},
{{17572779718695704238ull, 12146656064174699926ull,
  12669858996321162987ull, 5928554968950589205ull}},
{{12742602611514854490ull, 10571634061790987004ull,
  2002265690119290022ull, 7410693711188236507ull}},
{{17187498669051559864ull, 1995585270191978973ull,
  17392317120820413928ull, 4631683569492647816ull}},
{{7649315281032286118ull, 2494481587739973717ull,
  3293652327315965794ull, 5789604461865809771ull}},
{{14173330119717745552ull, 12341474021529742954ull,
  17952123464427120954ull, 7237005577332262213ull}},
{{8493290612792406132ull, 6203470490057402885ull,
  8605096275251737481ull, 9046256971665327767ull}},
{{7614149642208947785ull, 15406384102354346563ull,
  12295714199673417781ull, 5653910607290829854ull}},
{{4906001034333796827ull, 5422922072660769492ull,
  6146270712736996419ull, 7067388259113537318ull}},
{{6132501292917246033ull, 2166966572398573961ull,
  16906210427776021332ull, 8834235323891921647ull}},
{{15362028354141748531ull, 10577726144603884533ull,
  17483910545001095188ull, 5521397077432451029ull}},
{{5367477387395021951ull, 13222157680754855667ull,
  8019830125969205273ull, 6901746346790563787ull}},
{{2097660715816389535ull, 2692639045661405872ull,
  5413101639034118688ull, 8627182933488204734ull}},
{{1311037947385243460ull, 1682899403538378670ull,
  17218246579678487892ull, 5391989333430127958ull}},
{{10862169471086330132ull, 2103624254422973337ull,
  12299436187743334057ull, 6739986666787659948ull}},
{{18189397857285300569ull, 7241216336456104575ull,
  15374295234679167571ull, 8424983333484574935ull}},
{{18285902688444394712ull, 2219917201071371407ull,
  16526463549315561588ull, 5265614583427859334ull}},
{{18245692342128105486ull, 2774896501339214259ull,
  11434707399789676177ull, 6582018229284824168ull}},
{{18195429409232743953ull, 8080306645101405728ull,
  14293384249737095221ull, 8227522786606030210ull}},
{{11372143380770464971ull, 7356034662402072532ull,
  13545051174513072417ull, 5142201741628768881ull}},
{{14215179225963081214ull, 13806729346429978569ull,
  3096255912859176809ull, 6427752177035961102ull}},
{{3933915977171687805ull, 3423353627755309500ull,
  13093691927928746820ull, 8034690221294951377ull}},
{{11682069522587080686ull, 11362968054201844245ull,
  1266028427314384906ull, 5021681388309344611ull}},
{{767528847951687146ull, 4980338030897529499ull,
  15417593589425144845ull, 6277101735386680763ull}},
{{14794469115221772644ull, 10837108557049299777ull,
  14660305968354043152ull, 7846377169233350954ull}},
{{2329014169372526047ull, 6773192848155812361ull,
  13774377248648664874ull, 4903985730770844346ull}},
{{7522953730143045462ull, 17689863097049541259ull,
  7994599523956055284ull, 6129982163463555433ull}},
{{4792006144251418924ull, 3665584797602374958ull,
  14604935423372457010ull, 7662477704329444291ull}},
{{16830061895439300539ull, 6902676516928872252ull,
  6822241630394091679ull, 4789048565205902682ull}},
{{2590833295589574058ull, 4016659627733702412ull,
  17751174074847390407ull, 5986310706507378352ull}},
{{3238541619486967573ull, 409138516239740111ull, 3742223519849686393ull,
  7482888383134222941ull}},
{{8941617539820436589ull, 11784926618718307329ull,
  4644732709119747947ull, 4676805239458889338ull}},
{{15788707943202933640ull, 10119472254970496257ull,
  15029287923254460742ull, 5846006549323611672ull}},
{{5900826873721503338ull, 3425968281858344514ull, 339865830358524312ull,
  7307508186654514591ull}},
{{16599405629006654981ull, 4282460352322930642ull,
  14259890343230319102ull, 9134385233318143238ull}},
{{14986314536556547267ull, 16511595775483995363ull,
  4300745446091561534ull, 5708990770823839524ull}},
{{14121207152268296180ull, 11416122682500218396ull,
  5375931807614451918ull, 7136238463529799405ull}},
{{17651508940335370225ull, 5046781316270497187ull,
  11331600777945452802ull, 8920298079412249256ull}},
{{8726350078495912439ull, 7765924341096448646ull,
  7082250486215908001ull, 5575186299632655785ull}},
{{1684565561265114740ull, 14319091444797948712ull,
  13464499126197272905ull, 6968982874540819731ull}},
{{2105706951581393425ull, 4063806250715272178ull,
  12218937889319203228ull, 8711228593176024664ull}},
{{5927752863165758795ull, 11763250943551820919ull,
  7636836180824502017ull, 5444517870735015415ull}},
{{2798005060529810589ull, 869005624157612437ull, 4934359207603239618ull,
  6805647338418769269ull}},
{{8109192344089651141ull, 10309629067051791354ull,
  10779635027931437426ull, 8507059173023461586ull}},
{{9679931233483419867ull, 11055204185334757500ull,
  11348957910884536295ull, 5316911983139663491ull}},
{{12099914041854274834ull, 9207319213241058971ull,
  9574511370178282465ull, 6646139978924579364ull}},
{{10513206533890455638ull, 16120835034978711618ull,
  11968139212722853081ull, 8307674973655724205ull}},
{{11182440102108922678ull, 3157992869220612905ull,
  9785930017165477128ull, 5192296858534827628ull}},
{{142992072353989635ull, 3947491086525766132ull,
  12232412521456846410ull, 6490371073168534535ull}},
{{178740090442487044ull, 14157735895011983473ull,
  10678829633393670108ull, 8112963841460668169ull}},
{{11640927602595024163ull, 18071956971237265478ull,
  18203483566939513577ull, 5070602400912917605ull}},
{{5327787466389004395ull, 8754888158764418136ull,
  8919296403392228260ull, 6338253001141147007ull}},
{{6659734332986255494ull, 10943610198455522670ull,
  6537434485812897421ull, 7922816251426433759ull}},
{{17997392013398573396ull, 9145599383248395620ull,
  11003425581274142744ull, 4951760157141521099ull}},
{{4049995943038665129ull, 11431999229060494526ull,
  9142595958165290526ull, 6189700196426901374ull}},
{{14285866965653107219ull, 5066626999470842349ull,
  2204872910851837350ull, 7737125245533626718ull}},
{{11234509862746885964ull, 17001699929951440180ull,
  15213103624564562055ull, 4835703278458516698ull}},
{{14043137328433607455ull, 16640438894011912321ull,
  9793007493850926761ull, 6044629098073145873ull}},
{{3718863605259845606ull, 6965490562232726690ull,
  16852945385741046356ull, 7555786372591432341ull}},
{{6935975771714791408ull, 13576803638250229989ull,
  12838933875301847924ull, 4722366482869645213ull}},
{{13281655733070877164ull, 16971004547812787486ull,
  2213609288845146193ull, 5902958103587056517ull}},
{{7378697629483820647ull, 7378697629483820646ull,
  7378697629483820646ull, 7378697629483820646ull}},
{{0ull, 0ull, 0ull, 9223372036854775808ull}},
{{0ull, 0ull, 0ull, 5764607523034234880ull}},
{{0ull, 0ull, 0ull, 7205759403792793600ull}},
{{0ull, 0ull, 0ull, 9007199254740992000ull}},
{{0ull, 0ull, 0ull, 5629499534213120000ull}},
{{0ull, 0ull, 0ull, 7036874417766400000ull}},
{{0ull, 0ull, 0ull, 8796093022208000000ull}},
{{0ull, 0ull, 0ull, 5497558138880000000ull}},
{{0ull, 0ull, 0ull, 6871947673600000000ull}},
{{0ull, 0ull, 0ull, 8589934592000000000ull}},
{{0ull, 0ull, 0ull, 5368709120000000000ull}},
{{0ull, 0ull, 0ull, 6710886400000000000ull}},
{{0ull, 0ull, 0ull, 8388608000000000000ull}},
{{0ull, 0ull, 0ull, 5242880000000000000ull}},
{{0ull, 0ull, 0ull, 6553600000000000000ull}},
{{0ull, 0ull, 0ull, 8192000000000000000ull}},
{{0ull, 0ull, 0ull, 5120000000000000000ull}},
{{0ull, 0ull, 0ull, 6400000000000000000ull}},
{{0ull, 0ull, 0ull, 8000000000000000000ull}},
{{0ull, 0ull, 0ull, 5000000000000000000ull}},
{{0ull, 0ull, 0ull, 6250000000000000000ull}},
{{0ull, 0ull, 0ull, 7812500000000000000ull}},
{{0ull, 0ull, 0ull, 4882812500000000000ull}},
{{0ull, 0ull, 0ull, 6103515625000000000ull}},
{{0ull, 0ull, 0ull, 7629394531250000000ull}},
{{0ull, 0ull, 0ull, 4768371582031250000ull}},
{{0ull, 0ull, 0ull, 5960464477539062500ull}},
{{0ull, 0ull, 0ull, 7450580596923828125ull}},
{{0ull, 0ull, 2305843009213693952ull, 4656612873077392578ull}},
{{0ull, 0ull, 12105675798371893248ull, 5820766091346740722ull}},
{{0ull, 0ull, 5908722711110090752ull, 7275957614183425903ull}},
{{0ull, 0ull, 2774217370460225536ull, 9094947017729282379ull}},
{{0ull, 0ull, 17874786921033498624ull, 5684341886080801486ull}},
{{0ull, 0ull, 13120111614437097472ull, 7105427357601001858ull}},
{{0ull, 0ull, 7176767481191596032ull, 8881784197001252323ull}},
{{0ull, 0ull, 2179636666531053568ull, 5551115123125782702ull}},
{{0ull, 0ull, 11947917870018592768ull, 6938893903907228377ull}},
{{0ull, 0ull, 1099839282241077248ull, 8673617379884035472ull}},
{{0ull, 0ull, 687399551400673280ull, 5421010862427522170ull}},
{{0ull, 0ull, 10082621476105617408ull, 6776263578034402712ull}},
{{0ull, 0ull, 12603276845132021760ull, 8470329472543003390ull}},
{{0ull, 0ull, 3265362009780125696ull, 5293955920339377119ull}},
{{0ull, 0ull, 17916760567507320832ull, 6617444900424221398ull}},
{{0ull, 0ull, 13172578672529375232ull, 8271806125530276748ull}},
{{0ull, 0ull, 17456233707185635328ull, 5169878828456422967ull}},
{{0ull, 0ull, 17208606115554656256ull, 6462348535570528709ull}},
{{0ull, 0ull, 7675699589161156608ull, 8077935669463160887ull}},
{{0ull, 0ull, 11714841270866804736ull, 5048709793414475554ull}},
{{0ull, 0ull, 5420179551728730112ull, 6310887241768094443ull}},
{{0ull, 0ull, 2163538421233524736ull, 7888609052210118054ull}},
{{0ull, 0ull, 15187269568553116672ull, 4930380657631323783ull}},
{{0ull, 0ull, 14372400942264007936ull, 6162975822039154729ull}},
{{0ull, 0ull, 4130443122547846208ull, 7703719777548943412ull}},
{{0ull, 0ull, 11804898988447179688ull, 4814824860968089632ull}},
{{0ull, 0ull, 14756123735558974610ull, 6018531076210112040ull}},
{{0ull, 9223372036854775808ull, 18445154669448718262ull,
  7523163845262640050ull}},
{{0ull, 1152921504606846976ull, 16139907686832836818ull,
  4701977403289150031ull}},
{{0ull, 10664523917613334528ull, 15563198590113658118ull,
  5877471754111437539ull}},
{{0ull, 4107282860161892352ull, 14842312219214684744ull,
  7346839692639296924ull}},
{{0ull, 5134103575202365440ull, 106146200308804314ull,
  9183549615799121156ull}},
{{0ull, 7820500752928866304ull, 9289713412047778504ull,
  5739718509874450722ull}},
{{0ull, 9775625941161082880ull, 2388769728204947322ull,
  7174648137343063403ull}},
{{0ull, 2996160389596577792ull, 16821020215538347865ull,
  8968310171678829253ull}},
{{0ull, 13401815289566330880ull, 12818980643925161367ull,
  5605193857299268283ull}},
{{0ull, 12140583093530525696ull, 11412039786479063805ull,
  7006492321624085354ull}},
{{0ull, 1340670811630993408ull, 5041677696244053949ull,
  8758115402030106693ull}},
{{0ull, 3143762266483064832ull, 5456891569366227670ull,
  5473822126268816683ull}},
{{0ull, 13153074869958606848ull, 2209428443280396683ull,
  6842277657836020854ull}},
{{0ull, 11829657569020870656ull, 11985157590955271662ull,
  8552847072295026067ull}},
{{0ull, 2781849962210656256ull, 5184880485133350837ull,
  5345529420184391292ull}},
{{0ull, 8088998471190708224ull, 6481100606416688546ull,
  6681911775230489115ull}},
{{0ull, 887876052133609472ull, 3489689739593472779ull,
  8352389719038111394ull}},
{{0ull, 16695823597079363584ull, 6792742105673308390ull,
  5220243574398819621ull}},
{{0ull, 11646407459494428672ull, 13102613650519023392ull,
  6525304467998524526ull}},
{{0ull, 14558009324368035840ull, 7154895026294003432ull,
  8156630584998155658ull}},
{{0ull, 9098755827730022400ull, 9083495409861140049ull,
  5097894115623847286ull}},
{{0ull, 15985130803089915904ull, 2130997225471649253ull,
  6372367644529809108ull}},
{{0ull, 6146355448580231168ull, 2663746531839561567ull,
  7965459555662261385ull}},
{{0ull, 10759001183003726336ull, 13194056628468195739ull,
  4978412222288913365ull}},
{{0ull, 8837065460327270016ull, 2657512730303080962ull,
  6223015277861141707ull}},
{{0ull, 1822959788554311712ull, 17156948968161014915ull,
  7778769097326427133ull}},
{{0ull, 17280250932342302484ull, 13028936114314328273ull,
  4861730685829016958ull}},
{{0ull, 7765255610145714393ull, 7062798106038134534ull,
  6077163357286271198ull}},
{{4611686018427387904ull, 483197475827367183ull,
  18051869669402443976ull, 7596454196607838997ull}},
{{9799832789158199296ull, 301998422392104489ull,
  13588261552590221437ull, 4747783872879899373ull}},
{{16861477004875137024ull, 4989184046417518515ull,
  3150268885455613084ull, 5934729841099874217ull}},
{{16465160237666533376ull, 6236480058021898144ull,
  8549522125246904259ull, 7418412301374842771ull}},
{{10290725148541583360ull, 1591957027049992388ull,
  3037608319065621210ull, 4636507688359276732ull}},
{{12863406435676979200ull, 11213318320667266293ull,
  3797010398832026512ull, 5795634610449095915ull}},
{{2244199989314060288ull, 14016647900834082867ull,
  134576980112645236ull, 7244543263061369894ull}},
{{16640308041924739072ull, 17520809876042603583ull,
  9391593261995582353ull, 9055679078826712367ull}},
{{17317721553844043776ull, 4032977144885545383ull,
  12787274816388320827ull, 5659799424266695229ull}},
{{17035465923877666816ull, 429535412679543825ull,
  2149035465203237322ull, 7074749280333369037ull}},
{{7459274349564919808ull, 9760291302704205590ull,
  7297980349931434556ull, 8843436600416711296ull}},
{{50360450050686976ull, 15323554101044904302ull, 4561237718707146597ull,
  5527147875260444560ull}},
{{9286322599418134528ull, 5319384571023966665ull,
  5701547148383933247ull, 6908934844075555700ull}},
{{16219589267700056064ull, 2037544695352570427ull,
  7126933935479916559ull, 8636168555094444625ull}},
{{7831400283098841088ull, 8190994462236438373ull,
  15983548755743417609ull, 5397605346934027890ull}},
{{14400936372300939264ull, 14850429096222935870ull,
  10756063907824496203ull, 6747006683667534863ull}},
{{8777798428521398272ull, 13951350351851281934ull,
  8833393866353232350ull, 8433758354584418579ull}},
{{874437999398486016ull, 4107907951479663305ull, 3215028157257076267ull,
  5271098971615261612ull}},
{{5704733517675495424ull, 523198920922191227ull, 4018785196571345334ull,
  6588873714519077015ull}},
{{2519230878666981376ull, 9877370688007514842ull, 411795477286793763ull,
  8236092143148846269ull}},
{{6186205317594251264ull, 3867513670791002824ull,
  2563215182517940054ull, 5147557589468028918ull}},
{{7732756646992814080ull, 14057764125343529338ull,
  12427391015002200875ull, 6434446986835036147ull}},
{{442573771886241792ull, 12960519138252023769ull,
  10922552750325363190ull, 8043058733543795184ull}},
{{11805823653497370880ull, 3488638442980126951ull,
  6826595468953351994ull, 5026911708464871990ull}},
{{10145593548444325696ull, 13584170090579934497ull,
  17756616373046465800ull, 6283639635581089987ull}},
{{17293677953982795024ull, 16980212613224918121ull,
  17584084447880694346ull, 7854549544476362484ull}},
{{3891019693598165034ull, 15224318901692961730ull,
  1766680743070658158ull, 4909093465297726553ull}},
{{14087146653852482101ull, 9807026590261426354ull,
  6820036947265710602ull, 6136366831622158191ull}},
{{8385561280460826818ull, 3035411200972007135ull,
  3913360165654750349ull, 7670458539527697739ull}},
{{12158504827929098618ull, 4202975009821198411ull,
  140007094320525016ull, 4794036587204811087ull}},
{{10586445016483985368ull, 5253718762276498014ull,
  14010066923182819982ull, 5992545734006013858ull}},
{{4009684233750205902ull, 15790520489700398326ull,
  8289211617123749169ull, 7490682167507517323ull}},
{{16341110701376042401ull, 2951546278421667097ull,
  2874914251488649279ull, 4681676354692198327ull}},
{{6591330321437889289ull, 17524490903309247584ull,
  17428700869642975310ull, 5852095443365247908ull}},
{{8239162901797361611ull, 12682241592281783672ull,
  3339132013344167522ull, 7315119304206559886ull}},
{{10298953627246702013ull, 6629429953497453782ull,
  13397287053534985211ull, 9143899130258199857ull}},
{{1825159998601800855ull, 1837550711722214662ull,
  1455775380818283901ull, 5714936956411374911ull}},
{{11504822035107026876ull, 6908624408080156231ull,
  15654777281305018588ull, 7143671195514218638ull}},
{{9769341525456395691ull, 8635780510100195289ull,
  10345099564776497427ull, 8929588994392773298ull}},
{{17635053499478717067ull, 3091519809598928103ull,
  11077373246412698796ull, 5580993121495483311ull}},
{{17432130855921008430ull, 3864399761998660129ull,
  9235030539588485591ull, 6976241401869354139ull}},
{{7955105514619096825ull, 218813684070937258ull, 6932102156058219085ull,
  8720301752336692674ull}},
{{9583626965064323420ull, 2442601561758029738ull,
  8944249865963774832ull, 5450188595210432921ull}},
{{2756161669475628467ull, 3053251952197537173ull,
  15791998350882106444ull, 6812735744013041151ull}},
{{8056888105271923487ull, 3816564940246921466ull,
  15128311920175245151ull, 8515919680016301439ull}},
{{9647241084222340084ull, 9302882115295407772ull,
  16372723977750610075ull, 5322449800010188399ull}},
{{12059051355277925104ull, 7016916625691871811ull,
  15854218953760874690ull, 6653062250012735499ull}},
{{10462128175670018476ull, 17994517818969615572ull,
  15206087673773705458ull, 8316327812515919374ull}},
{{15762202146648537356ull, 15858259655283397636ull,
  4892118777681178007ull, 5197704882822449609ull}},
{{1256008609601120079ull, 15211138550676859142ull,
  10726834490528860413ull, 6497131103528062011ull}},
{{10793382798856175906ull, 5178865133063910215ull,
  8796857094733687613ull, 8121413879410077514ull}},
{{13663393276926191798ull, 5542633717378637836ull,
  10109721702635942662ull, 5075883674631298446ull}},
{{17079241596157739747ull, 16151664183578073103ull,
  3413780091440152519ull, 6344854593289123058ull}},
{{16737365976769786780ull, 15577894211045203475ull,
  13490597151154966457ull, 7931068241611403822ull}},
{{8155010726267422785ull, 2818654854262170316ull,
  3819937201044466132ull, 4956917651007127389ull}},
{{10193763407834278482ull, 3523318567827712895ull,
  9386607519732970569ull, 6196147063758909236ull}},
{{8130518241365460198ull, 9015834228212029023ull,
  11733259399666213211ull, 7745183829698636545ull}},
{{11999102928494494480ull, 3329053383418824187ull,
  415758097150301401ull, 4840739893561647841ull}},
{{10387192642190730196ull, 8773002747700918138ull,
  5131383639865264655ull, 6050924866952059801ull}},
{{3760618765883636937ull, 6354567416198759769ull,
  11025915568258968723ull, 7563656083690074751ull}},
{{13879601774745742846ull, 1665761625910530903ull,
  13808726257802937308ull, 4727285052306296719ull}},
{{12737816200004790653ull, 2082202032388163629ull,
  12649221803826283731ull, 5909106315382870899ull}},
{{2087212194723824604ull, 16437810595767368249ull,
  11199841236355466759ull, 7386382894228588624ull}},
{{12833722667770860138ull, 17191160649995687011ull,
  6999900772722166724ull, 4616489308892867890ull}},
{{11430467316286187268ull, 3042206738785057148ull,
  17973248002757484214ull, 5770611636116084862ull}},
{{14288084145357734085ull, 13026130460336097243ull,
  13243187966592079459ull, 7213264545145106078ull}},
{{13248419163269779702ull, 11670977056992733650ull,
  7330612921385323516ull, 9016580681431382598ull}},
{{12891947995471000218ull, 16517732697475234339ull,
  18416691131147990909ull, 5635362925894614123ull}},
{{11503248975911362368ull, 6812107816561879212ull,
  18409177895507600733ull, 7044203657368267654ull}},
{{14379061219889202960ull, 13126820789129736919ull,
  13788100332529725108ull, 8805254571710334568ull}},
{{15904442290071833706ull, 17427635030060861382ull,
  8617562707831078192ull, 5503284107318959105ull}},
{{10657180825735016325ull, 3337799713866525112ull,
  15383639403216235645ull, 6879105134148698881ull}},
{{13321476032168770406ull, 8783935660760544294ull,
  5394491198738130844ull, 8598881417685873602ull}},
{{3714236501678093600ull, 14713331824830115992ull,
  7983243017638719681ull, 5374300886053671001ull}},
{{4642795627097617000ull, 4556606725755481278ull,
  14590739790475787506ull, 6717876107567088751ull}},
{{15026866570726797057ull, 14919130444049127405ull,
  13626738719667346478ull, 8397345134458860939ull}},
{{11697634615917942113ull, 4712770509103316724ull,
  6210868690578397597ull, 5248340709036788087ull}},
{{14622043269897427641ull, 10502649154806533809ull,
  3151899844795609092ull, 6560425886295985109ull}},
{{4442496032089620839ull, 13128311443508167262ull,
  8551560824421899269ull, 8200532357869981386ull}},
{{16611618075338176737ull, 10511037661406298490ull,
  9956411533691074947ull, 5125332723668738366ull}},
{{11541150557317945113ull, 8527111058330485209ull,
  3222142380259067876ull, 6406665904585922958ull}},
{{591380141365267679ull, 10658888822913106512ull,
  13251050012178610653ull, 8008332380732403697ull}},
{{369612588353292299ull, 8967648523534385522ull, 1364377229970549802ull,
  5005207737957752311ull}},
{{9685387772296391182ull, 1986188617563206094ull,
  15540529592745350965ull, 6256509672447190388ull}},
{{2883362678515713170ull, 7094421790381395522ull, 978917917222137090ull,
  7820637090558987986ull}},
{{6413787692499708635ull, 9045699637415760105ull,
  5223509716691223585ull, 4887898181599367491ull}},
{{12628920634052023698ull, 15918810565197088035ull,
  1917701127436641577ull, 6109872726999209364ull}},
{{11174464774137641718ull, 6063455151214196332ull,
  2397126409295801972ull, 7637340908749011705ull}},
{{16207412520690801882ull, 13013031506363648515ull,
  13027419051878345992ull, 4773338067968132315ull}},
{{15647579632436114448ull, 16266289382954560644ull,
  11672587796420544586ull, 5966672584960165394ull}},
{{1112730466835591444ull, 11109489691838424998ull,
  5367362708670904925ull, 7458340731200206743ull}},
{{14530514597054408365ull, 9249274066612709575ull,
  10272130720560397434ull, 4661462957000129214ull}},
{{13551457227890622552ull, 2338220546411111161ull,
  3616791363845720985ull, 5826828696250161518ull}},
{{3104263479581114478ull, 7534461701441276856ull,
  13744361241661927039ull, 7283535870312701897ull}},
{{3880329349476393097ull, 4806391108374208166ull,
  3345393496795245087ull, 9104419837890877372ull}},
{{16260263898704909398ull, 9921523470374961959ull,
  11314242972351803987ull, 5690262398681798357ull}},
{{15713643854953748843ull, 7790218319541314545ull,
  307745660157591272ull, 7112827998352247947ull}},
{{5806996763410022342ull, 9737772899426643182ull,
  14219740130479152802ull, 8891034997940309933ull}},
{{17464431032413427676ull, 10697794080569039892ull,
  11193180590763164453ull, 5556896873712693708ull}},
{{3383794716807232979ull, 17983928619138687770ull,
  13991475738453955566ull, 6946121092140867135ull}},
{{13453115432863817032ull, 13256538737068583904ull,
  12877658654640056554ull, 8682651365176083919ull}},
{{8408197145539885645ull, 12897022729095252844ull,
  14966065686791117202ull, 5426657103235052449ull}},
{{10510246431924857056ull, 6897906374514290247ull,
  4872524053206732791ull, 6783321379043815562ull}},
{{8526122021478683416ull, 4010696949715474905ull,
  15314027103363191797ull, 8479151723804769452ull}},
{{16858041309492646895ull, 4812528602785865767ull,
  347894902747219065ull, 5299469827377980908ull}},
{{16460865618438420715ull, 10627346771909720113ull,
  434868628434023831ull, 6624337284222476135ull}},
{{6741023967765862181ull, 8672497446459762238ull,
  14378643840824693501ull, 8280421605278095168ull}},
{{18048198035135827576ull, 7726153913251045350ull,
  8986652400515433438ull, 5175263503298809480ull}},
{{13336875507065008661ull, 434320354709030880ull,
  11233315500644291798ull, 6469079379123511850ull}},
{{16671094383831260826ull, 9766272480241064408ull,
  4818272338950588939ull, 8086349223904389813ull}},
{{10419433989894538017ull, 3798077290936971303ull,
  5317263221057812039ull, 5053968264940243633ull}},
{{8412606468940784617ull, 135910595243826225ull,
  11258265044749652953ull, 6317460331175304541ull}},
{{15127444104603368675ull, 4781574262482170685ull,
  237773250654902479ull, 7896825413969130677ull}},
{{11760495574590799374ull, 9906012941692438534ull,
  2454451290873008001ull, 4935515883730706673ull}},
{{5477247431383723409ull, 16994202195542936072ull,
  7679750132018647905ull, 6169394854663383341ull}},
{{6846559289229654262ull, 7407694689146506378ull,
  14211373683450697786ull, 7711743568329229176ull}},
{{8890785574195921818ull, 9241495199143954390ull,
  8882108552156686116ull, 4819839730205768235ull}},
{{1890109930890126464ull, 11551868998929942988ull,
  6490949671768469741ull, 6024799662757210294ull}},
{{2362637413612658080ull, 604778193380265023ull,
  17337059126565362985ull, 7530999578446512867ull}},
{{8394177411148993156ull, 11907201416931135399ull,
  8529818944889657913ull, 4706874736529070542ull}},
{{5881035745508853541ull, 1048943715881755537ull,
  1438901644257296584ull, 5883593420661338178ull}},
{{11962980700313454830ull, 1311179644852194421ull,
  11021999092176396538ull, 7354491775826672722ull}},
{{1118667820109654825ull, 10862346592920018835ull,
  4554126828365719864ull, 9193114719783340903ull}},
{{16840068452064391930ull, 6788966620575011771ull,
  9763858295369656771ull, 5745696699864588064ull}},
{{16438399546653102009ull, 3874522257291376810ull,
  12204822869212070964ull, 7182120874830735080ull}},
{{11324627396461601703ull, 4843152821614221013ull,
  15256028586515088705ull, 8977651093538418850ull}},
{{9383735132002195016ull, 14556185559577357893ull,
  14146703884999318344ull, 5611031933461511781ull}},
{{16341354933430131674ull, 18195231949471697366ull,
  3848321800966984218ull, 7013789916826889727ull}},
{{11203321629932888785ull, 13520667899984845900ull,
  198716232781342369ull, 8767237396033612159ull}},
{{16225448055562831299ull, 1532888409849446831ull,
  7041726673129420837ull, 5479523372521007599ull}},
{{15670124051026151219ull, 6527796530739196443ull,
  4190472322984388142ull, 6849404215651259499ull}},
{{14975969045355301120ull, 17383117700278771362ull,
  626404385303097273ull, 8561755269564074374ull}},
{{13971666671774451104ull, 3946919535033150245ull,
  14226560796096599508ull, 5351097043477546483ull}},
{{3629525284435900168ull, 4933649418791437807ull,
  13171514976693361481ull, 6688871304346933104ull}},
{{18371964660827038922ull, 10778747791916685162ull,
  16464393720866701851ull, 8361089130433666380ull}},
{{16094163931444287230ull, 4430874360734234274ull,
  1066874038686912849ull, 5225680706521041488ull}},
{{10894332877450583230ull, 10150278969345180747ull,
  1333592548358641061ull, 6532100883151301860ull}},
{{9006230078385841133ull, 17299534730108863838ull,
  1666990685448301326ull, 8165126103939127325ull}},
{{1017207780563762804ull, 6200523187890651995ull,
  3347712187618882281ull, 5103203814961954578ull}},
{{15106567780986867217ull, 12362340003290702897ull,
  13408012271378378659ull, 6379004768702443222ull}},
{{5048151670951420310ull, 10841238985685990718ull,
  7536643302368197516ull, 7973755960878054028ull}},
{{16990152849626801406ull, 15999146402908520006ull,
  13933774100834899255ull, 4983597475548783767ull}},
{{12014319025178725949ull, 15387246985208262104ull,
  12805531607616236165ull, 6229496844435979709ull}},
{{15017898781473407436ull, 5399000676228163918ull,
  2171856454238131495ull, 7786871055544974637ull}},
{{4774500719993491744ull, 10291904450283684305ull,
  3663253293112526136ull, 4866794409715609148ull}},
{{10579811918419252584ull, 12864880562854605381ull,
  4579066616390657670ull, 6083493012144511435ull}},
{{17836450916451453633ull, 6857728666713480918ull,
  1112147252060934184ull, 7604366265180639294ull}},
{{6536095804354770617ull, 4286080416695925574ull,
  14530150087820247577ull, 4752728915737899558ull}},
{{17393491792298239079ull, 9969286539297294871ull,
  8939315572920533663ull, 5940911144672374448ull}},
{{17130178721945410945ull, 7849922155694230685ull,
  11174144466150667079ull, 7426138930840468060ull}},
{{13012204710429575793ull, 11823730374949976034ull,
  16207212328198942732ull, 4641336831775292537ull}},
{{7041883851182193933ull, 14779662968687470043ull,
  6423957354966514703ull, 5801671039719115672ull}},
{{4190668795550354512ull, 13862892692431949650ull,
  8029946693708143379ull, 7252088799648894590ull}},
{{14461708031292718948ull, 12716929847112549158ull,
  814061330280403416ull, 9065110999561118238ull}},
{{4426881501130561438ull, 7948081154445343224ull,
  14343846386707415847ull, 5665694374725698898ull}},
{{5533601876413201798ull, 5323415424629291126ull,
  8706435946529494001ull, 7082117968407123623ull}},
{{16140374382371278055ull, 11265955299214001811ull,
  6271358914734479597ull, 8852647460508904529ull}},
{{7781890979768354833ull, 9347065071222445084ull,
  15448814367777519508ull, 5532904662818065330ull}},
{{9727363724710443541ull, 11683831339028056355ull,
  10087645922867123577ull, 6916130828522581663ull}},
{{7547518637460666522ull, 769731118502906732ull, 7997871385156516568ull,
  8645163535653227079ull}},
{{13940571185267692384ull, 481081949064316707ull,
  11916198643363904711ull, 5403227209783266924ull}},
{{12814027963157227576ull, 14436410491612559596ull,
  14895248304204880888ull, 6754034012229083655ull}},
{{16017534953946534470ull, 18045513114515699495ull,
  14007374361828713206ull, 8442542515286354569ull}},
{{16928488373857665900ull, 6666759678144924280ull,
  1837079948501863898ull, 5276589072053971606ull}},
{{2713866393612530759ull, 17556821634535931159ull,
  11519721972482105680ull, 6595736340067464507ull}},
{{17227391047297827161ull, 3499282969460362332ull,
  9787966447175244197ull, 8244670425084330634ull}},
{{1543747367706366168ull, 4492894865126420410ull,
  10729165047911915527ull, 5152919015677706646ull}},
{{11153056246487733517ull, 1004432562980637608ull,
  4188084273035118601ull, 6441148769597133308ull}},
{{13941320308109666897ull, 5867226722153184914ull,
  5235105341293898251ull, 8051435961996416635ull}},
{{13325011210995929715ull, 1361173692132046619ull,
  966097829094992455ull, 5032147476247760397ull}},
{{12044577995317524239ull, 15536525170447221986ull,
  5819308304796128472ull, 6290184345309700496ull}},
{{5832350457292129491ull, 973912389349475867ull, 7274135380995160591ull,
  7862730431637125620ull}},
{{1339376026593886980ull, 7526224270984504273ull,
  13769706649976751177ull, 4914206519773203512ull}},
{{6285906051669746629ull, 14019466357158018245ull,
  17212133312470938971ull, 6142758149716504390ull}},
{{12469068583014571190ull, 12912646928020134902ull,
  12291794603733897906ull, 7678447687145630488ull}},
{{3181481845956719090ull, 12682090348439972218ull,
  7682371627333686191ull, 4799029804466019055ull}},
{{13200224344300674670ull, 11240926917122577368ull,
  4991278515739719835ull, 5998787255582523819ull}},
{{16500280430375843337ull, 9439472627975833806ull,
  1627412126247261890ull, 7498484069478154774ull}},
{{5700989250557514182ull, 10511356410912284033ull,
  14852190634186702393ull, 4686552543423846733ull}},
{{11737922581624280632ull, 17750881532067742945ull,
  4730180237451214279ull, 5858190679279808417ull}},
{{837345171748187077ull, 17576915896657290778ull,
  10524411315241405753ull, 7322738349099760521ull}},
{{10270053501540009654ull, 8136086815539449760ull,
  17767200162479145096ull, 9153422936374700651ull}},
{{6418783438462506034ull, 5085054259712156100ull,
  8798657092335771733ull, 5720889335234187907ull}},
{{8023479298078132543ull, 10968003843067583029ull,
  6386635346992326762ull, 7151111669042734884ull}},
{{14641035141025053582ull, 4486632766979702978ull,
  7983294183740408453ull, 8938889586303418605ull}},
{{13762332981568046393ull, 5109988488576008313ull,
  7295401874051449235ull, 5586805991439636628ull}},
{{3367858171677894279ull, 1775799592292622488ull,
  9119252342564311544ull, 6983507489299545785ull}},
{{4209822714597367849ull, 2219749490365778110ull,
  16010751446632777334ull, 8729384361624432231ull}},
{{16466197251905518618ull, 15222401486760775030ull,
  16924248681786567689ull, 5455865226015270144ull}},
{{11359374528027122464ull, 5192943803168805076ull,
  2708566778523657996ull, 6819831532519087681ull}},
{{14199218160033903080ull, 6491179753961006345ull,
  7997394491581960399ull, 8524789415648859601ull}},
{{1956982322380107569ull, 10974516373866710822ull,
  16527586603307195009ull, 5327993384780537250ull}},
{{11669599939829910269ull, 18329831485760776431ull,
  11436111217279217953ull, 6659991730975671563ull}},
{{9975313906359999932ull, 9077231301918806827ull,
  9683453003171634538ull, 8324989663719589454ull}},
{{3928728182261306006ull, 10284955582126642171ull,
  1440472108554883682ull, 5203118539824743409ull}},
{{299224209399244603ull, 3632822440803526906ull, 6412276154120992507ull,
  6503898174780929261ull}},
{{9597402298603831562ull, 18376086106286572344ull,
  12627031211078628537ull, 8129872718476161576ull}},
{{5998376436627394726ull, 4567524788788025859ull,
  7891894506924142836ull, 5081170449047600985ull}},
{{2886284527356855504ull, 5709405985985032324ull,
  14476554152082566449ull, 6351463061309501231ull}},
{{3607855659196069380ull, 11748443500908678309ull,
  13484006671675820157ull, 7939328826636876539ull}},
{{4560752796211237315ull, 9648620197281617895ull,
  6121661160583693646ull, 4962080516648047837ull}},
{{1089254976836658739ull, 2837403209747246561ull,
  12263762469157004962ull, 6202600645810059796ull}},
{{5973254739473211328ull, 12770126049038834009ull,
  15329703086446256202ull, 7753250807262574745ull}},
{{15262499258239226840ull, 12593014799076659159ull,
  2663535401387828270ull, 4845781754539109216ull}},
{{14466438054371645646ull, 6517896461991048141ull,
  3329419251734785338ull, 6057227193173886520ull}},
{{4247989512682393345ull, 17370742614343585985ull,
  4161774064668481672ull, 7571533991467358150ull}},
{{14184208491494965601ull, 10856714133964741240ull,
  16436166845699964757ull, 4732208744667098843ull}},
{{17730260614368707001ull, 18182578685883314454ull,
  15933522538697568042ull, 5915260930833873554ull}},
{{12939453731106107943ull, 13504851320499367260ull,
  10693531136517184245ull, 7394076163542341943ull}},
{{17310530618796093273ull, 10746375084525798489ull,
  13600985987964322009ull, 4621297602213963714ull}},
{{7803105218212952879ull, 18044654874084636016ull,
  7777860448100626703ull, 5776622002767454643ull}},
{{9753881522766191098ull, 17944132574178407116ull,
  5110639541698395475ull, 7220777503459318304ull}},
{{12192351903457738873ull, 17818479699295620991ull,
  6388299427122994344ull, 9025971879324147880ull}},
{{14537748967302168652ull, 11136549812059763119ull,
  3992687141951871465ull, 5641232424577592425ull}},
{{13560500190700322911ull, 85629209792540187ull, 9602544945867227236ull,
  7051540530721990531ull}},
{{12338939219948015734ull, 107036512240675234ull,
  7391495163906646141ull, 8814425663402488164ull}},
{{12323523030894897738ull, 2372740829364115973ull,
  13843056514296429646ull, 5509016039626555102ull}},
{{1569345733336458460ull, 12189298073559920775ull,
  8080448606015761249ull, 6886270049533193878ull}},
{{15796740221952736787ull, 1401564536667737256ull,
  877188720664925754ull, 8607837561916492348ull}},
{{9872962638720460492ull, 5487663853844723689ull,
  9771614987270354404ull, 5379898476197807717ull}},
{{16952889316827963519ull, 6859579817305904611ull,
  16826204752515330909ull, 6724873095247259646ull}},
{{16579425627607566495ull, 13186160790059768668ull,
  11809383903789387828ull, 8406091369059074558ull}},
{{1138768980399953251ull, 17464722530642131226ull,
  2769178921440979488ull, 5253807105661921599ull}},
{{10646833262354717372ull, 3384159089593112416ull,
  17296531707083388073ull, 6567258882077401998ull}},
{{13308541577943396715ull, 8841884880418778424ull,
  12397292596999459283ull, 8209073602596752498ull}},
{{8317838486214622947ull, 3220335041048042563ull,
  12359993891552049956ull, 5130671001622970311ull}},
{{5785612089340890780ull, 4025418801310053204ull,
  10838306346012674541ull, 6413338752028712889ull}}
};

static const UINT256 multipliers2_binary64[] =
  { {{918777112239470733ull, 5138421092069233273ull,
      15049182825743144437ull, 3877256883183270350ull}},
{{12103450741218138969ull, 5517356191756964747ull,
  4794053247662077369ull, 2423285551989543969ull}},
{{10517627408095285807ull, 11508381258123593838ull,
  10604252578004984615ull, 3029106939986929961ull}},
{{3923662223264331450ull, 9773790554227104394ull,
  17867001740933618673ull, 3786383674983662451ull}},
{{7063974907967595060ull, 17637834142460410006ull,
  8861033078869817718ull, 2366489796864789032ull}},
{{18053340671814269633ull, 12823920641220736699ull,
  11076291348587272148ull, 2958112246080986290ull}},
{{17954989821340449138ull, 16029900801525920874ull,
  4621992148879314377ull, 3697640307601232863ull}},
{{15833554656765168615ull, 3101158973312618690ull,
  9806274120690653342ull, 2311025192250770539ull}},
{{10568571284101684961ull, 13099820753495549171ull,
  7646156632435928773ull, 2888781490313463174ull}},
{{8599028086699718297ull, 2539717886587272752ull, 334323753690135159ull,
  3610976862891828968ull}},
{{10748785108374647871ull, 17009705413516254652ull,
  417904692112668948ull, 4513721078614786210ull}},
{{15941362729588930728ull, 1407693846592883349ull,
  4872876450997805997ull, 2821075674134241381ull}},
{{6091645356703999697ull, 6371303326668492091ull,
  10702781582174645400ull, 3526344592667801726ull}},
{{3002870677452611718ull, 7964129158335615114ull,
  4155104940863530942ull, 4407930740834752158ull}},
{{6488480191835270228ull, 365894705532371542ull,
  16431998643321870551ull, 2754956713021720098ull}},
{{17333972276648863593ull, 14292426437197628139ull,
  11316626267297562380ull, 3443695891277150123ull}},
{{17055779327383691587ull, 17865533046497035174ull,
  9534096815694565071ull, 4304619864096437654ull}},
{{6048176061187419338ull, 18083487181701728840ull,
  1347124491381715265ull, 2690387415060273534ull}},
{{7560220076484274172ull, 8769300921844997338ull,
  10907277651081919890ull, 3362984268825341917ull}},
{{226903058750566907ull, 1738254115451470865ull,
  18245783082279787767ull, 4203730336031677396ull}},
{{11671029457787574077ull, 8003937849798251146ull,
  2180242389570091546ull, 2627331460019798373ull}},
{{5365414785379691788ull, 781550275393038125ull, 7336989005390002337ull,
  3284164325024747966ull}},
{{11318454500152002639ull, 5588623862668685560ull,
  18394608293592278729ull, 4105205406280934957ull}},
{{7074034062595001650ull, 15022104960236398235ull,
  13802473192708868157ull, 2565753378925584348ull}},
{{4230856559816364158ull, 4942573145013334082ull,
  17253091490886085197ull, 3207191723656980435ull}},
{{14511942736625231005ull, 10789902449694055506ull,
  16954678345180218592ull, 4008989654571225544ull}},
{{13681650228818157283ull, 6743689031058784691ull,
  10596673965737636620ull, 2505618534107015965ull}},
{{12490376767595308699ull, 8429611288823480864ull,
  17857528475599433679ull, 3132023167633769956ull}},
{{15612970959494135874ull, 5925328092601963176ull,
  3875166520789740483ull, 3915028959542212446ull}},
{{9758106849683834921ull, 1397487048662533033ull,
  16257037130775751514ull, 2446893099713882778ull}},
{{16809319580532181555ull, 10970230847682942099ull,
  11097924376614913584ull, 3058616374642353473ull}},
{{16399963457237839040ull, 13712788559603677624ull,
  37347415486478268ull, 3823270468302941842ull}},
{{10249977160773649400ull, 17793864886607074323ull,
  4635028153106436821ull, 2389544042689338651ull}},
{{8200785432539673846ull, 8407273052976679192ull,
  1182099172955658123ull, 2986930053361673314ull}},
{{10250981790674592308ull, 5897405297793461086ull,
  10700996003049348462ull, 3733662566702091642ull}},
{{1795177600744232288ull, 17520936366403076891ull,
  11299808520333230692ull, 2333539104188807276ull}},
{{16079030056212454072ull, 3454426384294294497ull,
  14124760650416538366ull, 2916923880236009095ull}},
{{6263729514983403878ull, 13541405017222643930ull,
  13044264794593285053ull, 3646154850295011369ull}},
{{17053033930584030656ull, 3091698216246141200ull,
  2470272937959442605ull, 4557693562868764212ull}},
{{10658146206615019160ull, 4238154394367532202ull,
  10767292623079427436ull, 2848558476792977632ull}},
{{4099310721413998142ull, 5297692992959415253ull,
  13459115778849284295ull, 3560698095991222040ull}},
{{9735824420194885581ull, 2010430222771881162ull,
  16823894723561605369ull, 4450872619989027550ull}},
{{10696576281049191393ull, 12785733935300895486ull,
  5903248183798615451ull, 2781795387493142219ull}},
{{4147348314456713433ull, 11370481400698731454ull,
  2767374211320881410ull, 3477244234366427774ull}},
{{14407557429925667599ull, 4989729714018638509ull,
  12682589801005877571ull, 4346555292958034717ull}},
{{11310566402917236201ull, 812738062047955116ull,
  10232461634842367434ull, 2716597058098771698ull}},
{{14138208003646545252ull, 10239294614414719703ull,
  3567205006698183484ull, 3395746322623464623ull}},
{{13061073986130793660ull, 12799118268018399629ull,
  18294064313654893067ull, 4244682903279330778ull}},
{{10469014250545439990ull, 5693605908297805816ull,
  16045476214461696071ull, 2652926814549581736ull}},
{{13086267813181799987ull, 2505321366944869366ull,
  1610101194367568473ull, 3316158518186977171ull}},
{{7134462729622474176ull, 7743337727108474612ull,
  15847684548241624303ull, 4145198147733721463ull}},
{{13682411242868822168ull, 11757115107083878488ull,
  16822331870292097045ull, 2590748842333575914ull}},
{{17103014053586027710ull, 861335828572684398ull,
  11804542801010345499ull, 3238436052916969893ull}},
{{12155395530127758829ull, 14911727840998019210ull,
  920620445980768161ull, 4048045066146212367ull}},
{{12208808224757237173ull, 2402300872982680150ull,
  7492916806379061957ull, 2530028166341382729ull}},
{{6037638244091770658ull, 7614562109655738092ull,
  13977832026401215350ull, 3162535207926728411ull}},
{{7547047805114713322ull, 294830600214896807ull,
  12860604014574131284ull, 3953169009908410514ull}},
{{11634433905837777682ull, 9407641161989086312ull,
  12649563527536219956ull, 2470730631192756571ull}},
{{14543042382297222103ull, 11759551452486357890ull,
  11200268390992887041ull, 3088413288990945714ull}},
{{8955430941016751820ull, 864381260325783651ull, 4776963451886332994ull,
  3860516611238682143ull}},
{{3291301328921775936ull, 5151924306131002686ull,
  9903131185070039977ull, 2412822882024176339ull}},
{{13337498698006995728ull, 11051591401091141261ull,
  7767227962910162067ull, 3016028602530220424ull}},
{{2836815317226580948ull, 9202803232936538673ull,
  9709034953637702584ull, 3770035753162775530ull}},
{{13302224619335082852ull, 5751752020585336670ull,
  10679832864450952019ull, 2356272345726734706ull}},
{{7404408737314077757ull, 2578004007304282934ull,
  4126419043708914216ull, 2945340432158418383ull}},
{{32138884787821389ull, 3222505009130353668ull, 546337786208754866ull,
  3681675540198022979ull}},
{{40173605984776736ull, 13251503298267717893ull,
  14517980288043107294ull, 4602094425247528723ull}},
{{2330951512954179412ull, 3670503542989935779ull,
  6767894670813248107ull, 2876309015779705452ull}},
{{16748747446474887977ull, 18423187484019583435ull,
  8459868338516560133ull, 3595386269724631815ull}},
{{16324248289666222067ull, 9193926299742315582ull,
  5963149404718312263ull, 4494232837155789769ull}},
{{5590969162614000888ull, 12663732964980029095ull,
  15256183424017414924ull, 2808895523222368605ull}},
{{2377025434840113206ull, 15829666206225036369ull,
  5235171224739604943ull, 3511119404027960757ull}},
{{7582967811977529411ull, 15175396739353907557ull,
  11155650049351894083ull, 4388899255034950946ull}},
{{7045197891699649834ull, 7178779952882498271ull,
  11583967299272321706ull, 2743062034396844341ull}},
{{4194811346197174389ull, 18196846977957898647ull,
  644901068808238420ull, 3428827542996055427ull}},
{{631828164319080082ull, 4299314648737821693ull,
  14641184391292461738ull, 4286034428745069283ull}},
{{2700735611913119003ull, 7298757673888526462ull,
  6844897235344094634ull, 2678771517965668302ull}},
{{12599291551746174562ull, 18346819129215433885ull,
  17779493581034894100ull, 3348464397457085377ull}},
{{1914056384400554490ull, 4486779837809740741ull,
  8389308921011453914ull, 4185580496821356722ull}},
{{3502128249464040509ull, 7415923417058475867ull,
  9855004094059546600ull, 2615987810513347951ull}},
{{18212718367112214348ull, 9269904271323094833ull,
  7707069099147045346ull, 3269984763141684939ull}},
{{8930839903608104222ull, 2364008302299092734ull,
  5022150355506418779ull, 4087480953927106174ull}},
{{970088921327677235ull, 17618406253432790623ull,
  16973902027473675448ull, 2554675596204441358ull}},
{{15047669206941760256ull, 3576263743081436662ull,
  11994005497487318503ull, 3193344495255551698ull}},
{{9586214471822424512ull, 18305387734133959540ull,
  5769134835004372320ull, 3991680619069439623ull}},
{{15214756081743791128ull, 11440867333833724712ull,
  10523238299518814556ull, 2494800386918399764ull}},
{{571701028470187294ull, 14301084167292155891ull,
  13154047874398518195ull, 3118500483647999705ull}},
{{14549684340869897829ull, 13264669190687806959ull,
  2607501787715984032ull, 3898125604559999632ull}},
{{16011081740684767999ull, 8290418244179879349ull,
  1629688617322490020ull, 2436328502849999770ull}},
{{6178794120573796287ull, 10363022805224849187ull,
  11260482808507888333ull, 3045410628562499712ull}},
{{3111806632289857455ull, 17565464524958449388ull,
  14075603510634860416ull, 3806763285703124640ull}},
{{11168251182035936718ull, 10978415328099030867ull,
  8797252194146787760ull, 2379227053564452900ull}},
{{9348627959117532993ull, 13723019160123788584ull,
  10996565242683484700ull, 2974033816955566125ull}},
{{11685784948896916241ull, 17153773950154735730ull,
  18357392571781743779ull, 3717542271194457656ull}},
{{11915301611487960555ull, 8415265709633015879ull,
  11473370357363589862ull, 2323463919496536035ull}},
{{10282440995932562789ull, 1295710100186494041ull,
  9730026928277099424ull, 2904329899370670044ull}},
{{17464737263343091390ull, 1619637625233117551ull,
  12162533660346374280ull, 3630412374213337555ull}},
{{17219235560751476334ull, 2024547031541396939ull,
  10591481057005579946ull, 4538015467766671944ull}},
{{8456179216255978757ull, 5877027913140760991ull,
  6619675660628487466ull, 2836259667354169965ull}},
{{5958538001892585542ull, 16569656928280727047ull,
  12886280594212997236ull, 3545324584192712456ull}},
{{2836486483938344023ull, 2265327086641357193ull,
  16107850742766246546ull, 4431655730240890570ull}},
{{13302019098529934775ull, 6027515447578236149ull,
  14679092732656291995ull, 2769784831400556606ull}},
{{2792465817880254756ull, 2922708291045407283ull,
  9125493878965589186ull, 3462231039250695758ull}},
{{17325640327632482157ull, 12876757400661534911ull,
  2183495311852210674ull, 4327788799063369698ull}},
{{17746054232411383205ull, 12659659393840847223ull,
  5976370588335019575ull, 2704867999414606061ull}},
{{17570881772086841102ull, 11212888223873671125ull,
  12082149253846162373ull, 3381084999268257576ull}},
{{8128544159826387665ull, 181052224559925195ull,
  15102686567307702967ull, 4226356249085321970ull}},
{{2774497090677798339ull, 7030686667991035103ull,
  14050865122994702258ull, 2641472655678326231ull}},
{{17303179418629411635ull, 18011730371843569686ull,
  12951895385315989918ull, 3301840819597907789ull}},
{{12405602236431988736ull, 13291290927949686300ull,
  2354811176362823686ull, 4127301024497384737ull}},
{{16976873434624768768ull, 3695370811541166033ull,
  13000972031295234564ull, 2579563140310865460ull}},
{{7386033737998797248ull, 4619213514426457542ull,
  16251215039119043205ull, 3224453925388581825ull}},
{{9170135643720752ull, 10385702911460459832ull, 6478960743616640294ull,
  4030567406735727282ull}},
{{5731334777325470ull, 1879378301235399491ull, 8661036483187788088ull,
  2519104629209829551ull}},
{{13842222223753820550ull, 2349222876544249363ull,
  6214609585557347206ull, 3148880786512286939ull}},
{{12691091761264887783ull, 12159900632535087512ull,
  3156575963519296103ull, 3936100983140358674ull}},
{{7931932350790554864ull, 14517466922975511551ull,
  6584545995626947968ull, 2460063114462724171ull}},
{{5303229420060805676ull, 18146833653719389439ull,
  3618996476106297056ull, 3075078893078405214ull}},
{{2017350756648619191ull, 4236797993439685183ull,
  13747117631987647129ull, 3843848616348006517ull}},
{{8178373250546468851ull, 14177213791968272999ull,
  10897791529205973407ull, 2402405385217504073ull}},
{{5611280544755698159ull, 13109831221532953345ull,
  18233925429934854663ull, 3003006731521880091ull}},
{{11625786699372010603ull, 11775603008488803777ull,
  18180720768991180425ull, 3753758414402350114ull}},
{{348587659466424771ull, 442222852664420505ull, 15974636499046875670ull,
  2346099009001468821ull}},
{{5047420592760418868ull, 9776150602685301439ull,
  6133237568526430875ull, 2932623761251836027ull}},
{{1697589722523135681ull, 7608502234929238895ull,
  3054860942230650690ull, 3665779701564795034ull}},
{{15957045208436083313ull, 287255756806772810ull,
  13041948214643089171ull, 4582224626955993792ull}},
{{14584839273699939975ull, 16320435912500090670ull,
  8151217634151930731ull, 2863890391847496120ull}},
{{9007677055270149160ull, 15788858872197725434ull,
  10189022042689913414ull, 3579862989809370150ull}},
{{2036224282232910642ull, 10512701553392380985ull,
  3512905516507615960ull, 4474828737261712688ull}},
{{12801855222464038911ull, 6570438470870238115ull,
  2195565947817259975ull, 2796767960788570430ull}},
{{11390633009652660735ull, 3601362070160409740ull,
  11967829471626350777ull, 3495959950985713037ull}},
{{14238291262065825919ull, 9113388606127900079ull,
  1124728784250774759ull, 4369949938732141297ull}},
{{15816461066432223055ull, 12613396906471019405ull,
  12232170536225203984ull, 2731218711707588310ull}},
{{5935518277758115107ull, 15766746133088774257ull,
  6066841133426729172ull, 3414023389634485388ull}},
{{12031083865625031788ull, 1261688592651416205ull,
  7583551416783411466ull, 4267529237043106735ull}},
{{9825270425229338820ull, 5400241388834523032ull,
  11657248663130714022ull, 2667205773151941709ull}},
{{12281588031536673524ull, 15973673772897929598ull,
  736502773631228815ull, 3334007216439927137ull}},
{{6128613002566066097ull, 15355406197695024094ull,
  5532314485466423923ull, 4167509020549908921ull}},
{{17665441181885955023ull, 7291285864345696106ull,
  14986911599484984712ull, 2604693137843693075ull}},
{{12858429440502667971ull, 9114107330432120133ull,
  14121953480928842986ull, 3255866422304616344ull}},
{{2237978745346171251ull, 2169262126185374359ull,
  17652441851161053733ull, 4069833027880770430ull}},
{{8316265743482438888ull, 3661631838079552926ull,
  6421090138548270679ull, 2543645642425481519ull}},
{{1171960142498272802ull, 18412097852881604870ull,
  3414676654757950444ull, 3179557053031851899ull}},
{{10688322214977616811ull, 4568378242392454471ull,
  18103403873729601768ull, 3974446316289814873ull}},
{{13597730412002092363ull, 2855236401495284044ull,
  4397098393439919249ull, 2484028947681134296ull}},
{{16997163015002615453ull, 8180731520296492959ull,
  5496372991799899061ull, 3105036184601417870ull}},
{{16634767750325881413ull, 14837600418798004103ull,
  16093838276604649634ull, 3881295230751772337ull}},
{{17314258871594757739ull, 13885186280176140468ull,
  3141119895236824165ull, 2425809519219857711ull}},
{{3196079515783895558ull, 3521424794938011874ull,
  17761457924328193919ull, 3032261899024822138ull}},
{{13218471431584645255ull, 18236839048954678554ull,
  12978450368555466590ull, 3790327373781027673ull}},
{{12873230663167791189ull, 6786338387169286192ull,
  1194002452706084763ull, 2368954608613142296ull}},
{{16091538328959738986ull, 3871236965534219836ull,
  1492503065882605954ull, 2961193260766427870ull}},
{{1667678837490122116ull, 14062418243772550604ull,
  11089000869208033250ull, 3701491575958034837ull}},
{{10265671310286102131ull, 13400697420785232031ull,
  9236468552468714733ull, 2313432234973771773ull}},
{{8220403119430239759ull, 2915813720699376327ull,
  16157271709013281321ull, 2891790293717214716ull}},
{{5663817880860411795ull, 8256453169301608313ull,
  1749845562557050035ull, 3614737867146518396ull}},
{{11691458369502902647ull, 5708880443199622487ull,
  2187306953196312544ull, 4518422333933147995ull}},
{{14224690508580396011ull, 3568050276999764054ull,
  17507967910243553004ull, 2824013958708217496ull}},
{{8557491098870719205ull, 4460062846249705068ull,
  3438215814094889639ull, 3530017448385271871ull}},
{{10696863873588399007ull, 963392539384743431ull,
  18132827822900775761ull, 4412521810481589838ull}},
{{13603068948633831235ull, 12131335383183934404ull,
  6721331370885596946ull, 2757826131550993649ull}},
{{17003836185792289044ull, 5940797192125142197ull,
  13013350232034384087ull, 3447282664438742061ull}},
{{7419737176958197593ull, 2814310471729039843ull,
  2431629734760816397ull, 4309103330548427577ull}},
{{2331492726385179544ull, 4064787054044343854ull,
  13048983630293980008ull, 2693189581592767235ull}},
{{12137737944836250237ull, 5080983817555429817ull,
  11699543519440087106ull, 3366486976990959044ull}},
{{1337114375763149085ull, 15574601808799063080ull,
  14624429399300108882ull, 4208108721238698805ull}},
{{835696484851968178ull, 14345812148926802329ull,
  11446111383776262003ull, 2630067950774186753ull}},
{{5656306624492348127ull, 13320579167731115007ull,
  472581174438163792ull, 3287584938467733442ull}},
{{2458697262188047254ull, 16650723959663893759ull,
  9814098504902480548ull, 4109481173084666802ull}},
{{8454214816508611390ull, 1183330437935157791ull,
  10745497583991438247ull, 2568425733177916751ull}},
{{5956082502208376333ull, 15314221102701110951ull,
  8820185961561909904ull, 3210532166472395939ull}},
{{2833417109333082513ull, 696032304666837073ull, 6413546433524999477ull,
  4013165208090494924ull}},
{{13300100739401646331ull, 2740863199630467122ull,
  13231838557807900481ull, 2508228255056559327ull}},
{{7401753887397282105ull, 8037765017965471807ull,
  11928112178832487697ull, 3135285318820699159ull}},
{{4640506340819214727ull, 14658892290884227663ull,
  10298454205113221717ull, 3919106648525873949ull}},
{{9817845490653091061ull, 11467650691016336241ull,
  8742376887409457525ull, 2449441655328671218ull}},
{{16883992881743751730ull, 499505308488256589ull,
  1704599072407046099ull, 3061802069160839023ull}},
{{7269933046897525950ull, 14459439690892484449ull,
  15965806895790971335ull, 3827252586451048778ull}},
{{16072923200379423479ull, 15954678834448884636ull,
  14590315328296744988ull, 2392032866531905486ull}},
{{1644409926764727733ull, 1496604469351554180ull,
  9014522123516155428ull, 2990041083164881858ull}},
{{2055512408455909666ull, 1870755586689442725ull,
  2044780617540418477ull, 3737551353956102323ull}},
{{3590538264498637493ull, 3475065250894595655ull,
  17418888950458619212ull, 2335969596222563951ull}},
{{18323230885905460578ull, 4343831563618244568ull,
  17161925169645886111ull, 2919961995278204939ull}},
{{4457294533672274107ull, 818103436095417807ull,
  16840720443629969735ull, 3649952494097756174ull}},
{{959932148662954729ull, 14857687350401435971ull,
  11827528517682686360ull, 4562440617622195218ull}},
{{16740858657410204370ull, 9286054594000897481ull,
  12003891341979066879ull, 2851525386013872011ull}},
{{7091015266480591750ull, 6995882224073733948ull,
  10393178159046445695ull, 3564406732517340014ull}},
{{8863769083100739688ull, 4133166761664779531ull,
  3768100661953281311ull, 4455508415646675018ull}},
{{3234012667724268353ull, 9500758253681569063ull,
  6966748932148188723ull, 2784692759779171886ull}},
{{17877573889937499153ull, 7264261798674573424ull,
  17931808202040011712ull, 3480865949723964857ull}},
{{3900223288712322326ull, 9080327248343216781ull,
  8579702197267850928ull, 4351082437154956072ull}},
{{4743482564658895406ull, 5675204530214510488ull,
  5362313873292406830ull, 2719426523221847545ull}},
{{5929353205823619257ull, 16317377699622913918ull,
  11314578360042896441ull, 3399283154027309431ull}},
{{16635063544134299879ull, 6561664069246478685ull,
  9531536931626232648ull, 4249103942534136789ull}},
{{12702757724297631377ull, 4101040043279049178ull,
  8263053591480089357ull, 2655689964083835493ull}},
{{6655075118517263413ull, 9737986072526199377ull,
  14940503007777499600ull, 3319612455104794366ull}},
{{12930529916573967170ull, 12172482590657749221ull,
  9452256722867098692ull, 4149515568880992958ull}},
{{10387424207072423433ull, 16831173656015869071ull,
  1295974433364548778ull, 2593447230550620599ull}},
{{8372594240413141387ull, 11815595033165060531ull,
  15455026096987849685ull, 3241809038188275748ull}},
{{5854056782089038830ull, 934435736174161952ull, 872038547525260491ull,
  4052261297735344686ull}},
{{3658785488805649269ull, 16724923399604708884ull,
  14380082147485451518ull, 2532663311084590428ull}},
{{4573481861007061586ull, 11682782212651110297ull,
  17975102684356814398ull, 3165829138855738035ull}},
{{10328538344686214887ull, 5380105728959112063ull,
  17857192337018630094ull, 3957286423569672544ull}},
{{13372865493069966160ull, 17197624135881608751ull,
  11160745210636643808ull, 2473304014731045340ull}},
{{12104395847910069796ull, 3050286096142459323ull,
  13950931513295804761ull, 3091630018413806675ull}},
{{10518808791460199341ull, 8424543638605462058ull,
  12826978373192368047ull, 3864537523017258344ull}},
{{11185941513090012492ull, 12182868801769495642ull,
  8016861483245230029ull, 2415335951885786465ull}},
{{4759054854507739807ull, 1393527946929705841ull,
  14632762872483925441ull, 3019169939857233081ull}},
{{10560504586562062663ull, 6353595952089520205ull,
  4455895535322743089ull, 3773962424821541352ull}},
{{8906158375814983117ull, 15500212516124419888ull,
  2784934709576714430ull, 2358726515513463345ull}},
{{11132697969768728896ull, 10151893608300749052ull,
  8092854405398280942ull, 2948408144391829181ull}},
{{13915872462210911119ull, 3466494973521160507ull,
  14727754025175239082ull, 3685510180489786476ull}},
{{12783154559336250995ull, 13556490753756226442ull,
  18409692531469048852ull, 4606887725612233095ull}},
{{12601157618012544776ull, 17696178757952417334ull,
  18423586859809237388ull, 2879304828507645684ull}},
{{6528074985660905162ull, 3673479373730970052ull,
  4582739501051995120ull, 3599131035634557106ull}},
{{8160093732076131452ull, 4591849217163712565ull,
  14951796413169769708ull, 4498913794543196382ull}},
{{7405901591761276110ull, 12093277797582096161ull,
  4733186739803718163ull, 2811821121589497739ull}},
{{13869063008128983041ull, 10504911228550232297ull,
  1304797406327259800ull, 3514776401986872174ull}},
{{3501270704879065090ull, 13131139035687790372ull,
  10854368794763850558ull, 4393470502483590217ull}},
{{11411666227404191489ull, 3595275878877481078ull,
  18313195542795876359ull, 2745919064052243885ull}},
{{5041210747400463553ull, 18329152903879015060ull,
  9056436373212681736ull, 3432398830065304857ull}},
{{6301513434250579442ull, 4464697056139217209ull,
  15932231484943240075ull, 4290498537581631071ull}},
{{15467660942475081911ull, 484592650873316803ull,
  16875173705730606903ull, 2681561585988519419ull}},
{{14722890159666464485ull, 14440798868873809716ull,
  16482281113735870724ull, 3351951982485649274ull}},
{{18403612699583080606ull, 18050998586092262145ull,
  11379479355315062597ull, 4189939978107061593ull}},
{{4584728909598343523ull, 13587717125521357793ull,
  194645569430832267ull, 2618712486316913496ull}},
{{10342597155425317307ull, 12372960388474309337ull,
  243306961788540334ull, 3273390607896141870ull}},
{{17539932462709034538ull, 6242828448738110863ull,
  9527505739090451226ull, 4091738259870177337ull}},
{{17879986816834228443ull, 8513453798888707193ull,
  17483906133000001776ull, 2557336412418860835ull}},
{{8514925465760621841ull, 10641817248610883992ull,
  17243196647822614316ull, 3196670515523576044ull}},
{{10643656832200777301ull, 13302271560763604990ull,
  3107251736068716279ull, 3995838144404470056ull}},
{{2040599501698097909ull, 15231448753118334975ull,
  1942032335042947674ull, 2497398840252793785ull}},
{{16385807432404786099ull, 9815938904543142910ull,
  7039226437231072497ull, 3121748550315992231ull}},
{{11258887253651206815ull, 16881609649106316542ull,
  4187347028111452717ull, 3902185687894990289ull}},
{{2425118515104616356ull, 12856849039905141791ull,
  14146306938638127708ull, 2438866054934368930ull}},
{{16866456199162934157ull, 16071061299881427238ull,
  8459511636442883827ull, 3048582568667961163ull}},
{{11859698212098891888ull, 15477140606424396144ull,
  5962703527126216880ull, 3810728210834951454ull}},
{{7412311382561807430ull, 9673212879015247590ull,
  17561747759736049262ull, 2381705131771844658ull}},
{{42017191347483479ull, 2868144061914283680ull, 12728812662815285770ull,
  2977131414714805823ull}},
{{52521489184354349ull, 12808552114247630408ull,
  11299329810091719308ull, 3721414268393507279ull}},
{{32825930740221468ull, 17228717108259544813ull,
  13979610158948406423ull, 2325883917745942049ull}},
{{4652718431852664739ull, 16924210366897043112ull,
  3639454643403344317ull, 2907354897182427562ull}},
{{5815898039815830924ull, 7320204903339140178ull,
  13772690341108956205ull, 3634193621478034452ull}},
{{16493244586624564463ull, 13761942147601313126ull,
  17215862926386195256ull, 4542742026847543065ull}},
{{5696591848212964885ull, 8601213842250820704ull,
  3842385301350290179ull, 2839213766779714416ull}},
{{7120739810266206107ull, 6139831284386137976ull,
  4802981626687862724ull, 3549017208474643020ull}},
{{8900924762832757633ull, 7674789105482672470ull,
  6003727033359828405ull, 4436271510593303775ull}},
{{951391958343085617ull, 7102586200140364246ull,
  10669858423490974609ull, 2772669694120814859ull}},
{{10412611984783632829ull, 13489918768602843211ull,
  8725637010936330357ull, 3465837117651018574ull}},
{{8404078962552153132ull, 3027340405471390302ull,
  1683674226815637139ull, 4332296397063773218ull}},
{{640863333167707804ull, 18032988817915476603ull,
  5663982410187161115ull, 2707685248164858261ull}},
{{14636137221741798467ull, 17929550003966957849ull,
  11691664031161339298ull, 3384606560206072826ull}},
{{4460113471895084371ull, 13188565468103921504ull,
  5391208002096898315ull, 4230758200257591033ull}},
{{2787570919934427732ull, 5937010408351256988ull,
  14898720047379031207ull, 2644223875160994395ull}},
{{3484463649918034665ull, 2809576992011683331ull,
  14011714040796401105ull, 3305279843951242994ull}},
{{18190637617679707043ull, 8123657258441992067ull,
  8291270514140725573ull, 4131599804939053743ull}},
{{9063305501836122950ull, 7383128795739938994ull,
  12099573098979035339ull, 2582249878086908589ull}},
{{2105759840440377880ull, 4617224976247535839ull,
  1289408318441630462ull, 3227812347608635737ull}},
{{16467257855832636061ull, 14994903257164195606ull,
  6223446416479425981ull, 4034765434510794671ull}},
{{5680350141468009635ull, 11677657544941316206ull,
  10807183037940723094ull, 2521728396569246669ull}},
{{16323809713689787851ull, 5373699894321869449ull,
  18120664815853291772ull, 3152160495711558336ull}},
{{6569704086830071102ull, 6717124867902336812ull,
  4204086946107063099ull, 3940200619639447921ull}},
{{13329437091123570247ull, 1892360033225266555ull,
  14156769387385384197ull, 2462625387274654950ull}},
{{12050110345477074904ull, 6977136059958971098ull,
  8472589697376954438ull, 3078281734093318688ull}},
{{5839265894991567822ull, 17944792111803489681ull,
  10590737121721193047ull, 3847852167616648360ull}},
{{15178756230438199649ull, 18133024097518262906ull,
  6619210701075745654ull, 2404907604760405225ull}},
{{9750073251192973753ull, 13442908085043052825ull,
  12885699394772069972ull, 3006134505950506531ull}},
{{16799277582418605095ull, 16803635106303816031ull,
  11495438225037699561ull, 3757668132438133164ull}},
{{17417077516652710041ull, 3584742913798803163ull,
  16408020927503338034ull, 2348542582773833227ull}},
{{17159660877388499647ull, 13704300679103279762ull,
  15898340140951784638ull, 2935678228467291534ull}},
{{12226204059880848751ull, 7907003812024323895ull,
  10649553139334954990ull, 3669597785584114418ull}},
{{10671069056423673034ull, 660382728175629061ull,
  4088569387313917930ull, 4586997231980143023ull}},
{{8975261169478489598ull, 5024425223537156067ull,
  9472884894712280562ull, 2866873269987589389ull}},
{{6607390443420724094ull, 15503903566276220892ull,
  16452792136817738606ull, 3583591587484486736ull}},
{{8259238054275905117ull, 10156507420990500307ull,
  2119246097312621642ull, 4479489484355608421ull}},
{{2856180774708746746ull, 10959503156546450596ull,
  3630371820034082478ull, 2799680927722255263ull}},
{{3570225968385933433ull, 4476006908828287437ull,
  18373022830324766810ull, 3499601159652819078ull}},
{{9074468478909804695ull, 14818380672890135104ull,
  13742906501051182704ull, 4374501449566023848ull}},
{{5671542799318627935ull, 9261487920556334440ull,
  8589316563156989190ull, 2734063405978764905ull}},
{{7089428499148284918ull, 2353487863840642242ull,
  15348331722373624392ull, 3417579257473456131ull}},
{{18085157660790131956ull, 2941859829800802802ull,
  14573728634539642586ull, 4271974071841820164ull}},
{{15914909556421220376ull, 6450348412052889655ull,
  18331952433442052424ull, 2669983794901137602ull}},
{{15281950927099137566ull, 8062935515066112069ull,
  13691568504947789722ull, 3337479743626422003ull}},
{{5267380603591758246ull, 855297356977864279ull,
  12502774612757349249ull, 4171849679533027504ull}},
{{10209641904885930760ull, 12063775894179634934ull,
  7814234132973343280ull, 2607406049708142190ull}},
{{3538680344252637642ull, 15079719867724543668ull,
  544420629361903292ull, 3259257562135177738ull}},
{{4423350430315797052ull, 402905760946127969ull, 9903897823557154924ull,
  4074071952668972172ull}},
{{14293809065015842918ull, 9475188137446105788ull,
  15413308176577997635ull, 2546294970418107607ull}},
{{17867261331269803647ull, 7232299153380244331ull,
  14654949202295109140ull, 3182868713022634509ull}},
{{17722390645659866655ull, 9040373941725305414ull,
  4483628447586722713ull, 3978585891278293137ull}},
{{6464808135110028755ull, 17179448759646785644ull,
  14331482825810171455ull, 2486616182048933210ull}},
{{8081010168887535944ull, 16862624931131094151ull,
  8690981495407938511ull, 3108270227561166513ull}},
{{5489576692682032026ull, 16466595145486479785ull,
  15475412887687311043ull, 3885337784451458141ull}},
{{14960200478994739776ull, 7985778956715355913ull,
  11977976064018263354ull, 2428336115282161338ull}},
{{4865192543461261008ull, 758851659039419084ull, 5749098043168053385ull,
  3035420144102701673ull}},
{{6081490679326576260ull, 5560250592226661759ull,
  11798058572387454635ull, 3794275180128377091ull}},
{{10718460702220192019ull, 1169313610927969647ull,
  5067943598528465195ull, 2371421987580235682ull}},
{{8786389859347852119ull, 15296700068942125771ull,
  15558301535015357301ull, 2964277484475294602ull}},
{{6371301305757427245ull, 5285817030895493502ull,
  10224504881914420819ull, 3705346855594118253ull}},
{{17817121371380555740ull, 997792635095989486ull,
  8696158560410206964ull, 2315841784746323908ull}},
{{13048029677370918867ull, 1247240793869986858ull,
  10870198200512758705ull, 2894802230932904885ull}},
{{7086665059858872776ull, 6170737010764871477ull,
  18199433769068336285ull, 3618502788666131106ull}},
{{13470017343250978874ull, 12325107281883477250ull,
  13525920174480644548ull, 4523128485832663883ull}},
{{13030446857959249701ull, 16926564088031949089ull,
  6147857099836708890ull, 2826955303645414927ull}},
{{2453000517166898414ull, 11934833073185160554ull,
  3073135356368498209ull, 3533694129556768659ull}},
{{12289622683313398825ull, 1083483286199286980ull,
  17676477250742786474ull, 4417117661945960823ull}},
{{16904386213925650074ull, 5288863072301942266ull,
  17965327309355323402ull, 2760698538716225514ull}},
{{11907110730552286784ull, 15834450877232203641ull,
  13233287099839378444ull, 3450873173395281893ull}},
{{1048830357908194768ull, 1346319522830702936ull,
  2706550819517059344ull, 4313591466744102367ull}},
{{655518973692621730ull, 841449701769189335ull, 8609123289839243946ull,
  2695994666715063979ull}},
{{14654456772397940874ull, 10275184164066262476ull,
  6149718093871667028ull, 3369993333393829974ull}},
{{18318070965497426093ull, 12843980205082828095ull,
  16910519654194359593ull, 4212491666742287467ull}},
{{18366323381076973164ull, 1109958600535685703ull,
  8263231774657780794ull, 2632807291713929667ull}},
{{18346218207918828551ull, 10610820287524382937ull,
  5717353699894838088ull, 3291009114642412084ull}},
{{9097714704616371977ull, 13263525359405478672ull,
  7146692124868547610ull, 4113761393303015105ull}},
{{5686071690385232486ull, 12901389368055812074ull,
  15995897624111312016ull, 2571100870814384440ull}},
{{16330961649836316415ull, 16126736710069765092ull,
  1548127956429588404ull, 3213876088517980551ull}},
{{1966957988585843903ull, 1711676813877654750ull,
  15770218000819149218ull, 4017345110647475688ull}},
{{15064406798148316151ull, 5681484027100922122ull,
  9856386250511968261ull, 2510840694154672305ull}},
{{9607136460830619381ull, 11713541052303540557ull,
  16932168831567348230ull, 3138550867693340381ull}},
{{16620606594465662130ull, 5418554278524649888ull,
  7330152984177021576ull, 3923188584616675477ull}},
{{10387879121541038832ull, 3386596424077906180ull,
  6887188624324332437ull, 2451992865385422173ull}},
{{12984848901926298539ull, 8844931548524770629ull,
  13220671798832803450ull, 3064991081731777716ull}},
{{2396003072125709462ull, 1832792398801187479ull,
  16525839748541004313ull, 3831238852164722145ull}},
{{8415030947719650270ull, 12674710295319211934ull,
  3411120815197045839ull, 2394524282602951341ull}},
{{1295416647794787029ull, 11231701850721627014ull,
  8875587037423695203ull, 2993155353253689176ull}},
{{10842642846598259595ull, 9427941294974645863ull,
  11094483796779619004ull, 3741444191567111470ull}},
{{13694180806764994103ull, 15115835346213929472ull,
  2322366354559873973ull, 2338402619729444669ull}},
{{17117726008456242628ull, 5059736127485248128ull,
  7514643961627230371ull, 2923003274661805836ull}},
{{2950413436860751669ull, 1712984140929172257ull,
  9393304952034037964ull, 3653754093327257295ull}},
{{8299702814503327491ull, 2141230176161465321ull,
  7129945171615159551ull, 4567192616659071619ull}},
{{16716529305133049442ull, 8255797887741997681ull,
  2150372723045780767ull, 2854495385411919762ull}},
{{7060603576134148090ull, 5708061341250109198ull,
  11911337940662001767ull, 3568119231764899702ull}},
{{18049126507022460921ull, 2523390658135248593ull,
  5665800388972726401ull, 4460149039706124628ull}},
{{4363175039247956220ull, 13106334207403000131ull,
  12764497279962729808ull, 2787593149816327892ull}},
{{842282780632557370ull, 16382917759253750164ull,
  15955621599953412260ull, 3484491437270409865ull}},
{{1052853475790696713ull, 2031903125357636089ull,
  6109468944659601614ull, 4355614296588012332ull}},
{{12187248468437655206ull, 15104997508630686267ull,
  13041790127267026816ull, 2722258935367507707ull}},
{{10622374567119681103ull, 434502812078806218ull,
  11690551640656395617ull, 3402823669209384634ull}},
{{4054596172044825571ull, 5154814533525895677ull,
  5389817513965718713ull, 4253529586511730793ull}},
{{4839965616741709934ull, 14750974129522154558ull,
  14897850992297043955ull, 2658455991569831745ull}},
{{15273329057781913225ull, 13827031643475305293ull,
  4787255685089141232ull, 3323069989462289682ull}},
{{5256603266945227819ull, 17283789554344131617ull,
  15207441643216202348ull, 4153837486827862102ull}},
{{14814592087909237147ull, 1578996434610306452ull,
  4892965008582738564ull, 2596148429267413814ull}},
{{71496036176994818ull, 1973745543262883066ull, 15339578297583199013ull,
  3245185536584267267ull}},
{{9312742082076019330ull, 7078867947505991736ull,
  14562786853551610862ull, 4056481920730334084ull}},
{{5820463801297512082ull, 18259350522473408547ull,
  18325113820324532596ull, 2535301200456458802ull}},
{{2663893733194502198ull, 4377444079382209068ull,
  13683020238550889938ull, 3169126500570573503ull}},
{{3329867166493127747ull, 14695177136082537143ull,
  12492089279761224518ull, 3961408125713216879ull}},
{{8998696006699286698ull, 4572799691624197810ull,
  14725084827491847180ull, 2475880078570760549ull}},
{{2024997971519332565ull, 5715999614530247263ull,
  4571297979082645263ull, 3094850098213450687ull}},
{{16366305519681329418ull, 2533313499735421174ull,
  1102436455425918675ull, 3868562622766813359ull}},
{{5617254931373442982ull, 17724222001830495898ull,
  7606551812282281027ull, 2417851639229258349ull}},
{{16244940701071579536ull, 17543591483860731968ull,
  14119875783780239188ull, 3022314549036572936ull}},
{{1859431802629922803ull, 3482745281116363345ull,
  17649844729725298986ull, 3777893186295716170ull}},
{{12691359922712171512ull, 6788401819125114994ull,
  15642838974505699770ull, 2361183241434822606ull}},
{{6640827866535438582ull, 17708874310761169551ull,
  10330176681277348904ull, 2951479051793528258ull}},
{{3689348814741910324ull, 3689348814741910323ull,
  3689348814741910323ull, 3689348814741910323ull}},
{{0ull, 0ull, 0ull, 4611686018427387904ull}},
{{0ull, 0ull, 0ull, 2882303761517117440ull}},
{{0ull, 0ull, 0ull, 3602879701896396800ull}},
{{0ull, 0ull, 0ull, 4503599627370496000ull}},
{{0ull, 0ull, 0ull, 2814749767106560000ull}},
{{0ull, 0ull, 0ull, 3518437208883200000ull}},
{{0ull, 0ull, 0ull, 4398046511104000000ull}},
{{0ull, 0ull, 0ull, 2748779069440000000ull}},
{{0ull, 0ull, 0ull, 3435973836800000000ull}},
{{0ull, 0ull, 0ull, 4294967296000000000ull}},
{{0ull, 0ull, 0ull, 2684354560000000000ull}},
{{0ull, 0ull, 0ull, 3355443200000000000ull}},
{{0ull, 0ull, 0ull, 4194304000000000000ull}},
{{0ull, 0ull, 0ull, 2621440000000000000ull}},
{{0ull, 0ull, 0ull, 3276800000000000000ull}},
{{0ull, 0ull, 0ull, 4096000000000000000ull}},
{{0ull, 0ull, 0ull, 2560000000000000000ull}},
{{0ull, 0ull, 0ull, 3200000000000000000ull}},
{{0ull, 0ull, 0ull, 4000000000000000000ull}},
{{0ull, 0ull, 0ull, 2500000000000000000ull}},
{{0ull, 0ull, 0ull, 3125000000000000000ull}},
{{0ull, 0ull, 0ull, 3906250000000000000ull}},
{{0ull, 0ull, 0ull, 2441406250000000000ull}},
{{0ull, 0ull, 0ull, 3051757812500000000ull}},
{{0ull, 0ull, 0ull, 3814697265625000000ull}},
{{0ull, 0ull, 0ull, 2384185791015625000ull}},
{{0ull, 0ull, 0ull, 2980232238769531250ull}},
{{0ull, 0ull, 9223372036854775808ull, 3725290298461914062ull}},
{{0ull, 0ull, 1152921504606846976ull, 2328306436538696289ull}},
{{0ull, 0ull, 6052837899185946624ull, 2910383045673370361ull}},
{{0ull, 0ull, 12177733392409821184ull, 3637978807091712951ull}},
{{0ull, 0ull, 10610480722084888576ull, 4547473508864641189ull}},
{{0ull, 0ull, 8937393460516749312ull, 2842170943040400743ull}},
{{0ull, 0ull, 6560055807218548736ull, 3552713678800500929ull}},
{{0ull, 0ull, 12811755777450573824ull, 4440892098500626161ull}},
{{0ull, 0ull, 1089818333265526784ull, 2775557561562891351ull}},
{{0ull, 0ull, 15197330971864072192ull, 3469446951953614188ull}},
{{0ull, 0ull, 549919641120538624ull, 4336808689942017736ull}},
{{0ull, 0ull, 343699775700336640ull, 2710505431213761085ull}},
{{0ull, 0ull, 5041310738052808704ull, 3388131789017201356ull}},
{{0ull, 0ull, 6301638422566010880ull, 4235164736271501695ull}},
{{0ull, 0ull, 10856053041744838656ull, 2646977960169688559ull}},
{{0ull, 0ull, 8958380283753660416ull, 3308722450212110699ull}},
{{0ull, 0ull, 6586289336264687616ull, 4135903062765138374ull}},
{{0ull, 0ull, 17951488890447593472ull, 2584939414228211483ull}},
{{0ull, 0ull, 17827675094632103936ull, 3231174267785264354ull}},
{{0ull, 0ull, 13061221831435354112ull, 4038967834731580443ull}},
{{0ull, 0ull, 5857420635433402368ull, 2524354896707237777ull}},
{{0ull, 0ull, 11933461812719140864ull, 3155443620884047221ull}},
{{0ull, 0ull, 1081769210616762368ull, 3944304526105059027ull}},
{{0ull, 0ull, 16817006821131334144ull, 2465190328815661891ull}},
{{0ull, 0ull, 16409572507986779776ull, 3081487911019577364ull}},
{{0ull, 0ull, 2065221561273923104ull, 3851859888774471706ull}},
{{0ull, 0ull, 5902449494223589844ull, 2407412430484044816ull}},
{{0ull, 0ull, 7378061867779487305ull, 3009265538105056020ull}},
{{0ull, 4611686018427387904ull, 9222577334724359131ull,
  3761581922631320025ull}},
{{0ull, 576460752303423488ull, 17293325880271194217ull,
  2350988701644575015ull}},
{{0ull, 5332261958806667264ull, 17004971331911604867ull,
  2938735877055718769ull}},
{{0ull, 2053641430080946176ull, 7421156109607342372ull,
  3673419846319648462ull}},
{{0ull, 2567051787601182720ull, 53073100154402157ull,
  4591774807899560578ull}},
{{0ull, 3910250376464433152ull, 4644856706023889252ull,
  2869859254937225361ull}},
{{0ull, 4887812970580541440ull, 10417756900957249469ull,
  3587324068671531701ull}},
{{0ull, 10721452231653064704ull, 17633882144623949740ull,
  4484155085839414626ull}},
{{0ull, 15924279681637941248ull, 15632862358817356491ull,
  2802596928649634141ull}},
{{0ull, 15293663583620038656ull, 5706019893239531902ull,
  3503246160812042677ull}},
{{0ull, 9893707442670272512ull, 11744210884976802782ull,
  4379057701015053346ull}},
{{0ull, 1571881133241532416ull, 11951817821537889643ull,
  2736911063134408341ull}},
{{0ull, 15799909471834079232ull, 1104714221640198341ull,
  3421138828918010427ull}},
{{0ull, 5914828784510435328ull, 15215950832332411639ull,
  4276423536147513033ull}},
{{0ull, 10614297017960103936ull, 2592440242566675418ull,
  2672764710092195646ull}},
{{0ull, 4044499235595354112ull, 12463922340063120081ull,
  3340955887615244557ull}},
{{0ull, 9667310062921580544ull, 1744844869796736389ull,
  4176194859519055697ull}},
{{0ull, 8347911798539681792ull, 12619743089691430003ull,
  2610121787199409810ull}},
{{0ull, 5823203729747214336ull, 6551306825259511696ull,
  3262652233999262263ull}},
{{0ull, 7279004662184017920ull, 3577447513147001716ull,
  4078315292499077829ull}},
{{0ull, 13772749950719787008ull, 4541747704930570024ull,
  2548947057811923643ull}},
{{0ull, 17215937438399733760ull, 1065498612735824626ull,
  3186183822264904554ull}},
{{0ull, 12296549761144891392ull, 10555245302774556591ull,
  3982729777831130692ull}},
{{0ull, 14602872628356638976ull, 15820400351088873677ull,
  2489206111144456682ull}},
{{0ull, 4418532730163635008ull, 10552128402006316289ull,
  3111507638930570853ull}},
{{0ull, 10134851931131931664ull, 17801846520935283265ull,
  3889384548663213566ull}},
{{0ull, 17863497503025927050ull, 6514468057157164136ull,
  2430865342914508479ull}},
{{9223372036854775808ull, 3882627805072857196ull,
  3531399053019067267ull, 3038581678643135599ull}},
{{11529215046068469760ull, 241598737913683591ull,
  18249306871555997796ull, 3798227098303919498ull}},
{{14123288431433875456ull, 9374371248050828052ull,
  16017502813149886526ull, 2373891936439949686ull}},
{{17654110539292344320ull, 2494592023208759257ull,
  10798506479582582350ull, 2967364920549937108ull}},
{{8232580118833266688ull, 12341612065865724880ull,
  13498133099478227937ull, 3709206150687421385ull}},
{{5145362574270791680ull, 795978513524996194ull, 1518804159532810605ull,
  2318253844179638366ull}},
{{15655075254693265408ull, 5606659160333633146ull,
  11121877236270789064ull, 2897817305224547957ull}},
{{10345472031511805952ull, 7008323950417041433ull, 67288490056322618ull,
  3622271631530684947ull}},
{{17543526057817145344ull, 17983776974876077599ull,
  13919168667852566984ull, 4527839539413356183ull}},
{{17882232813776797696ull, 11239860609297548499ull,
  15617009445048936221ull, 2829899712133347614ull}},
{{17741104998793609216ull, 214767706339771912ull,
  10297889769456394469ull, 3537374640166684518ull}},
{{3729637174782459904ull, 4880145651352102795ull,
  3648990174965717278ull, 4421718300208355648ull}},
{{25180225025343488ull, 16885149087377227959ull, 2280618859353573298ull,
  2763573937630222280ull}},
{{13866533336563843072ull, 11883064322366759140ull,
  2850773574191966623ull, 3454467422037777850ull}},
{{17333166670704803840ull, 10242144384531061021ull,
  12786839004594734087ull, 4318084277547222312ull}},
{{13139072178404196352ull, 13318869267972994994ull,
  7991774377871708804ull, 2698802673467013945ull}},
{{7200468186150469632ull, 16648586584966243743ull,
  14601403990767023909ull, 3373503341833767431ull}},
{{4388899214260699136ull, 6975675175925640967ull,
  13640068970031391983ull, 4216879177292209289ull}},
{{9660591036554018816ull, 11277326012594607460ull,
  1607514078628538133ull, 2635549485807630806ull}},
{{12075738795692523520ull, 261599460461095613ull,
  11232764635140448475ull, 3294436857259538507ull}},
{{1259615439333490688ull, 14162057380858533229ull,
  9429269775498172689ull, 4118046071574423134ull}},
{{3093102658797125632ull, 1933756835395501412ull,
  1281607591258970027ull, 2573778794734014459ull}},
{{3866378323496407040ull, 16252254099526540477ull,
  15437067544355876245ull, 3217223493417518073ull}},
{{9444658922797896704ull, 6480259569126011884ull,
  5461276375162681595ull, 4021529366771897592ull}},
{{15126283863603461248ull, 1744319221490063475ull,
  3413297734476675997ull, 2513455854232435995ull}},
{{14296168811076938656ull, 6792085045289967248ull,
  18101680223378008708ull, 3141819817790544993ull}},
{{17870211013846173320ull, 8490106306612459060ull,
  8792042223940347173ull, 3927274772238181242ull}},
{{1945509846799082517ull, 7612159450846480865ull,
  10106712408390104887ull, 2454546732648863276ull}},
{{7043573326926241051ull, 4903513295130713177ull,
  12633390510487631109ull, 3068183415811079095ull}},
{{13416152677085189217ull, 10741077637340779375ull,
  11180052119682150982ull, 3835229269763848869ull}},
{{15302624450819325117ull, 2101487504910599205ull,
  9293375584015038316ull, 2397018293602405543ull}},
{{5293222508241992684ull, 2626859381138249007ull,
  7005033461591409991ull, 2996272867003006929ull}},
{{2004842116875102951ull, 17118632281704974971ull,
  13367977845416650392ull, 3745341083753758661ull}},
{{17393927387542797009ull, 10699145176065609356ull,
  10660829162599100447ull, 2340838177346099163ull}},
{{3295665160718944645ull, 8762245451654623792ull,
  8714350434821487655ull, 2926047721682623954ull}},
{{4119581450898680806ull, 6341120796140891836ull,
  1669566006672083761ull, 3657559652103279943ull}},
{{5149476813623351007ull, 12538087013603502699ull,
  15922015563622268413ull, 4571949565129099928ull}},
{{912579999300900428ull, 10142147392715883139ull,
  9951259727263917758ull, 2857468478205687455ull}},
{{14975783054408289246ull, 3454312204040078115ull,
  7827388640652509294ull, 3571835597757109319ull}},
{{14108042799582973654ull, 13541262291904873452ull,
  5172549782388248713ull, 4464794497196386649ull}},
{{18040898786594134342ull, 1545759904799464051ull,
  14762058660061125206ull, 2790496560747741655ull}},
{{17939437464815280023ull, 11155571917854105872ull,
  13840887306649018603ull, 3488120700934677069ull}},
{{3977552757309548413ull, 9332778878890244437ull,
  3466051078029109542ull, 4360150876168346337ull}},
{{4791813482532161710ull, 1221300780879014869ull,
  13695496969836663224ull, 2725094297605216460ull}},
{{10601452871592590042ull, 1526625976098768586ull,
  17119371212295829030ull, 3406367872006520575ull}},
{{4028444052635961744ull, 11131654506978236541ull,
  16787527996942398383ull, 4257959840008150719ull}},
{{4823620542111170042ull, 13874813094502479694ull,
  17409734025730080845ull, 2661224900005094199ull}},
{{15252897714493738360ull, 3508458312845935905ull,
  17150481513735213153ull, 3326531125006367749ull}},
{{5231064087835009238ull, 8997258909484807786ull,
  7603043836886852729ull, 4158163906257959687ull}},
{{7881101073324268678ull, 17152501864496474626ull,
  11669431425695364811ull, 2598852441411224804ull}},
{{628004304800560040ull, 16828941312193205379ull,
  14586789282119206014ull, 3248565551764031005ull}},
{{14620063436282863761ull, 11812804603386730915ull,
  4398428547366843806ull, 4060706939705038757ull}},
{{6831696638463095899ull, 2771316858689318918ull,
  5054860851317971331ull, 2537941837315649223ull}},
{{17762992834933645682ull, 17299204128643812359ull,
  1706890045720076259ull, 3172427296644561529ull}},
{{17592055025239669198ull, 17012319142377377545ull,
  6745298575577483228ull, 3965534120805701911ull}},
{{4077505363133711393ull, 1409327427131085158ull,
  11133340637377008874ull, 2478458825503563694ull}},
{{14320253740771915049ull, 10985031320768632255ull,
  4693303759866485284ull, 3098073531879454618ull}},
{{13288631157537505907ull, 13731289150960790319ull,
  15090001736687882413ull, 3872591914849318272ull}},
{{15222923501102023048ull, 10887898728564187901ull,
  9431251085429926508ull, 2420369946780823920ull}},
{{5193596321095365098ull, 13609873410705234877ull,
  11789063856787408135ull, 3025462433476029900ull}},
{{11103681419796594277ull, 12400655744954155692ull,
  14736329820984260169ull, 3781828041845037375ull}},
{{16163172924227647231ull, 832880812955265451ull,
  16127735165756244462ull, 2363642526153148359ull}},
{{15592280136857171135ull, 10264473053048857622ull,
  15547982938767917673ull, 2954553157691435449ull}},
{{10266978134216688110ull, 17442277334738459932ull,
  5599920618177733379ull, 3693191447114294312ull}},
{{15640233370740205877ull, 8595580324997843505ull,
  3499950386361083362ull, 2308244654446433945ull}},
{{5715233658143093634ull, 1521103369392528574ull,
  8986624001378742107ull, 2885305818058042431ull}},
{{16367414109533642851ull, 15736437267022824429ull,
  6621593983296039729ull, 3606632272572553039ull}},
{{6624209581634889851ull, 5835488528496366825ull,
  3665306460692661758ull, 4508290340715691299ull}},
{{15669346034590275917ull, 17482238385592392977ull,
  18431717602428771262ull, 2817681462947307061ull}},
{{5751624487955681184ull, 12629425945135715414ull,
  9204588947753800366ull, 3522101828684133827ull}},
{{16412902646799377288ull, 6563410394564868459ull,
  6894050166264862554ull, 4402627285855167284ull}},
{{7952221145035916853ull, 8713817515030430691ull,
  13532153390770314904ull, 2751642053659479552ull}},
{{5328590412867508163ull, 10892271893788038364ull,
  16915191738462893630ull, 3439552567074349440ull}},
{{6660738016084385203ull, 4391967830380272147ull,
  2697245599369065422ull, 4299440708842936801ull}},
{{1857118250839046800ull, 16580037949269833804ull,
  13214993545674135648ull, 2687150443026835500ull}},
{{2321397813548808500ull, 2278303362877740639ull,
  16518741932092669561ull, 3358938053783544375ull}},
{{16736805322218174337ull, 7459565222024563702ull,
  16036741396688449047ull, 4198672567229430469ull}},
{{5848817307958971057ull, 11579757291406434170ull,
  12328806382143974606ull, 2624170354518394043ull}},
{{16534393671803489629ull, 5251324577403266904ull,
  10799321959252580354ull, 3280212943147992554ull}},
{{2221248016044810420ull, 15787527758608859439ull,
  4275780412210949634ull, 4100266178934990693ull}},
{{8305809037669088369ull, 14478890867557925053ull,
  4978205766845537473ull, 2562666361834369183ull}},
{{14993947315513748365ull, 4263555529165242604ull,
  1611071190129533938ull, 3203332952292961479ull}},
{{295690070682633840ull, 14552816448311329064ull,
  15848897042944081134ull, 4004166190366201848ull}},
{{184806294176646150ull, 4483824261767192761ull, 9905560651840050709ull,
  2502603868978876155ull}},
{{4842693886148195591ull, 10216466345636378855ull,
  7770264796372675482ull, 3128254836223595194ull}},
{{1441681339257856585ull, 3547210895190697761ull, 489458958611068545ull,
  3910318545279493993ull}},
{{12430265883104630126ull, 13746221855562655860ull,
  11835126895200387600ull, 2443949090799683745ull}},
{{15537832353880787657ull, 17182777319453319825ull,
  958850563718320788ull, 3054936363499604682ull}},
{{5587232387068820859ull, 3031727575607098166ull,
  10421935241502676794ull, 3818670454374505852ull}},
{{17327078297200176749ull, 6506515753181824257ull,
  15737081562793948804ull, 2386669033984066157ull}},
{{7823789816218057224ull, 8133144691477280322ull,
  5836293898210272293ull, 2983336292480082697ull}},
{{556365233417795722ull, 14778116882773988307ull,
  11907053391190228270ull, 3729170365600103371ull}},
{{16488629335381979991ull, 4624637033306354787ull,
  5136065360280198717ull, 2330731478500064607ull}},
{{15999100650800087084ull, 10392482310060331388ull,
  1808395681922860492ull, 2913414348125080759ull}},
{{1552131739790557239ull, 12990602887575414236ull,
  16095552657685739327ull, 3641767935156350948ull}},
{{1940164674738196549ull, 11626567591041879891ull,
  1672696748397622543ull, 4552209918945438686ull}},
{{17353503986207230507ull, 14184133772042256787ull,
  14880493523030677801ull, 2845131199340899178ull}},
{{17080193964331650230ull, 3895109159770657272ull,
  9377244866933571444ull, 3556413999176123973ull}},
{{2903498381705011171ull, 4868886449713321591ull,
  16333242102094352209ull, 4445517498970154966ull}},
{{8732215516206713838ull, 14572269077139295754ull,
  5596590295381582226ull, 2778448436856346854ull}},
{{1691897358403616490ull, 8991964309569343885ull,
  16219109906081753591ull, 3473060546070433567ull}},
{{6726557716431908516ull, 6628269368534291952ull,
  15662201364174804085ull, 4341325682588041959ull}},
{{4204098572769942823ull, 6448511364547626422ull,
  16706404880250334409ull, 2713328551617526224ull}},
{{14478495252817204336ull, 12672325224111920931ull,
  2436262026603366395ull, 3391660689521907781ull}},
{{13486433047594117516ull, 11228720511712513260ull,
  7657013551681595898ull, 4239575861902384726ull}},
{{17652392691601099256ull, 11629636338247708691ull,
  173947451373609532ull, 2649734913688990454ull}},
{{17453804846073986166ull, 14537045422809635864ull,
  9440806351071787723ull, 3312168642111238067ull}},
{{3370511983882931091ull, 13559620760084656927ull,
  7189321920412346750ull, 4140210802639047584ull}},
{{9024099017567913788ull, 3863076956625522675ull,
  4493326200257716719ull, 2587631751649404740ull}},
{{6668437753532504331ull, 217160177354515440ull, 5616657750322145899ull,
  3234539689561755925ull}},
{{8335547191915630413ull, 14106508276975308012ull,
  11632508206330070277ull, 4043174611952194906ull}},
{{14433089031802044817ull, 11122410682323261459ull,
  11882003647383681827ull, 2526984132470121816ull}},
{{13429675271325168117ull, 9291327334476688920ull,
  14852504559229602284ull, 3158730165587652270ull}},
{{16787094089156460146ull, 11614159168095861150ull,
  9342258662182227047ull, 3948412706984565338ull}},
{{5880247787295399687ull, 14176378507700995075ull,
  10450597682291279808ull, 2467757941865353336ull}},
{{2738623715691861705ull, 17720473134626243844ull,
  13063247102864099760ull, 3084697427331691670ull}},
{{3423279644614827131ull, 3703847344573253189ull,
  7105686841725348893ull, 3855871784164614588ull}},
{{4445392787097960909ull, 4620747599571977195ull,
  13664426312933118866ull, 2409919865102884117ull}},
{{945054965445063232ull, 14999306536319747302ull,
  3245474835884234870ull, 3012399831378605147ull}},
{{10404690743661104848ull, 9525761133544908319ull,
  17891901600137457300ull, 3765499789223256433ull}},
{{13420460742429272386ull, 15176972745320343507ull,
  4264909472444828956ull, 2353437368264535271ull}},
{{12163889909609202579ull, 524471857940877768ull, 719450822128648292ull,
  2941796710330669089ull}},
{{15204862387011503223ull, 655589822426097210ull,
  5510999546088198269ull, 3677245887913336361ull}},
{{9782705946909603221ull, 5431173296460009417ull,
  11500435451037635740ull, 4596557359891670451ull}},
{{17643406262886971773ull, 12617855347142281693ull,
  4881929147684828385ull, 2872848349932294032ull}},
{{8219199773326551005ull, 1937261128645688405ull,
  6102411434606035482ull, 3591060437415367540ull}},
{{14885685735085576660ull, 11644948447661886314ull,
  7628014293257544352ull, 4488825546769209425ull}},
{{13915239602855873316ull, 7278092779788678946ull,
  16296723979354434980ull, 2805515966730755890ull}},
{{8170677466715065837ull, 9097615974735848683ull,
  11147532937338267917ull, 3506894958413444863ull}},
{{5601660814966444393ull, 15983705986847198758ull,
  9322730153245446992ull, 4383618698016806079ull}},
{{17336096064636191458ull, 9989816241779499223ull,
  12744235373419486226ull, 2739761686260503799ull}},
{{17058434062367851418ull, 3263898265369598221ull,
  11318608198346969879ull, 3424702107825629749ull}},
{{7487984522677650560ull, 17914930886994161489ull,
  313202192651548636ull, 4280877634782037187ull}},
{{16209205372742001360ull, 1973459767516575122ull,
  16336652434903075562ull, 2675548521738773241ull}},
{{11038134679072725892ull, 11690196746250494711ull,
  6585757488346680740ull, 3344435652173466552ull}},
{{9185982330413519461ull, 14612745932813118389ull,
  8232196860433350925ull, 4180544565216833190ull}},
{{8047081965722143615ull, 11438809217221892945ull,
  533437019343456424ull, 2612840353260520744ull}},
{{14670538475580067423ull, 14298511521527366181ull,
  666796274179320530ull, 3266050441575650930ull}},
{{4503115039192920567ull, 8649767365054431919ull,
  10056867379578926471ull, 4082563051969563662ull}},
{{9731975927136657210ull, 12323633630800101805ull,
  1673856093809441140ull, 2551601907480977289ull}},
{{16776655927348209417ull, 15404542038500127256ull,
  6704006135689189329ull, 3189502384351221611ull}},
{{2524075835475710155ull, 5420619492842995359ull,
  3768321651184098758ull, 3986877980439027014ull}},
{{8495076424813400703ull, 17222945238309035811ull,
  16190259087272225435ull, 2491798737774391883ull}},
{{6007159512589362975ull, 16916995529458906860ull,
  15626137840662893890ull, 3114748422217989854ull}},
{{7508949390736703718ull, 11922872374968857767ull,
  10309300263973841555ull, 3893435527772487318ull}},
{{11610622396851521680ull, 5145952225141842152ull,
  1831626646556263068ull, 2433397204857804574ull}},
{{14513277996064402100ull, 6432440281427302690ull,
  11512905345050104643ull, 3041746506072255717ull}},
{{8918225458225726817ull, 3428864333356740459ull, 556073626030467092ull,
  3802183132590319647ull}},
{{3268047902177385309ull, 11366412245202738595ull,
  7265075043910123788ull, 2376364457868949779ull}},
{{17920117933003895348ull, 14208015306503423243ull,
  4469657786460266831ull, 2970455572336187224ull}},
{{17788461397827481281ull, 13148333114701891150ull,
  5587072233075333539ull, 3713069465420234030ull}},
{{6506102355214787897ull, 5911865187474988017ull,
  17326978200954247174ull, 2320668415887646268ull}},
{{12744313962445872775ull, 16613203521198510829ull,
  3211978677483257351ull, 2900835519859557836ull}},
{{2095334397775177256ull, 16154818383070750633ull,
  4014973346854071689ull, 3626044399824447295ull}},
{{7230854015646359474ull, 6358464923556274579ull, 407030665140201708ull,
  4532555499780559119ull}},
{{2213440750565280719ull, 13197412614077447420ull,
  7171923193353707923ull, 2832847187362849449ull}},
{{2766800938206600899ull, 11885079749169421371ull,
  13576590010119522808ull, 3541058984203561811ull}},
{{17293559228040414836ull, 14856349686461776713ull,
  12359051494222015606ull, 4426323730254452264ull}},
{{3890945489884177417ull, 4673532535611222542ull,
  7724407183888759754ull, 2766452331409032665ull}},
{{14087053899209997579ull, 15065287706368803985ull,
  14267194998288337596ull, 3458065414261290831ull}},
{{3773759318730333261ull, 384865559251453366ull,
  13222307729433034092ull, 4322581767826613539ull}},
{{16193657629488622000ull, 9463913011386934161ull,
  5958099321681952355ull, 2701613604891633462ull}},
{{6407013981578613788ull, 7218205245806279798ull,
  16670996188957216252ull, 3377017006114541827ull}},
{{17232139513828043043ull, 9022756557257849747ull,
  16227059217769132411ull, 4221271257643177284ull}},
{{8464244186928832950ull, 3333379839072462140ull, 918539974250931949ull,
  2638294536026985803ull}},
{{10580305233661041188ull, 8778410817267965579ull,
  14983233023095828648ull, 3297868170033732253ull}},
{{8613695523648913581ull, 10973013521584956974ull,
  4893983223587622098ull, 4122335212542165317ull}},
{{771873683853183084ull, 11469819469417986013ull,
  5364582523955957763ull, 2576459507838853323ull}},
{{5576528123243866759ull, 9725588318345094612ull,
  2094042136517559300ull, 3220574384798566654ull}},
{{6970660154054833449ull, 12156985397931368265ull,
  11840924707501724933ull, 4025717980998208317ull}},
{{15885877642352740666ull, 9903958882920799117ull,
  9706420951402272035ull, 2516073738123880198ull}},
{{6022288997658762120ull, 7768262585223610993ull,
  2909654152398064236ull, 3145092172654850248ull}},
{{12139547265500840554ull, 9710328231529513741ull,
  3637067690497580295ull, 3931365215818562810ull}},
{{9893060050151719298ull, 12986484172347027944ull,
  6884853324988375588ull, 2457103259886601756ull}},
{{12366325062689649123ull, 16233105215433784930ull,
  8606066656235469485ull, 3071379074858252195ull}},
{{6234534291507285595ull, 6456323464010067451ull,
  6145897301866948953ull, 3839223843572815244ull}},
{{1590740922978359545ull, 15564417211074761917ull,
  13064557850521618903ull, 2399514902233009527ull}},
{{6600112172150337335ull, 14843835495416064492ull,
  11719011294724635725ull, 2999393627791261909ull}},
{{8250140215187921669ull, 4719736313987916903ull, 813706063123630945ull,
  3749242034739077387ull}},
{{12073866662133532899ull, 14479050242310917824ull,
  16649467353948127004ull, 2343276271711923366ull}},
{{15092333327666916124ull, 18098812802888647280ull,
  11588462155580382947ull, 2929095339639904208ull}},
{{418672585874093539ull, 18011829985183421197ull,
  14485577694475478684ull, 3661369174549880260ull}},
{{5135026750770004827ull, 4068043407769724880ull,
  18106972118094348356ull, 4576711468187350325ull}},
{{3209391719231253017ull, 11765899166710853858ull,
  13622700583022661674ull, 2860444667617093953ull}},
{{13235111685893842080ull, 5484001921533791514ull,
  3193317673496163381ull, 3575555834521367442ull}},
{{7320517570512526791ull, 11466688420344627297ull,
  13215019128724980034ull, 4469444793151709302ull}},
{{16104538527638799005ull, 11778366281142779964ull,
  3647700937025724617ull, 2793402995719818314ull}},
{{1683929085838947140ull, 887899796146311244ull,
  13782998208136931580ull, 3491753744649772892ull}},
{{2104911357298683925ull, 1109874745182889055ull,
  17228747760171164475ull, 4364692180812216115ull}},
{{8233098625952759309ull, 16834572780235163323ull,
  8462124340893283844ull, 2727932613007635072ull}},
{{5679687264013561232ull, 2596471901584402538ull,
  10577655426116604806ull, 3409915766259543840ull}},
{{16322981116871727348ull, 12468961913835278980ull,
  13222069282645756007ull, 4262394707824429800ull}},
{{978491161190053785ull, 14710630223788131219ull,
  8263793301653597504ull, 2663996692390268625ull}},
{{15058172006769730943ull, 18388287779735164023ull,
  14941427645494384784ull, 3329995865487835781ull}},
{{14211028990034775774ull, 4538615650959403413ull,
  4841726501585817269ull, 4162494831859794727ull}},
{{11187736127985428811ull, 5142477791063321085ull,
  9943608091132217649ull, 2601559269912371704ull}},
{{149612104699622302ull, 11039783257256539261ull,
  12429510113915272061ull, 3251949087390464630ull}},
{{4798701149301915781ull, 18411415089998061980ull,
  6313515605539314268ull, 4064936359238080788ull}},
{{12222560255168473171ull, 2283762394394012929ull,
  13169319290316847226ull, 2540585224523800492ull}},
{{1443142263678427752ull, 12078075029847291970ull,
  16461649112896059032ull, 3175731530654750615ull}},
{{11027299866452810498ull, 15097593787309114962ull,
  15965375372692685886ull, 3969664413318438269ull}},
{{11503748434960394466ull, 4824310098640808947ull,
  12284202617146622631ull, 2481040258324023918ull}},
{{9767999525273105178ull, 1418701604873623280ull,
  6131881234578502481ull, 3101300322905029898ull}},
{{12209999406591381472ull, 6385063024519417004ull,
  16888223580077903909ull, 3876625403631287372ull}},
{{16854621665974389228ull, 6296507399538329579ull,
  1331767700693914135ull, 2422890877269554608ull}},
{{16456591064040598631ull, 3258948230995524070ull,
  1664709625867392669ull, 3028613596586943260ull}},
{{11347366793195972481ull, 8685371307171792992ull,
  2080887032334240836ull, 3785766995733679075ull}},
{{7092104245747482801ull, 14651729103837146428ull,
  17441455459704758186ull, 2366104372333549421ull}},
{{8865130307184353501ull, 9091289342941657227ull,
  7966761269348784021ull, 2957630465416936777ull}},
{{6469726865553053972ull, 15975797697104459438ull,
  14570137605113367930ull, 3697038081771170971ull}},
{{17878637346252822445ull, 14596559579117675052ull,
  6800492993982161004ull, 2310648801106981857ull}},
{{3901552609106476440ull, 18245699473897093816ull,
  13112302260905089159ull, 2888311001383727321ull}},
{{4876940761383095549ull, 18195438323943979366ull,
  2555319770849197737ull, 3610388751729659152ull}},
{{15319547988583645245ull, 8909239849647810495ull,
  3194149713561497172ull, 4512985939662073940ull}},
{{16492246520505860134ull, 14791646942884657367ull,
  11219715607830711540ull, 2820616212288796212ull}},
{{16003622132204937264ull, 42814604896270093ull,
  14024644509788389426ull, 3525770265360995265ull}},
{{6169469609974007867ull, 9276890292975113425ull,
  3695747581953323070ull, 4407212831701244082ull}},
{{15385133552302224677ull, 1186370414682057986ull,
  6921528257148214823ull, 2754508019813277551ull}},
{{10008044903523005038ull, 15318021073634736195ull,
  4040224303007880624ull, 3443135024766596939ull}},
{{7898370110976368394ull, 700782268333868628ull, 438594360332462877ull,
  4303918780958246174ull}},
{{14159853356215006054ull, 2743831926922361844ull,
  14109179530489953010ull, 2689949238098903858ull}},
{{17699816695268757568ull, 12653161945507728113ull,
  8413102376257665454ull, 3362436547623629823ull}},
{{8289712813803783248ull, 6593080395029884334ull,
  5904691951894693914ull, 4203045684529537279ull}},
{{569384490199976626ull, 8732361265321065613ull,
  10607961497575265552ull, 2626903552830960799ull}},
{{5323416631177358686ull, 10915451581651332016ull,
  8648265853541694036ull, 3283629441038700999ull}},
{{6654270788971698358ull, 13644314477064165020ull,
  6198646298499729641ull, 4104536801298376249ull}},
{{13382291279962087282ull, 1610167520524021281ull,
  15403368982630800786ull, 2565335500811485155ull}},
{{2892806044670445390ull, 11236081437509802410ull,
  14642525209861113078ull, 3206669376014356444ull}}
};

// **********************************************************************

#if __ENABLE_BINARY80__

static const UINT128 breakpoints_binary80[] =
  { {{6337302757928054309ull, 494016656451265ull}},
{{5069842206342443447ull, 395213325161012ull}},
{{15123920209299685727ull, 316170660128809ull}},
{{13130225890653766194ull, 505873056206095ull}},
{{10504180712523012955ull, 404698444964876ull}},
{{4713995755276500041ull, 323758755971901ull}},
{{163695578958579419ull, 518014009555042ull}},
{{11199002907392594505ull, 414411207644033ull}},
{{16337899955397896250ull, 331528966115226ull}},
{{315198225443261738ull, 530446345784363ull}},
{{7630856209838430037ull, 424357076627490ull}},
{{6104684967870744030ull, 339485661301992ull}},
{{13456844763335100771ull, 543177058083187ull}},
{{3386778181184259970ull, 434541646466550ull}},
{{2709422544947407976ull, 347633317173240ull}},
{{4335076071915852762ull, 556213307477184ull}},
{{7157409672274592533ull, 444970645981747ull}},
{{16793974182045404996ull, 355976516785397ull}},
{{6056481716152503350ull, 284781213428318ull}},
{{6001021931102095037ull, 455649941485309ull}},
{{8490166359623586353ull, 364519953188247ull}},
{{17860179531924600052ull, 291615962550597ull}},
{{13818891992111718790ull, 466585540080956ull}},
{{7365764778947464709ull, 373268432064765ull}},
{{5892611823157971767ull, 298614745651812ull}},
{{13117527731794665151ull, 477783593042899ull}},
{{14183371000177642444ull, 382226874434319ull}},
{{15036045614884024278ull, 305781499547455ull}},
{{5610928910104887229ull, 489250399275929ull}},
{{8178091942825820106ull, 391400319420743ull}},
{{13921171183744476731ull, 313120255536594ull}},
{{11205827449765431801ull, 500992408858551ull}},
{{5275313145070435117ull, 400793927086841ull}},
{{530901701314437771ull, 320635141669473ull}},
{{15606837981070741726ull, 513016226671156ull}},
{{8796121570114683058ull, 410412981336925ull}},
{{7036897256091746446ull, 328330385069540ull}},
{{11259035609746794314ull, 525328616111264ull}},
{{12696577302539345774ull, 420262892889011ull}},
{{6467913027289566296ull, 336210314311209ull}},
{{17727358473147126720ull, 537936502897934ull}},
{{17871235593259611699ull, 430349202318347ull}},
{{6918290845123868713ull, 344279361854678ull}},
{{7379916537456279618ull, 550846978967485ull}},
{{5903933229965023694ull, 440677583173988ull}},
{{12101844213455839602ull, 352542066539190ull}},
{{9681475370764671681ull, 282033653231352ull}},
{{732965334255833398ull, 451253845170164ull}},
{{4275721082146577041ull, 361003076136131ull}},
{{18177972124684902926ull, 288802460908904ull}},
{{18016708955270113712ull, 462083937454247ull}},
{{7034669534732270323ull, 369667149963398ull}},
{{13006433257269636905ull, 295733719970718ull}},
{{17120944396889508724ull, 473173951953149ull}},
{{17386104332253517303ull, 378539161562519ull}},
{{17598232280544724165ull, 302831329250015ull}},
{{9710427575162007049ull, 484530126800025ull}},
{{7768342060129605639ull, 387624101440020ull}},
{{6214673648103684511ull, 310099281152016ull}},
{{2564780207482074571ull, 496158849843226ull}},
{{16809219424953300950ull, 396927079874580ull}},
{{13447375539962640760ull, 317541663899664ull}},
{{10447754419714494246ull, 508066662239463ull}},
{{15736901165255416043ull, 406453329791570ull}},
{{12589520932204332835ull, 325162663833256ull}},
{{12764535862043111889ull, 520260262133210ull}},
{{10211628689634489511ull, 416208209706568ull}},
{{15548000581191412255ull, 332966567765254ull}},
{{13808754485680528639ull, 532746508424407ull}},
{{3668305959060602265ull, 426197206739526ull}},
{{17692040026216123105ull, 340957765391620ull}},
{{9860519968236245352ull, 545532424626593ull}},
{{15267113604072816928ull, 436425939701274ull}},
{{15903039698000163865ull, 349140751761019ull}},
{{14376817072574531215ull, 558625202817631ull}},
{{7812104843317714649ull, 446900162254105ull}},
{{6249683874654171719ull, 357520129803284ull}},
{{8689095914465247698ull, 286016103842627ull}},
{{17591902277886306641ull, 457625766148203ull}},
{{3005475378083314343ull, 366100612918563ull}},
{{9783077931950472121ull, 292880490334850ull}},
{{15652924691120755393ull, 468608784535760ull}},
{{12522339752896604314ull, 374887027628608ull}},
{{17396569431801104098ull, 299909622102886ull}},
{{2009069387688394294ull, 479855395364619ull}},
{{5296604324892625759ull, 383884316291695ull}},
{{4237283459914100607ull, 307107453033356ull}},
{{17847699980088291941ull, 491371924853369ull}},
{{17967508798812543876ull, 393097539882695ull}},
{{14374007039050035101ull, 314478031906156ull}},
{{15619713632996235515ull, 503164851049850ull}},
{{12495770906396988412ull, 402531880839880ull}},
{{9996616725117590729ull, 322025504671904ull}},
{{4926540315962414197ull, 515240807475047ull}},
{{15009278696995662327ull, 412192645980037ull}},
{{4628725328112709215ull, 329754116784030ull}},
{{7405960524980334745ull, 527606586854448ull}},
{{13303466049468088442ull, 422085269483558ull}},
{{18021470469058291400ull, 337668215586846ull}},
{{3008911047299893978ull, 540269144938955ull}},
{{2407128837839915182ull, 432215315951164ull}},
{{5615051885013842469ull, 345772252760931ull}},
{{1605385386538327304ull, 553235604417490ull}},
{{1284308309230661843ull, 442588483533992ull}},
{{12095493091610260444ull, 354070786827193ull}},
{{17055092102772029002ull, 283256629461754ull}},
{{16220100920209515433ull, 453210607138807ull}},
{{5597383106683791700ull, 362568485711046ull}},
{{788557670605123037ull, 290054788568837ull}},
{{4951041087710107183ull, 464087661710139ull}},
{{7650181684909996069ull, 371270129368111ull}},
{{2430796533186086532ull, 297016103494489ull}},
{{11267972082581559098ull, 475225765591182ull}},
{{1635680036581426632ull, 380180612472946ull}},
{{16065939288232782598ull, 304144489978356ull}},
{{18326805231688631511ull, 486631183965370ull}},
{{14661444185350905209ull, 389304947172296ull}},
{{8039806533538813844ull, 311443957737837ull}},
{{16553039268404012473ull, 498310332380539ull}},
{{16931780229465120302ull, 398648265904431ull}},
{{9856075368830185918ull, 318918612723545ull}},
{{15769720590128297469ull, 510269780357672ull}},
{{5237078842618817329ull, 408215824286138ull}},
{{11568360703578874509ull, 326572659428910ull}},
{{62633052016647599ull, 522516255086257ull}},
{{11118152885839049049ull, 418013004069005ull}},
{{8894522308671239239ull, 334410403255204ull}},
{{3163189249648251813ull, 535056645208327ull}},
{{13598597843944332420ull, 428045316166661ull}},
{{7189529460413555613ull, 342436252933329ull}},
{{435200692435958011ull, 547898004693327ull}},
{{11416206998174497378ull, 438318403754661ull}},
{{5443616783797687579ull, 350654723003729ull}},
{{16088484483560120774ull, 561047556805966ull}},
{{9181438772106186296ull, 448838045444773ull}},
{{14723848647168769683ull, 359070436355818ull}},
{{711032473509284777ull, 287256349084655ull}},
{{1137651957614855643ull, 459610158535448ull}},
{{8288819195575705161ull, 367688126828358ull}},
{{14009752985944384775ull, 294150501462686ull}},
{{15036907148027194994ull, 470640802340298ull}},
{{961479274196025025ull, 376512641872239ull}},
{{4458532234098730343ull, 301210113497791ull}},
{{18201698018783699519ull, 481936181596465ull}},
{{14561358415026959615ull, 385548945277172ull}},
{{4270389102537747046ull, 308439156221738ull}},
{{3143273749318484950ull, 493502649954781ull}},
{{17272014258422429253ull, 394802119963824ull}},
{{17506960221479853725ull, 315841695971059ull}},
{{16943089910142034991ull, 505346713553695ull}},
{{13554471928113627993ull, 404277370842956ull}},
{{7154228727748992071ull, 323421896674365ull}},
{{11446765964398387314ull, 517475034678984ull}},
{{12846761586260620174ull, 413980027743187ull}},
{{2898711639524675493ull, 331184022194550ull}},
{{4637938623239480789ull, 529894435511280ull}},
{{3710350898591584631ull, 423915548409024ull}},
{{6657629533615178028ull, 339132438727219ull}},
{{18030904883268105491ull, 542611901963550ull}},
{{14424723906614484393ull, 434089521570840ull}},
{{11539779125291587514ull, 347271617256672ull}},
{{3706251341498898730ull, 555634587610676ull}},
{{17722396332166760277ull, 444507670088540ull}},
{{14177917065733408221ull, 355606136070832ull}},
{{3963636023102905931ull, 284484908856666ull}},
{{17409864081190380459ull, 455175854170665ull}},
{{13927891264952304367ull, 364140683336532ull}},
{{3763615382478022847ull, 291312546669226ull}},
{{17089831056190567525ull, 466100074670761ull}},
{{9982516030210543697ull, 372880059736609ull}},
{{11675361638910345281ull, 298304047789287ull}},
{{3923183363288911157ull, 477286476462860ull}},
{{3138546690631128925ull, 381829181170288ull}},
{{9889534981988723786ull, 305463344936230ull}},
{{15823255971181958059ull, 488741351897968ull}},
{{1590558332719835477ull, 390993081518375ull}},
{{1272446666175868382ull, 312794465214700ull}},
{{2035914665881389411ull, 500471144343520ull}},
{{1628731732705111529ull, 400376915474816ull}},
{{16060380645131730516ull, 320301532379852ull}},
{{10939213773243127533ull, 512482451807764ull}},
{{12440719833336412349ull, 409985961446211ull}},
{{6263227051927219556ull, 327988769156969ull}},
{{17399860912567371936ull, 524782030651150ull}},
{{13919888730053897549ull, 419825624520920ull}},
{{11135910984043118039ull, 335860499616736ull}},
{{10438759944985168216ull, 537376799386778ull}},
{{15729705585471955219ull, 429901439509422ull}},
{{5205066838893743529ull, 343921151607538ull}},
{{4638758127488079324ull, 550273842572061ull}},
{{21657687248553136ull, 440219074057649ull}},
{{3706674964540752832ull, 352175259246119ull}},
{{6654688786374512588ull, 281740207396895ull}},
{{10647502058199220142ull, 450784331835032ull}},
{{1139304017075555467ull, 360627465468026ull}},
{{15668838472628085666ull, 288501972374420ull}},
{{6623397482495385450ull, 461603155799073ull}},
{{12677415615480129006ull, 369282524639258ull}},
{{17520630121867923851ull, 295426019711406ull}},
{{2207566491795305900ull, 472681631538251ull}},
{{16523448452403886013ull, 378145305230600ull}},
{{13218758761923108810ull, 302516244184480ull}},
{{2703269945367422481ull, 484025990695169ull}},
{{5851964771035848308ull, 387220792556135ull}},
{{4681571816828678646ull, 309776634044908ull}},
{{3801166092183975511ull, 495642614471853ull}},
{{10419630503231001055ull, 396514091577482ull}},
{{957006773100980197ull, 317211273261986ull}},
{{12599257281187299286ull, 507538037219177ull}},
{{2700708195466018782ull, 406030429775342ull}},
{{13228613000598545995ull, 324824343820273ull}},
{{17476431986215763269ull, 519718950112437ull}},
{{6602447959488789969ull, 415775160089950ull}},
{{5281958367591031975ull, 332620128071960ull}},
{{8451133388145651160ull, 532192204915136ull}},
{{3071557895774610605ull, 425753763932109ull}},
{{6146595131361598807ull, 340603011145687ull}},
{{13523901024920468415ull, 544964817833099ull}},
{{14508469634678285055ull, 435971854266479ull}},
{{15296124522484538367ull, 348777483413183ull}},
{{2337706347523799448ull, 558043973461094ull}},
{{5559513892760949882ull, 446435178768875ull}},
{{4447611114208759905ull, 357148143015100ull}},
{{3558088891367007924ull, 285718514412080ull}},
{{5692942226187212679ull, 457149623059328ull}},
{{11933051410433590789ull, 365719698447462ull}},
{{2167743498863051985ull, 292575758757970ull}},
{{3468389598180883176ull, 468121214012752ull}},
{{13842758122770437511ull, 374496971210201ull}},
{{7384857683474439685ull, 299597576968161ull}},
{{4437074664075282850ull, 479356123149058ull}},
{{10928357360744046927ull, 383484898519246ull}},
{{5053337073853327218ull, 306787918815397ull}},
{{11774688132907233872ull, 490860670104635ull}},
{{9419750506325787098ull, 392688536083708ull}},
{{14914498034544450324ull, 314150828866966ull}},
{{16484499225787299873ull, 502641326187146ull}},
{{9498250565887929575ull, 402113060949717ull}},
{{219902823226523014ull, 321690448759774ull}},
{{7730542146646257468ull, 514704718015638ull}},
{{13563131346800826621ull, 411763774412510ull}},
{{10850505077440661297ull, 329411019530008ull}},
{{13671459309163147752ull, 527057631248013ull}},
{{18315865076814338848ull, 421646104998410ull}},
{{14652692061451471078ull, 337316883998728ull}},
{{1308214409870891786ull, 539707014397966ull}},
{{15803966786864354722ull, 431765611518372ull}},
{{5264475800007663131ull, 345412489214698ull}},
{{4733812465270350686ull, 552659982743517ull}},
{{14855096416442011519ull, 442127986194813ull}},
{{816030688927878245ull, 353702388955851ull}},
{{15410219810109943889ull, 282961911164680ull}},
{{6209607622466358606ull, 452739057863489ull}},
{{8657034912714997208ull, 362191246290791ull}},
{{3236279115430087443ull, 289752997032633ull}},
{{1488697769946229586ull, 463604795252213ull}},
{{8569655845440804315ull, 370883836201770ull}},
{{6855724676352643452ull, 296707068961416ull}},
{{3590461852680408877ull, 474731310338266ull}},
{{17629764741111968395ull, 379785048270612ull}},
{{6725114163405754069ull, 303828038616490ull}},
{{10760182661449206511ull, 486124861786384ull}},
{{12297494943901275532ull, 388899889429107ull}},
{{2459298325637199779ull, 311119911543286ull}},
{{15002923765245250616ull, 497791858469257ull}},
{{4623641382712379847ull, 398233486775406ull}},
{{9564291427993554ull, 318586789420325ull}},
{{15302866284789687ull, 509738863072520ull}},
{{12242293027831749ull, 407791090458016ull}},
{{14767189093389906692ull, 326232872366412ull}},
{{8870107290456209415ull, 521972595786260ull}},
{{7096085832364967532ull, 417578076629008ull}},
{{13055566295375794672ull, 334062461303206ull}},
{{13510208443117450829ull, 534499938085130ull}},
{{10808166754493960663ull, 427599950468104ull}},
{{12335882218337078853ull, 342079960374483ull}},
{{16048062734597415842ull, 547327936599173ull}},
{{1770403743452201704ull, 437862349279339ull}},
{{5105671809503671686ull, 350289879423471ull}},
{{790377265722054052ull, 560463807077554ull}},
{{4321650627319553565ull, 448371045662043ull}},
{{10836018131339463498ull, 358696836529634ull}},
{{12358163319813481122ull, 286957469223707ull}},
{{5015666052733928502ull, 459131950757932ull}},
{{15080579286412873771ull, 367305560606345ull}},
{{12064463429130299017ull, 293844448485076ull}},
{{11924443857124657781ull, 470151117576122ull}},
{{2160857456215905578ull, 376120894060898ull}},
{{9107383594456545109ull, 300896715248718ull}},
{{10882464936388561851ull, 481434744397949ull}},
{{12395320763852759804ull, 385147795518359ull}},
{{13605605425824118166ull, 308118236414687ull}},
{{7011573422350947774ull, 492989178263500ull}},
{{5609258737880758219ull, 394391342610800ull}},
{{4487406990304606575ull, 315513074088640ull}},
{{7179851184487370520ull, 504820918541824ull}},
{{9433229762331806739ull, 403856734833459ull}},
{{11235932624607355715ull, 323085387866767ull}},
{{3220096940404127851ull, 516936620586828ull}},
{{9954775181807122927ull, 413549296469462ull}},
{{585122515961877695ull, 330839437175570ull}},
{{936196025539004313ull, 529343099480912ull}},
{{11817003264656934420ull, 423474479584729ull}},
{{13142951426467457859ull, 338779583667783ull}},
{{17339373467606022251ull, 542047333868453ull}},
{{2803452329859086831ull, 433637867094763ull}},
{{9621459493371090111ull, 346910293675810ull}},
{{15394335189393744178ull, 555056469881296ull}},
{{8626119336773085019ull, 444045175905037ull}},
{{17968941913644198985ull, 355236140724029ull}},
{{18064502345657269511ull, 284188912579223ull}},
{{6767110864600169279ull, 454702260126758ull}},
{{12792386321163956069ull, 363761808101406ull}},
{{6544560242189254532ull, 291009446481125ull}},
{{10471296387502807252ull, 465615114369800ull}},
{{8377037110002245801ull, 372492091495840ull}},
{{6701629688001796641ull, 297993673196672ull}},
{{14411956315544784949ull, 476789877114675ull}},
{{11529565052435827959ull, 381431901691740ull}},
{{9223652041948662367ull, 305145521353392ull}},
{{448008150218495ull, 488232834165428ull}},
{{7379056036003995442ull, 390586267332342ull}},
{{16971291273028927323ull, 312469013865873ull}},
{{5017973148394821778ull, 499950422185398ull}},
{{11393076148199678069ull, 399960337748318ull}},
{{16493158548043563102ull, 319968270198654ull}},
{{15321007232643969993ull, 511949232317847ull}},
{{4878108156631355348ull, 409559385854278ull}},
{{11281184154788904925ull, 327647508683422ull}},
{{3292499388694606587ull, 524236013893476ull}},
{{17391394769923326562ull, 419388811114780ull}},
{{13913115815938661250ull, 335511048891824ull}},
{{11192938861276127030ull, 536817678226919ull}},
{{12643699903762811947ull, 429454142581535ull}},
{{10114959923010249558ull, 343563314065228ull}},
{{12494587062074488970ull, 549701302504365ull}},
{{9995669649659591176ull, 439761042003492ull}},
{{617838090243852294ull, 351808833602794ull}},
{{8367238573873984317ull, 562894133764470ull}},
{{6693790859099187453ull, 450315307011576ull}},
{{1665683872537439639ull, 360252245609261ull}},
{{16089942356997593004ull, 288201796487408ull}},
{{3607814882744686868ull, 461122874379854ull}},
{{6575600720937659817ull, 368898299503883ull}},
{{12639178206233948500ull, 295118639603106ull}},
{{12843987500490496954ull, 472189823364970ull}},
{{10275190000392397563ull, 377751858691976ull}},
{{4530803185572007727ull, 302201486953581ull}},
{{18317331541140943334ull, 483522379125729ull}},
{{18343214047654664990ull, 386817903300583ull}},
{{3606524793898001022ull, 309454322640467ull}},
{{9459788484978711959ull, 495126916224747ull}},
{{189133158499148921ull, 396101532979798ull}},
{{7530004156283139783ull, 316881226383838ull}},
{{8358657835311113330ull, 507009962214141ull}},
{{2997577453506980341ull, 405607969771313ull}},
{{9776759592289404919ull, 324486375817050ull}},
{{15642815347663047870ull, 519178201307280ull}},
{{12514252278130438296ull, 415342561045824ull}},
{{13700750637246260960ull, 332274048836659ull}},
{{10853154575368286567ull, 531638478138655ull}},
{{8682523660294629253ull, 425310782510924ull}},
{{10635367742977613726ull, 340248626008739ull}},
{{5948541944538450992ull, 544397801613983ull}},
{{12137531185114581440ull, 435518241291186ull}},
{{6020676133349754829ull, 348414593032949ull}},
{{17011779442843428373ull, 557463348852718ull}},
{{2541377110049011728ull, 445970679082175ull}},
{{2033101688039209383ull, 356776543265740ull}},
{{1626481350431367506ull, 285421234612592ull}},
{{6291718975432098333ull, 456673975380147ull}},
{{16101421624571409636ull, 365339180304117ull}},
{{5502439670173307062ull, 292271344243294ull}},
{{16182601101761111946ull, 467634150789270ull}},
{{12946080881408889557ull, 374107320631416ull}},
{{6667515890385201322ull, 299285856505133ull}},
{{6978676609874411793ull, 478857370408213ull}},
{{12961638917383350080ull, 383085896326570ull}},
{{10369311133906680064ull, 306468717061256ull}},
{{9212200184766867457ull, 490349947298010ull}},
{{7369760147813493965ull, 392279957838408ull}},
{{13274505747734615819ull, 313823966270726ull}},
{{13860511566891564664ull, 502118346033162ull}},
{{3709711624029431084ull, 401694676826530ull}},
{{2967769299223544867ull, 321355741461224ull}},
{{12127128508241492434ull, 514169186337958ull}},
{{17080400436077014594ull, 411335349070366ull}},
{{9974971534119701352ull, 329068279256293ull}},
{{12270605639849611840ull, 526509246810069ull}},
{{13505833326621599795ull, 421207397448055ull}},
{{10804666661297279836ull, 336965917958444ull}},
{{6219420213849916768ull, 539145468733511ull}},
{{1286187356338023091ull, 431316374986809ull}},
{{4718298699812328796ull, 345053099989447ull}},
{{11238626734441636397ull, 552084959983115ull}},
{{8990901387553309118ull, 441667967986492ull}},
{{18260767554268378264ull, 353334374389193ull}},
{{3540567599188971641ull, 282667499511355ull}},
{{5664908158702354626ull, 452267999218168ull}},
{{11910624156445704347ull, 361814399374534ull}},
{{13217848139898473801ull, 289451519499627ull}},
{{6391161764869916789ull, 463122431199404ull}},
{{8802278226637843754ull, 370497944959523ull}},
{{14420520210794095650ull, 296398355967618ull}},
{{936739448819091101ull, 474237369548190ull}},
{{749391559055272880ull, 379389895638552ull}},
{{11667559691469949274ull, 303511916510841ull}},
{{11289397876868098192ull, 485619066417346ull}},
{{5342169486752568230ull, 388495253133877ull}},
{{15341782033627785554ull, 310796202507101ull}},
{{17168153624320636240ull, 497273924011362ull}},
{{6355825269972688346ull, 397819139209090ull}},
{{5084660215978150676ull, 318255311367272ull}},
{{11824805160306951406ull, 509208498187635ull}},
{{9459844128245561124ull, 407366798550108ull}},
{{14946572932080269546ull, 325893438840086ull}},
{{16535819061844610627ull, 521429502144138ull}},
{{2160608805249957532ull, 417143601715311ull}},
{{16485882303167607318ull, 333714881372248ull}},
{{4241318796616709770ull, 533943810195598ull}},
{{10771752666777188463ull, 427155048156478ull}},
{{15996099762905571416ull, 341724038525182ull}},
{{10836364361681272974ull, 546758461640292ull}},
{{1290393859861197733ull, 437406769312234ull}},
{{4721663902630868509ull, 349925415449787ull}},
{{11244011058951299938ull, 559880664719659ull}},
{{12684557661902950274ull, 447904531775727ull}},
{{2768948500038539572ull, 358323625420582ull}},
{{13283205244256562627ull, 286658900336465ull}},
{{2806384317100948588ull, 458654240538345ull}},
{{2245107453680758870ull, 366923392430676ull}},
{{16553481221912248389ull, 293538713944540ull}},
{{8038825881350045807ull, 469661942311265ull}},
{{6431060705080036645ull, 375729553849012ull}},
{{16212895008289760286ull, 300583643079209ull}},
{{14872585569037885488ull, 480933828926735ull}},
{{11898068455230308390ull, 384747063141388ull}},
{{16897152393668067358ull, 307797650513110ull}},
{{8588699756159356158ull, 492476240820977ull}},
{{17939006249153215896ull, 393980992656781ull}},
{{10661856184580662393ull, 315184794125425ull}},
{{17058969895329059830ull, 504295670600680ull}},
{{13647175916263247864ull, 403436536480544ull}},
{{14607089547752508614ull, 322749229184435ull}},
{{4924599202694462167ull, 516398766695097ull}},
{{15007725806381300703ull, 413119013356077ull}},
{{4627483015621219916ull, 330495210684862ull}},
{{11093321639735862189ull, 528792337095779ull}},
{{12564006126530600074ull, 423033869676623ull}},
{{17429902530708300706ull, 338427095741298ull}},
{{5751751160681819190ull, 541483353186078ull}},
{{11980098558029275998ull, 433186682548862ull}},
{{2205381216939600152ull, 346549346039090ull}},
{{3528609947103360244ull, 554478953662544ull}},
{{6512236772424598518ull, 443583162930035ull}},
{{5209789417939678814ull, 354866530344028ull}},
{{11546529163835563698ull, 283893224275222ull}},
{{3717051403169260624ull, 454229158840356ull}},
{{17731036381503049792ull, 363383327072284ull}},
{{17874177919944350157ull, 290706661657827ull}},
{{13841289412943318958ull, 465130658652524ull}},
{{14762380345096565490ull, 372104526922019ull}},
{{15499253090819162715ull, 297683621537615ull}},
{{6352060871601108728ull, 476293794460185ull}},
{{5081648697280886982ull, 381035035568148ull}},
{{11444016587308530232ull, 304828028454518ull}},
{{14621077724951738048ull, 487724845527229ull}},
{{15386210994703300762ull, 390179876421783ull}},
{{1240922351536909640ull, 312143901137427ull}},
{{5674824577200965747ull, 499430241819883ull}},
{{11918557291244593244ull, 399544193455906ull}},
{{5845497018253764272ull, 319635354764725ull}},
{{9352795229206022835ull, 511416567623560ull}},
{{7482236183364818268ull, 409133254098848ull}},
{{13364486576175675261ull, 327306603279078ull}},
{{17693829707139170094ull, 523690565246525ull}},
{{14155063765711336075ull, 418952452197220ull}},
{{11324051012569068860ull, 335161961757776ull}},
{{10739783990626689530ull, 536259138812442ull}},
{{1213129563017530978ull, 429007311049954ull}},
{{4659852465155935105ull, 343205848839963ull}},
{{3766415129507585846ull, 549129358143941ull}},
{{17770527362573709969ull, 439303486515152ull}},
{{6837724260575147329ull, 351442789212122ull}},
{{14629707631662146050ull, 562308462739395ull}},
{{11703766105329716840ull, 449846770191516ull}},
{{5673664069521863148ull, 359877416153213ull}},
{{11917628885101311165ull, 287901932922570ull}},
{{621462142452546248ull, 460643092676113ull}},
{{7875867343445857645ull, 368514474140890ull}},
{{6300693874756686116ull, 294811579312712ull}},
{{13770459014352608109ull, 471698526900339ull}},
{{14705716026223996810ull, 377358821520271ull}},
{{8075224006237287125ull, 301887057216217ull}},
{{16609707224721569723ull, 483019291545947ull}},
{{5909068150293435132ull, 386415433236758ull}},
{{12105952149718568752ull, 309132346589406ull}},
{{11990825810065889357ull, 494611754543050ull}},
{{9592660648052711486ull, 395689403634440ull}},
{{7674128518442169188ull, 316551522907552ull}},
{{15967954444249381025ull, 506482436652083ull}},
{{1706317111173773850ull, 405185949321667ull}},
{{12433100133164750050ull, 324148759457333ull}},
{{16203611398321689757ull, 518638015131733ull}},
{{1894842674431620836ull, 414910412105387ull}},
{{12583920583771027638ull, 331928329684309ull}},
{{9066226489807913251ull, 531085327494895ull}},
{{7252981191846330601ull, 424868261995916ull}},
{{2113036138735154157ull, 339894609596733ull}},
{{18138253080943887945ull, 543831375354772ull}},
{{7131904835271289710ull, 435065100283818ull}},
{{13084221497700852414ull, 348052080227054ull}},
{{9866707952095632893ull, 556883328363287ull}},
{{514668732192685668ull, 445506662690630ull}},
{{411734985754148534ull, 356405330152504ull}},
{{4018736803345229150ull, 285124264122003ull}},
{{2740630070610456318ull, 456198822595205ull}},
{{2192504056488365054ull, 364959058076164ull}},
{{5443352059932602366ull, 291967246460931ull}},
{{1330665666408343140ull, 467147594337490ull}},
{{1064532533126674512ull, 373718075469992ull}},
{{11919672470727070579ull, 298974460375993ull}},
{{15382127138421402604ull, 478359136601589ull}},
{{15995050525479032406ull, 382687309281271ull}},
{{9106691605641315602ull, 306149847425017ull}},
{{18260055383768015286ull, 489839755880027ull}},
{{7229346677530591582ull, 391871804704022ull}},
{{16851523786250204235ull, 313497443763217ull}},
{{12205042799032685484ull, 501595910021148ull}},
{{17142731868709969034ull, 401276728016918ull}},
{{2646139050742244257ull, 321021382413535ull}},
{{4233822481187590812ull, 513634211861656ull}},
{{18144453243917713942ull, 410907369489324ull}},
{{18204911409876081477ull, 328725895591459ull}},
{{18059811811575999394ull, 525961432946335ull}},
{{14447849449260799515ull, 420769146357068ull}},
{{490233115182908642ull, 336615317085655ull}},
{{784372984292653828ull, 538584507337048ull}},
{{8006196016917943708ull, 430867605869638ull}},
{{13783654443018175613ull, 344694084695710ull}},
{{3607103035119529365ull, 551510535513137ull}},
{{13953728872321354462ull, 441208428410509ull}},
{{14852331912598993892ull, 352966742728407ull}},
{{4503167900595374467ull, 282373394182726ull}},
{{18273115085178330118ull, 451797430692361ull}},
{{10929143253400753771ull, 361437944553889ull}},
{{12432663417462513340ull, 289150355643111ull}},
{{12513563838456200698ull, 462640569028978ull}},
{{17389548700248781204ull, 370112455223182ull}},
{{6532941330715204317ull, 296089964178546ull}},
{{3074008499660506261ull, 473743942685674ull}},
{{6148555614470315332ull, 378995154148539ull}},
{{8608193306318162589ull, 303196123318831ull}},
{{6394411660625239496ull, 485113797310130ull}},
{{5115529328500191597ull, 388091037848104ull}},
{{7781772277542063600ull, 310472830278483ull}},
{{8761486829325391438ull, 496756528445573ull}},
{{14387887092944133796ull, 397405222756458ull}},
{{442263230129576067ull, 317924178205167ull}},
{{4396969982949232031ull, 508678685128267ull}},
{{14585622430585116595ull, 406942948102613ull}},
{{600451500242362306ull, 325554358482091ull}},
{{12028768844613510660ull, 520886973571345ull}},
{{9623015075690808528ull, 416709578857076ull}},
{{4009063245810736499ull, 333367663085661ull}},
{{17482547637522909368ull, 533388260937057ull}},
{{6607340480534506848ull, 426710608749646ull}},
{{1596523569685695155ull, 341368486999717ull}},
{{6243786526239022571ull, 546189579199547ull}},
{{16063075665216949027ull, 436951663359637ull}},
{{5471762902689738575ull, 349561330687710ull}},
{{8754820644303581720ull, 559298129100336ull}},
{{3314507700700955053ull, 447438503280269ull}},
{{6340954975302674365ull, 357950802624215ull}},
{{5072763980242139492ull, 286360642099372ull}},
{{11805771183129333511ull, 458177027358995ull}},
{{9444616946503466809ull, 366541621887196ull}},
{{3866344742460863124ull, 293233297509757ull}},
{{9875500402679291321ull, 469173276015611ull}},
{{4211051507401522734ull, 375338620812489ull}},
{{7058190020663128510ull, 300270896649991ull}},
{{3914406403577184970ull, 480433434639986ull}},
{{17888920381829389269ull, 384346747711988ull}},
{{3243089861237780445ull, 307477398169591ull}},
{{16256990222206179682ull, 491963837071345ull}},
{{13005592177764943746ull, 393571069657076ull}},
{{6715124927470044673ull, 314856855725661ull}},
{{3365502254468250831ull, 503770969161058ull}},
{{10071099433058421311ull, 403016775328846ull}},
{{4367530731704826726ull, 322413420263077ull}},
{{10677397985469633085ull, 515861472420923ull}},
{{15920616017859527114ull, 412689177936738ull}},
{{1668446370061890721ull, 330151342349391ull}},
{{13737560636324756124ull, 528242147759025ull}},
{{10990048509059804899ull, 422593718207220ull}},
{{8792038807247843919ull, 338074974565776ull}},
{{6688564462112729625ull, 540919959305242ull}},
{{16418898013915914669ull, 432735967444193ull}},
{{2067071966907000766ull, 346188773955355ull}},
{{3307315147051201226ull, 553902038328568ull}},
{{10024549747124781627ull, 443121630662854ull}},
{{11708988612441735624ull, 354497304530283ull}},
{{16745888519437209146ull, 283597843624226ull}},
{{967979927906162371ull, 453756549798763ull}},
{{8153081571808750543ull, 363005239839010ull}},
{{6522465257447000435ull, 290404191871208ull}},
{{6746595597173290372ull, 464646706993933ull}},
{{12775974107222452944ull, 371717365595146ull}},
{{6531430471036052032ull, 297373892476117ull}},
{{14139637568399593575ull, 475798227961787ull}},
{{3933012425235854213ull, 380638582369430ull}},
{{3146409940188683371ull, 304510865895544ull}},
{{12412953533785714040ull, 487217385432870ull}},
{{9930362827028571232ull, 389773908346296ull}},
{{4254941446880946662ull, 311819126677037ull}},
{{10497255129751424983ull, 498910602683259ull}},
{{12087152918543050309ull, 399128482146607ull}},
{{2291024705350619601ull, 319302785717286ull}},
{{14733685972786722331ull, 510884457147657ull}},
{{4408251148745557219ull, 408707565718126ull}},
{{18283996177964087068ull, 326966052574500ull}},
{{10807649811032987692ull, 523145684119201ull}},
{{4956771034084479831ull, 418516547295361ull}},
{{276068012525673541ull, 334813237836289ull}},
{{7820406449524898313ull, 535701180538062ull}},
{{17324371603845649620ull, 428560944430449ull}},
{{17548846097818430019ull, 342848755544359ull}},
{{17010107312283757061ull, 548558008870975ull}},
{{13608085849827005649ull, 438846407096780ull}},
{{10886468679861604519ull, 351077125677424ull}},
{{6350303443552836261ull, 561723401083879ull}},
{{8769591569584179332ull, 449378720867103ull}},
{{14394370885151164112ull, 359502976693682ull}},
{{4136799078637110643ull, 287602381354946ull}},
{{17686924970045107998ull, 460163810167913ull}},
{{3081493531810355429ull, 368131048134331ull}},
{{17222590084415925636ull, 294504838507464ull}},
{{16488097690839750048ull, 471207741611943ull}},
{{2122431708446069069ull, 376966193289555ull}},
{{1697945366756855255ull, 301572954631644ull}},
{{10095410216294789055ull, 482516727410630ull}},
{{8076328173035831244ull, 386013381928504ull}},
{{10150411353170575318ull, 308810705542803ull}},
{{12551309350331010186ull, 494097128868485ull}},
{{10041047480264808149ull, 395277703094788ull}},
{{15411535613695667165ull, 316222162475830ull}},
{{6211712908203515849ull, 505955459961329ull}},
{{8658719141304723002ull, 404764367969063ull}},
{{14305672942527599048ull, 323811494375250ull}},
{{4442332634334606861ull, 518098391000401ull}},
{{18311261366435326781ull, 414478712800320ull}},
{{14649009093148261425ull, 331582970240256ull}},
{{16059716919553397634ull, 530532752384410ull}},
{{12847773535642718107ull, 424426201907528ull}},
{{17656916457997995132ull, 339540961526022ull}},
{{13493671073829150919ull, 543265538441636ull}},
{{7105588044321410412ull, 434612430753309ull}},
{{9373819250199038652ull, 347689944602647ull}},
{{240715541350820551ull, 556303911364236ull}},
{{14949967692048297734ull, 445043129091388ull}},
{{891927709412907217ull, 356034503273111ull}},
{{15470937426497967066ull, 284827602618488ull}},
{{2617406993945285367ull, 455724164189582ull}},
{{13161972039381959263ull, 364579331351665ull}},
{{10529577631505567411ull, 291663465081332ull}},
{{2089928951441266565ull, 466661544130132ull}},
{{12739989605378744221ull, 373329235304105ull}},
{{10191991684302995377ull, 298663388243284ull}},
{{5239140250659061634ull, 477861421189255ull}},
{{4191312200527249307ull, 382289136951404ull}},
{{7042398575163709769ull, 305831309561123ull}},
{{7578488905520025307ull, 489330095297797ull}},
{{17130837568641751215ull, 391464076238237ull}},
{{6325972425429580325ull, 313171260990590ull}},
{{10121555880687328521ull, 501074017584944ull}},
{{11786593519291773140ull, 400859214067955ull}},
{{9429274815433418512ull, 320687371254364ull}},
{{4018793260467738650ull, 513099794006983ull}},
{{10593732237858011566ull, 410479835205586ull}},
{{4785636975544498930ull, 328383868164469ull}},
{{15035716790355018934ull, 525414189063150ull}},
{{12028573432284015147ull, 420331351250520ull}},
{{9622858745827212118ull, 336265081000416ull}},
{{8017876363839718742ull, 538024129600666ull}},
{{2724952276329864670ull, 430419303680533ull}},
{{9558659450547712383ull, 344335442944426ull}},
{{7915157491392519166ull, 550936708711082ull}},
{{17400172437339746302ull, 440749366968865ull}},
{{13920137949871797042ull, 352599493575092ull}},
{{3757412730413616987ull, 282079594860074ull}},
{{13390557998145607826ull, 451327351776118ull}},
{{18091144028000306907ull, 361061881420894ull}},
{{18162264037142155849ull, 288849505136715ull}},
{{10612878385717897742ull, 462159208218745ull}},
{{8490302708574318193ull, 369727366574996ull}},
{{3102893352117544231ull, 295781893259997ull}},
{{8653978178129981094ull, 473251029215995ull}},
{{6923182542503984875ull, 378600823372796ull}},
{{1849197219261277577ull, 302880658698237ull}},
{{6648064365559954446ull, 484609053917179ull}},
{{9007800307189873880ull, 387687243133743ull}},
{{14584937875235719750ull, 310149794506994ull}},
{{12267854156151420631ull, 496239671211191ull}},
{{6124934510179226182ull, 396991736968953ull}},
{{12278645237627201592ull, 317593389575162ull}},
{{4888437121235881254ull, 508149423320260ull}},
{{3910749696988705003ull, 406519538656208ull}},
{{10507297387074784649ull, 325215630924966ull}},
{{9432978189835834792ull, 520345009479946ull}},
{{3857033737126757510ull, 416276007583957ull}},
{{14153673433927136978ull, 333020806067165ull}},
{{4199133420573867549ull, 532833289707465ull}},
{{3359306736459094039ull, 426266631765972ull}},
{{13755491833393006201ull, 341013305412777ull}},
{{7251391674461168629ull, 545621288660444ull}},
{{9490462154310845226ull, 436497030928355ull}},
{{7592369723448676181ull, 349197624742684ull}},
{{1079745113292150920ull, 558716199588295ull}},
{{863796090633720736ull, 446972959670636ull}},
{{15448432131474617881ull, 357578367736508ull}},
{{1290699260953963335ull, 286062694189207ull}},
{{5754467632268251660ull, 457700310702731ull}},
{{914225291072691005ull, 366160248562185ull}},
{{731380232858152804ull, 292928198849748ull}},
{{15927603631540685779ull, 468685118159596ull}},
{{9052734090490638300ull, 374948094527677ull}},
{{18310233716618241609ull, 299958475622141ull}},
{{3470932243395814313ull, 479933560995427ull}},
{{13844792238942382420ull, 383946848796341ull}},
{{7386484976411995613ull, 307157479037073ull}},
{{8129027147517282657ull, 491451966459317ull}},
{{17571268162239557095ull, 393161573167453ull}},
{{2988968085565914707ull, 314529258533963ull}},
{{1093000122163553208ull, 503246813654341ull}},
{{15631795356698483859ull, 402597450923472ull}},
{{5126738655874966440ull, 322077960738778ull}},
{{4513433034658035982ull, 515324737182045ull}},
{{3610746427726428785ull, 412259789745636ull}},
{{17645992401148784321ull, 329807831796508ull}},
{{6097494953386592975ull, 527692530874414ull}},
{{8567344777451184703ull, 422154024699531ull}},
{{3164527007219037439ull, 337723219759625ull}},
{{5063243211550459903ull, 540357151615400ull}},
{{4050594569240367922ull, 432285721292320ull}},
{{3240475655392294338ull, 345828577033856ull}},
{{16252807492853401910ull, 553325723254169ull}},
{{16691594809024631851ull, 442660578603335ull}},
{{13353275847219705481ull, 354128462882668ull}},
{{18061318307259585031ull, 283302770306134ull}},
{{17830062847389605080ull, 453284432489815ull}},
{{14264050277911684064ull, 362627545991852ull}},
{{4032542592845526605ull, 290102036793482ull}},
{{10141416963294752891ull, 464163258869571ull}},
{{4423784755893891990ull, 371330607095657ull}},
{{14607074248940844561ull, 297064485676525ull}},
{{4924574724595799682ull, 475303177082441ull}},
{{250310964934729422ull, 380242541665953ull}},
{{7578946401431604184ull, 304194033332762ull}},
{{15815663057032477018ull, 486710453332419ull}},
{{16341879260367891938ull, 389368362665935ull}},
{{13073503408294313550ull, 311494690132748ull}},
{{17228256638528991357ull, 498391504212397ull}},
{{6403907681339372439ull, 398713203369918ull}},
{{12501823774555318598ull, 318970562695934ull}},
{{8934871595062778787ull, 510352900313495ull}},
{{7147897276050223030ull, 408282320250796ull}},
{{2028969006098268100ull, 326625856200637ull}},
{{6935699224499139284ull, 522601369921019ull}},
{{9237908194341221750ull, 418081095936815ull}},
{{7390326555472977400ull, 334464876749452ull}},
{{15513871303498674164ull, 535143802799123ull}},
{{1343050598573208361ull, 428115042239299ull}},
{{4763789293600477012ull, 342492033791439ull}},
{{15000760499244583866ull, 547987254066302ull}},
{{4621910769911846446ull, 438389803253042ull}},
{{14765575060155208127ull, 350711842602433ull}},
{{1488827207796871064ull, 561138948163894ull}},
{{4880410580979407174ull, 448911158531115ull}},
{{3904328464783525739ull, 359128926824892ull}},
{{14191509216052551561ull, 287303141459913ull}},
{{570321857232620558ull, 459685026335862ull}},
{{11524303930011827416ull, 367748021068689ull}},
{{12908791958751372256ull, 294198416854951ull}},
{{13275369504518374964ull, 470717466967922ull}},
{{3241597974130879324ull, 376573973574338ull}},
{{9971976008788524106ull, 301259178859470ull}},
{{15955161614061638570ull, 482014686175152ull}},
{{5385431661765490209ull, 385611748940122ull}},
{{15376391773638123137ull, 308489399152097ull}},
{{9844831578853355726ull, 493583038643356ull}},
{{4186516448340774258ull, 394866430914685ull}},
{{3349213158672619406ull, 315893144731748ull}},
{{1669392239134280727ull, 505429031570797ull}},
{{12403560235533155551ull, 404343225256637ull}},
{{2544150558942703794ull, 323474580205310ull}},
{{4070640894308326071ull, 517559328328496ull}},
{{18013907974414302150ull, 414047462662796ull}},
{{10721777564789531397ull, 331237970130237ull}},
{{2397448844695608942ull, 529980752208380ull}},
{{1917959075756487153ull, 423984601766704ull}},
{{5223716075347100046ull, 339187681413363ull}},
{{4668596905813449750ull, 542700290261381ull}},
{{45528709908849477ull, 434160232209105ull}},
{{36422967927079582ull, 347328185767284ull}},
{{7436974378167147977ull, 555725097227654ull}},
{{9638928317275628705ull, 444580077782123ull}},
{{15089840283304323610ull, 355664062225698ull}},
{{1003825782417727918ull, 284531249780559ull}},
{{8984818881352185316ull, 455249999648894ull}},
{{10877203919823658576ull, 364199999719115ull}},
{{8701763135858926861ull, 291359999775292ull}},
{{17612169832116193301ull, 466175999640467ull}},
{{6711038236209133994ull, 372940799712374ull}},
{{9058179403709217518ull, 298352639769899ull}},
{{3425040601709017060ull, 477364223631839ull}},
{{6429381296109123971ull, 381891378905471ull}},
{{1454156222145388854ull, 305513103124377ull}},
{{6015998770174532489ull, 488820964999003ull}},
{{12191496645623446638ull, 391056771999202ull}},
{{2374499687014936664ull, 312845417599362ull}},
{{7488548313965808985ull, 500552668158979ull}},
{{9680187465914557511ull, 400442134527183ull}},
{{15122847602215466655ull, 320353707621746ull}},
{{16817858534060926003ull, 512565932194794ull}},
{{17143635641990651125ull, 410052745755835ull}},
{{13714908513592520900ull, 328042196604668ull}},
{{18254504807006123117ull, 524867514567469ull}},
{{18292952660346808817ull, 419894011653975ull}},
{{14634362128277447053ull, 335915209323180ull}},
{{4968235331534363670ull, 537464334917089ull}},
{{7663937079969401259ull, 429971467933671ull}},
{{2441800849233610684ull, 343977174346937ull}},
{{7596230173515687418ull, 550363478955099ull}},
{{9766332953554460257ull, 440290783164079ull}},
{{11502415177585478529ull, 352232626531263ull}},
{{16580629771552203469ull, 281786101225010ull}},
{{8082263560773973935ull, 450857761960017ull}},
{{17533857292844910118ull, 360686209568013ull}},
{{2959039390050197124ull, 288548967654411ull}},
{{15802509468306046369ull, 461678348247057ull}},
{{5263309945161016449ull, 369342678597646ull}},
{{521299141386902836ull, 295474142878117ull}},
{{4523427440960954861ull, 472758628604987ull}},
{{14686788396994494858ull, 378206902883989ull}},
{{15438779532337506209ull, 302565522307191ull}},
{{17323349622256189289ull, 484104835691506ull}},
{{10169330883063041108ull, 387283868553205ull}},
{{8135464706450432886ull, 309827094842564ull}},
{{1948697086094961649ull, 495723351748103ull}},
{{8937655298359789965ull, 396578681398482ull}},
{{18218170682913562942ull, 317262945118785ull}},
{{10702329018952149091ull, 507620712190057ull}},
{{1183165585677898626ull, 406096569752046ull}},
{{15703927727509960194ull, 324877255801636ull}},
{{17747586734532115664ull, 519803609282618ull}},
{{3130022943399961561ull, 415842887426095ull}},
{{2504018354719969249ull, 332674309940876ull}},
{{15074475811777681768ull, 532278895905401ull}},
{{8370231834680235091ull, 425823116724321ull}},
{{3006836653002277750ull, 340658493379457ull}},
{{8500287459545554723ull, 545053589407131ull}},
{{3110881152894533455ull, 436042871525705ull}},
{{2488704922315626764ull, 348834297220564ull}},
{{11360625505188823469ull, 558134875552902ull}},
{{1709802774667238129ull, 446507900442322ull}},
{{12435888663959521473ull, 357206320353857ull}},
{{2570013301683796532ull, 285765056283086ull}},
{{15180067726919805421ull, 457224090052937ull}},
{{4765356552052023690ull, 365779272042350ull}},
{{3812285241641618952ull, 292623417633880ull}},
{{6099656386626590323ull, 468197468214208ull}},
{{12258422738785092905ull, 374557974571366ull}},
{{6117389376286164001ull, 299646379657093ull}},
{{6098474187315952078ull, 479434207451349ull}},
{{8568128164594671986ull, 383547365961079ull}},
{{10543851346417647912ull, 306837892768863ull}},
{{13180813339526326336ull, 490940628430181ull}},
{{6855301856879150745ull, 392752502744145ull}},
{{5484241485503320596ull, 314202002195316ull}},
{{1396088747321492308ull, 502723203512506ull}},
{{15874266256824835139ull, 402178562810004ull}},
{{16388761820201778434ull, 321742850248003ull}},
{{4085926023871383556ull, 514788560396806ull}},
{{18026136078064748137ull, 411830848317444ull}},
{{18110257677193708833ull, 329464678653955ull}},
{{10529668209800382517ull, 527143485846329ull}},
{{12113083382582216337ull, 421714788677063ull}},
{{17069164335549593716ull, 337371830941650ull}},
{{8863918863169798329ull, 539794929506641ull}},
{{3401786275793928340ull, 431835943605313ull}},
{{10100126650118963318ull, 345468754884250ull}},
{{16160202640190341310ull, 552750007814800ull}},
{{12928162112152273048ull, 442200006251840ull}},
{{10342529689721818438ull, 353760005001472ull}},
{{895326122293634104ull, 283008004001178ull}},
{{16189917054637455859ull, 452812806401884ull}},
{{16641282458451875011ull, 362250245121507ull}},
{{5934328337277679362ull, 289800196097206ull}},
{{2116227710160466333ull, 463680313755530ull}},
{{1692982168128373066ull, 370944251004424ull}},
{{5043734549244608776ull, 296755400803539ull}},
{{15448672908275194689ull, 474808641285662ull}},
{{4980240697136335104ull, 379846913028530ull}},
{{3984192557709068083ull, 303877530422824ull}},
{{13753405721818329580ull, 486204048676518ull}},
{{18381422206938484310ull, 388963238941214ull}},
{{18394486580292697771ull, 311170591152971ull}},
{{3605736825274944172ull, 497872945844755ull}},
{{2884589460219955338ull, 398298356675804ull}},
{{5997020382917874593ull, 318638685340643ull}},
{{5905883797926689026ull, 509821896545029ull}},
{{8414055853083261544ull, 407857517236023ull}},
{{14109942311950429882ull, 326286013788818ull}},
{{439814810669225872ull, 522057622062110ull}},
{{351851848535380697ull, 417646097649688ull}},
{{7660179108312125204ull, 334116878119750ull}},
{{12256286573299400327ull, 534587004991600ull}},
{{9805029258639520261ull, 427669603993280ull}},
{{7844023406911616209ull, 342135683194624ull}},
{{1482391006832854965ull, 547417093111399ull}},
{{4875261620208194295ull, 437933674489119ull}},
{{7589558110908465759ull, 350346939591295ull}},
{{12143292977453545215ull, 560555103346072ull}},
{{2335936752479015526ull, 448444082676858ull}},
{{9247447031467033067ull, 358755266141486ull}},
{{3708608810431716130ull, 287004212913189ull}},
{{13312471726174566455ull, 459206740661102ull}},
{{3271279751455832517ull, 367365392528882ull}},
{{13685070245390396983ull, 293892314023105ull}},
{{3449368318915083558ull, 470227702436969ull}},
{{6448843469873977169ull, 376182161949575ull}},
{{5159074775899181735ull, 300945729559660ull}},
{{8254519641438690777ull, 481513167295456ull}},
{{2914266898409042298ull, 385210533836365ull}},
{{2331413518727233838ull, 308168427069092ull}},
{{7419610444705484465ull, 493069483310547ull}},
{{17003734799990118541ull, 394455586648437ull}},
{{6224290210508274187ull, 315564469318750ull}},
{{9958864336813238699ull, 504903150910000ull}},
{{7967091469450590959ull, 403922520728000ull}},
{{6373673175560472767ull, 323138016582400ull}},
{{10197877080896756428ull, 517020826531840ull}},
{{8158301664717405142ull, 413616661225472ull}},
{{17594687775999655083ull, 330893328980377ull}},
{{13394105182631806841ull, 529429326368604ull}},
{{14404632960847355796ull, 423543461094883ull}},
{{455659924452153667ull, 338834768875907ull}},
{{4418404693865356190ull, 542135630201451ull}},
{{18292119014059926245ull, 433708504161160ull}},
{{14633695211247940996ull, 346966803328928ull}},
{{1277819449545243655ull, 555146885326286ull}},
{{15779650818603836216ull, 444117508261028ull}},
{{1555674210657338003ull, 355294006608823ull}},
{{8623236998009691049ull, 284235205287058ull}},
{{10107830382073595355ull, 454776328459293ull}},
{{15464961935142696931ull, 363821062767434ull}},
{{16061318362856067868ull, 291056850213947ull}},
{{10940714121602067296ull, 465690960342316ull}},
{{5063222482539743513ull, 372552768273853ull}},
{{11429275615515615457ull, 298042214619082ull}},
{{3529445725857343439ull, 476867543390532ull}},
{{13891603024911605720ull, 381494034712425ull}},
{{11113282419929284576ull, 305195227769940ull}},
{{17781251871886855322ull, 488312364431904ull}},
{{17914350312251394581ull, 390649891545523ull}},
{{3263433805575384695ull, 312519913236419ull}},
{{12600191718404436159ull, 500031861178270ull}},
{{10080153374723548927ull, 400025488942616ull}},
{{4374773885036928818ull, 320020391154093ull}},
{{3310289401317175786ull, 512032625846549ull}},
{{6337580335795650952ull, 409626100677239ull}},
{{8759413083378431085ull, 327700880541791ull}},
{{6636363303921669089ull, 524321408866866ull}},
{{1619741828395424948ull, 419457127093493ull}},
{{8674491092200160605ull, 335565701674794ull}},
{{2811139303294525999ull, 536905122679671ull}},
{{17006306701603262092ull, 429524098143736ull}},
{{9915696546540699350ull, 343619278514989ull}},
{{4797068030239387991ull, 549790845623983ull}},
{{11216352053675331039ull, 439832676499186ull}},
{{5283732828198354508ull, 351866141199349ull}},
{{7916335077300593929ull, 281492912959479ull}},
{{1598089679455219318ull, 450388660735167ull}},
{{12346518187789906424ull, 360310928588133ull}},
{{17255912179715745785ull, 288248742870506ull}},
{{1784017784351820994ull, 461197988592811ull}},
{{16184609486449098088ull, 368958390874248ull}},
{{1879641144933547501ull, 295166712699399ull}},
{{10386123461377496648ull, 472266740319038ull}},
{{15687596398585817965ull, 377813392255230ull}},
{{12550077118868654372ull, 302250713804184ull}},
{{9012076945964116025ull, 483601142086695ull}},
{{7209661556771292820ull, 386880913669356ull}},
{{2078380430675123933ull, 309504730935485ull}},
{{3325408689080198293ull, 495207569496776ull}},
{{17417722210231799927ull, 396166055597420ull}},
{{13934177768185439941ull, 316932844477936ull}},
{{14915986799612883260ull, 507092551164698ull}},
{{864742995464575638ull, 405674040931759ull}},
{{4381143211113570834ull, 324539232745407ull}},
{{10699177952523623658ull, 519262772392651ull}},
{{4869993547276988603ull, 415410217914121ull}},
{{206646023079680559ull, 332328174331297ull}},
{{4019982451669399218ull, 531725078930075ull}},
{{3215985961335519374ull, 425380063144060ull}},
{{2572788769068415499ull, 340304050515248ull}},
{{427113215767554476ull, 544486480824397ull}},
{{11409737016839774550ull, 435589184659517ull}},
{{1749091983987998994ull, 348471347727614ull}},
{{10177244803864619036ull, 557554156364182ull}},
{{763098213607874583ull, 446043325091346ull}},
{{15367873829853940959ull, 356834660073076ull}},
{{8604950249141242444ull, 285467728058461ull}},
{{6389222769142167264ull, 456748364893538ull}},
{{12490075844797554457ull, 365398691914830ull}},
{{9992060675838043566ull, 292318953531864ull}},
{{4919250637115138736ull, 467710325650983ull}},
{{11314098139175931635ull, 374168260520786ull}},
{{5361929696598834985ull, 299334608416629ull}},
{{15957785144041956622ull, 478935373466606ull}},
{{9076879300491654975ull, 383148298773285ull}},
{{7261503440393323980ull, 306518639018628ull}},
{{7929056689887408044ull, 490429822429805ull}},
{{6343245351909926435ull, 392343857943844ull}},
{{8763945096269851471ull, 313875086355075ull}},
{{14022312154031762355ull, 502200138168120ull}},
{{11217849723225409884ull, 401760110534496ull}},
{{5284930963838417584ull, 321408088427597ull}},
{{12145238356883378457ull, 514252941484155ull}},
{{9716190685506702766ull, 411402353187324ull}},
{{11462301363147272536ull, 329121882549859ull}},
{{7271635736809905088ull, 526595012079775ull}},
{{5817308589447924070ull, 421276009663820ull}},
{{4653846871558339256ull, 337020807731056ull}},
{{67457365009522164ull, 539233292369690ull}},
{{53965892007617731ull, 431386633895752ull}},
{{11111219157831825154ull, 345109307116601ull}},
{{10399253023047099600ull, 552174891386562ull}},
{{940704788953859034ull, 441739913109250ull}},
{{752563831163087227ull, 353391930487400ull}},
{{602051064930469781ull, 282713544389920ull}},
{{963281703888751651ull, 452341671023872ull}},
{{11838671807336732290ull, 361873336819097ull}},
{{2092239816385565186ull, 289498669455278ull}},
{{18104978965184545590ull, 463197871128444ull}},
{{18173331986889546795ull, 370558296902755ull}},
{{14538665589511637436ull, 296446637522204ull}},
{{12193818498992888928ull, 474314620035527ull}},
{{2376357169710490496ull, 379451696028422ull}},
{{12969132179994123366ull, 303561356822737ull}},
{{5993216229022956094ull, 485698170916380ull}},
{{4794572983218364875ull, 388558536733104ull}},
{{7525007201316602223ull, 310846829386483ull}},
{{8350662707364653234ull, 497354927018373ull}},
{{14059227795375543233ull, 397883941614698ull}},
{{179335792074703617ull, 318307153291759ull}},
{{7665634896803346434ull, 509291445266814ull}},
{{9821856732184587470ull, 407433156213451ull}},
{{4168136571005759653ull, 325946524970761ull}},
{{17737064957834946414ull, 521514439953217ull}},
{{6810954336784136485ull, 417211551962574ull}},
{{9138112284169219511ull, 333769241570059ull}},
{{3552933210445020249ull, 534030786512095ull}},
{{2842346568356016199ull, 427224629209676ull}},
{{17031272513652454252ull, 341779703367740ull}},
{{8803291948134375187ull, 546847525388385ull}},
{{7042633558507500150ull, 437478020310708ull}},
{{13012804476289820766ull, 349982416248566ull}},
{{13441789532579892579ull, 559971865997706ull}},
{{7064082811322003740ull, 447977492798165ull}},
{{5651266249057602992ull, 358381994238532ull}},
{{15589059443471813363ull, 286705595390825ull}},
{{6495751035845349765ull, 458728952625321ull}},
{{1507252013934369489ull, 366983162100257ull}},
{{12273848055373226561ull, 293586529680205ull}},
{{1191412814887610881ull, 469738447488329ull}},
{{4642479066651999028ull, 375790757990663ull}},
{{11092680882805419869ull, 300632606392530ull}},
{{17748289412488671790ull, 481012170228048ull}},
{{3130585085765206463ull, 384809736182439ull}},
{{6193816883354075493ull, 307847788945951ull}},
{{2531409383882700143ull, 492556462313522ull}},
{{13093173951331891084ull, 394045169850817ull}},
{{3095841531581692221ull, 315236135880654ull}},
{{12332044080014528200ull, 504377817409046ull}},
{{6176286449269712237ull, 403502253927237ull}},
{{16009075603641500759ull, 322801803141789ull}},
{{14546474521600670245ull, 516482885026863ull}},
{{569133173054805226ull, 413186308021491ull}},
{{15212701797411485474ull, 330549046417192ull}},
{{9582927616890735465ull, 528878474267508ull}},
{{15045039722996409018ull, 423102779414006ull}},
{{8346682963655216891ull, 338482223531205ull}},
{{13354692741848347027ull, 541571557649928ull}},
{{18062451822962498268ull, 433257246119942ull}},
{{7071263828886177968ull, 346605796895954ull}},
{{245975681992153779ull, 554569275033527ull}},
{{11264826989819453993ull, 443655420026821ull}},
{{5322512777113652871ull, 354924336021457ull}},
{{15326056665916653266ull, 283939468817165ull}},
{{6074946591757093610ull, 454303150107465ull}},
{{4859957273405674888ull, 363442520085972ull}},
{{14956012262950270880ull, 290754016068777ull}},
{{9172224361752792115ull, 465206425710044ull}},
{{11027128304144144015ull, 372165140568035ull}},
{{8821702643315315212ull, 297732112454428ull}},
{{10425375414562594017ull, 476371379927085ull}},
{{8340300331650075213ull, 381097103941668ull}},
{{14050937894803880817ull, 304877683153334ull}},
{{11413454187460478338ull, 487804293045335ull}},
{{9130763349968382670ull, 390243434436268ull}},
{{14683308309458526782ull, 312194747549014ull}},
{{12425246850907911882ull, 499511596078423ull}},
{{17318895110210150152ull, 399609276862738ull}},
{{2787069643942389152ull, 319687421490191ull}},
{{15527357874533553613ull, 511499874384305ull}},
{{12421886299626842890ull, 409199899507444ull}},
{{13626857854443384635ull, 327359919605955ull}},
{{3356228493399863801ull, 523775871369529ull}},
{{6374331609461801364ull, 419020697095623ull}},
{{12478162917053261737ull, 335216557676498ull}},
{{16275711852543308457ull, 536346492282397ull}},
{{5641871852550826119ull, 429077193825918ull}},
{{11892195111524481542ull, 343261755060734ull}},
{{7959465734213439497ull, 549218808097175ull}},
{{6367572587370751598ull, 439375046477740ull}},
{{5094058069896601278ull, 351500037182192ull}},
{{11839841726576472368ull, 562400059491507ull}},
{{2093175751777357248ull, 449920047593206ull}},
{{16431935860389527091ull, 359936038074564ull}},
{{16834897503053531996ull, 287948830459651ull}},
{{1110394301692278932ull, 460718128735443ull}},
{{8267013070837643792ull, 368574502988354ull}},
{{10302959271412025356ull, 294859602390683ull}},
{{12795386019517330247ull, 471775363825093ull}},
{{17615006445097684844ull, 377420291060074ull}},
{{17781353970820058198ull, 301936232848059ull}},
{{17382119909086362148ull, 483097972556895ull}},
{{13905695927269089718ull, 386478378045516ull}},
{{7435207927073361451ull, 309182702436413ull}},
{{8206983868575467999ull, 494692323898261ull}},
{{2876238280118464076ull, 395753859118609ull}},
{{5990339438836681584ull, 316603087294887ull}},
{{13273891916880600858ull, 506564939671819ull}},
{{14308462348246391010ull, 405251951737455ull}},
{{11446769878597112808ull, 324201561389964ull}},
{{7246785361529649523ull, 518722498223943ull}},
{{13176125918707540264ull, 414977998579154ull}},
{{14230249549707942535ull, 331982398863323ull}},
{{632306391081246117ull, 531171838181318ull}},
{{7884542742348817540ull, 424937470545054ull}},
{{9996983008620964355ull, 339949976436043ull}},
{{12305823999051632645ull, 543919962297669ull}},
{{13534008013983216439ull, 435135969838135ull}},
{{10827206411186573151ull, 348108775870508ull}},
{{13634181443156606719ull, 556974041392813ull}},
{{18286042784009106021ull, 445579233114250ull}},
{{14628834227207284817ull, 356463386491400ull}},
{{11703067381765827853ull, 285170709193120ull}},
{{278163737115772950ull, 456273134708993ull}},
{{7601228619176439006ull, 365018507767194ull}},
{{9770331710083061528ull, 292014806213755ull}},
{{15632530736132898445ull, 467223689942008ull}},
{{1437978144680587786ull, 373778951953607ull}},
{{12218428959970201199ull, 299023161562885ull}},
{{1102742262242770302ull, 478437058500617ull}},
{{11950240254019947211ull, 382749646800493ull}},
{{16938889832699778415ull, 306199717440394ull}},
{{16034177288093914495ull, 489919547904631ull}},
{{9137993015733221273ull, 391935638323705ull}},
{{7310394412586577018ull, 313548510658964ull}},
{{628584615912792260ull, 501677617054343ull}},
{{7881565322214054454ull, 401342093643474ull}},
{{9994601072513153886ull, 321073674914779ull}},
{{4923315271795315249ull, 513717879863647ull}},
{{15006698661661983169ull, 410974303890917ull}},
{{4626661299845765888ull, 328779443112734ull}},
{{14781355709237046068ull, 526047108980374ull}},
{{15514433382131547178ull, 420837687184299ull}},
{{16100895520447148065ull, 336670149747439ull}},
{{14693386388489705935ull, 538672239595903ull}},
{{686662666566033778ull, 430937791676723ull}},
{{7928027762736647669ull, 344750233341378ull}},
{{8995495605636725947ull, 551600373346205ull}},
{{7196396484509380758ull, 441280298676964ull}},
{{9446466002349414929ull, 353024238941571ull}},
{{3867823987137621620ull, 282419391153257ull}},
{{9877867194162104916ull, 451871025845211ull}},
{{4212944940587773609ull, 361496820676169ull}},
{{7059704767212129211ull, 289197456540935ull}},
{{11295527627539406737ull, 462715930465496ull}},
{{5347073287289615066ull, 370172744372397ull}},
{{15345705074057423023ull, 296138195497917ull}},
{{9795732859524235544ull, 473821112796668ull}},
{{15215283917103209081ull, 379056890237334ull}},
{{15861575948424477588ull, 303245512189867ull}},
{{10621126258511522848ull, 485192819503788ull}},
{{15875598636293038925ull, 388154255603030ull}},
{{12700478909034431140ull, 310523404482424ull}},
{{9252719810229358855ull, 496837447171879ull}},
{{11091524662925397407ull, 397469957737503ull}},
{{16251917359824138572ull, 317975966190002ull}},
{{11245672516750980422ull, 508761545904004ull}},
{{12685886828142694661ull, 407009236723203ull}},
{{17527407091997976375ull, 325607389378562ull}},
{{13286456088229120908ull, 520971823005700ull}},
{{10629164870583296726ull, 416777458404560ull}},
{{8503331896466637381ull, 333421966723648ull}},
{{9915982219604709486ull, 533475146757837ull}},
{{554088146199946942ull, 426780117406270ull}},
{{443270516959957554ull, 341424093925016ull}},
{{11777279271361663056ull, 546278550280025ull}},
{{9421823417089330445ull, 437022840224020ull}},
{{7537458733671464356ull, 349618272179216ull}},
{{4681236344390522323ull, 559389235486746ull}},
{{55640260770507535ull, 447511388389397ull}},
{{11112558652842136998ull, 358009110711517ull}},
{{1511349292789888952ull, 286407288569214ull}},
{{9796856497947642969ull, 458251661710742ull}},
{{458787568874293729ull, 366601329368594ull}},
{{4056378869841345306ull, 293281063494875ull}},
{{6490206191746152490ull, 469249701591800ull}},
{{5192164953396921992ull, 375399761273440ull}},
{{4153731962717537594ull, 300319809018752ull}},
{{10335319955089970473ull, 480511694430003ull}},
{{15646953593555797025ull, 384409355544002ull}},
{{5138865245360816973ull, 307527484435202ull}},
{{11911533207319217481ull, 492043975096323ull}},
{{16907924195339194631ull, 393635180077058ull}},
{{2458292912045624735ull, 314908144061647ull}},
{{7622617474014909900ull, 503853030498635ull}},
{{6098093979211927920ull, 403082424398908ull}},
{{12257172812853362982ull, 322465939519126ull}},
{{12232778871081560125ull, 515945503230602ull}},
{{2407525467381427454ull, 412756402584482ull}},
{{12994066818130872932ull, 330205122067585ull}},
{{2343762835299845076ull, 528328195308137ull}},
{{12943056712465607030ull, 422662556246509ull}},
{{14043794184714395947ull, 338130044997207ull}},
{{7712675436575392223ull, 541008071995532ull}},
{{17238186793486044748ull, 432806457596425ull}},
{{13790549434788835798ull, 346245166077140ull}},
{{3618135021952585662ull, 553992265723425ull}},
{{2894508017562068529ull, 443193812578740ull}},
{{2315606414049654823ull, 354555050062992ull}},
{{12920531575465454828ull, 283644040050393ull}},
{{16983501706002817402ull, 453830464080629ull}},
{{17276150179544164245ull, 363064371264503ull}},
{{2752873699409600426ull, 290451497011603ull}},
{{715249104313450359ull, 464722395218565ull}},
{{572199283450760287ull, 371777916174852ull}},
{{11525805870986339199ull, 297422332939881ull}},
{{11062591764094322073ull, 475875732703810ull}},
{{8850073411275457658ull, 380700586163048ull}},
{{14458756358504186773ull, 304560468930438ull}},
{{997917285155236897ull, 487296750288702ull}},
{{11866380272349920487ull, 389837400230961ull}},
{{5803755403138026067ull, 311869920184769ull}},
{{16664706274504662353ull, 498991872295630ull}},
{{13331765019603729883ull, 399193497836504ull}},
{{14354760830424894229ull, 319354798269203ull}},
{{831524440228368828ull, 510967677230726ull}},
{{15422614811150336355ull, 408774141784580ull}},
{{12338091848920269084ull, 327019313427664ull}},
{{8672900514046699565ull, 523230901484263ull}},
{{14317018040721180298ull, 418584721187410ull}},
{{11453614432576944238ull, 334867776949928ull}},
{{14636434277381200459ull, 535788443119885ull}},
{{11709147421904960367ull, 428630754495908ull}},
{{16746015567007788940ull, 342904603596726ull}},
{{968183204019090041ull, 548647365754763ull}},
{{8153244192699092679ull, 438917892603810ull}},
{{6522595354159274143ull, 351134314083048ull}},
{{6746803751912928307ull, 561814902532877ull}},
{{16465489445756073615ull, 449451922026301ull}},
{{9483042741862948569ull, 359561537621041ull}},
{{3897085378748448532ull, 287649230096833ull}},
{{2545987791255607328ull, 460238768154933ull}},
{{9415487862488306508ull, 368191014523946ull}},
{{3843041475248734883ull, 294552811619157ull}},
{{9838215175139886137ull, 471284498590651ull}},
{{4181223325369998586ull, 377027598872521ull}},
{{18102373919263640162ull, 301622079098016ull}},
{{3138356567628451997ull, 482595326556827ull}},
{{13578731698328492567ull, 386076261245461ull}},
{{7173636543920883730ull, 308861008996369ull}},
{{409772026047682999ull, 494177614394191ull}},
{{15085212879805787692ull, 395342091515352ull}},
{{4689472674360809507ull, 316273673212282ull}},
{{11192505093719205535ull, 506037877139651ull}},
{{5264655260233454104ull, 404830301711721ull}},
{{522375393444852960ull, 323864241369377ull}},
{{4525149444253675060ull, 518182786191003ull}},
{{10998817184886760694ull, 414546228952802ull}},
{{1420356118425587909ull, 331636983162242ull}},
{{5961918604222850978ull, 530619173059587ull}},
{{15837581327604011752ull, 424495338447669ull}},
{{16359413876825119724ull, 339596270758135ull}},
{{7728318129210639943ull, 543354033213017ull}},
{{17250700947594242924ull, 434683226570413ull}},
{{2732514313849663370ull, 347746581256331ull}},
{{15440069346385192361ull, 556394530010129ull}},
{{16041404291850064212ull, 445115624008103ull}},
{{1765076989254320400ull, 356092499206483ull}},
{{8790759220887276966ull, 284873999365186ull}},
{{6686517123935822500ull, 455798398984298ull}},
{{12727911328632478646ull, 364638719187438ull}},
{{17561026692389803563ull, 291710975349950ull}},
{{9650898634114134086ull, 466737560559921ull}},
{{4031370092549396945ull, 373390048447937ull}},
{{14293142518265248526ull, 298712038758349ull}},
{{11800981584998666672ull, 477939262013359ull}},
{{13130134082740843661ull, 382351409610687ull}},
{{3125409636708854282ull, 305881127688550ull}},
{{5000655418734166851ull, 489409804301680ull}},
{{4000524334987333481ull, 391527843441344ull}},
{{6889768282731777108ull, 313222274753075ull}},
{{11023629252370843373ull, 501155639604920ull}},
{{8818903401896674698ull, 400924511683936ull}},
{{3365773906775429435ull, 320739609347149ull}},
{{12763935880324507743ull, 513183374955438ull}},
{{17589846333743426841ull, 410546699964350ull}},
{{14071877066994741473ull, 328437359971480ull}},
{{4068259233482034740ull, 525499775954369ull}},
{{6943956201527538115ull, 420399820763495ull}},
{{5555164961222030492ull, 336319856610796ull}},
{{1509566308471428142ull, 538111770577274ull}},
{{4897001861519052836ull, 430489416461819ull}},
{{7606950303957152592ull, 344391533169455ull}},
{{12171120486331444148ull, 551026453071128ull}},
{{17115594018548975964ull, 440821162456902ull}},
{{6313777585355360125ull, 352656929965522ull}},
{{16119068512510019070ull, 282125543972417ull}},
{{11033114361048389219ull, 451400870355868ull}},
{{16205189118322532021ull, 361120696284694ull}},
{{16653500109399935940ull, 288896557027755ull}},
{{8198856101330345889ull, 462234491244409ull}},
{{10248433695806187034ull, 369787592995527ull}},
{{820049327161128981ull, 295830074396422ull}},
{{5001427738199716693ull, 473328119034275ull}},
{{4001142190559773354ull, 378662495227420ull}},
{{3200913752447818683ull, 302929996181936ull}},
{{16189508448142240863ull, 484687993891097ull}},
{{5572909129029972044ull, 387750395112878ull}},
{{11837024932707798281ull, 310200316090302ull}},
{{4181844633364835958ull, 496320505744484ull}},
{{7034824521433779089ull, 397056404595587ull}},
{{16695906061372754241ull, 317645123676469ull}},
{{15645403253970675816ull, 508232197882351ull}},
{{8826973788434630330ull, 406585758305881ull}},
{{3372230216005793940ull, 325268606644705ull}},
{{5395568345609270305ull, 520429770631528ull}},
{{11695152305971236890ull, 416343816505222ull}},
{{1977424215293168866ull, 333075053204178ull}},
{{17921274003436711478ull, 532920085126684ull}},
{{18026368017491279506ull, 426336068101347ull}},
{{7042396784509202958ull, 341068854481078ull}},
{{7578486040472814410ull, 545710167169725ull}},
{{6062788832378251528ull, 436568133735780ull}},
{{4850231065902601222ull, 349254506988624ull}},
{{15139067334927982602ull, 558807211181798ull}},
{{1043207423716655112ull, 447045768945439ull}},
{{4523914753715234413ull, 357636615156351ull}},
{{18376527061939828823ull, 286109292125080ull}},
{{10955699225394174501ull, 457774867400129ull}},
{{12453908195057249924ull, 366219893920103ull}},
{{17341824185529620585ull, 292975915136082ull}},
{{12989523437879751644ull, 468761464217732ull}},
{{3012921120819980669ull, 375009171374186ull}},
{{17167732155623625828ull, 300007337099348ull}},
{{5332278560546339385ull, 480011739358958ull}},
{{11644520477920892155ull, 384009391487166ull}},
{{5626267567594803400ull, 307207513189733ull}},
{{5312679293409775118ull, 491532021103573ull}},
{{11628841064211640740ull, 393225616882858ull}},
{{16681770480853133239ull, 314580493506286ull}},
{{865391066171640920ull, 503328789610059ull}},
{{4381661667679223059ull, 402663031688047ull}},
{{14573375778369109417ull, 322130425350437ull}},
{{8560005986422933774ull, 515408680560700ull}},
{{6848004789138347019ull, 412326944448560ull}},
{{5478403831310677615ull, 329861555558848ull}},
{{5076097315355173862ull, 527778488894157ull}},
{{15128924296509870059ull, 422222791115325ull}},
{{12103139437207896047ull, 337778232892260ull}},
{{918279025823082059ull, 540445172627617ull}},
{{11802669664884196617ull, 432356138102093ull}},
{{16820833361391177940ull, 345884910481674ull}},
{{15845286934000153734ull, 553415856770679ull}},
{{16365578361942033311ull, 442732685416543ull}},
{{2024416245327895679ull, 354186148333235ull}},
{{1619532996262316543ull, 283348918666588ull}},
{{17348648052987347762ull, 453358269866540ull}},
{{13878918442389878209ull, 362686615893232ull}},
{{3724437124428081921ull, 290149292714586ull}},
{{17027145843310662043ull, 464238868343337ull}},
{{6243019045164708988ull, 371391094674670ull}},
{{4994415236131767191ull, 297112875739736ull}},
{{612366748327006859ull, 475380601183578ull}},
{{7868591028145426133ull, 380304480946862ull}},
{{17362919266742071876ull, 304243584757489ull}},
{{16712624382561584033ull, 486789735611983ull}},
{{2302053061823536256ull, 389431788489587ull}},
{{12909688893684559975ull, 311545430791669ull}},
{{9587455785669564990ull, 498472689266671ull}},
{{3980615813793741669ull, 398778151413337ull}},
{{14252539095260724304ull, 319022521130669ull}},
{{11736016108191427918ull, 510436033809071ull}},
{{5699464071811232011ull, 408348827047257ull}},
{{15627617701674716578ull, 326679061637805ull}},
{{6557444248969994910ull, 522686498620489ull}},
{{8935304213917906251ull, 418149198896391ull}},
{{3458894556392414677ull, 334519359117113ull}},
{{1844882475485953161ull, 535230974587381ull}},
{{16233301239356403821ull, 428184779669904ull}},
{{16675989806227033380ull, 342547823735923ull}},
{{4545490801511791469ull, 548076517977478ull}},
{{11015090270693253822ull, 438461214381982ull}},
{{1433374587070782411ull, 350768971505586ull}},
{{13361445783538982827ull, 561230354408937ull}},
{{3310458997347365615ull, 448984283527150ull}},
{{2648367197877892492ull, 359187426821720ull}},
{{2118693758302313994ull, 287349941457376ull}},
{{14457956457509433360ull, 459759906331801ull}},
{{7877016351265636365ull, 367807925065441ull}},
{{2612264266270598768ull, 294246340052353ull}},
{{490274011291047706ull, 470794144083765ull}},
{{392219209032838165ull, 376635315267012ull}},
{{11381821811452001502ull, 301308252213609ull}},
{{7142868454097471433ull, 482093203541775ull}},
{{5714294763277977146ull, 385674562833420ull}},
{{4571435810622381717ull, 308539650266736ull}},
{{18382343741221541717ull, 493663440426777ull}},
{{7327177363493412727ull, 394930752341422ull}},
{{16929788335020461151ull, 315944601873137ull}},
{{12330266077065096550ull, 505511362997020ull}},
{{9864212861652077240ull, 404409090397616ull}},
{{4202021474579751468ull, 323527272318093ull}},
{{3033885544585692026ull, 517643635708949ull}},
{{6116457250410463944ull, 414114908567159ull}},
{{8582514615070281478ull, 331291926853727ull}},
{{17421372198854360689ull, 530067082965963ull}},
{{2869051314857757582ull, 424053666372771ull}},
{{17052636310853847358ull, 339242933098216ull}},
{{1458776394172783511ull, 542788692957147ull}},
{{12235067559563957778ull, 434230954365717ull}},
{{2409356418167345576ull, 347384763492574ull}},
{{11233667898551573568ull, 555815621588118ull}},
{{16365631948325079501ull, 444652497270494ull}},
{{16781854373401973924ull, 355721997816395ull}},
{{13425483498721579139ull, 284577598253116ull}},
{{14102075968470705976ull, 455324157204986ull}},
{{7592311960034654458ull, 364259325763989ull}},
{{9763198382769633889ull, 291407460611191ull}},
{{8242419782947593577ull, 466251936977906ull}},
{{2904587011616164538ull, 373001549582325ull}},
{{2323669609292931630ull, 298401239665860ull}},
{{3717871374868690609ull, 477441983465376ull}},
{{17731692358862593780ull, 381953586772300ull}},
{{14185353887090075024ull, 305562869417840ull}},
{{4249822145634568422ull, 488900591068545ull}},
{{3399857716507654738ull, 391120472854836ull}},
{{17477281432173765083ull, 312896378283868ull}},
{{5827557403026562194ull, 500634205254190ull}},
{{4662045922421249755ull, 400507364203352ull}},
{{14797683182162730773ull, 320405891362681ull}},
{{16297595461976548591ull, 512649426180290ull}},
{{13038076369581238873ull, 410119540944232ull}},
{{3051763466181170452ull, 328095632755386ull}},
{{15950867990115603693ull, 524953012408617ull}},
{{5381996762608662308ull, 419962409926894ull}},
{{7994946224828840169ull, 335969927941515ull}},
{{12791913959726144271ull, 537551884706424ull}},
{{13922879982522825740ull, 430041507765139ull}},
{{14827652800760170915ull, 344033206212111ull}},
{{16345546851732452818ull, 550453129939378ull}},
{{2008391037160231285ull, 440362503951503ull}},
{{8985410459212005674ull, 352290003161202ull}},
{{18256374811595335509ull, 281832002528961ull}},
{{3384757995359164552ull, 450931204046339ull}},
{{6397155211029241965ull, 360744963237071ull}},
{{1428375354081483248ull, 288595970589657ull}},
{{5974749381272283521ull, 461753552943451ull}},
{{1090450690275916493ull, 369402842354761ull}},
{{15629755811188374487ull, 295522273883808ull}},
{{2871516409449937241ull, 472835638214094ull}},
{{5986561942301860116ull, 378268510571275ull}},
{{4789249553841488093ull, 302614808457020ull}},
{{7662799286146380949ull, 484183693531232ull}},
{{17198285873142835728ull, 387346954824985ull}},
{{13758628698514268583ull, 309877563859988ull}},
{{18324457102880919409ull, 495804102175981ull}},
{{10970216867562825204ull, 396643281740785ull}},
{{8776173494050260163ull, 317314625392628ull}},
{{10352528775738505938ull, 507703400628205ull}},
{{8282023020590804750ull, 406162720502564ull}},
{{10314967231214554123ull, 324930176402051ull}},
{{9125249940459465951ull, 519888282243282ull}},
{{18368246396593303731ull, 415910625794625ull}},
{{14694597117274642984ull, 332728500635700ull}},
{{5064611313929877159ull, 532365601017121ull}},
{{362340236401991404ull, 425892480813697ull}},
{{11357918633347324093ull, 340713984650957ull}},
{{3415274554388077256ull, 545142375441532ull}},
{{13800266087736192774ull, 436113900353225ull}},
{{11040212870188954219ull, 348891120282580ull}},
{{17664340592302326751ull, 558225792452128ull}},
{{3063426029616130431ull, 446580633961703ull}},
{{9829438453176724991ull, 357264507169362ull}},
{{484853133057559347ull, 285811605735490ull}},
{{775765012892094955ull, 457298569176784ull}},
{{4309960825055586287ull, 365838855341427ull}},
{{14516015104270199999ull, 292671084273141ull}},
{{15846926537348499352ull, 468273734837026ull}},
{{8988192415136889159ull, 374618987869621ull}},
{{3501205117367601004ull, 299695190295697ull}},
{{9291277002530071929ull, 479512304473115ull}},
{{7433021602024057543ull, 383609843578492ull}},
{{17014463725844977004ull, 306887874862793ull}},
{{5087049072900501268ull, 491020599780470ull}},
{{4069639258320401014ull, 392816479824376ull}},
{{18013106665623962104ull, 314253183859500ull}},
{{10374226591288787751ull, 502805094175201ull}},
{{4610032458289119877ull, 402244075340161ull}},
{{18445421225598937194ull, 321795260272128ull}},
{{7376581072506837572ull, 514872416435406ull}},
{{2211916043263559735ull, 411897933148325ull}},
{{1769532834610847788ull, 329518346518660ull}},
{{2831252535377356460ull, 527229354429856ull}},
{{17022397287269526461ull, 421783483543884ull}},
{{17307266644557531492ull, 337426786835107ull}},
{{12934231372324409095ull, 539882858936172ull}},
{{2968687468375706629ull, 431906287148938ull}},
{{9753647604184385950ull, 345525029719150ull}},
{{15605836166695017520ull, 552840047550640ull}},
{{12484668933356014016ull, 442272038040512ull}},
{{2609037517200990566ull, 353817630432410ull}},
{{2087230013760792453ull, 283054104345928ull}},
{{18096963280984909217ull, 452886566953484ull}},
{{18166919439529837697ull, 362309253562787ull}},
{{7154837922140049511ull, 289847402850230ull}},
{{11447740675424079218ull, 463755844560368ull}},
{{16536890169823084021ull, 371004675648294ull}},
{{16918860950600377540ull, 296803740518635ull}},
{{8623433447251052448ull, 474885984829817ull}},
{{17966793202026572928ull, 379908787863853ull}},
{{3305388117395527373ull, 303927030291083ull}},
{{1599272173090933473ull, 486283248465733ull}},
{{8658115367956567425ull, 389026598772586ull}},
{{3237143479623343617ull, 311221279018069ull}},
{{12558127196881170433ull, 497954046428910ull}},
{{10046501757504936346ull, 398363237143128ull}},
{{15415899035487769723ull, 318690589714502ull}},
{{9908043197812790265ull, 509904943543204ull}},
{{11615783372992142535ull, 407923954834563ull}},
{{16671324327877534674ull, 326339163867650ull}},
{{8227374850894503863ull, 522142662188241ull}},
{{2892551065973692767ull, 417714129750593ull}},
{{9692738482262774860ull, 334171303800474ull}},
{{4440335127394708807ull, 534674086080759ull}},
{{7241616916657677369ull, 427739268864607ull}},
{{16861339977551872864ull, 342191415091685ull}},
{{8531399890373444967ull, 547506264146697ull}},
{{17893166356524486943ull, 438005011317357ull}},
{{6935835455735768908ull, 350404009053886ull}},
{{3718639099693409607ull, 560646414486218ull}},
{{10353608909238548332ull, 448517131588974ull}},
{{11972235942132748989ull, 358813705271179ull}},
{{13267137568448109514ull, 287050964216943ull}},
{{17538071294775064900ull, 459281542747109ull}},
{{17719805850561962243ull, 367425234197687ull}},
{{6797147050965749148ull, 293940187358150ull}},
{{10875435281545198637ull, 470304299773040ull}},
{{8700348225236158909ull, 376243439818432ull}},
{{18028325024414658097ull, 300994751854745ull}},
{{10398575965353901339ull, 481591602967593ull}},
{{15697558401766941718ull, 385273282374074ull}},
{{16247395536155463697ull, 308218625899259ull}},
{{14927786413623010946ull, 493149801438815ull}},
{{11942229130898408757ull, 394519841151052ull}},
{{2175085675234906359ull, 315615872920842ull}},
{{7169485895117760498ull, 504985396673347ull}},
{{16803635160319939368ull, 403988317338677ull}},
{{6064210498772130848ull, 323190653870942ull}},
{{13392085612777319680ull, 517105046193507ull}},
{{3334970860738035098ull, 413684036954806ull}},
{{17425371947558069371ull, 330947229563844ull}},
{{16812548671867180024ull, 529515567302151ull}},
{{9760690122751833696ull, 423612453841721ull}},
{{4119203283459556633ull, 338889963073377ull}},
{{10280074068277200937ull, 542223940917403ull}},
{{15602756884105581396ull, 433779152733922ull}},
{{5103507877800644470ull, 347023322187138ull}},
{{4476263789739120829ull, 555237315499421ull}},
{{18338406290758937956ull, 444189852399536ull}},
{{10981376217865240042ull, 355351881919629ull}},
{{12474449789034102356ull, 284281505535703ull}},
{{16269770847712653447ull, 454850408857125ull}},
{{13015816678170122758ull, 363880327085700ull}},
{{10412653342536098206ull, 291104261668560ull}},
{{16660245348057757130ull, 465766818669696ull}},
{{9638847463704295381ull, 372613454935757ull}},
{{332380341479615658ull, 298090763948606ull}},
{{11599854990593116023ull, 476945222317769ull}},
{{12969232807216403141ull, 381556177854215ull}},
{{10375386245773122513ull, 305244942283372ull}},
{{1843222734269354728ull, 488391907653396ull}},
{{16231973446383125075ull, 390713526122716ull}},
{{9296229942364589737ull, 312570820898173ull}},
{{11184619093041433256ull, 500113313437077ull}},
{{1568997644949325959ull, 400090650749662ull}},
{{12323244560185191736ull, 320072520599729ull}},
{{8649144852070575809ull, 512116032959567ull}},
{{17987362325882191617ull, 409692826367653ull}},
{{3321843416480022324ull, 327754261094123ull}},
{{1625600651626125395ull, 524406817750597ull}},
{{12368526965526631285ull, 419525454200477ull}},
{{2516123942937484382ull, 335620363360382ull}},
{{7715147123441885334ull, 536992581376611ull}},
{{2482768884011597944ull, 429594065101289ull}},
{{5675563921951188678ull, 343675252081031ull}},
{{1702204645638081239ull, 549880403329650ull}},
{{1361763716510464991ull, 439904322663720ull}},
{{1089410973208371993ull, 351923458130976ull}},
{{15628924037534338887ull, 281538766504780ull}},
{{6559534386345390604ull, 450462026407649ull}},
{{8936976323818222806ull, 360369621126119ull}},
{{10838929873796488568ull, 288295696900895ull}},
{{17342287798074381709ull, 461273115041432ull}},
{{6495132608975684721ull, 369018492033146ull}},
{{1506757272438637453ull, 295214793626517ull}},
{{6100160450643730249ull, 472343669802427ull}},
{{15948174804740715168ull, 377874935841941ull}},
{{9069191029050661811ull, 302299948673553ull}},
{{10821356831739148575ull, 483679917877685ull}},
{{8657085465391318860ull, 386943934302148ull}},
{{14304366001796875735ull, 309555147441718ull}},
{{750892714423539236ull, 495288235906750ull}},
{{600714171538831389ull, 396230588725400ull}},
{{480571337231065111ull, 316984470980320ull}},
{{768914139569704178ull, 507175153568512ull}},
{{11683177755881494312ull, 405740122854809ull}},
{{13035891019447105773ull, 324592098283847ull}},
{{6100030372147727944ull, 519347357254156ull}},
{{1190675482976272032ull, 415477885803325ull}},
{{952540386381017625ull, 332382308642660ull}},
{{1524064618209628201ull, 531811693828256ull}},
{{15976646953535343853ull, 425449355062604ull}},
{{16470666377570185406ull, 340359484050083ull}},
{{4216973315660834710ull, 544575174480134ull}},
{{7062927467270578091ull, 435660139584107ull}},
{{16718388418042193443ull, 348528111667285ull}},
{{8302677395157957892ull, 557644978667657ull}},
{{17710188360352097283ull, 446115982934125ull}},
{{14168150688281677827ull, 356892786347300ull}},
{{11334520550625342261ull, 285514229077840ull}},
{{18135232881000547618ull, 456822766524544ull}},
{{18197535119542348418ull, 365458213219635ull}},
{{14558028095633878734ull, 292366570575708ull}},
{{1156752064562744035ull, 467786512921134ull}},
{{4614750466392105551ull, 374229210336907ull}},
{{14759846817339415411ull, 299383368269525ull}},
{{5169010834033513041ull, 479013389231241ull}},
{{445859852484900110ull, 383210711384993ull}},
{{7735385511471740734ull, 306568569107994ull}},
{{1308570374129054205ull, 490509710572791ull}},
{{15804251558270884657ull, 392407768458232ull}},
{{5264703617132887079ull, 313926214766586ull}},
{{1044828157928798680ull, 502281943626538ull}},
{{8214560155826859591ull, 401825554901230ull}},
{{6571648124661487672ull, 321460443920984ull}},
{{17893334628942200923ull, 514336710273574ull}},
{{18004016517895671061ull, 411469368218859ull}},
{{18092562029058447172ull, 329175494575087ull}},
{{14190703987525874183ull, 526680791320140ull}},
{{11352563190020699346ull, 421344633056112ull}},
{{1703352922532738830ull, 337075706444890ull}},
{{2725364676052382129ull, 539321130311824ull}},
{{5869640555583816026ull, 431456904249459ull}},
{{8385061259208963144ull, 345165523399567ull}},
{{17105446829476251354ull, 552264837439307ull}},
{{6305659834097180437ull, 441811869951446ull}},
{{1355179052535834026ull, 353449495961157ull}},
{{12152189686254398190ull, 282759596768925ull}},
{{996759424297485489ull, 452415354830281ull}},
{{15554802798405629684ull, 361932283864224ull}},
{{16133191053466414070ull, 289545827091379ull}},
{{14745059241320531543ull, 463273323346207ull}},
{{4417349763572604588ull, 370618658676966ull}},
{{18291275069825724963ull, 296494926941572ull}},
{{14508644852753518648ull, 474391883106516ull}},
{{7917567067460904595ull, 379513506485213ull}},
{{13712751283452544323ull, 303610805188170ull}},
{{3493657979814519300ull, 485777288301073ull}},
{{10173624013335436087ull, 388621830640858ull}},
{{15517596840152169516ull, 310897464512686ull}},
{{17449457314759650579ull, 497435943220298ull}},
{{2891519407581989493ull, 397948754576239ull}},
{{6002564340807501918ull, 318359003660991ull}},
{{2225405315808182422ull, 509374405857586ull}},
{{16537719511614187231ull, 407499524686068ull}},
{{2162129165065618815ull, 325999619748855ull}},
{{3459406664104990104ull, 521599391598168ull}},
{{10146222960767812729ull, 417279513278534ull}},
{{11806327183356160507ull, 333823610622827ull}},
{{4132728234402215518ull, 534117776996524ull}},
{{6995531402263682738ull, 427294221597219ull}},
{{9285773936552856513ull, 341835377277775ull}},
{{14857238298484570421ull, 546936603644440ull}},
{{11885790638787656337ull, 437549282915552ull}},
{{2129934881546304423ull, 350039426332442ull}},
{{7097244625215997401ull, 560063082131907ull}},
{{16745842144398528890ull, 448050465705525ull}},
{{13396673715518823112ull, 358440372564420ull}},
{{10717338972415058489ull, 286752298051536ull}},
{{9769044726380272937ull, 458803676882458ull}},
{{15193933410588038996ull, 367042941505966ull}},
{{8465797913728520873ull, 293634353204773ull}},
{{9855927847223723074ull, 469814965127637ull}},
{{506044648295157813ull, 375851972102110ull}},
{{404835718636126250ull, 300681577681688ull}},
{{15405132408785443294ull, 481090524290700ull}},
{{12324105927028354635ull, 384872419432560ull}},
{{9859284741622683708ull, 307897935546048ull}},
{{12085506771854383610ull, 492636696873677ull}},
{{2289707787999686241ull, 394109357498942ull}},
{{12899812674625479962ull, 315287485999153ull}},
{{16950351464658857617ull, 504459977598645ull}},
{{13560281171727086093ull, 403567982078916ull}},
{{7158876122639758551ull, 322854385663133ull}},
{{7764852981481703359ull, 516567017061013ull}},
{{13590580014669183334ull, 413253613648810ull}},
{{10872464011735346667ull, 330602890919048ull}},
{{13706593604034644344ull, 528964625470477ull}},
{{3586577253743894829ull, 423171700376382ull}},
{{13937308247220846833ull, 338537360301105ull}},
{{3852949121843803316ull, 541659776481769ull}},
{{6771708112216952976ull, 433327821185415ull}},
{{5417366489773562381ull, 346662256948332ull}},
{{12357135198379610133ull, 554659611117331ull}},
{{6196359343961777783ull, 443727688893865ull}},
{{4957087475169422226ull, 354982151115092ull}},
{{15033716424361268751ull, 283985720892073ull}},
{{1917853390526568062ull, 454377153427318ull}},
{{8912980341905075096ull, 363501722741854ull}},
{{10819733088265970400ull, 290801378193483ull}},
{{13622224126483642317ull, 465282205109573ull}},
{{18276476930670734500ull, 372225764087658ull}},
{{3553135100310856630ull, 297780611270127ull}},
{{9374364975239280932ull, 476448978032203ull}},
{{14878189609675245392ull, 381159182425762ull}},
{{4523854058256375667ull, 304927345940610ull}},
{{7238166493210201067ull, 487883753504976ull}},
{{2101184379826250531ull, 390307002803981ull}},
{{16438342762828641717ull, 312245602243184ull}},
{{15233301976300095778ull, 499592963589095ull}},
{{12186641581040076622ull, 399674370871276ull}},
{{6059964450090150975ull, 319739496697021ull}},
{{2317245490660420913ull, 511583194715234ull}},
{{5543145207270247054ull, 409266555772187ull}},
{{15502562610041928612ull, 327413244617749ull}},
{{13736053731841354811ull, 523861191388399ull}},
{{14678191800214994172ull, 419088953110719ull}},
{{15431902254913905660ull, 335271162488575ull}},
{{6244299534152697441ull, 536433859981721ull}},
{{1306090812580247629ull, 429147087985377ull}},
{{12112919094289929073ull, 343317670388301ull}},
{{12001972921380065871ull, 549308272621282ull}},
{{2222880707620232050ull, 439446618097026ull}},
{{16535699825063826933ull, 351557294477620ull}},
{{8010375646392571477ull, 562491671164193ull}},
{{13786998146597877828ull, 449993336931354ull}},
{{14718947332020212585ull, 359994669545083ull}},
{{707111421390439099ull, 287995735636067ull}},
{{4820727088966612881ull, 460793177017707ull}},
{{14924628115399021274ull, 368634541614165ull}},
{{11939702492319217019ull, 294907633291332ull}},
{{4346128728743105939ull, 471852213266132ull}},
{{14544949427220215720ull, 377481770612905ull}},
{{11635959541776172576ull, 301985416490324ull}},
{{7549488822616145153ull, 483176666384519ull}},
{{9728939872834826445ull, 386541333107615ull}},
{{7783151898267861156ull, 309233066486092ull}},
{{16142391851970488173ull, 494772906377747ull}},
{{5535215852092569892ull, 395818325102198ull}},
{{11806870311157876560ull, 316654660081758ull}},
{{15201643683110692173ull, 506647456130813ull}},
{{1093268502262822769ull, 405317964904651ull}},
{{15632010060777899508ull, 324254371923720ull}},
{{6564472023535087597ull, 518806995077953ull}},
{{12630275248311890724ull, 415045596062362ull}},
{{2725522569165691932ull, 332036476849890ull}},
{{4360836110665107092ull, 531258362959824ull}},
{{7178017703273995997ull, 425006690367859ull}},
{{9431762977361107120ull, 340005352294287ull}},
{{333425504810130100ull, 544008563670860ull}},
{{266740403848104080ull, 435206850936688ull}},
{{7592089952562303910ull, 348165480749350ull}},
{{12147343924099686257ull, 557064769198960ull}},
{{9717875139279749005ull, 445651815359168ull}},
{{15152997740907619851ull, 356521452287334ull}},
{{15811747007468006204ull, 285217161829867ull}},
{{10541399952981168633ull, 456347458927788ull}},
{{15811817591868755553ull, 365077967142230ull}},
{{12649454073495004442ull, 292062373713784ull}},
{{9171080073366276138ull, 467299797942055ull}},
{{7336864058693020911ull, 373839838353644ull}},
{{9558840061696327052ull, 299071870682915ull}},
{{15294144098714123283ull, 478514993092664ull}},
{{15924664093713208949ull, 382811994474131ull}},
{{9050382460228656836ull, 306249595579305ull}},
{{14480611936365850938ull, 489999352926888ull}},
{{516443104866949781ull, 391999482341511ull}},
{{15170549742861201117ull, 313599585873208ull}},
{{2136786700126459849ull, 501759337397134ull}},
{{5398778174843078202ull, 401407469917707ull}},
{{15387068984100193531ull, 321125975934165ull}},
{{6172566300850758034ull, 513801561494665ull}},
{{4938053040680606427ull, 411041249195732ull}},
{{15018488876770216111ull, 328832999356585ull}},
{{5582838129122794162ull, 526132798970537ull}},
{{15534316947523966299ull, 420906239176429ull}},
{{16116802372761083363ull, 336724991341143ull}},
{{3650790907966271441ull, 538759986145830ull}},
{{2920632726373017153ull, 431007988916664ull}},
{{6025854995840324045ull, 344806391133331ull}},
{{2262670363860697827ull, 551690225813330ull}},
{{1810136291088558261ull, 441352180650664ull}},
{{5137457847612756932ull, 353081744520531ull}},
{{420617463348295222ull, 282465395616425ull}},
{{672987941357272356ull, 451944632986280ull}},
{{538390353085817885ull, 361555706389024ull}},
{{4120061097210564631ull, 289244565111219ull}},
{{13970795385020724056ull, 462791304177950ull}},
{{11176636308016579245ull, 370233043342360ull}},
{{8941309046413263396ull, 296186434673888ull}},
{{10616745659519311110ull, 473898295478221ull}},
{{4804047712873538565ull, 379118636382577ull}},
{{14911284614524561821ull, 303294909106061ull}},
{{16479357753755478268ull, 485271854569698ull}},
{{2115439758778651645ull, 388217483655759ull}},
{{5381700621764831639ull, 310573986924607ull}},
{{12300069809565640946ull, 496918379079371ull}},
{{6150707032910602433ull, 397534703263497ull}},
{{15988612070554212916ull, 318027762610797ull}},
{{10824384053919099374ull, 508844420177276ull}},
{{4970158428393369176ull, 407075536141821ull}},
{{286777927972785017ull, 325660428913457ull}},
{{4148193499498366351ull, 521056686261531ull}},
{{18075950058566334373ull, 416845349009224ull}},
{{18150108861594977822ull, 333476279207379ull}},
{{17972127734326233546ull, 533562046731807ull}},
{{6999004557977166190ull, 426849637385446ull}},
{{1909854831639822629ull, 341479709908357ull}},
{{6745116545365626529ull, 546367535853371ull}},
{{1706744421550590900ull, 437094028682697ull}},
{{12433441981466203690ull, 349675222946157ull}},
{{5136111911378284611ull, 559480356713852ull}},
{{15176935973328358658ull, 447584285371081ull}},
{{8452199963920776603ull, 358067428296865ull}},
{{6761759971136621283ull, 286453942637492ull}},
{{14508164768560504376ull, 458326308219987ull}},
{{4227834185364582854ull, 366661046575990ull}},
{{3382267348291666283ull, 293328837260792ull}},
{{9100976572008576376ull, 469326139617267ull}},
{{18348827701832592071ull, 375460911693813ull}},
{{3611015717240342687ull, 300368729355051ull}},
{{16845671591810279269ull, 480589966968081ull}},
{{9787188458706313092ull, 384471973574465ull}},
{{7829750766965050473ull, 307577578859572ull}},
{{16216950041885991081ull, 492124126175315ull}},
{{12973560033508792865ull, 393699300940252ull}},
{{3000150397323213645ull, 314959440752202ull}},
{{8489589450459052156ull, 503935105203523ull}},
{{14170369189851062371ull, 403148084162818ull}},
{{268248907655118927ull, 322518467330255ull}},
{{429198252248190284ull, 516029547728408ull}},
{{7722056231282372873ull, 412823638182726ull}},
{{2488296170283987975ull, 330258910546181ull}},
{{15049320316680111730ull, 528414256873889ull}},
{{15728805068085999707ull, 422731405499111ull}},
{{8893695239726889443ull, 338185124399289ull}},
{{3161865939337292139ull, 541096199038863ull}},
{{9908190380953654357ull, 432876959231090ull}},
{{7926552304762923486ull, 346301567384872ull}},
{{16371832502362587901ull, 554082507815795ull}},
{{13097466001890070320ull, 443266006252636ull}},
{{6788623986770145933ull, 354612805002109ull}},
{{9120248004158027070ull, 283690244001687ull}},
{{18281745621394753635ull, 453904390402699ull}},
{{18314745311857713231ull, 363123512322159ull}},
{{18341145064228080908ull, 290498809857727ull}},
{{14588436843797288160ull, 464798095772364ull}},
{{15360098289779740851ull, 371838476617891ull}},
{{8598729817081882358ull, 297470781294313ull}},
{{10068618892589101449ull, 475953250070901ull}},
{{4365546299329370836ull, 380762600056721ull}},
{{18249832298431137962ull, 304610080045376ull}},
{{3374289974296448476ull, 487376128072603ull}},
{{10078129608920979427ull, 389900902458082ull}},
{{683806057652962895ull, 311920721966466ull}},
{{12162136136470471603ull, 499073155146345ull}},
{{9729708909176377282ull, 399258524117076ull}},
{{4094418312599191502ull, 319406819293661ull}},
{{17619115744384437374ull, 511050910869857ull}},
{{6716594966023729252ull, 408840728695886ull}},
{{1683927158077073079ull, 327072582956709ull}},
{{10072981082407137572ull, 523316132730734ull}},
{{11747733680667620381ull, 418652906184587ull}},
{{2019489315050275658ull, 334922324947670ull}},
{{3231182904080441054ull, 535875719916272ull}},
{{13652992767490083812ull, 428700575933017ull}},
{{3543696584508246403ull, 342960460746414ull}},
{{13048612164697014892ull, 548736737194262ull}},
{{3060192102273791267ull, 438989389755410ull}},
{{2448153681819033014ull, 351191511804328ull}},
{{227697076168542499ull, 561906418886925ull}},
{{182157660934833999ull, 449525135109540ull}},
{{145726128747867199ull, 359620108087632ull}},
{{11184627347224024729ull, 287696086470105ull}},
{{17895403755558439566ull, 460313738352168ull}},
{{3248276560221020683ull, 368250990681735ull}},
{{2598621248176816547ull, 294600792545388ull}},
{{468445182340996152ull, 471361268072621ull}},
{{15132151404840438214ull, 377089014458096ull}},
{{8416372309130440248ull, 301671211566477ull}},
{{17155544509350614720ull, 482673938506363ull}},
{{2656389163254760807ull, 386139150805091ull}},
{{16882506589571449938ull, 308911320644072ull}},
{{12254615284346678608ull, 494258113030516ull}},
{{6114343412735432563ull, 395406490424413ull}},
{{12270172359672166697ull, 316325192339530ull}},
{{1185531701765915099ull, 506120307743249ull}},
{{4637774176154642403ull, 404896246194599ull}},
{{7399568155665624245ull, 323916996955679ull}},
{{771262604839267823ull, 518267195129087ull}},
{{11685056528097145228ull, 414613756103269ull}},
{{13037394037219626505ull, 331691004882615ull}},
{{2413086385841850793ull, 530705607812185ull}},
{{1930469108673480634ull, 424564486249748ull}},
{{8923072916422605154ull, 339651588999798ull}},
{{10587567851534257923ull, 543442542399677ull}},
{{1091356651743585692ull, 434754033919742ull}},
{{11941131765620599523ull, 347803227135793ull}},
{{15416462010251048914ull, 556485163417269ull}},
{{16022518422942749454ull, 445188130733815ull}},
{{12818014738354199563ull, 356150504587052ull}},
{{2875714161199539004ull, 284920403669642ull}},
{{8290491472661172730ull, 455872645871427ull}},
{{17700439622354669154ull, 364698116697141ull}},
{{10471002883141825000ull, 291758493357713ull}},
{{13064255798285009676ull, 466813589372341ull}},
{{6762055823886097418ull, 373450871497873ull}},
{{12788342288592698581ull, 298760697198298ull}},
{{16771998847006407406ull, 478017115517277ull}},
{{6038901448121305278ull, 382413692413822ull}},
{{15899167602722775192ull, 305930953931057ull}},
{{10681272905388799015ull, 489489526289692ull}},
{{1166320694827218565ull, 391591621031754ull}},
{{4622405370603685175ull, 313273296825403ull}},
{{3706499778223985958ull, 501237274920645ull}},
{{2965199822579188766ull, 400989819936516ull}},
{{17129555117030992306ull, 320791855949212ull}},
{{12649892928281946397ull, 513266969518740ull}},
{{10119914342625557117ull, 410613575614992ull}},
{{717233844616625047ull, 328490860491994ull}},
{{8526271780870420722ull, 525585376787190ull}},
{{6821017424696336578ull, 420468301429752ull}},
{{16524860383982800232ull, 336374641143801ull}},
{{614334911179108109ull, 538199425830083ull}},
{{7870165558427107133ull, 430559540664066ull}},
{{2606783631999775383ull, 344447632531253ull}},
{{481504996457730290ull, 551116212050005ull}},
{{385203997166184232ull, 440892969640004ull}},
{{3997512012474857709ull, 352714375712003ull}},
{{10576707239463706813ull, 282171500569602ull}},
{{2165336324174289609ull, 451474400911364ull}},
{{5421617874081342010ull, 361179520729091ull}},
{{647945484523163285ull, 288943616583273ull}},
{{15794108034204702549ull, 462309786533236ull}},
{{8945937612621851716ull, 369847829226589ull}},
{{10846098904839391696ull, 295878263381271ull}},
{{9975060618259206067ull, 473405221410034ull}},
{{11669397309349275177ull, 378724177128027ull}},
{{1956820217995599495ull, 302979341702422ull}},
{{6820261163534869515ull, 484766946723875ull}},
{{5456208930827895612ull, 387813557379100ull}},
{{4364967144662316490ull, 310250845903280ull}},
{{6983947431459706384ull, 496401353445248ull}},
{{12965855574651585753ull, 397121082756198ull}},
{{17751382089205089249ull, 317696866204958ull}},
{{6266118454276680859ull, 508314985927934ull}},
{{8702243578163255011ull, 406651988742347ull}},
{{18029841306756334978ull, 325321590993877ull}},
{{14090350831842494672ull, 520514545590204ull}},
{{14961629480215906061ull, 416411636472163ull}},
{{901257139946993879ull, 333129309177731ull}},
{{12510057868140921176ull, 533006894684369ull}},
{{13697395109254647264ull, 426405515747495ull}},
{{10957916087403717811ull, 341124412597996ull}},
{{10153968110362127852ull, 545799060156794ull}},
{{11812523303031612605ull, 436639248125435ull}},
{{9450018642425290084ull, 349311398500348ull}},
{{11430681013138553811ull, 558898237600557ull}},
{{1765847181027022402ull, 447118590080446ull}},
{{16170073003789259214ull, 357694872064356ull}},
{{9246709588289497048ull, 286155897651485ull}},
{{14794735341263195277ull, 457849436242376ull}},
{{8146439458268645899ull, 366279548993901ull}},
{{2827802751873006396ull, 293023639195121ull}},
{{15592530847222541203ull, 468837822712193ull}},
{{1405978233552301993ull, 375070258169755ull}},
{{1124782586841841594ull, 300056206535804ull}},
{{9178349768430767197ull, 480089930457286ull}},
{{3653331000002703434ull, 384071944365829ull}},
{{6612013614744073071ull, 307257555492663ull}},
{{6889872968848606590ull, 491612088788261ull}},
{{1822549560336974949ull, 393289671030609ull}},
{{5147388463011490282ull, 314631736824487ull}},
{{11925170355560294775ull, 503410778919179ull}},
{{13229485099190146143ull, 402728623135343ull}},
{{17962285708835937561ull, 322182898508274ull}},
{{17671610689911769128ull, 515492637613239ull}},
{{17826637366671325625ull, 412394110090591ull}},
{{10571961078595150177ull, 329915288072473ull}},
{{13225788911010329960ull, 527864460915957ull}},
{{3201933499324443322ull, 422291568732766ull}},
{{17318942058427195950ull, 337833254986212ull}},
{{12952912034515872228ull, 540533207977940ull}},
{{10362329627612697782ull, 432426566382352ull}},
{{911166072606337579ull, 345941253105882ull}},
{{5147214530912050450ull, 553506004969411ull}},
{{428422809987730037ull, 442804803975529ull}},
{{4032087062732094352ull, 354243843180423ull}},
{{10604367279669496128ull, 283395074544338ull}},
{{13277638832729283482ull, 453432119270941ull}},
{{6932762251441516463ull, 362745695416753ull}},
{{12924907430637033816ull, 290196556333402ull}},
{{5922456630051612814ull, 464314490133444ull}},
{{8427314118783200574ull, 371451592106755ull}},
{{6741851295026560459ull, 297161273685404ull}},
{{18165659701526317381ull, 475458037896646ull}},
{{10843178946479143582ull, 380366430317317ull}},
{{1295845527699494219ull, 304293144253854ull}},
{{9452050473803011397ull, 486869030806166ull}},
{{3872291564300498794ull, 389495224644933ull}},
{{10476530880924219682ull, 311596179715946ull}},
{{9383751779994930845ull, 498553887545514ull}},
{{11196350238737854999ull, 398843110036411ull}},
{{5267731376248373676ull, 319074488029129ull}},
{{15807067831481218528ull, 510519180846606ull}},
{{8956305450443064499ull, 408415344677285ull}},
{{7165044360354451599ull, 326732275741828ull}},
{{7774722161825212236ull, 522771641186925ull}},
{{6219777729460169788ull, 418217312949540ull}},
{{4975822183568135831ull, 334573850359632ull}},
{{11650664308450927653ull, 535318160575411ull}},
{{5631182632018831799ull, 428254528460329ull}},
{{8194294920356975762ull, 342603622768263ull}},
{{9421523057829250896ull, 548165796429221ull}},
{{3847869631521490394ull, 438532637143377ull}},
{{14146342149442923285ull, 350826109714701ull}},
{{15255449809624856609ull, 561321775543522ull}},
{{4825662218216064641ull, 449057420434818ull}},
{{11239227404056672359ull, 359245936347854ull}},
{{12680730737987248210ull, 287396749078283ull}},
{{16599820366037686814ull, 459834798525253ull}},
{{2211809848604418481ull, 367867838820203ull}},
{{9148145508367355431ull, 294294271056162ull}},
{{18326381628129679013ull, 470870833689859ull}},
{{18350454117245653534ull, 376696666951887ull}},
{{7301665664312702181ull, 301357333561510ull}},
{{11682665062900323489ull, 482171733698416ull}},
{{5656783235578348468ull, 385737386958733ull}},
{{11904124217946499421ull, 308589909566986ull}},
{{11667901119230578427ull, 493743855307178ull}},
{{16713018524868283388ull, 394995084245742ull}},
{{5991717190410806064ull, 315996067396594ull}},
{{16965445134141110349ull, 505593707834550ull}},
{{13572356107312888279ull, 404474966267640ull}},
{{10857884885850310623ull, 323579973014112ull}},
{{2615220558392855705ull, 517727956822580ull}},
{{2092176446714284564ull, 414182365458064ull}},
{{5363089972113337974ull, 331345892366451ull}},
{{1202246325897520112ull, 530153427786322ull}},
{{12029843504943747059ull, 424122742229057ull}},
{{2245177174471177001ull, 339298193783246ull}},
{{14660329923379614171ull, 542877110053193ull}},
{{660217494477960367ull, 434301688042555ull}},
{{528173995582368294ull, 347441350434044ull}},
{{8223776022415609917ull, 555906160694470ull}},
{{6579020817932487933ull, 444724928555576ull}},
{{1573867839604080023ull, 355779942844461ull}},
{{16016489530650905311ull, 284623954275568ull}},
{{3490290360589986559ull, 455398326840910ull}},
{{2792232288471989247ull, 364318661472728ull}},
{{9612483460261412044ull, 291454929178182ull}},
{{622578277450617978ull, 466327886685092ull}},
{{11566109066186225352ull, 373062309348073ull}},
{{16631584882432800928ull, 298449847478458ull}},
{{4474442923441019546ull, 477519755965534ull}},
{{7268903153494725960ull, 382015804772427ull}},
{{16883168967021511737ull, 305612643817941ull}},
{{1187628644041046518ull, 488980230108707ull}},
{{12018149359458568184ull, 391184184086965ull}},
{{9614519487566854547ull, 312947347269572ull}},
{{625835921139325982ull, 500715755631316ull}},
{{15258063995879102079ull, 400572604505052ull}},
{{4827753567219461016ull, 320458083604042ull}},
{{11413754522293047950ull, 512732933766467ull}},
{{1752305988350617713ull, 410186347013174ull}},
{{5091193605422404494ull, 328149077610539ull}},
{{15524607398159667837ull, 525038524176862ull}},
{{5040988289043913623ull, 420030819341490ull}},
{{4032790631235130898ull, 336024655473192ull}},
{{10141813824718119760ull, 537639448757107ull}},
{{734753430290675162ull, 430111559005686ull}},
{{15345198003200181422ull, 344089247204548ull}},
{{2416223916668828337ull, 550542795527278ull}},
{{9311676762818883316ull, 440434236421822ull}},
{{70643780771286006ull, 352347389137458ull}},
{{7435212654100849451ull, 281877911309966ull}},
{{4517642617077538476ull, 451004658095946ull}},
{{18371509352629672073ull, 360803726476756ull}},
{{11007858667361827335ull, 288642981181405ull}},
{{17612573867778923737ull, 461828769890248ull}},
{{3022012649997408020ull, 369463015912199ull}},
{{6106958934739836739ull, 295570412729759ull}},
{{17149831925067559429ull, 472912660367614ull}},
{{17409214354795957866ull, 378330128294091ull}},
{{10238022669094855970ull, 302664102635273ull}},
{{12691487455809859229ull, 484262564216437ull}},
{{2774492335164066736ull, 387410051373150ull}},
{{2219593868131253389ull, 309928041098520ull}},
{{3551350189010005423ull, 495884865757632ull}},
{{13909126595433735308ull, 396707892606105ull}},
{{11127301276346988246ull, 317366314084884ull}},
{{6735635597929450224ull, 507786102535815ull}},
{{5388508478343560179ull, 406228882028652ull}},
{{15378853226900579113ull, 324983105622921ull}},
{{17227467533557105935ull, 519972968996674ull}},
{{17471322841587595071ull, 415978375197339ull}},
{{17666407088011986380ull, 332782700157871ull}},
{{2440809637625805945ull, 532452320252595ull}},
{{1952647710100644756ull, 425961856202076ull}},
{{16319513427048157098ull, 340769484961660ull}},
{{7664477409567499741ull, 545231175938657ull}},
{{17199628371879730762ull, 436184940750925ull}},
{{13759702697503784610ull, 348947952600740ull}},
{{3568780242296503760ull, 558316724161185ull}},
{{2855024193837203008ull, 446653379328948ull}},
{{9662716984553583052ull, 357322703463158ull}},
{{15108871217126687088ull, 285858162770526ull}},
{{16795496317918878695ull, 457373060432842ull}},
{{6057699424851282309ull, 365898448346274ull}},
{{8535508354622936171ull, 292718758677019ull}},
{{2588766923170966904ull, 468350013883231ull}},
{{16828408797504414816ull, 374680011106584ull}},
{{17152075852745442176ull, 299744008885267ull}},
{{12685926105425066189ull, 479590414216428ull}},
{{17527438513823873597ull, 383672331373142ull}},
{{6643253181575278231ull, 306937865098514ull}},
{{18007902720004265817ull, 491100584157622ull}},
{{7027624546519592007ull, 392880467326098ull}},
{{13000797266699494252ull, 314304373860878ull}},
{{17111926811977280480ull, 502886998177405ull}},
{{13689541449581824384ull, 402309598541924ull}},
{{14640981974407369830ull, 321847678833539ull}},
{{12357524714826060759ull, 514956286133663ull}},
{{17264717401344669253ull, 411965028906930ull}},
{{13811773921075735403ull, 329572023125544ull}},
{{11030791829495445675ull, 527315237000871ull}},
{{5135284648854446217ull, 421852189600697ull}},
{{15176274163309287943ull, 337481751680557ull}},
{{9524643402327219416ull, 539970802688892ull}},
{{241017092377954886ull, 431976642151114ull}},
{{3882162488644274232ull, 345581313720891ull}},
{{17279506426056569741ull, 552930101953425ull}},
{{13823605140845255793ull, 442344081562740ull}},
{{11058884112676204634ull, 353875265250192ull}},
{{1468409660657143061ull, 283100212200154ull}},
{{9728153086535249544ull, 452960339520246ull}},
{{4093173654486289312ull, 362368271616197ull}},
{{14342585367814762419ull, 289894617292957ull}},
{{8190741329535978578ull, 463831387668732ull}},
{{17620639507854513832ull, 371065110134985ull}},
{{14096511606283611066ull, 296852088107988ull}},
{{418325681602315766ull, 474963340972782ull}},
{{11402706989507583582ull, 379970672778225ull}},
{{9122165591606066866ull, 303976538222580ull}},
{{14595464946569706985ull, 486362461156128ull}},
{{608325513030034619ull, 389089968924903ull}},
{{7865358039907848341ull, 311271975139922ull}},
{{16273921678594467669ull, 498035160223875ull}},
{{13019137342875574135ull, 398428128179100ull}},
{{10415309874300459308ull, 318742502543280ull}},
{{16664495798880734894ull, 509988004069248ull}},
{{2263550194878856945ull, 407990403255399ull}},
{{5500188970644995879ull, 326392322604319ull}},
{{16178999982515814053ull, 522227716166910ull}},
{{12943199986012651243ull, 417782172933528ull}},
{{17733257618293941640ull, 334225738346822ull}},
{{13615816930302665332ull, 534761181354916ull}},
{{7203304729500221942ull, 427808945083933ull}},
{{13141341413083998200ull, 342247156067146ull}},
{{13647448631450576474ull, 547595449707434ull}},
{{14607307719902371503ull, 438076359765947ull}},
{{4307148546438076556ull, 350461087812758ull}},
{{3202088859559012166ull, 560737740500413ull}},
{{9940368717131030379ull, 448590192400330ull}},
{{7952294973704824303ull, 358872153920264ull}},
{{10051184793705769766ull, 287097723136211ull}},
{{8703198040445410979ull, 459356357017938ull}},
{{14341256061840149429ull, 367485085614350ull}},
{{11473004849472119543ull, 293988068491480ull}},
{{18356807759155391270ull, 470380909586368ull}},
{{3617399763098582046ull, 376304727669095ull}},
{{2893919810478865637ull, 301043782135276ull}},
{{15698318140991915989ull, 481670051416441ull}},
{{8869305698051622468ull, 385336041133153ull}},
{{14474142187925118620ull, 308268832906522ull}},
{{8401232241712548500ull, 493230132650436ull}},
{{3031636978628128477ull, 394584106120349ull}},
{{6114658397644413105ull, 315667284896279ull}},
{{17162151065714881614ull, 505067655834046ull}},
{{10040372037829994968ull, 404054124667237ull}},
{{653600000780175328ull, 323243299733790ull}},
{{1045760001248280525ull, 517189279574064ull}},
{{4525956815740534743ull, 413751423659251ull}},
{{18378160711560069087ull, 331001138927400ull}},
{{10958313064786558924ull, 529601822283841ull}},
{{5077301637087336816ull, 423681457827073ull}},
{{11440538939153690099ull, 338945166261658ull}},
{{14615513487903993835ull, 542312266018653ull}},
{{624364346097464098ull, 433849812814923ull}},
{{7878189106361791925ull, 347079850251938ull}},
{{8915753755436956757ull, 555327760403101ull}},
{{3443254189607655082ull, 444262208322481ull}},
{{17511998610653765359ull, 355409766657984ull}},
{{17698947703264922610ull, 284327813326387ull}},
{{13560921066256234884ull, 454924501322220ull}},
{{10848736853004987907ull, 363939601057776ull}},
{{4989640667662080002ull, 291151680846221ull}},
{{604727438775507357ull, 465842689353954ull}},
{{4173130765762316209ull, 372674151483163ull}},
{{10717202242093673613ull, 298139321186530ull}},
{{17147523587349877782ull, 477022913898448ull}},
{{2649972425654171256ull, 381618331118759ull}},
{{5809326755265247328ull, 305294664895007ull}},
{{12984271623166306048ull, 488471463832011ull}},
{{6698068483791134515ull, 390777171065609ull}},
{{9047803601774817935ull, 312621736852487ull}},
{{18165834577581619020ull, 500194778963979ull}},
{{18222016476807205539ull, 400155823171183ull}},
{{3509566737220033461ull, 320124658536947ull}},
{{9304655594293963862ull, 512199453659115ull}},
{{7443724475435171089ull, 409759562927292ull}},
{{17023026024573867841ull, 327807650341833ull}},
{{5100748750866726606ull, 524492240546934ull}},
{{7769947815435291608ull, 419593792437547ull}},
{{17284004696573964256ull, 335675033950037ull}},
{{12897012255550701517ull, 537080054320060ull}},
{{10317609804440561214ull, 429664043456048ull}},
{{15632785473036269617ull, 343731234764838ull}},
{{2876363868406569449ull, 549969975623742ull}},
{{13369137538950986528ull, 439975980498993ull}},
{{18074007660644609869ull, 351980784399194ull}},
{{18148554943257598218ull, 281584627519355ull}},
{{10590943835502605534ull, 450535404030969ull}},
{{12162103883143994750ull, 360428323224775ull}},
{{9729683106515195800ull, 288342658579820ull}},
{{15567492970424313280ull, 461348253727712ull}},
{{5075296746855629978ull, 369078602982170ull}},
{{4060237397484503982ull, 295262882385736ull}},
{{17564426280200937341ull, 472420611817177ull}},
{{6672843394676929226ull, 377936489453742ull}},
{{16406321159967274351ull, 302349191562993ull}},
{{4114020967496177022ull, 483758706500790ull}},
{{3291216773996941618ull, 387006965200632ull}},
{{13701019863423284264ull, 309605572160505ull}},
{{3474887707767703206ull, 495368915456809ull}},
{{6469258980956072888ull, 396295132365447ull}},
{{16243453628990589280ull, 317036105892357ull}},
{{11232130547417301555ull, 507257769427772ull}},
{{1607006808450020598ull, 405806215542218ull}},
{{8664303076243837124ull, 324644972433774ull}},
{{2794838477764408430ull, 519431955894039ull}},
{{5925219596953437067ull, 415545564715231ull}},
{{1050826862820839330ull, 332436451772185ull}},
{{1681322980513342929ull, 531898322835496ull}},
{{16102453643378315636ull, 425518658268396ull}},
{{9192614099960742185ull, 340414926614717ull}},
{{18397531374679097820ull, 544663882583547ull}},
{{7339327470259457609ull, 435731106066838ull}},
{{13250159605691386734ull, 348584884853470ull}},
{{2753511295396667158ull, 557735815765553ull}},
{{9581506665801154373ull, 446188652612442ull}},
{{286507703157102852ull, 356950922089954ull}},
{{3918554977267592605ull, 285560737671963ull}},
{{2580339148886237845ull, 456897180275141ull}},
{{16821666578076631568ull, 365517744220112ull}},
{{6078635632977484608ull, 292414195376090ull}},
{{9725817012763975373ull, 467862712601744ull}},
{{11470002424953090622ull, 374290170081395ull}},
{{9176001939962472497ull, 299432136065116ull}},
{{7302905474456135350ull, 479091417704186ull}},
{{2152975564822997956ull, 383273134163349ull}},
{{5411729266600308688ull, 306618507330679ull}},
{{16037464456044314548ull, 490589611729086ull}},
{{9140622750093541315ull, 392471689383269ull}},
{{11001847014816743375ull, 313977351506615ull}},
{{17602955223706789400ull, 502363762410584ull}},
{{17771712993707341843ull, 401891009928467ull}},
{{6838672765482052828ull, 321512807942774ull}},
{{18320574054255105172ull, 514420492708438ull}},
{{3588412799178353168ull, 411536394166751ull}},
{{17628125498310323827ull, 329229115333400ull}},
{{9758256723586966507ull, 526766584533441ull}},
{{4117256564127662883ull, 421413267626753ull}},
{{10672502880785950952ull, 337130614101402ull}},
{{2318609350289880231ull, 539408982562244ull}},
{{5544236294973814508ull, 431527186049795ull}},
{{4435389035979051606ull, 345221748839836ull}},
{{18164668901792213540ull, 552354798143737ull}},
{{7153037491949950186ull, 441883838514990ull}},
{{5722429993559960148ull, 353507070811992ull}},
{{15645990439073699088ull, 282805656649593ull}},
{{2897491814066456602ull, 452489050639350ull}},
{{2317993451253165282ull, 361991240511480ull}},
{{1854394761002532225ull, 289592992409184ull}},
{{10345729247087872207ull, 463348787854694ull}},
{{11965932212412208089ull, 370679030283755ull}},
{{9572745769929766471ull, 296543224227004ull}},
{{4248346787661895384ull, 474469158763207ull}},
{{14466723874355247277ull, 379575327010565ull}},
{{11573379099484197821ull, 303660261608452ull}},
{{3760011300207075222ull, 485856418573524ull}},
{{6697357854907570501ull, 388685134858819ull}},
{{9047235098667966724ull, 310948107887055ull}},
{{14475576157868746758ull, 497516972619288ull}},
{{512414482069266437ull, 398013578095431ull}},
{{15167326844623054442ull, 318410862476344ull}},
{{13199676507171156138ull, 509457379962151ull}},
{{6870392390995014587ull, 407565903969721ull}},
{{1806965098054101346ull, 326052723175777ull}},
{{6580492971628472478ull, 521684357081243ull}},
{{12643092006786598628ull, 417347485664994ull}},
{{13803822420171189226ull, 333877988531995ull}},
{{3639371798564351146ull, 534204781651193ull}},
{{10290195068335301563ull, 427363825320954ull}},
{{11921504869410151573ull, 341891060256763ull}},
{{15385058976314332194ull, 547025696410821ull}},
{{8618698366309555432ull, 437620557128657ull}},
{{17963005137273375315ull, 350096445702925ull}},
{{10294064145927848889ull, 560154313124681ull}},
{{4545902502000368788ull, 448123450499745ull}},
{{3636722001600295030ull, 358498760399796ull}},
{{17666772860247877317ull, 286799008319836ull}},
{{2441394873203231445ull, 458878413311739ull}},
{{5642464713304495479ull, 367102730649391ull}},
{{824622955901686060ull, 293682184519513ull}},
{{16076791988410338989ull, 469891495231220ull}},
{{12861433590728271191ull, 375913196184976ull}},
{{6599798057840706629ull, 300730556947981ull}},
{{3180979263061309961ull, 481168891116770ull}},
{{2544783410449047969ull, 384935112893416ull}},
{{16793221987326879668ull, 307948090314732ull}},
{{12111759920755366176ull, 492716944503572ull}},
{{2310710307120472294ull, 394173555602858ull}},
{{9227265875180198482ull, 315338844482286ull}},
{{7384927770804496924ull, 504542151171658ull}},
{{13286639846127418186ull, 403633720937326ull}},
{{6939963062160024225ull, 322906976749861ull}},
{{3725243269972218115ull, 516651162799778ull}},
{{10358892245461595138ull, 413320930239822ull}},
{{908416166885455464ull, 330656744191858ull}},
{{16210861125984370035ull, 529050790706972ull}},
{{5589991271303675382ull, 423240632565578ull}},
{{11850690646526760952ull, 338592506052462ull}},
{{4203709775475176230ull, 541748009683940ull}},
{{3362967820380140984ull, 433398407747152ull}},
{{13758420700529843757ull, 346718726197721ull}},
{{14634775491363929365ull, 554749961916354ull}},
{{15397169207833053815ull, 443799969533083ull}},
{{1249688922040712082ull, 355039975626467ull}},
{{12067797581858300635ull, 284031980501173ull}},
{{15619127316231370693ull, 454451168801877ull}},
{{5116604223501275908ull, 363560935041502ull}},
{{15161329823026751696ull, 290848748033201ull}},
{{16879430087358982068ull, 465357996853122ull}},
{{6124846440403365008ull, 372286397482498ull}},
{{12278574781806512652ull, 297829117985998ull}},
{{15956370836148509921ull, 476526588777597ull}},
{{5386399039434987290ull, 381221271022078ull}},
{{11687816861031810479ull, 304977016817662ull}},
{{3943111718683255473ull, 487963226908260ull}},
{{3154489374946604378ull, 390370581526608ull}},
{{9902289129441104149ull, 312296465221286ull}},
{{8464964977621945992ull, 499674344354058ull}},
{{14150669611581377440ull, 399739475483246ull}},
{{7631186874523191629ull, 319791580386597ull}},
{{15899247813979016930ull, 511666528618555ull}},
{{12719398251183213544ull, 409333222894844ull}},
{{13864867415688481158ull, 327466578315875ull}},
{{3737043791392018237ull, 523946525305401ull}},
{{17747030292081255882ull, 419157220244320ull}},
{{14197624233665004706ull, 335325776195456ull}},
{{15337501144380186883ull, 536521241912730ull}},
{{12270000915504149506ull, 429216993530184ull}},
{{13505349547145229928ull, 343373594824147ull}},
{{6851164016464726593ull, 549397751718636ull}},
{{1791582398429870951ull, 439518201374909ull}},
{{5122614733485807084ull, 351614561099927ull}},
{{11885532388319201658ull, 562583297759883ull}},
{{16887123540139181972ull, 450066638207906ull}},
{{9820350017369435255ull, 360053310566325ull}},
{{7856280013895548204ull, 288042648453060ull}},
{{12570048022232877126ull, 460868237524896ull}},
{{6366689603044391378ull, 368694590019917ull}},
{{16161398126661244072ull, 294955672015933ull}},
{{3722144114206528576ull, 471929075225494ull}},
{{6667064106107133184ull, 377543260180395ull}},
{{5333651284885706547ull, 302034608144316ull}},
{{1155144426333309829ull, 483255373030906ull}},
{{15681510800034289156ull, 386604298424724ull}},
{{16234557454769341648ull, 309283438739779ull}},
{{14907245483405215667ull, 494853501983647ull}},
{{4547098757240351887ull, 395882801586918ull}},
{{11016376635276102156ull, 316706241269534ull}},
{{6558156172216032480ull, 506729986031255ull}},
{{5246524937772825984ull, 405383988825004ull}},
{{7886568764960171110ull, 324307191060003ull}},
{{8929161209194363454ull, 518891505696005ull}},
{{7143328967355490763ull, 415113204556804ull}},
{{9404011988626302933ull, 332090563645443ull}},
{{11357070367060174370ull, 531344901832709ull}},
{{12775005108390049819ull, 425075921466167ull}},
{{2841306457228219209ull, 340060737172934ull}},
{{11924787961048971381ull, 544097179476694ull}},
{{13229179183581087428ull, 435277743581355ull}},
{{10583343346864869942ull, 348222194865084ull}},
{{5865302910758060938ull, 557155511784135ull}},
{{4692242328606448751ull, 445724409427308ull}},
{{11132491492368979647ull, 356579527541846ull}},
{{5216644379153273394ull, 285263622033477ull}},
{{12035979821387147754ull, 456421795253563ull}},
{{17007481486593538850ull, 365137436202850ull}},
{{13605985189274831080ull, 292109948962280ull}},
{{3322832229130178112ull, 467375918339649ull}},
{{6347614598046052812ull, 373900734671719ull}},
{{8767440493178752573ull, 299120587737375ull}},
{{14027904789086004117ull, 478592940379800ull}},
{{11222323831268803294ull, 382874352303840ull}},
{{8977859065015042635ull, 306299481843072ull}},
{{18053923318765978539ull, 490079170948915ull}},
{{14443138655012782831ull, 392063336759132ull}},
{{4175813294526405618ull, 313650669407306ull}},
{{17749347715467979959ull, 501841071051689ull}},
{{17888826987116294291ull, 401472856841351ull}},
{{10621712774951125109ull, 321178285473081ull}},
{{9616042810437979529ull, 513885256756930ull}},
{{7692834248350383623ull, 411108205405544ull}},
{{9843616213422217221ull, 328886564324435ull}},
{{15749785941475547554ull, 526218502919096ull}},
{{8910479938438527720ull, 420974802335277ull}},
{{18196430394976553146ull, 336779841868221ull}},
{{3288846928769112771ull, 538847746989155ull}},
{{2631077543015290217ull, 431078197591324ull}},
{{5794210849154142496ull, 344862558073059ull}},
{{16649434988130448641ull, 551780092916894ull}},
{{17008896805246269236ull, 441424074333515ull}},
{{13607117444197015389ull, 353139259466812ull}},
{{3506996325873791664ull, 282511407573450ull}},
{{5611194121398066663ull, 452018252117520ull}},
{{4488955297118453331ull, 361614601694016ull}},
{{18348559496662403957ull, 289291681355212ull}},
{{14600299935692205039ull, 462866690168340ull}},
{{11680239948553764031ull, 370293352134672ull}},
{{1965494329359190578ull, 296234681707738ull}},
{{17902186185942346219ull, 473975490732380ull}},
{{14321748948753876975ull, 379180392585904ull}},
{{15146747973745011903ull, 303344314068723ull}},
{{2098703869540557106ull, 485350902509958ull}},
{{9057660725116266331ull, 388280722007966ull}},
{{3556779765351102741ull, 310624577606373ull}},
{{2001498809819854063ull, 496999324170197ull}},
{{12669245492081614220ull, 397599459336157ull}},
{{2756698764181470730ull, 318079567468926ull}},
{{15478764466916084137ull, 508927307950281ull}},
{{8693662758790956987ull, 407141846360225ull}},
{{6954930207032765589ull, 325713477088180ull}},
{{11127888331252424943ull, 521141563341088ull}},
{{16281008294485760601ull, 416913250672870ull}},
{{13024806635588608480ull, 333530600538296ull}},
{{13460992987457952923ull, 533648960861274ull}},
{{14458143204708272661ull, 426919168689019ull}},
{{15255863378508528452ull, 341535334951215ull}},
{{5962637331904093908ull, 546456535921945ull}},
{{4770109865523275126ull, 437165228737556ull}},
{{126739077676709777ull, 349732182990045ull}},
{{202782524282735644ull, 559571492784072ull}},
{{11230272463651919485ull, 447657194227257ull}},
{{1605520341437714941ull, 358125755381806ull}},
{{16041811532117813246ull, 286500604305444ull}},
{{14598852007162770224ull, 458400966888711ull}},
{{7989732790988305856ull, 366720773510969ull}},
{{10081135047532555008ull, 293376618808775ull}},
{{16129816076052088013ull, 469402590094040ull}},
{{12903852860841670410ull, 375522072075232ull}},
{{2944384659189515682ull, 300417657660186ull}},
{{15779061898928956060ull, 480668252256297ull}},
{{5244551889659344202ull, 384534601805038ull}},
{{11574339141211296008ull, 307627681444030ull}},
{{72198552228521997ull, 492204290310449ull}},
{{3747107656524727921ull, 393763432248359ull}},
{{6687034939961692660ull, 315010745798687ull}},
{{14388604718680618579ull, 504017193277899ull}},
{{15200232589686405186ull, 403213754622319ull}},
{{15849534886491034472ull, 322571003697855ull}},
{{6912511744676103539ull, 516113605916569ull}},
{{9219358210482793155ull, 412890884733255ull}},
{{7375486568386234524ull, 330312707786604ull}},
{{732732065192244269ull, 528500332458567ull}},
{{11654232096379526384ull, 422800265966853ull}},
{{16702083306587441754ull, 338240212773482ull}},
{{11965938031572265514ull, 541184340437572ull}},
{{2194052795773991764ull, 432947472350058ull}},
{{9133939866103014058ull, 346357977880046ull}},
{{7235606156281001846ull, 554172764608074ull}},
{{9477833739766711800ull, 443338211686459ull}},
{{11271615806555279763ull, 354670569349167ull}},
{{1638595015760403164ull, 283736455479334ull}},
{{10000449654700465709ull, 453978328766934ull}},
{{11689708538502282890ull, 363182663013547ull}},
{{1973069201318005666ull, 290546130410838ull}},
{{17914305981076450358ull, 464873808657340ull}},
{{14331444784861160287ull, 371899046925872ull}},
{{4086458198405107583ull, 297519237540698ull}},
{{2848984302706261810ull, 476030780065117ull}},
{{13347233886390740417ull, 380824624052093ull}},
{{18056484738596412980ull, 304659699241674ull}},
{{17822329137528529799ull, 487455518786679ull}},
{{17947212124764734162ull, 389964415029343ull}},
{{3289723255586056360ull, 311971532023475ull}},
{{5263557208937690176ull, 499154451237560ull}},
{{4210845767150152141ull, 399323560990048ull}},
{{10747374243203942359ull, 319458848792038ull}},
{{13506449974384397452ull, 511134158067261ull}},
{{7115811164765607638ull, 408907326453809ull}},
{{9381997746554396434ull, 327125861163047ull}},
{{253801135519393001ull, 523401377860876ull}},
{{14960436167383155694ull, 418721102288700ull}},
{{11968348933906524555ull, 334976881830960ull}},
{{702614220540887672ull, 535963010929537ull}},
{{11630137820658441107ull, 428770408743629ull}},
{{12993459071268663209ull, 343016326994903ull}},
{{17100185699287950811ull, 548826123191845ull}},
{{13680148559430360649ull, 439060898553476ull}},
{{7254770032802378196ull, 351248718842781ull}},
{{4228934422999984467ull, 561997950148450ull}},
{{3383147538399987574ull, 449598360118760ull}},
{{2706518030719990059ull, 359678688095008ull}},
{{9543912054059812693ull, 287742950476006ull}},
{{7891561657011879663ull, 460388720761610ull}},
{{6313249325609503730ull, 368310976609288ull}},
{{12429297089971423631ull, 294648781287430ull}},
{{1440131270244726193ull, 471438050059889ull}},
{{4841453830937691278ull, 377150440047911ull}},
{{183814250008242699ull, 301720352038329ull}},
{{7672800429497008965ull, 482752563261326ull}},
{{2448891528855696849ull, 386202050609061ull}},
{{16716508482052198772ull, 308961640487248ull}},
{{4610320682832056096ull, 494338624779598ull}},
{{11066954175749465523ull, 395470899823678ull}},
{{16232260970083393065ull, 316376719858942ull}},
{{11214222293165787611ull, 506202751774308ull}},
{{16350075464016450735ull, 404962201419446ull}},
{{9390711556471250265ull, 323969761135557ull}},
{{267743231386359131ull, 518351617816892ull}},
{{11282241029334818274ull, 414681294253513ull}},
{{16404490452951675266ull, 331745035402810ull}},
{{7800440651013128809ull, 530792056644497ull}},
{{17308398965036234017ull, 424633645315597ull}},
{{6468021542545166567ull, 339706916252478ull}},
{{6659485653330356185ull, 543531066003965ull}},
{{5327588522664284948ull, 434824852803172ull}},
{{15330117262357158928ull, 347859882242537ull}},
{{9770792360803812992ull, 556575811588060ull}},
{{7816633888643050393ull, 445260649270448ull}},
{{13632004740398260961ull, 356208519416358ull}},
{{18284301421802429415ull, 284966815533086ull}},
{{3429440571690514802ull, 455946904852939ull}},
{{6432901272094322165ull, 364757523882351ull}},
{{1456972202933547408ull, 291806019105881ull}},
{{13399201968919406823ull, 466889630569409ull}},
{{14408710389877435782ull, 373511704455527ull}},
{{4148270682418127979ull, 298809363564422ull}},
{{10326581906610915090ull, 478094981703075ull}},
{{8261265525288732072ull, 382475985362460ull}},
{{6609012420230985657ull, 305980788289968ull}},
{{6885071057627666729ull, 489569261263949ull}},
{{9197405660844043706ull, 391655409011159ull}},
{{11047273343417145288ull, 313324327208927ull}},
{{2918242090499791168ull, 501318923534284ull}},
{{6023942487141743258ull, 401055138827427ull}},
{{15887200433939125576ull, 320844111061941ull}},
{{18040823064818780275ull, 513350577699106ull}},
{{10743309637113113897ull, 410680462159285ull}},
{{8594647709690491117ull, 328544369727428ull}},
{{10062087520762875465ull, 525670991563885ull}},
{{8049670016610300372ull, 420536793251108ull}},
{{13818433642772060944ull, 336429434600886ull}},
{{14730796198951476864ull, 538287095361418ull}},
{{716590514935450521ull, 430629676289135ull}},
{{573272411948360417ull, 344503741031308ull}},
{{15674631118085017960ull, 551205985650092ull}},
{{5161007264984193722ull, 440964788520074ull}},
{{7818154626729265300ull, 352771830816059ull}},
{{9943872516125322563ull, 282217464652847ull}},
{{1152800766832874809ull, 451547943444556ull}},
{{15679635872433941140ull, 361238354755644ull}},
{{16233057512689063235ull, 288990683804515ull}},
{{7526147946592949560ull, 462385094087225ull}},
{{6020918357274359648ull, 369908075269780ull}},
{{4816734685819487718ull, 295926460215824ull}},
{{15085473126795000996ull, 473482336345318ull}},
{{1000332057210269827ull, 378785869076255ull}},
{{800265645768215862ull, 303028695261004ull}},
{{8659122662712966025ull, 484845912417606ull}},
{{3237949315428462497ull, 387876729934085ull}},
{{2590359452342769997ull, 310301383947268ull}},
{{455226309006521673ull, 496482214315629ull}},
{{4053529861947127662ull, 397185771452503ull}},
{{10621521519041522776ull, 317748617162002ull}},
{{2237039171498795148ull, 508397787459204ull}},
{{5478980151940946442ull, 406718229967363ull}},
{{11761881751036577800ull, 325374583973890ull}},
{{372266727948972864ull, 520599334358225ull}},
{{297813382359178291ull, 416479467486580ull}},
{{238250705887342633ull, 333183573989264ull}},
{{7759898758903568859ull, 533093718382822ull}},
{{17275965451348586057ull, 426474974706257ull}},
{{6442074731595048199ull, 341179979765006ull}},
{{2928621941068256472ull, 545887967624010ull}},
{{2342897552854605178ull, 436710374099208ull}},
{{9253015671767504788ull, 349368299279366ull}},
{{7426127445344187015ull, 558989278846986ull}},
{{2251553141533439289ull, 447191423077589ull}},
{{5490591327968661754ull, 357753138462071ull}},
{{703124247633019080ull, 286202510769657ull}},
{{4814347610954740852ull, 457924017231451ull}},
{{162129274021882358ull, 366339213785161ull}},
{{14887098678185147179ull, 293071371028128ull}},
{{1683264996644773548ull, 468914193645006ull}},
{{16104007256283460131ull, 375131354916004ull}},
{{16572554619768678428ull, 300105083932803ull}},
{{4379994503178423545ull, 480168134292486ull}},
{{18261390861510380129ull, 384134507433988ull}},
{{3541066244982573134ull, 307307605947191ull}},
{{16733752436197847984ull, 491692169515505ull}},
{{13387001948958278387ull, 393353735612404ull}},
{{14398950373908533033ull, 314682988489923ull}},
{{902227709802190913ull, 503492781583878ull}},
{{8100479797325573377ull, 402794225267102ull}},
{{17548430282086189671ull, 322235380213681ull}},
{{2252046748144531211ull, 515576608341891ull}},
{{16559032657483266262ull, 412461286673512ull}},
{{5868528496502792363ull, 329969029338810ull}},
{{9389645594404467781ull, 527950446942096ull}},
{{3822367660781663902ull, 422360357553677ull}},
{{14125940572851062091ull, 337888286042941ull}},
{{15222807287077878699ull, 540621257668706ull}},
{{8488897014920392636ull, 432497006134965ull}},
{{6791117611936314109ull, 345997604907972ull}},
{{14555136993840012897ull, 553596167852755ull}},
{{11644109595072010318ull, 442876934282204ull}},
{{13004636490799518577ull, 354301547425763ull}},
{{17782406822123435508ull, 283441237940610ull}},
{{10005106841687945197ull, 453505980704977ull}},
{{625387843866535511ull, 362804784563982ull}},
{{11568356719318959379ull, 290243827651185ull}},
{{62626677200783390ull, 464390124241897ull}},
{{11118147785986357682ull, 371512099393517ull}},
{{1515820599305265499ull, 297209679514814ull}},
{{9804010588372245445ull, 475535487223702ull}},
{{464510841213975709ull, 380428389778962ull}},
{{11439655117196911537ull, 304342711823169ull}},
{{7235401743289327490ull, 486948338917071ull}},
{{2098972579889551669ull, 389558671133657ull}},
{{12747224508137372304ull, 311646936906925ull}},
{{1948815139310244071ull, 498635099051081ull}},
{{16316447370415836550ull, 398908079240864ull}},
{{16742506711074579563ull, 319126463392691ull}},
{{962569034525955038ull, 510602341428307ull}},
{{11838101671846495000ull, 408481873142645ull}},
{{9470481337477196000ull, 326785498514116ull}},
{{7774072510479692954ull, 522856797622586ull}},
{{2529909193641844040ull, 418285438098069ull}},
{{5713276169655385555ull, 334628350478455ull}},
{{9141241871448616888ull, 535405360765528ull}},
{{14691691126642714157ull, 428324288612422ull}},
{{4374655271830350679ull, 342659430889938ull}},
{{3310099620186650764ull, 548255089423901ull}},
{{17405474955116961904ull, 438604071539120ull}},
{{13924379964093569523ull, 350883257231296ull}},
{{14900310313065890590ull, 561413211570074ull}},
{{15609597065194622795ull, 449130569256059ull}},
{{16177026466897608559ull, 359304455404847ull}},
{{5562923544034266201ull, 287443564323878ull}},
{{5211328855712915599ull, 459909702918205ull}},
{{4169063084570332479ull, 367927762334564ull}},
{{7024599282398176306ull, 294342209867651ull}},
{{3860661222353261444ull, 470947535788242ull}},
{{14156575422108340125ull, 376758028630593ull}},
{{257213893460941130ull, 301406422904475ull}},
{{411542229537505808ull, 482250276647160ull}},
{{329233783630004647ull, 385800221317728ull}},
{{7642084656387824364ull, 308640177054182ull}},
{{15916684264962429305ull, 493824283286691ull}},
{{9043998597228033121ull, 395059426629353ull}},
{{14613896507266247143ull, 316047541303482ull}},
{{8624839152658354136ull, 505676066085572ull}},
{{17967917766352414278ull, 404540852868457ull}},
{{6995636583598110776ull, 323632682294766ull}},
{{3814320904273156596ull, 517812291671626ull}},
{{17808851982386166569ull, 414249833337300ull}},
{{14247081585908933255ull, 331399866669840ull}},
{{4348586463744741593ull, 530239786671745ull}},
{{3478869170995793274ull, 424191829337396ull}},
{{17540490595764275912ull, 339353463469916ull}},
{{2239343250029469197ull, 542965541551867ull}},
{{12859521044249306327ull, 434372433241493ull}},
{{17666314464883265708ull, 347497946593194ull}},
{{17198056699587494164ull, 555996714549111ull}},
{{10069096544928085008ull, 444797371639289ull}},
{{11744626050684378329ull, 355837897311431ull}},
{{5706352025805592340ull, 284670317849145ull}},
{{9130163241288947745ull, 455472508558632ull}},
{{18372177037256889165ull, 364378006846905ull}},
{{14697741629805511332ull, 291502405477524ull}},
{{12448340163463087162ull, 466403848764039ull}},
{{13648020945512380053ull, 373123079011231ull}},
{{7229067941667993719ull, 298498463208985ull}},
{{11566508706668789950ull, 477597541134376ull}},
{{5563858150593121637ull, 382078032907501ull}},
{{761737705732586986ull, 305662426326001ull}},
{{12286826773397870148ull, 489059882121601ull}},
{{6140112603976385795ull, 391247905697281ull}},
{{1222741268439198313ull, 312998324557825ull}},
{{1956386029502717301ull, 500797319292520ull}},
{{1565108823602173840ull, 400637855434016ull}},
{{16009482317849380365ull, 320510284347212ull}},
{{10857776449591367292ull, 512816454955540ull}},
{{8686221159673093833ull, 410253163964432ull}},
{{18017023371964206036ull, 328202531171545ull}},
{{10380493321433178042ull, 525124049874473ull}},
{{15683092286630363080ull, 420099239899578ull}},
{{1478427385078559494ull, 336079391919663ull}},
{{17122879075093336484ull, 537727027071460ull}},
{{13698303260074669187ull, 430181621657168ull}},
{{18337340237543555996ull, 344145297325734ull}},
{{18271697935843958624ull, 550632475721175ull}},
{{14617358348675166899ull, 440505980576940ull}},
{{11693886678940133519ull, 352404784461552ull}},
{{1976411713668286169ull, 281923827569242ull}},
{{6851607556611168194ull, 451078124110787ull}},
{{16549332489514665525ull, 360862499288629ull}},
{{16928814806353642743ull, 288689999430903ull}},
{{4950010801714366449ull, 461903999089446ull}},
{{270659826629582836ull, 369523199271557ull}},
{{11284574305529397238ull, 295618559417245ull}},
{{18055318888847035582ull, 472989695067592ull}},
{{7065557481593807819ull, 378391756054074ull}},
{{9341794800016956578ull, 302713404843259ull}},
{{3878825235801399556ull, 484341447749215ull}},
{{3103060188641119645ull, 387473158199372ull}},
{{13550494595138626685ull, 309978526559497ull}},
{{6923396093254161404ull, 495965642495196ull}},
{{1849368059861418800ull, 396772513996157ull}},
{{12547540892114866009ull, 317418011196925ull}},
{{1629321353674233999ull, 507868817915081ull}},
{{16060852341907028492ull, 406295054332064ull}},
{{16538030688267533117ull, 325036043465651ull}},
{{635407398034680725ull, 520057669545043ull}},
{{7887023547911565226ull, 416046135636034ull}},
{{9998967653071162504ull, 332836908508827ull}},
{{1240952985946218714ull, 532539053614124ull}},
{{4682111203498885294ull, 426031242891299ull}},
{{7435037777541018558ull, 340824994313039ull}},
{{828013999839898724ull, 545319990900863ull}},
{{8041108829355739626ull, 436255992720690ull}},
{{6432887063484591700ull, 349004794176552ull}},
{{13981968116317257044ull, 558407670682483ull}},
{{117528048828074666ull, 446726136545987ull}},
{{11162068883288190702ull, 357380909236789ull}},
{{12619003921372462885ull, 285904727389431ull}},
{{12811708644712119969ull, 457447563823090ull}},
{{10249366915769695975ull, 365958051058472ull}},
{{820795903131936134ull, 292766440846778ull}},
{{16070668703978739107ull, 468426305354844ull}},
{{16545883777924901609ull, 374741044283875ull}},
{{13236707022339921287ull, 299792835427100ull}},
{{2731987162034322444ull, 479668536683361ull}},
{{16942984988595099248ull, 383734829346688ull}},
{{2486341546650348428ull, 306987863477351ull}},
{{15046192918866288455ull, 491180581563761ull}},
{{8347605520351120441ull, 392944465251009ull}},
{{10367433231022806676ull, 314355572200807ull}},
{{1830497910668849389ull, 502968915521292ull}},
{{12532444772760810481ull, 402375132417033ull}},
{{17404653447692469031ull, 321900105933626ull}},
{{2022003813114578187ull, 515040169493803ull}},
{{8996300679975483196ull, 412032135595042ull}},
{{18265086988206117526ull, 329625708476033ull}},
{{7088046292678326103ull, 527401133561654ull}},
{{9359785848884571206ull, 421920906849323ull}},
{{14866526308591477611ull, 337536725479458ull}},
{{1650349205294902238ull, 540058760767134ull}},
{{5009628178977832114ull, 432047008613707ull}},
{{15075748987407996661ull, 345637606890965ull}},
{{5674454306143243041ull, 553020171025545ull}},
{{4539563444914594433ull, 442416136820436ull}},
{{18389046014899316839ull, 353932909456348ull}},
{{3643190367693722501ull, 283146327565079ull}},
{{13207802217793776649ull, 453034124104126ull}},
{{6876892959493110996ull, 362427299283301ull}},
{{1812165552852578473ull, 289941839426641ull}},
{{13967511328789856527ull, 463906943082625ull}},
{{11174009063031885222ull, 371125554466100ull}},
{{8939207250425508177ull, 296900443572880ull}},
{{14302731600680813084ull, 475040709716608ull}},
{{374138836318919498ull, 380032567773287ull}},
{{11367357513280866568ull, 304026054218629ull}},
{{7119725577023655539ull, 486441686749807ull}},
{{16763826905844655401ull, 389153349399845ull}},
{{13411061524675724320ull, 311322679519876ull}},
{{14079000809997338266ull, 498116287231802ull}},
{{3884503018514049967ull, 398493029785442ull}},
{{14175648859036970943ull, 318794423828353ull}},
{{544945286007691570ull, 510071078125366ull}},
{{15193351487773794548ull, 408056862500292ull}},
{{4775983560735214992ull, 326445490000234ull}},
{{15020271326660164634ull, 522312784000374ull}},
{{15705565876070042031ull, 417850227200299ull}},
{{16253801515597943948ull, 334280181760239ull}},
{{14938035980730979347ull, 534848290816383ull}},
{{882382340359052508ull, 427878632653107ull}},
{{11773952316512972976ull, 342302906122485ull}},
{{391579632711205145ull, 547684649795977ull}},
{{11381310150394695086ull, 438147719836781ull}},
{{5415699305573845745ull, 350518175869425ull}},
{{8665118888918153193ull, 560829081391080ull}},
{{6932095111134522554ull, 448663265112864ull}},
{{9235024903649528366ull, 358930612090291ull}},
{{3698671108177712370ull, 287144489672233ull}},
{{2228524958342429469ull, 459431183475573ull}},
{{9161517596157764221ull, 367544946780458ull}},
{{14707911706410032023ull, 294035957424366ull}},
{{16153961100772230591ull, 470457531878986ull}},
{{9233820065875874150ull, 376366025503189ull}},
{{11076404867442609643ull, 301092820402551ull}},
{{10343550158424354783ull, 481748512644082ull}},
{{896142497255663180ull, 385398810115266ull}},
{{15474309256772171836ull, 308319048092212ull}},
{{10001499551867833646ull, 493310476947540ull}},
{{8001199641494266916ull, 394648381558032ull}},
{{17469006157421144503ull, 315718705246425ull}},
{{9503665778164279588ull, 505149928394281ull}},
{{3913583807789513347ull, 404119942715425ull}},
{{3130867046231610678ull, 323295954172340ull}},
{{5009387273970577085ull, 517273526675744ull}},
{{7696858633918371991ull, 413818821340595ull}},
{{6157486907134697593ull, 331055057072476ull}},
{{2473281421931695502ull, 529688091315962ull}},
{{13046671581771087371ull, 423750473052769ull}},
{{14126686080158780220ull, 339000378442215ull}},
{{4155953654544496737ull, 542400605507545ull}},
{{3324762923635597389ull, 433920484406036ull}},
{{17417205597876119204ull, 347136387524828ull}},
{{5731436068150328788ull, 555418220039726ull}},
{{895800039778352707ull, 444334576031781ull}},
{{15474035290790323458ull, 355467660825424ull}},
{{16068577047374169090ull, 284374128660339ull}},
{{14641676831572939574ull, 454998605856543ull}},
{{645295021032620689ull, 363998884685235ull}},
{{516236016826096551ull, 291199107748188ull}},
{{15583372885889395775ull, 465918572397100ull}},
{{12466698308711516620ull, 372734857917680ull}},
{{9973358646969213296ull, 298187886334144ull}},
{{4889327390925010305ull, 477100618134631ull}},
{{222113097998097920ull, 381680494507705ull}},
{{177690478398478336ull, 305344395606164ull}},
{{7663002394921385985ull, 488551032969862ull}},
{{17198448360162839757ull, 390840826375889ull}},
{{17448107502872182129ull, 312672661100711ull}},
{{2091530301402119144ull, 500276257761139ull}},
{{5362573055863605638ull, 400221006208911ull}},
{{600709629948974187ull, 320176804967129ull}},
{{8339833037402179346ull, 512282887947406ull}},
{{2982517615179833154ull, 409826310357925ull}},
{{2386014092143866523ull, 327861048286340ull}},
{{3817622547430186437ull, 524577677258144ull}},
{{6743446852686059473ull, 419662141806515ull}},
{{5394757482148847578ull, 335729713445212ull}},
{{12320960786180066448ull, 537167541512339ull}},
{{13546117443685963482ull, 429734033209871ull}},
{{7147545140206860462ull, 343787226567897ull}},
{{15125421039072887063ull, 550059562508635ull}},
{{12100336831258309650ull, 440047650006908ull}},
{{17058967094490468367ull, 352038120005526ull}},
{{9957824860850464370ull, 281630496004421ull}},
{{8553822147876922346ull, 450608793607074ull}},
{{10532406533043448200ull, 360487034885659ull}},
{{12115274041176668883ull, 288389627908527ull}},
{{4627043206915028920ull, 461423404653644ull}},
{{7390983380273933459ull, 369138723722915ull}},
{{5912786704219146767ull, 295310978978332ull}},
{{13149807541492545151ull, 472497566365331ull}},
{{6830497218452125798ull, 377998053092265ull}},
{{5464397774761700638ull, 302398442473812ull}},
{{12432385254360631344ull, 483837507958099ull}},
{{13635257018230415399ull, 387070006366479ull}},
{{14597554429326242642ull, 309656005093183ull}},
{{1219994198470526288ull, 495449608149094ull}},
{{4665344173518331354ull, 396359686519275ull}},
{{3732275338814665083ull, 317087749215420ull}},
{{5971640542103464133ull, 507340398744672ull}},
{{15845358877908502276ull, 405872318995737ull}},
{{5297589472842981174ull, 324697855196590ull}},
{{8476143156548769879ull, 519516568314544ull}},
{{10470263339980926226ull, 415613254651635ull}},
{{8376210671984740981ull, 332490603721308ull}},
{{9712588260433675246ull, 531984965954093ull}},
{{15148768237830760843ull, 425587972763274ull}},
{{15808363405006518998ull, 340470378210619ull}},
{{14225335003784699427ull, 544752605136991ull}},
{{7690919188285849219ull, 435802084109593ull}},
{{13531432980112500021ull, 348641667287674ull}},
{{10582246323954269064ull, 557826667660279ull}},
{{12155145873905325575ull, 446261334128223ull}},
{{17102814328608081106ull, 357009067302578ull}},
{{2614205018660733915ull, 285607253842063ull}},
{{493379215115263941ull, 456971606147301ull}},
{{15152098631059852446ull, 365577284917840ull}},
{{12121678904847881957ull, 292461827934272ull}},
{{4637290988788969838ull, 467938924694836ull}},
{{20483976289265547ull, 374351139755869ull}},
{{3705735995773322761ull, 299480911804695ull}},
{{5929177593237316417ull, 479169458887512ull}},
{{15811388518815584103ull, 383335567110009ull}},
{{16338459629794377606ull, 306668453688007ull}},
{{11384140148703362877ull, 490669525900812ull}},
{{1728614489478869655ull, 392535620720650ull}},
{{1382891591583095724ull, 314028496576520ull}},
{{2212626546532953159ull, 502445594522432ull}},
{{12838147681452093496ull, 401956475617945ull}},
{{10270518145161674797ull, 321565180494356ull}},
{{9054131402774859029ull, 514504288790970ull}},
{{7243305122219887223ull, 411603431032776ull}},
{{2105295283033999455ull, 329282744826221ull}},
{{14436518897080130098ull, 526852391721953ull}},
{{481168673438373109ull, 421481913377563ull}},
{{7763632568234519133ull, 337185530702050ull}},
{{12421812109175230614ull, 539496849123280ull}},
{{9937449687340184491ull, 431597479298624ull}},
{{11639308564614057916ull, 345277983438899ull}},
{{7554847259156761696ull, 552444773502239ull}},
{{9733226622067319680ull, 441955818801791ull}},
{{4097232482911945421ull, 353564655041433ull}},
{{10656483615813376983ull, 282851724033146ull}},
{{9671676155817582526ull, 452562758453034ull}},
{{11426689739395976344ull, 362050206762427ull}},
{{1762654162032960429ull, 289640165409942ull}},
{{6509595473994647010ull, 463424264655907ull}},
{{16275722823421448577ull, 370739411724725ull}},
{{13020578258737158862ull, 296591529379780ull}},
{{2386181140269902563ull, 474546447007649ull}},
{{5598293726957832374ull, 379637157606119ull}},
{{8167983796308176222ull, 303709726084895ull}},
{{13068774074093081955ull, 485935561735832ull}},
{{3076321629790644918ull, 388748449388666ull}},
{{17218452562800157227ull, 310998759510932ull}},
{{12792128841512610271ull, 497598015217492ull}},
{{2855005443726267570ull, 398078412173994ull}},
{{5973353169722924379ull, 318462729739195ull}},
{{9557365071556679007ull, 509540367582712ull}},
{{267194427761522559ull, 407632294066170ull}},
{{213755542209218047ull, 326105835252936ull}},
{{11410055311760479845ull, 521769336404697ull}},
{{1749346619924563230ull, 417415469123758ull}},
{{8778174925423471230ull, 333932375299006ull}},
{{6666382251193733322ull, 534291800478410ull}},
{{5333105800954986657ull, 427433440382728ull}},
{{11645182270247809972ull, 341946752306182ull}},
{{3874896373428854663ull, 547114803689892ull}},
{{14167963542968814700ull, 437691842951913ull}},
{{266324390149320790ull, 350153474361531ull}},
{{11494165468464644234ull, 560245558978449ull}},
{{12884681189513625711ull, 448196447182759ull}},
{{13997093766352810892ull, 358557157746207ull}},
{{3818977383598428067ull, 286845726196966ull}},
{{17178410257983215877ull, 458953161915145ull}},
{{13742728206386572701ull, 367162529532116ull}},
{{7304833750367347838ull, 293730023625693ull}},
{{7998385185845846217ull, 469968037801109ull}},
{{10088056963418587297ull, 375974430240887ull}},
{{691747941251049191ull, 300779544192710ull}},
{{1106796706001678706ull, 481247270708336ull}},
{{15642832623768984258ull, 384997816566668ull}},
{{1446219654789456436ull, 307998253253335ull}},
{{2313951447663130299ull, 492797205205336ull}},
{{16608556417098145532ull, 394237764164268ull}},
{{2218798689452785456ull, 315390211331415ull}},
{{3550077903124456729ull, 504624338130264ull}},
{{6529411137241475706ull, 403699470504211ull}},
{{1534180095051270242ull, 322959576403369ull}},
{{9833385781565853034ull, 516735322245390ull}},
{{7866708625252682427ull, 413388257796312ull}},
{{17361413344427876911ull, 330710606237049ull}},
{{16710214906858872088ull, 529136969979279ull}},
{{17057520740229007994ull, 423309575983423ull}},
{{2577970147957475425ull, 338647660786739ull}},
{{11503449866215781327ull, 541836257258782ull}},
{{1824062263488804415ull, 433469005807026ull}},
{{16216645069758684825ull, 346775204645620ull}},
{{7499888037904344104ull, 554840327432993ull}},
{{13378608059807295930ull, 443872261946394ull}},
{{14392235262587747067ull, 355097809557115ull}},
{{11513788210070197653ull, 284078247645692ull}},
{{3664665877144674953ull, 454525196233108ull}},
{{10310430331199560608ull, 363620156986486ull}},
{{4558995450217738163ull, 290896125589189ull}},
{{14673090349832201708ull, 465433800942702ull}},
{{4359774650381940720ull, 372347040754162ull}},
{{14555866164531283546ull, 297877632603329ull}},
{{12221339419024322704ull, 476604212165327ull}},
{{2398373905735637516ull, 381283369732262ull}},
{{12986745568814240983ull, 305026695785809ull}},
{{9710746465877054603ull, 488042713257295ull}},
{{7768597172701643682ull, 390434170605836ull}},
{{2525528923419404623ull, 312347336484669ull}},
{{11419543906954868043ull, 499755738375470ull}},
{{9135635125563894434ull, 399804590700376ull}},
{{3619159285709205224ull, 319843672560301ull}},
{{16858701301360459328ull, 511749876096481ull}},
{{9797612226346457139ull, 409399900877185ull}},
{{7838089781077165711ull, 327519920701748ull}},
{{8851594834981554815ull, 524031873122797ull}},
{{18149322312210974822ull, 419225498498237ull}},
{{7140760220284959211ull, 335380398798590ull}},
{{11425216352455934738ull, 536608638077744ull}},
{{12829521896706658113ull, 429286910462195ull}},
{{10263617517365326490ull, 343429528369756ull}},
{{9043090398300701739ull, 549487245391610ull}},
{{7234472318640561391ull, 439589796313288ull}},
{{13166275484396269759ull, 351671837050630ull}},
{{2619296701324479999ull, 562674939281009ull}},
{{5784786175801494322ull, 450139951424807ull}},
{{15695875384866926427ull, 360111961139845ull}},
{{12556700307893541142ull, 288089568911876ull}},
{{12712022863145845180ull, 460943310259002ull}},
{{2790920661032855498ull, 368754648207202ull}},
{{13300782973052015368ull, 295003718565761ull}},
{{13902555127399403942ull, 472005949705218ull}},
{{53997657693792184ull, 377604759764175ull}},
{{43198126155033747ull, 302083807811340ull}},
{{69117001848053996ull, 483334092498144ull}},
{{3744642416220353520ull, 386667273998515ull}},
{{2995713932976282816ull, 309333819198812ull}},
{{8482491107503962829ull, 494934110718099ull}},
{{10475341700745080586ull, 395947288574479ull}},
{{12069622175337974792ull, 316757830859583ull}},
{{15622046665798849344ull, 506812529375333ull}},
{{1429590888413348506ull, 405450023500267ull}},
{{12211719154956409774ull, 324360018800213ull}},
{{15849401833188345316ull, 518976030080341ull}},
{{8990172651808765929ull, 415180824064273ull}},
{{14570835750930833390ull, 332144659251418ull}},
{{1177244313037871484ull, 531431454802270ull}},
{{941795450430297187ull, 425145163841816ull}},
{{15510831619311879043ull, 340116131073452ull}},
{{10059935331931365176ull, 544185809717524ull}},
{{11737297080287002464ull, 435348647774019ull}},
{{13079186478971512294ull, 348278918219215ull}},
{{2479954292644868055ull, 557246269150745ull}},
{{1983963434115894444ull, 445797015320596ull}},
{{16344566006260356848ull, 356637612256476ull}},
{{9386303990266375155ull, 285310089805181ull}},
{{7639388754942379602ull, 456496143688290ull}},
{{6111511003953903681ull, 365196914950632ull}},
{{15957255247388853915ull, 292157531960505ull}},
{{7084864322112614648ull, 467452051136809ull}},
{{9357240272432002041ull, 373961640909447ull}},
{{107094588461780986ull, 299169312727558ull}},
{{14928746600506490871ull, 478670900364092ull}},
{{4564299650921372051ull, 382936720291274ull}},
{{7340788535479007964ull, 306349376233019ull}},
{{677215212540681772ull, 490159001972831ull}},
{{15299167429000186711ull, 392127201578264ull}},
{{15928682757942059692ull, 313701761262611ull}},
{{18107194783223474860ull, 501922818020178ull}},
{{3417709382353048919ull, 401538254416143ull}},
{{10112865135366259781ull, 321230603532914ull}},
{{5112537772360284681ull, 513968965652663ull}},
{{11468727847372048391ull, 411175172522130ull}},
{{9174982277897638713ull, 328940138017704ull}},
{{3611925200410490971ull, 526304220828327ull}},
{{13957586604554123746ull, 421043376662661ull}},
{{7476720468901388674ull, 336834701330129ull}},
{{894706306016490908ull, 538935522128207ull}},
{{11783811489038923696ull, 431148417702565ull}},
{{9427049191231138957ull, 344918734162052ull}},
{{325883447002181039ull, 551869974659284ull}},
{{3950055572343655154ull, 441495979727427ull}},
{{14228090902100655093ull, 353196783781941ull}},
{{7693123906938613751ull, 282557427025553ull}},
{{8619649436359871678ull, 452091883240885ull}},
{{6895719549087897343ull, 361673506592708ull}},
{{12895273268754138520ull, 289338805274166ull}},
{{13253739600522800987ull, 462942088438666ull}},
{{6913642865676330466ull, 370353670750933ull}},
{{12909611922024885019ull, 296282936600746ull}},
{{13276681445755995384ull, 474052698561194ull}},
{{14310693971346706631ull, 379242158848955ull}},
{{11448555177077365304ull, 303393727079164ull}},
{{7249641839098053518ull, 485429963326663ull}},
{{13178411100762263460ull, 388343970661330ull}},
{{10542728880609810768ull, 310675176529064ull}},
{{5800319764749966260ull, 497080282446503ull}},
{{12018953441283793654ull, 397664225957202ull}},
{{2236465123543214277ull, 318131380765762ull}},
{{7267693012411053167ull, 509010209225219ull}},
{{9503503224670752856ull, 407208167380175ull}},
{{7602802579736602285ull, 325766533904140ull}},
{{12164484127578563656ull, 521226454246624ull}},
{{13420936116804761248ull, 416981163397299ull}},
{{14426097708185719322ull, 333584930717839ull}},
{{12013709888871419945ull, 533735889148543ull}},
{{16989665540580956603ull, 426988711318834ull}},
{{17281081247206675605ull, 341590969055067ull}},
{{12892334736563039676ull, 546545550488108ull}},
{{17692565418734252387ull, 437236440390486ull}},
{{10464703520245491586ull, 349789152312389ull}},
{{5675479188167055569ull, 559662643699823ull}},
{{11919080980017465101ull, 447730114959858ull}},
{{16913962413497792727ull, 358184091967886ull}},
{{9841821116056323858ull, 286547273574309ull}},
{{4678867341464387204ull, 458475637718895ull}},
{{3743093873171509763ull, 366780510175116ull}},
{{17751870357504849103ull, 293424408140092ull}},
{{13645597313040117273ull, 469479053024148ull}},
{{18295175479915914465ull, 375583242419318ull}},
{{3568093939707000602ull, 300466593935455ull}},
{{5708950303531200963ull, 480746550296728ull}},
{{11945857872308781417ull, 384597240237382ull}},
{{2177988668363204487ull, 307677792189906ull}},
{{14552828313606858149ull, 492284467503849ull}},
{{15331611465627396843ull, 393827574003079ull}},
{{15954637987243827797ull, 315062059202463ull}},
{{3391327891138662537ull, 504099294723942ull}},
{{13781108757136660999ull, 403279435779153ull}},
{{18403584635193149445ull, 322623548623322ull}},
{{14688340157341397820ull, 516197677797316ull}},
{{8061323311131207933ull, 412958142237853ull}},
{{13827756278388786992ull, 330366513790282ull}},
{{7367014786454417895ull, 528586422064452ull}},
{{16961658273389265286ull, 422869137651561ull}},
{{9879977803969501905ull, 338295310121249ull}},
{{4739918042125472079ull, 541272496193999ull}},
{{7481283248442287987ull, 433017996955199ull}},
{{9674375413495740712ull, 346414397564159ull}},
{{4410954217367454170ull, 554263036102655ull}},
{{3528763373893963336ull, 443410428882124ull}},
{{6512359513857080992ull, 354728343105699ull}},
{{8899236425827575117ull, 283782674484559ull}},
{{3170731837098389218ull, 454052279175295ull}},
{{2536585469678711374ull, 363241823340236ull}},
{{16786663634710610392ull, 290593458672188ull}},
{{4722568927085514688ull, 464949533875502ull}},
{{14846101585894142720ull, 371959627100401ull}},
{{8187532453973403853ull, 297567701680321ull}},
{{5721354296873625518ull, 476108322688514ull}},
{{8266432252240810738ull, 380886658150811ull}},
{{2923796987050738267ull, 304709326520649ull}},
{{12056772808765001874ull, 487534922433038ull}},
{{17024115876495822145ull, 390027937946430ull}},
{{13619292701196657716ull, 312022350357144ull}},
{{10722821877688921376ull, 499235760571431ull}},
{{4888908687409226778ull, 399388608457145ull}},
{{3911126949927381422ull, 319510886765716ull}},
{{17325849564109541245ull, 511217418825145ull}},
{{13860679651287632996ull, 408973935060116ull}},
{{7399194906288196074ull, 327179148048093ull}},
{{8149363035319203395ull, 523486636876949ull}},
{{10208839242997273039ull, 418789309501559ull}},
{{11856420209139728754ull, 335031447601247ull}},
{{4212877075655924714ull, 536050316161996ull}},
{{18127696919492381064ull, 428840252929596ull}},
{{10812808720851994528ull, 343072202343677ull}},
{{2543098694395549952ull, 548915523749884ull}},
{{5723827770258350285ull, 439132418999907ull}},
{{15647108660432411197ull, 351305935199925ull}},
{{6588629782982306300ull, 562089496319881ull}},
{{1581555011643934717ull, 449671597055905ull}},
{{1265244009315147773ull, 359737277644724ull}},
{{4701544022194028542ull, 287789822115779ull}},
{{14901168064994266314ull, 460463715385246ull}},
{{8231585637253502728ull, 368370972308197ull}},
{{17653314954028533152ull, 294696777846557ull}},
{{13487908667478011750ull, 471514844554492ull}},
{{3411629304498588754ull, 377211875643594ull}},
{{6418652258340781326ull, 301769500514875ull}},
{{10269843613345250122ull, 482831200823800ull}},
{{8215874890676200097ull, 386264960659040ull}},
{{6572699912540960078ull, 309011968527232ull}},
{{14205668674807446448ull, 494419149643571ull}},
{{7675186125104046835ull, 395535319714857ull}},
{{17208195344308968438ull, 316428255771885ull}},
{{9086368477184797884ull, 506285209235017ull}},
{{18337141225973569277ull, 405028167388013ull}},
{{3601666536553124452ull, 324022533910411ull}},
{{16830712902710730093ull, 518436054256657ull}},
{{6085872692684763428ull, 414748843405326ull}},
{{1179349339405900419ull, 331799074724261ull}},
{{12955005387275171640ull, 530878519558817ull}},
{{2985306680336316666ull, 424702815647054ull}},
{{6077594159010963656ull, 339762252517643ull}},
{{6034801839675631526ull, 543619604028229ull}},
{{8517190286482415544ull, 434895683222583ull}},
{{14192449858669753082ull, 347916546578066ull}},
{{15329222144387784284ull, 556666474524906ull}},
{{8574028900768317104ull, 445333179619925ull}},
{{6859223120614653683ull, 356266543695940ull}},
{{5487378496491722946ull, 285013234956752ull}},
{{12469154409128667038ull, 456021175930803ull}},
{{17354021156786754277ull, 364816940744642ull}},
{{6504519295945582775ull, 291853552595714ull}},
{{17785928502996753086ull, 466965684153142ull}},
{{6850045172913581823ull, 373572547322514ull}},
{{9169384953072775781ull, 298858037858011ull}},
{{7292318295432620604ull, 478172860572818ull}},
{{13212552265829917129ull, 382538288458254ull}},
{{14259390627405844027ull, 306030630766603ull}},
{{678932115397888504ull, 489649009226566ull}},
{{15300540951285952096ull, 391719207381252ull}},
{{4861735131544941030ull, 313375365905002ull}},
{{11468125025213815971ull, 501400585448003ull}},
{{16553197649654873423ull, 401120468358402ull}},
{{5863860490240078092ull, 320896374686722ull}},
{{13071525599126035271ull, 513434199498755ull}},
{{10457220479300828217ull, 410747359599004ull}},
{{12055125198182572897ull, 328597887679203ull}},
{{15598851502350206312ull, 525756620286725ull}},
{{12479081201880165049ull, 420605296229380ull}},
{{9983264961504132039ull, 336484236983504ull}},
{{4905177494180880293ull, 538374779173607ull}},
{{14992188439570435204ull, 430699823338885ull}},
{{11993750751656348163ull, 344559858671108ull}},
{{15500652387908246738ull, 551295773873773ull}},
{{1332475466100866421ull, 441036619099019ull}},
{{4755329187622603460ull, 352829295279215ull}},
{{3804263350098082768ull, 282263436223372ull}},
{{9776170174898842752ull, 451621497957395ull}},
{{7820936139919074202ull, 361297198365916ull}},
{{2567400097193349038ull, 289037758692733ull}},
{{418491340767448138ull, 462460413908373ull}},
{{7713490702097779157ull, 369968331126698ull}},
{{13549490191162043972ull, 295974664901358ull}},
{{17989835491117360032ull, 473559463842173ull}},
{{3323821948668157056ull, 378847571073739ull}},
{{6348406373676435968ull, 303078056858991ull}},
{{2778752568398476902ull, 484924890974386ull}},
{{16980397313686422814ull, 387939912779508ull}},
{{2516271406723407282ull, 310351930223607ull}},
{{7715383065499361974ull, 496563088357771ull}},
{{2482957637657579256ull, 397250470686217ull}},
{{13054412554351794374ull, 317800376548973ull}},
{{17197711272220960676ull, 508480602478357ull}},
{{6379471388292947894ull, 406784481982686ull}},
{{1414228295892447992ull, 325427585586149ull}},
{{9641462902911737434ull, 520684136937838ull}},
{{15091867951813210594ull, 416547309550270ull}},
{{12073494361450568475ull, 333237847640216ull}},
{{11938893348837088914ull, 533180556224346ull}},
{{5861765864327760808ull, 426544444979477ull}},
{{15757459135687939616ull, 341235555983581ull}},
{{17833236987616882739ull, 545976889573730ull}},
{{14266589590093506191ull, 436781511658984ull}},
{{15102620486816715276ull, 349425209327187ull}},
{{9406797519939103149ull, 559080334923500ull}},
{{7525438015951282519ull, 447264267938800ull}},
{{6020350412761026015ull, 357811414351040ull}},
{{4816280330208820812ull, 286249131480832ull}},
{{11395397343076023623ull, 457998610369331ull}},
{{5426969059718908575ull, 366398888295465ull}},
{{4341575247775126860ull, 293119110636372ull}},
{{10635869211182113299ull, 468990577018195ull}},
{{8508695368945690639ull, 375192461614556ull}},
{{3117607480414642188ull, 300153969291645ull}},
{{4988171968663427501ull, 480246350866632ull}},
{{15058584019156472970ull, 384197080693305ull}},
{{12046867215325178376ull, 307357664554644ull}},
{{8206941100294554433ull, 491772263287431ull}},
{{2876204065493733223ull, 393417810629945ull}},
{{2300963252394986578ull, 314734248503956ull}},
{{14749587648057709495ull, 503574797606329ull}},
{{15489018933188077919ull, 402859838085063ull}},
{{1323168702324731366ull, 322287870468051ull}},
{{13185116367945301155ull, 515660592748881ull}},
{{6858744279614330601ull, 412528474199105ull}},
{{5486995423691464480ull, 330022779359284ull}},
{{16157890307390163815ull, 528036446974854ull}},
{{16615661060654041375ull, 422429157579883ull}},
{{2224482404297502131ull, 337943326063907ull}},
{{7248520661617913732ull, 540709321702251ull}},
{{2109467714552420663ull, 432567457361801ull}},
{{16444969430609577823ull, 346053965889440ull}},
{{7865207015265772901ull, 553686345423105ull}},
{{6292165612212618321ull, 442949076338484ull}},
{{8723081304512004980ull, 354359261070787ull}},
{{18046511487835334953ull, 283487408856629ull}},
{{17806371936310804956ull, 453579854170607ull}},
{{6866399919564823318ull, 362863883336486ull}},
{{1803771120909948331ull, 290291106669189ull}},
{{10264731422939737977ull, 464465770670702ull}},
{{833087508867969735ull, 371572616536562ull}},
{{11734516451320106757ull, 297258093229249ull}},
{{7707179877886439842ull, 475612949166799ull}},
{{9855092717051062197ull, 380490359333439ull}},
{{11573422988382760081ull, 304392287466751ull}},
{{11138779151928595483ull, 487027659946802ull}},
{{1532325692059055740ull, 389622127957442ull}},
{{12293906997872975561ull, 311697702365953ull}},
{{15980902381854850575ull, 498716323785525ull}},
{{12784721905483880460ull, 398973059028420ull}},
{{10227777524387104368ull, 319178447222736ull}},
{{8985746409535546343ull, 510685515556378ull}},
{{14567294757112257721ull, 408548412445102ull}},
{{4275138176205985530ull, 326838729956082ull}},
{{10529569896671487171ull, 522941967929731ull}},
{{4734307102595279414ull, 418353574343785ull}},
{{3787445682076223531ull, 334682859475028ull}},
{{2370564276580047327ull, 535492575160045ull}},
{{1896451421264037861ull, 428394060128036ull}},
{{16274556395978871582ull, 342715248102428ull}},
{{3903197345114732592ull, 548344396963886ull}},
{{17879953135059427366ull, 438675517571108ull}},
{{3235916063821810923ull, 350940414056887ull}},
{{8866814516856807801ull, 561504662491019ull}},
{{10782800428227356564ull, 449203729992815ull}},
{{8626240342581885251ull, 359362983994252ull}},
{{17969038718291239170ull, 287490387195401ull}},
{{2925020246072610410ull, 459984619512643ull}},
{{9718713826341908974ull, 367987695610114ull}},
{{11464319875815437503ull, 294390156488091ull}},
{{10964214171820879358ull, 471024250380946ull}},
{{5082022522714793163ull, 376819400304757ull}},
{{15133664462397565500ull, 301455520243805ull}},
{{5767119066126553184ull, 482328832390089ull}},
{{8303044067643152871ull, 385863065912071ull}},
{{2953086439372611973ull, 308690452729657ull}},
{{8414287117738089480ull, 493904724367451ull}},
{{3042080879448561261ull, 395123779493961ull}},
{{17191059962526490302ull, 316099023595168ull}},
{{5369603051590922544ull, 505758437752270ull}},
{{4295682441272738035ull, 404606750201816ull}},
{{18193941211985831721ull, 323685400161452ull}},
{{14352910680209689460ull, 517896640258324ull}},
{{15171677358909661891ull, 414317312206659ull}},
{{15826690701869639836ull, 331453849765327ull}},
{{10565309864023782445ull, 530326159624524ull}},
{{12141596705960936279ull, 424260927699619ull}},
{{13402626179510659347ull, 339408742159695ull}},
{{2997457813507503339ull, 543053987455513ull}},
{{9776663880289823317ull, 434443189964410ull}},
{{7821331104231858654ull, 347554551971528ull}},
{{8824780952029063523ull, 556087283154445ull}},
{{7059824761623250819ull, 444869826523556ull}},
{{1958510994556690332ull, 355895861218845ull}},
{{1566808795645352265ull, 284716688975076ull}},
{{13574940517258294594ull, 455546702360121ull}},
{{7170603599064725352ull, 364437361888097ull}},
{{16804529323477511251ull, 291549889510477ull}},
{{12129851658596376709ull, 466479823216764ull}},
{{13393230141619011690ull, 373183858573411ull}},
{{7025235298553299029ull, 298547086858729ull}},
{{172330033459547477ull, 477675338973967ull}},
{{11205910470993368951ull, 382140271179173ull}},
{{16343426006278515807ull, 305712216943338ull}},
{{4013388721594163353ull, 489139547109342ull}},
{{14278757421501061652ull, 391311637687473ull}},
{{354959492975118352ull, 313049310149979ull}},
{{7946632818244010009ull, 500878896239966ull}},
{{2667957439853297684ull, 400703116991973ull}},
{{9513063581366458794ull, 320562493593578ull}},
{{11531552915444423747ull, 512899989749725ull}},
{{9225242332355538998ull, 410319991799780ull}},
{{7380193865884431198ull, 328255993439824ull}},
{{740263741189358947ull, 525209589503719ull}},
{{4281559807693397481ull, 420167671602975ull}},
{{3425247846154717985ull, 336134137282380ull}},
{{5480396553847548776ull, 537814619651808ull}},
{{11763014872561859667ull, 430251695721446ull}},
{{5721063083307577410ull, 344201356577157ull}},
{{12843049748034034180ull, 550722170523451ull}},
{{6585090983685317021ull, 440577736418761ull}},
{{1578723972206343293ull, 352462189135009ull}},
{{4952327992506984958ull, 281969751308007ull}},
{{11613073602753086256ull, 451151602092811ull}},
{{5601110067460558681ull, 360921281674249ull}},
{{8170236868710357268ull, 288737025339399ull}},
{{2004332545710840660ull, 461979240543039ull}},
{{5292814851310582851ull, 369583392434431ull}},
{{544903066306555957ull, 295666713947545ull}},
{{871844906090489532ull, 473066742316072ull}},
{{11765522369098122595ull, 378453393852857ull}},
{{2033720265794677430ull, 302762715082286ull}},
{{14321998869497214857ull, 484420344131657ull}},
{{4078901466113951239ull, 387536275305326ull}},
{{18020516431858802284ull, 310029020244260ull}},
{{10386082217264532039ull, 496046432390817ull}},
{{930168144327804985ull, 396837145912654ull}},
{{4433483330204154311ull, 317469716730123ull}},
{{3404224513584736575ull, 507951546768197ull}},
{{13791426055093520229ull, 406361237414557ull}},
{{3654443214590995537ull, 325088989931646ull}},
{{16915155587571323829ull, 520142383890633ull}},
{{2464078025831328093ull, 416113907112507ull}},
{{13039308864890793444ull, 332891125690005ull}},
{{2416150110115717895ull, 532625801104009ull}},
{{5622268902834484639ull, 426100640883207ull}},
{{15565861566493318681ull, 340880512706565ull}},
{{6458634432679758274ull, 545408820330505ull}},
{{5166907546143806619ull, 436327056264404ull}},
{{7822874851656955618ull, 349061645011523ull}},
{{8827250947909218666ull, 558498632018437ull}},
{{18129847202553105902ull, 446798905614749ull}},
{{18193226576784395045ull, 357439124491799ull}},
{{18243930076169426359ull, 285951299593439ull}},
{{18122241677645351205ull, 457522079349503ull}},
{{3429746897890549994ull, 366017663479603ull}},
{{10122495147796260642ull, 292814130783682ull}},
{{1438596977506375734ull, 468502609253892ull}},
{{12218924026230831557ull, 374802087403113ull}},
{{17153836850468485892ull, 299841669922490ull}},
{{8999394887040025811ull, 479746671875985ull}},
{{7199515909632020649ull, 383797337500788ull}},
{{13138310357189437166ull, 307037870000630ull}},
{{2574552497793547849ull, 491260592001009ull}},
{{5748990812976748602ull, 393008473600807ull}},
{{15667239094607129851ull, 314406778880645ull}},
{{6620838477661856147ull, 503050846209033ull}},
{{12675368411613305564ull, 402440676967226ull}},
{{6450945914548734128ull, 321952541573781ull}},
{{2942815833794153958ull, 515124066518050ull}},
{{2354252667035323166ull, 412099253214440ull}},
{{1883402133628258533ull, 329679402571552ull}},
{{6702792228547123976ull, 527487044114483ull}},
{{12740931412321519827ull, 421989635291586ull}},
{{6503396315115305539ull, 337591708233269ull}},
{{17784131733668309508ull, 540146733173230ull}},
{{14227305386934647607ull, 432117386538584ull}},
{{15071193124289628408ull, 345693909230867ull}},
{{9356513739895764161ull, 553110254769388ull}},
{{14863908621400431975ull, 442488203815510ull}},
{{11891126897120345580ull, 353990563052408ull}},
{{16891599147180097110ull, 283192450441926ull}},
{{1201116932294783114ull, 453107920707083ull}},
{{8339591175319647138ull, 362486336565666ull}},
{{2982324125513807387ull, 289989069252533ull}},
{{1082369786080181496ull, 463982510804053ull}},
{{8244593458347965843ull, 371186008643242ull}},
{{17663721210904103644ull, 296948806914593ull}},
{{6125861048995103892ull, 475118091063350ull}},
{{4900688839196083113ull, 380094472850680ull}},
{{3920551071356866490ull, 304075578280544ull}},
{{13651579343654807031ull, 486520925248870ull}},
{{10921263474923845625ull, 389216740199096ull}},
{{5047661965197166177ull, 311373392159277ull}},
{{11765607959057376206ull, 498197427454843ull}},
{{16791183996729721611ull, 398557941963874ull}},
{{17122296012125687612ull, 318846353571099ull}},
{{16327627175175369210ull, 510154165713759ull}},
{{16751450554882205691ull, 408123332571007ull}},
{{6022462814421943906ull, 326498666056806ull}},
{{2257242873591289604ull, 522397865690890ull}},
{{1805794298873031683ull, 417918292552712ull}},
{{12512681883324156316ull, 334334634042169ull}},
{{8952244569092919136ull, 534935414467471ull}},
{{3472446840532424986ull, 427948331573977ull}},
{{13846003916651670958ull, 342358665259181ull}},
{{14774908637158852887ull, 547773864414690ull}},
{{11819926909727082310ull, 438219091531752ull}},
{{2077243898297845201ull, 350575273225402ull}},
{{7012939052018462645ull, 560920437160643ull}},
{{12989048871098590763ull, 448736349728514ull}},
{{14080587911620782933ull, 358989079782811ull}},
{{7575121514554716023ull, 287191263826249ull}},
{{1052147979061814668ull, 459506022121999ull}},
{{4531067197991362057ull, 367604817697599ull}},
{{7314202573134999969ull, 294083854158079ull}},
{{634677672790268981ull, 470534166652927ull}},
{{11575788582457946154ull, 376427333322341ull}},
{{5571282051224446600ull, 301141866657873ull}},
{{5224702467217204237ull, 481826986652597ull}},
{{15247808417999494359ull, 385461589322077ull}},
{{4819549104915774841ull, 308369271457662ull}},
{{11400627382607150069ull, 493390834332259ull}},
{{12809850720827630378ull, 394712667465807ull}},
{{2869182947178283656ull, 315770133972646ull}},
{{15658739159710984820ull, 505232214356233ull}},
{{1458944883543056886ull, 404185771484987ull}},
{{12235202351060176478ull, 323348617187989ull}},
{{8508277317470551396ull, 517357787500783ull}},
{{14185319483460261763ull, 413886230000626ull}},
{{7658906772026299087ull, 331108984000501ull}},
{{4875553205758257894ull, 529774374400802ull}},
{{14968489008832337284ull, 423819499520641ull}},
{{8285442392323959504ull, 339055599616513ull}},
{{9567359012976424884ull, 542488959386421ull}},
{{3964538395639229584ull, 433991167509137ull}},
{{14239677160737114637ull, 347192934007309ull}},
{{11715437012953652449ull, 555508694411695ull}},
{{9372349610362921959ull, 444406955529356ull}},
{{3808530873548427244ull, 355525564423485ull}},
{{3046824698838741795ull, 284420451538788ull}},
{{1185570703400076549ull, 455072722462061ull}},
{{15705851821687702532ull, 364058177969648ull}},
{{1496635013124431056ull, 291246542375719ull}},
{{9773313650482910336ull, 465994467801150ull}},
{{7818650920386328269ull, 372795574240920ull}},
{{6254920736309062615ull, 298236459392736ull}},
{{2629175548610679538ull, 477178335028378ull}},
{{9482038068372364277ull, 381742668022702ull}},
{{206932825214070775ull, 305394134418162ull}},
{{4020441335084423563ull, 488630615069059ull}},
{{6905701882809449174ull, 390904492055247ull}},
{{16592607950473290309ull, 312723593644197ull}},
{{11790777461789623201ull, 500357749830716ull}},
{{5743273154689788238ull, 400286199864573ull}},
{{11973316153235651236ull, 320228959891658ull}},
{{15467957030435131655ull, 512366335826653ull}},
{{1306319180122374355ull, 409893068661323ull}},
{{8423752973581720130ull, 327914454929058ull}},
{{9788655942988841885ull, 524663127886493ull}},
{{15209622383874894154ull, 419730502309194ull}},
{{15857046721841825647ull, 335784401847355ull}},
{{6924530681237369419ull, 537255042955769ull}},
{{9228973359731805858ull, 429804034364615ull}},
{{7383178687785444686ull, 343843227491692ull}},
{{15502434715198621822ull, 550149163986707ull}},
{{5023250142675076811ull, 440119331189366ull}},
{{329251299398151125ull, 352095464951493ull}},
{{7642098669002341547ull, 281676371961194ull}},
{{1159311426178015505ull, 450682195137911ull}},
{{15684844399910053697ull, 360545756110328ull}},
{{1479829075702311988ull, 288436604888263ull}},
{{17125121780091340474ull, 461498567821220ull}},
{{13700097424073072379ull, 369198854256976ull}},
{{7270729124516547580ull, 295359083405581ull}},
{{4254468969742655482ull, 472574533448930ull}},
{{3403575175794124385ull, 378059626759144ull}},
{{6412208955377209831ull, 302447701407315ull}},
{{10259534328603535730ull, 483916322251704ull}},
{{11896976277624738907ull, 387133057801363ull}},
{{16896278651583611772ull, 309706446241090ull}},
{{8587301768824227220ull, 495530313985745ull}},
{{6869841415059381776ull, 396424251188596ull}},
{{1806524317305595097ull, 317139400950877ull}},
{{6579787722430862479ull, 507423041521403ull}},
{{12642527807428510630ull, 405938433217122ull}},
{{2735324616458987857ull, 324750746573698ull}},
{{687170571592470248ull, 519601194517917ull}},
{{11617782901499707168ull, 415680955614333ull}},
{{16672923950683586381ull, 332544764491466ull}},
{{851236617900365947ull, 532071623186347ull}},
{{11749035738546023727ull, 425657298549077ull}},
{{2020530961352998335ull, 340525838839262ull}},
{{6922198352906707660ull, 544841342142819ull}},
{{9227107497067276451ull, 435873073714255ull}},
{{7381685997653821161ull, 348698458971404ull}},
{{742651152020382888ull, 557917534354247ull}},
{{11662167365842037280ull, 446334027483397ull}},
{{1951036263189809178ull, 357067221986718ull}},
{{8939526640035667988ull, 285653777589374ull}},
{{3235196179831337812ull, 457046044142999ull}},
{{6277505758606980573ull, 365636835314399ull}},
{{8711353421627494781ull, 292509468251519ull}},
{{2870119030378260681ull, 468015149202431ull}},
{{17053490483270249837ull, 374412119361944ull}},
{{17332141201358110193ull, 299529695489555ull}},
{{9284681848463424693ull, 479247512783289ull}},
{{11117094293512650077ull, 383398010226631ull}},
{{5204326620068209739ull, 306718408181305ull}},
{{8326922592109135582ull, 490749453090088ull}},
{{14040235703171129112ull, 392599562472070ull}},
{{11232188562536903290ull, 314079649977656ull}},
{{10592804070575224617ull, 502527439964250ull}},
{{8474243256460179694ull, 402021951971400ull}},
{{6779394605168143755ull, 321617561577120ull}},
{{10847031368269030008ull, 514588098523392ull}},
{{1298927465131403360ull, 411670478818714ull}},
{{4728490786847033011ull, 329336383054971ull}},
{{186887629471432172ull, 526938212887954ull}},
{{3838858918319056060ull, 421550570310363ull}},
{{10449784764139065495ull, 337240456248290ull}},
{{16719655622622504792ull, 539584729997264ull}},
{{17065073312839914156ull, 431667783997811ull}},
{{9962709835530021002ull, 345334227198249ull}},
{{4872289292622302634ull, 552534763517199ull}},
{{7587180248839752430ull, 442027810813759ull}},
{{9759093013813712267ull, 353622248651007ull}},
{{428576781567149167ull, 282897798920806ull}},
{{11753769294733169637ull, 452636478273289ull}},
{{13092364250528446033ull, 362109182618631ull}},
{{6784542585680846503ull, 289687346094905ull}},
{{10855268137089354405ull, 463499753751848ull}},
{{16062912139155304170ull, 370799803001478ull}},
{{1782283267098512367ull, 296639842401183ull}},
{{17609048486325261080ull, 474623747841892ull}},
{{6708541159576388217ull, 379698998273514ull}},
{{9056181742403020897ull, 303759198618811ull}},
{{7111193158361012789ull, 486014717790098ull}},
{{13067652156172630878ull, 388811774232078ull}},
{{17832819354421925348ull, 311049419385662ull}},
{{13775115708107439265ull, 497679071017060ull}},
{{11020092566485951412ull, 398143256813648ull}},
{{16194771682672581776ull, 318514605450918ull}},
{{3775541803824668902ull, 509623368721470ull}},
{{3020433443059735122ull, 407698694977176ull}},
{{17173742013415429390ull, 326158955981740ull}},
{{9031243147755135408ull, 521854329570785ull}},
{{7224994518204108327ull, 417483463656628ull}},
{{13158693244047107308ull, 333986770925302ull}},
{{6296513931507730400ull, 534378833480484ull}},
{{8726559959948094643ull, 427503066784387ull}},
{{18049294412184206684ull, 342002453427509ull}},
{{17810824615268999725ull, 547203925484015ull}},
{{14248659692215199780ull, 437763140387212ull}},
{{4020230124288339177ull, 350210512309770ull}},
{{6432368198861342684ull, 560336819695632ull}},
{{16213941003314805117ull, 448269455756505ull}},
{{12971152802651844093ull, 358615564605204ull}},
{{14066271056863385598ull, 286892451684163ull}},
{{369940802529955017ull, 459027922694662ull}},
{{11363999086249694983ull, 367222338155729ull}},
{{12780548083741666310ull, 293777870524583ull}},
{{16759528119244755773ull, 470044592839333ull}},
{{2339576051170073649ull, 376035674271467ull}},
{{12939707285161789888ull, 300828539417173ull}},
{{17014182841516953498ull, 481325663067477ull}},
{{6232648643729742152ull, 385060530453982ull}},
{{16054165359209524691ull, 308048424363185ull}},
{{7239920501025687890ull, 492877478981097ull}},
{{16859982845046281282ull, 394301983184877ull}},
{{6109288646553204379ull, 315441586547902ull}},
{{13464210649227037330ull, 504706538476643ull}},
{{18150066148865450510ull, 403765230781314ull}},
{{18209401733834270731ull, 323012184625051ull}},
{{3309601070941460908ull, 516819495400083ull}},
{{10026378486236989373ull, 413455596320066ull}},
{{4331753974247681175ull, 330764477056053ull}},
{{3241457544054379557ull, 529223163289685ull}},
{{2593166035243503645ull, 423378530631748ull}},
{{9453230457678623562ull, 338702824505398ull}},
{{11435819917543887377ull, 541924519208637ull}},
{{1769958304551289255ull, 433539615366910ull}},
{{1415966643641031404ull, 346831692293528ull}},
{{17022941888793291540ull, 554930707669644ull}},
{{17307702325776543555ull, 443944566135715ull}},
{{13846161860621234844ull, 355155652908572ull}},
{{3698231859013167228ull, 284124522326858ull}},
{{2227822159679157243ull, 454599235722973ull}},
{{9160955357227146440ull, 363679388578378ull}},
{{14707461915265537799ull, 290943510862702ull}},
{{8774543805457219185ull, 465509617380324ull}},
{{10708983859107685671ull, 372407693904259ull}},
{{12256535902028058860ull, 297926155123407ull}},
{{4853062184277252884ull, 476681848197452ull}},
{{14950496191647533277ull, 381345478557961ull}},
{{8271048138576116298ull, 305076382846369ull}},
{{2165630577496055107ull, 488122212554191ull}},
{{16489899720964485379ull, 390497770043352ull}},
{{5813222147287767656ull, 312398216034682ull}},
{{12990504250402338574ull, 499837145655491ull}},
{{6703054585579960536ull, 399869716524393ull}},
{{12741141297947789075ull, 319895773219514ull}},
{{9317779632490731550ull, 511833237151223ull}},
{{14832921335476405887ull, 409466589720978ull}},
{{798290624155393740ull, 327573271776783ull}},
{{16034660257616271276ull, 524117234842852ull}},
{{5449030576609196375ull, 419293787874282ull}},
{{15427270905513088069ull, 335435030299425ull}},
{{6236889375111389295ull, 536696048479081ull}},
{{1300162685347201113ull, 429356838783265ull}},
{{1040130148277760890ull, 343485471026612ull}},
{{5353557051986327748ull, 549576753642579ull}},
{{7972194456330972521ull, 439661402914063ull}},
{{13756453194548598663ull, 351729122331250ull}},
{{3563581037568206246ull, 562766595730001ull}},
{{17608260089022206289ull, 450213276584000ull}},
{{14086608071217765031ull, 360170621267200ull}},
{{11269286456974212025ull, 288136497013760ull}},
{{18030858331158739240ull, 461018395222016ull}},
{{10735337850185081069ull, 368814716177613ull}},
{{15966967909631885501ull, 295051772942090ull}},
{{7100404581701465186ull, 472082836707345ull}},
{{5680323665361172149ull, 377666269365876ull}},
{{854910117547027396ull, 302133015492701ull}},
{{12435902632300974803ull, 483412824788321ull}},
{{6259373291098869519ull, 386730259830657ull}},
{{16075545077104826585ull, 309384207864525ull}},
{{7274128049658170920ull, 495014732583241ull}},
{{2129953624984626413ull, 396011786066593ull}},
{{9082660529471521777ull, 316809428853274ull}},
{{3464210402928703873ull, 506895086165239ull}},
{{6460717137084873422ull, 405516068932191ull}},
{{1479224894925988414ull, 324412855145753ull}},
{{17124155090849222756ull, 519060568233204ull}},
{{17388672887421288528ull, 415248454586563ull}},
{{2842891865711299852ull, 332198763669251ull}},
{{15616673429363810734ull, 531518021870801ull}},
{{8803989928749138264ull, 425214417496641ull}},
{{3353843128257400288ull, 340171533997313ull}},
{{1676800190469930137ull, 544274454395701ull}},
{{16098835411343585403ull, 435419563516560ull}},
{{12879068329074868322ull, 348335650813248ull}},
{{16917160511777878992ull, 557337041301197ull}},
{{6155030779938482547ull, 445869633040958ull}},
{{12302722253434606684ull, 356695706432766ull}},
{{6152828988005775024ull, 285356565146213ull}},
{{6155177566067329716ull, 456570504233941ull}},
{{1234793238111953449ull, 365256403387153ull}},
{{8366532219973383406ull, 292205122709722ull}},
{{17075800366699323773ull, 467528196335555ull}},
{{13660640293359459018ull, 374022557068444ull}},
{{14617861049429477537ull, 299218045654755ull}},
{{4941833605377612444ull, 478748873047609ull}},
{{7642815699044000278ull, 382999098438087ull}},
{{17182299003460931192ull, 306399278750469ull}},
{{16423631961311758938ull, 490238846000751ull}},
{{9449556754307496827ull, 392191076800601ull}},
{{3870296588704087139ull, 313752861440481ull}},
{{17260520986152270392ull, 502004578304769ull}},
{{17497765603663726636ull, 401603662643815ull}},
{{13998212482930981309ull, 321282930115052ull}},
{{7639744713721928802ull, 514052688184084ull}},
{{9801144585719453365ull, 411242150547267ull}},
{{462218039091742045ull, 328993720437814ull}},
{{8118246492030607919ull, 526389952700502ull}},
{{17562643637850217305ull, 421111962160401ull}},
{{10360766095538263520ull, 336889569728321ull}},
{{9198528123377400987ull, 539023311565314ull}},
{{11048171313443831112ull, 431218649252251ull}},
{{5149188236013154567ull, 344974919401801ull}},
{{860003548137226661ull, 551959871042882ull}},
{{11756049282735512298ull, 441567896834305ull}},
{{9404839426188409838ull, 353254317467444ull}},
{{11213220355692638194ull, 282603453973955ull}},
{{17941152569108221110ull, 452165526358328ull}},
{{3284875611060845918ull, 361732421086663ull}},
{{10006598118332497381ull, 289385936869330ull}},
{{16010556989331995810ull, 463017498990928ull}},
{{1740399147239865678ull, 370413999192743ull}},
{{8771016947275713189ull, 296331199354194ull}},
{{2965580671415410133ull, 474129918966711ull}},
{{17129859796099969399ull, 379303935173368ull}},
{{2635841392654244550ull, 303443148138695ull}},
{{4217346228246791280ull, 485509037021912ull}},
{{14441923426823163993ull, 388407229617529ull}},
{{15242887556200441518ull, 310725783694023ull}},
{{2252527201469244489ull, 497161253910438ull}},
{{9180719390659216238ull, 397729003128350ull}},
{{7344575512527372990ull, 318183202502680ull}},
{{11751320820043796785ull, 509093124004288ull}},
{{16779754285518858074ull, 407274499203430ull}},
{{13423803428415086459ull, 325819599362744ull}},
{{10410039041238407365ull, 521311358980391ull}},
{{4638682418248815569ull, 417049087184313ull}},
{{11089643564082873101ull, 333639269747450ull}},
{{17743429702532596963ull, 533822831595920ull}},
{{14194743762026077570ull, 427058265276736ull}},
{{7666446194878951733ull, 341646612221389ull}},
{{1198267467580591803ull, 546634579554223ull}},
{{8337311603548294089ull, 437307663643378ull}},
{{14048546912322455917ull, 349846130914702ull}},
{{7720279800748288175ull, 559753809463524ull}},
{{9865572655340540863ull, 447803047570819ull}},
{{11581806939014343014ull, 358242438056655ull}},
{{9265445551211474411ull, 286593950445324ull}},
{{3756666437712628088ull, 458550320712519ull}},
{{6694681964912012793ull, 366840256570015ull}},
{{5355745571929610235ull, 293472205256012ull}},
{{12258541729829286699ull, 469555528409619ull}},
{{13496182198605339682ull, 375644422727695ull}},
{{10796945758884271746ull, 300515538182156ull}},
{{9896415584731014147ull, 480824861091450ull}},
{{7917132467784811318ull, 384659888873160ull}},
{{6333705974227849054ull, 307727911098528ull}},
{{6444580744022648163ull, 492364657757645ull}},
{{5155664595218118531ull, 393891726206116ull}},
{{435182861432584501ull, 315113380964893ull}},
{{15453687837259776495ull, 504181409543828ull}},
{{1294903825582090226ull, 403345127635063ull}},
{{8414620689949492827ull, 322676102108050ull}},
{{13463393103919188524ull, 516281763372880ull}},
{{10770714483135350819ull, 413025410698304ull}},
{{12305920401250190978ull, 330420328558643ull}},
{{16000123827258395243ull, 528672525693829ull}},
{{16489447876548626517ull, 422938020555063ull}},
{{2123511857013170244ull, 338350416444051ull}},
{{14465665415446803360ull, 541360666310481ull}},
{{7883183517615532365ull, 433088533048385ull}},
{{6306546814092425892ull, 346470826438708ull}},
{{6401126087805971104ull, 554353322301933ull}},
{{12499598499728597530ull, 443482657841546ull}},
{{6310329985040967700ull, 354786126273237ull}},
{{16116310432258505130ull, 283828901018589ull}},
{{14718050247387877238ull, 454126241629743ull}},
{{706393753684570821ull, 363300993303795ull}},
{{565115002947656657ull, 290640794643036ull}},
{{11972230448941981621ull, 465025271428857ull}},
{{2199086729669764650ull, 372020217143086ull}},
{{16516664642703453013ull, 297616173714468ull}},
{{4290570539874062881ull, 476185877943150ull}},
{{3432456431899250305ull, 380948702354520ull}},
{{2745965145519400244ull, 304758961883616ull}},
{{15461590677056771360ull, 487614339013785ull}},
{{12369272541645417088ull, 390091471211028ull}},
{{17274115662800154317ull, 312073176968822ull}},
{{12881189801512605614ull, 499317083150116ull}},
{{6615603026468174168ull, 399453666520093ull}},
{{12671180050658359981ull, 319562933216074ull}},
{{9205841636827645000ull, 511300693145719ull}},
{{11054022124204026323ull, 409040554516575ull}},
{{8843217699363221058ull, 327232443613260ull}},
{{14149148318981153694ull, 523571909781216ull}},
{{7629969840443012632ull, 418857527824973ull}},
{{13482673501838230752ull, 335086022259978ull}},
{{17882928788199258880ull, 536137635615965ull}},
{{14306343030559407104ull, 428910108492772ull}},
{{4066376794963705036ull, 343128086794218ull}},
{{2816854057200017735ull, 549004938870749ull}},
{{5942832060501924511ull, 439203951096599ull}},
{{8443614463143449932ull, 351363160877279ull}},
{{2441736696803788922ull, 562181057403647ull}},
{{13021435801668762107ull, 449744845922917ull}},
{{3038451011851189039ull, 359795876738334ull}},
{{6120109624222861555ull, 287836701390667ull}},
{{13481524213498488811ull, 460538722225067ull}},
{{3406521741314970402ull, 368430977780054ull}},
{{6414566207793886645ull, 294744782224043ull}},
{{6573957117728308309ull, 471591651558469ull}},
{{8948514508924556970ull, 377273321246775ull}},
{{7158811607139645576ull, 301818656997420ull}},
{{11454098571423432922ull, 482909851195872ull}},
{{1784581227654925691ull, 386327880956698ull}},
{{8806362611607761199ull, 309062304765358ull}},
{{10400831363830507596ull, 494499687624573ull}},
{{15699362720548226723ull, 395599750099658ull}},
{{1491443732212850409ull, 316479800079727ull}},
{{6075658786282470977ull, 506367680127563ull}},
{{12239224658509797428ull, 405094144102050ull}},
{{9791379726807837942ull, 324075315281640ull}},
{{15666207562892540708ull, 518520504450624ull}},
{{16222314865055942890ull, 414816403560499ull}},
{{16667200706786664635ull, 331853122848399ull}},
{{15599474686632932446ull, 530964996557439ull}},
{{16168928564048256280ull, 424771997245951ull}},
{{9245794036496694701ull, 339817597796761ull}},
{{7414572828910890875ull, 543708156474818ull}},
{{13310355892612533346ull, 434966525179854ull}},
{{14337633528831937000ull, 347973220143883ull}},
{{804120757679637262ull, 556757152230214ull}},
{{4332645420885620132ull, 445405721784171ull}},
{{18223511595676137399ull, 356324577427336ull}},
{{10889460461798999596ull, 285059661941869ull}},
{{6355090294652668384ull, 456095459106991ull}},
{{1394723420980224384ull, 364876367285593ull}},
{{8494476366268000153ull, 291901093828474ull}},
{{2523115741803069276ull, 467041750125559ull}},
{{5707841408184365744ull, 373633400100447ull}},
{{15634319570773223564ull, 298906720080357ull}},
{{10257516054269516411ull, 478250752128572ull}},
{{827315213931792482ull, 382600601702858ull}},
{{8040549800629254632ull, 306080481362286ull}},
{{5486182051522986765ull, 489728770179658ull}},
{{11767643270702210058ull, 391783016143726ull}},
{{5724765801819857723ull, 313426412914981ull}},
{{1780927653427951711ull, 501482260663970ull}},
{{1424742122742361369ull, 401185808531176ull}},
{{15897188957161530388ull, 320948646824940ull}},
{{6988758257748897005ull, 513517834919905ull}},
{{5591006606199117604ull, 410814267935924ull}},
{{8162154099701204406ull, 328651414348739ull}},
{{1991400115296196080ull, 525842262957983ull}},
{{8971817721720777511ull, 420673810366386ull}},
{{3488105362634711685ull, 336539048293109ull}},
{{12959666209699359343ull, 538462477268974ull}},
{{14057081782501397798ull, 430769981815179ull}},
{{14935014240743028561ull, 344615985452143ull}},
{{1759929896737383759ull, 551385576723430ull}},
{{1407943917389907007ull, 441108461378744ull}},
{{4815703948653835929ull, 352886769102995ull}},
{{3852563158923068743ull, 282309415282396ull}},
{{17232147498502640958ull, 451695064451833ull}},
{{2717671554576381797ull, 361356051561467ull}},
{{13242183687886836407ull, 289084841249173ull}},
{{17498145085877027929ull, 462535745998677ull}},
{{6619818439217801696ull, 370028596798942ull}},
{{16363901195599972327ull, 296022877439153ull}},
{{4046149024508493784ull, 473636603902646ull}},
{{17994314478574436320ull, 378909283122116ull}},
{{10706102768117638732ull, 303127426497693ull}},
{{13440415614246311649ull, 485003882396309ull}},
{{14441681306138959642ull, 388003105917047ull}},
{{4174647415427347067ull, 310402484733638ull}},
{{2990087049941844985ull, 496643975573821ull}},
{{17149464898921117280ull, 397315180459056ull}},
{{10030223104394983501ull, 317852144367245ull}},
{{16048356967031973602ull, 508563430987592ull}},
{{5459987944141758235ull, 406850744790074ull}},
{{8057339170055316911ull, 325480595832059ull}},
{{1823696227862776089ull, 520768953331295ull}},
{{1458956982290220871ull, 416615162665036ull}},
{{15924560844799817989ull, 333292130132028ull}},
{{3343204463228246844ull, 533267408211246ull}},
{{17431958829550238768ull, 426613926568996ull}},
{{10256218248898280691ull, 341291141255197ull}},
{{1652553939269607813ull, 546065826008316ull}},
{{16079438410383327543ull, 436852660806652ull}},
{{5484853098822841388ull, 349482128645322ull}},
{{12465113772858456544ull, 559171405832515ull}},
{{9972091018286765235ull, 447337124666012ull}},
{{598975185145591542ull, 357869699732810ull}},
{{479180148116473233ull, 286295759786248ull}},
{{15524083495953998467ull, 458073215657996ull}},
{{8729917982021288450ull, 366458572526397ull}},
{{18051980829842761729ull, 293166858021117ull}},
{{14125774068780777475ull, 469066972833788ull}},
{{232572810798891010ull, 375253578267031ull}},
{{14943453507606754101ull, 300202862613624ull}},
{{12841479167945075592ull, 480324580181799ull}},
{{13962532149097970797ull, 384259664145439ull}},
{{14859374534020286960ull, 307407731316351ull}},
{{16396301624948638490ull, 491852370106162ull}},
{{5738343670475090146ull, 393481896084930ull}},
{{4590674936380072117ull, 314785516867944ull}},
{{14723777527691936033ull, 503656826988710ull}},
{{11779022022153548826ull, 402925461590968ull}},
{{16801915247206659707ull, 322340369272774ull}},
{{15815017951304924563ull, 515744590836439ull}},
{{16341363175785849973ull, 412595672669151ull}},
{{9383741725886769655ull, 330076538135321ull}},
{{7635289131935010802ull, 528122461016514ull}},
{{9797580120289918965ull, 422497968813211ull}},
{{4148715281490024849ull, 337998375050569ull}},
{{14016642079867860405ull, 540797400080910ull}},
{{11213313663894288324ull, 432637920064728ull}},
{{16349348560599251305ull, 346110336051782ull}},
{{11401562437991160796ull, 553776537682852ull}},
{{1742552320909107990ull, 443021230146282ull}},
{{12462088300953017362ull, 354416984117025ull}},
{{9969670640762413889ull, 283533587293620ull}},
{{15951473025219862223ull, 453653739669792ull}},
{{5382480790692069132ull, 362922991735834ull}},
{{7995333447295565629ull, 290338393388667ull}},
{{16481882330414815329ull, 464541429421867ull}},
{{5806808234848031617ull, 371633143537494ull}},
{{8334795402620335617ull, 297306514829995ull}},
{{13335672644192536987ull, 475690423727992ull}},
{{3289840485870208943ull, 380552338982394ull}},
{{6321221203438077478ull, 304441871185915ull}},
{{10113953925500923964ull, 487106993897464ull}},
{{11780511955142649495ull, 389685595117971ull}},
{{5735060749372209272ull, 311748476094377ull}},
{{12865446013737445159ull, 498797561751003ull}},
{{17671054440473776774ull, 399038049400802ull}},
{{6758145922895200772ull, 319230439520642ull}},
{{14502382291374231559ull, 510768703233027ull}},
{{4223208203615564601ull, 408614962586422ull}},
{{14446613007118182650ull, 326891970069137ull}},
{{8357185552421450948ull, 523027152110620ull}},
{{6685748441937160758ull, 418421721688496ull}},
{{1659249938807818283ull, 334737377350797ull}},
{{6344148716834419577ull, 535579803761275ull}},
{{5075318973467535661ull, 428463843009020ull}},
{{4060255178774028529ull, 342771074407216ull}},
{{17564454730264176616ull, 548433719051545ull}},
{{14051563784211341293ull, 438746975241236ull}},
{{7551902212627162711ull, 350997580192989ull}},
{{1014997095977729368ull, 561596128308783ull}},
{{8190695306266004141ull, 449276902647026ull}},
{{2863207430270892990ull, 359421522117621ull}},
{{17047961203184355684ull, 287537217694096ull}},
{{1451296221901596833ull, 460059548310555ull}},
{{1161036977521277466ull, 368047638648444ull}},
{{4618178396758932296ull, 294438110918755ull}},
{{7389085434814291674ull, 471100977470008ull}},
{{13289965977335253985ull, 376880781976006ull}},
{{6942623967126292865ull, 301504625580805ull}},
{{11108198347402068584ull, 482407400929288ull}},
{{16265256307405475514ull, 385925920743430ull}},
{{13012205045924380411ull, 308740736594744ull}},
{{9751481629253277688ull, 493985178551591ull}},
{{4111836488660711827ull, 395188142841273ull}},
{{10668166820412390108ull, 316150514273018ull}},
{{13379718097917913850ull, 505840822836829ull}},
{{14393123293076241403ull, 404672658269463ull}},
{{446452190235262153ull, 323738126615571ull}},
{{11782369948602150414ull, 517981002584913ull}},
{{16804593588365540978ull, 414384802067930ull}},
{{13443674870692432782ull, 331507841654344ull}},
{{10441833348882161482ull, 530412546646951ull}},
{{4664117864363818862ull, 424330037317561ull}},
{{41945476749144767ull, 339464029854049ull}},
{{7445810392282452273ull, 543142447766478ull}},
{{13335345943309782465ull, 434513958213182ull}},
{{3289579125164005326ull, 347611166570546ull}},
{{16331373044488139491ull, 556177866512873ull}},
{{1997051991364780623ull, 444942293210299ull}},
{{5286990407833734821ull, 355953834568239ull}},
{{7918941141008898180ull, 284763067654591ull}},
{{5291608196130416442ull, 455620908247346ull}},
{{543937742162422831ull, 364496726597877ull}},
{{11503196637955669234ull, 291597381278301ull}},
{{11026416991245250128ull, 466555810045282ull}},
{{1442435963512379456ull, 373244648036226ull}},
{{15911344029777544858ull, 298595718428980ull}},
{{7011406373934520156ull, 477753149486369ull}},
{{9298473913889526448ull, 382202519589095ull}},
{{7438779131111621158ull, 305762015671276ull}},
{{4523348980294773207ull, 489219225074042ull}},
{{14686725628461549535ull, 391375380059233ull}},
{{681334058543508659ull, 313100304047387ull}},
{{4779483308411524177ull, 500960486475819ull}},
{{7512935461471129665ull, 400768389180655ull}},
{{6010348369176903732ull, 320614711344524ull}},
{{16995255020166866618ull, 512983538151238ull}},
{{2528157571907762324ull, 410386830520991ull}},
{{16779921316493851152ull, 328309464416792ull}},
{{12090478847422520551ull, 525295143066868ull}},
{{17051080707421837087ull, 420236114453494ull}},
{{17330213380679379993ull, 336188891562795ull}},
{{9281597335377456373ull, 537902226500473ull}},
{{14803975497785785745ull, 430321781200378ull}},
{{775133954002897626ull, 344257424960303ull}},
{{15997609585372277495ull, 550811879936484ull}},
{{16487436483039732319ull, 440649503949187ull}},
{{5811251556947965209ull, 352519603159350ull}},
{{4649001245558372167ull, 282015682527480ull}},
{{7438401992893395467ull, 451225092043968ull}},
{{13329419223798537020ull, 360980073635174ull}},
{{14352884193780739939ull, 288784058908139ull}},
{{11896568265823452933ull, 462054494253023ull}},
{{16895952242142582993ull, 369643595402418ull}},
{{2448715349488335425ull, 295714876321935ull}},
{{3917944559181336680ull, 473143802115096ull}},
{{17891750906312710636ull, 378515041692076ull}},
{{10624051910308258186ull, 302812033353661ull}},
{{9619785427009392451ull, 484499253365858ull}},
{{15074525971091334607ull, 387599402692686ull}},
{{8370271962131157363ull, 310079522154149ull}},
{{2324388695184120811ull, 496127235446639ull}},
{{5548859770889206972ull, 396901788357311ull}},
{{749739001969455254ull, 317521430685849ull}},
{{8578280032634949053ull, 508034289097358ull}},
{{14241321655591779889ull, 406427431277886ull}},
{{7703708509731513588ull, 325141945022309ull}},
{{1257887171344690771ull, 520227112035695ull}},
{{1006309737075752617ull, 416181689628556ull}},
{{15562443048628243386ull, 332945351702844ull}},
{{13831862433579458449ull, 532712562724551ull}},
{{7376141132121656436ull, 426170050179641ull}},
{{2211564090955414825ull, 340936040143713ull}},
{{18295897804496305013ull, 545497664229940ull}},
{{14636718243597044011ull, 436398131383952ull}},
{{4330676965393814562ull, 349118505107162ull}},
{{10618431959372013623ull, 558589608171459ull}},
{{12184094382239521221ull, 446871686537167ull}},
{{2368577876307796330ull, 357497349229734ull}},
{{5584211115788147387ull, 285997879383787ull}},
{{12624086600002946143ull, 457596607014059ull}},
{{13788618094744267238ull, 366077285611247ull}},
{{3652196846311593144ull, 292861828488998ull}},
{{2154166139356638707ull, 468578925582397ull}},
{{12791379355711041935ull, 374863140465917ull}},
{{2854405855085012902ull, 299890512372734ull}},
{{11945746997619841289ull, 479824819796374ull}},
{{13245946412837783355ull, 383859855837099ull}},
{{14286105945012137007ull, 307087884669679ull}},
{{11789723067793688242ull, 491340615471487ull}},
{{2053080824751129947ull, 393072492377190ull}},
{{1642464659800903957ull, 314457993901752ull}},
{{6317292270423356655ull, 503132790242803ull}},
{{12432531445822505970ull, 402506232194242ull}},
{{2567327527174184130ull, 322004985755394ull}},
{{11486421672962515254ull, 515207977208630ull}},
{{9189137338370012203ull, 412166381766904ull}},
{{11040658685437920086ull, 329733105413523ull}},
{{13975705081958761815ull, 527572968661637ull}},
{{3801866436083188805ull, 422058374929310ull}},
{{3041493148866551044ull, 337646699943448ull}},
{{1177040223444571347ull, 540234719909517ull}},
{{12009678622981388047ull, 432187775927613ull}},
{{16986440527868931084ull, 345750220742090ull}},
{{8731560770880738119ull, 553200353187345ull}},
{{6985248616704590495ull, 442560282549876ull}},
{{1898850078621762073ull, 354048226039901ull}},
{{16276475321865050951ull, 283238580831920ull}},
{{7595616441274529906ull, 453181729331073ull}},
{{13455190782503444571ull, 362545383464858ull}},
{{18142850255486576303ull, 290036306771886ull}},
{{3203118705585149823ull, 464058090835019ull}},
{{6251843779210030181ull, 371246472668015ull}},
{{5001475023368024145ull, 296997178134412ull}},
{{11691708852130748956ull, 475195485015059ull}},
{{13042715896446509488ull, 380156388012047ull}},
{{3055475087673386944ull, 304125110409638ull}},
{{1199411325535508787ull, 486600176655421ull}},
{{15716924319396048322ull, 389280141324336ull}},
{{8884190640774928334ull, 311424113059469ull}},
{{3146658581014154366ull, 498278580895151ull}},
{{17274722123778964785ull, 398622864716120ull}},
{{13819777699023171828ull, 318898291772896ull}},
{{14732946688953254279ull, 510237266836634ull}},
{{15475706165904513746ull, 408189813469307ull}},
{{5001867303239790350ull, 326551850775446ull}},
{{624290055699843915ull, 522482961240714ull}},
{{4188780859301785455ull, 417986368992571ull}},
{{18108419946409069657ull, 334389095194056ull}},
{{3148030211061139188ull, 535022552310491ull}},
{{17275819427816552643ull, 428018041848392ull}},
{{6441957912769421468ull, 342414433478714ull}},
{{17685830289914894996ull, 547863093565942ull}},
{{6769966602448095350ull, 438290474852754ull}},
{{9105322096700386603ull, 350632379882203ull}},
{{10879166539978708242ull, 561011807811525ull}},
{{8703333231982966594ull, 448809446249220ull}},
{{6962666585586373275ull, 359047556999376ull}},
{{1880784453727188297ull, 287238045599501ull}},
{{14077301570189232244ull, 459580872959201ull}},
{{7572492441409475472ull, 367664698367361ull}},
{{2368645138385670055ull, 294131758693889ull}},
{{11168529850900892734ull, 470610813910222ull}},
{{1556126251236893541ull, 376488651128178ull}},
{{8623598630473335479ull, 301190920902542ull}},
{{17487106623499247090ull, 481905473444067ull}},
{{6610987669315577025ull, 385524378755254ull}},
{{8978138950194371943ull, 308419503004203ull}},
{{10675673505569084786ull, 493471204806725ull}},
{{8540538804455267829ull, 394776963845380ull}},
{{6832431043564214263ull, 315821571076304ull}},
{{18310587299186563468ull, 505314513722086ull}},
{{10959121024607340451ull, 404251610977669ull}},
{{12456645634427782684ull, 323401288782135ull}},
{{1483888941374900678ull, 517442062051417ull}},
{{12255157597325651512ull, 413953649641133ull}},
{{17182823707344341856ull, 331162919712906ull}},
{{1667076228557574707ull, 529860671540651ull}},
{{16091056241813701059ull, 423888537232520ull}},
{{12872844993450960847ull, 339110829786016ull}},
{{13217854360037716709ull, 542577327657626ull}},
{{6884934673288263044ull, 434061862126101ull}},
{{1818598923888700112ull, 347249489700881ull}},
{{13977804722447651149ull, 555599183521409ull}},
{{14871592592700031242ull, 444479346817127ull}},
{{4518576444676204347ull, 355583477453702ull}},
{{14682907599966694447ull, 284466781962961ull}},
{{16113954530462890469ull, 455146851140738ull}},
{{1823117180144581406ull, 364117480912591ull}},
{{16215889003083306417ull, 291293984730072ull}},
{{11188027145965648975ull, 466070375568116ull}},
{{5261072902030608857ull, 372856300454493ull}},
{{11587555951108307732ull, 298285040363594ull}},
{{7472043077547561402ull, 477256064581751ull}},
{{2288285647296138798ull, 381804851665401ull}},
{{16588023776804552331ull, 305443881332320ull}},
{{8094093969177732114ull, 488710210131713ull}},
{{13853972804826006338ull, 390968168105370ull}},
{{11083178243860805070ull, 312774534484296ull}},
{{10354387560693467466ull, 500439255174874ull}},
{{11972858863296684296ull, 400351404139899ull}},
{{13267635905379257760ull, 320281123311919ull}},
{{10160171004381081446ull, 512449797299071ull}},
{{4438787988762954834ull, 409959837839257ull}},
{{14619076835236094836ull, 327967870271405ull}},
{{4943778862668200123ull, 524748592434249ull}},
{{7644371904876470421ull, 419798873947399ull}},
{{9804846338643086660ull, 335839099157919ull}},
{{4619707697603207687ull, 537342558652671ull}},
{{6417343340655826ull, 429874046922137ull}},
{{11073180318898255630ull, 343899237537709ull}},
{{6649042066011478039ull, 550238780060335ull}},
{{5319233652809182431ull, 440191024048268ull}},
{{11634084551731166591ull, 352152819238614ull}},
{{12996616456126843596ull, 281722255390891ull}},
{{13415888700319129108ull, 450755608625426ull}},
{{7043362145513392963ull, 360604486900341ull}},
{{1945340901668804047ull, 288483589520273ull}},
{{17869940701637727768ull, 461573743232436ull}},
{{10606603746568271891ull, 369258994585949ull}},
{{12174631811996527836ull, 295407195668759ull}},
{{8411364454968713569ull, 472651513070015ull}},
{{6729091563974970855ull, 378121210456012ull}},
{{16451319695405707653ull, 302496968364809ull}},
{{15254065068423401276ull, 483995149383695ull}},
{{12203252054738721021ull, 387196119506956ull}},
{{6073252829049066493ull, 309756895605565ull}},
{{9717204526478506390ull, 495611032968904ull}},
{{11463112435924715435ull, 396488826375123ull}},
{{16549187578223592994ull, 317191061100098ull}},
{{4342607236706286852ull, 507505697760158ull}},
{{10852783418848850128ull, 406004558208126ull}},
{{4992877920337169779ull, 324803646566501ull}},
{{609907043055651000ull, 519685834506402ull}},
{{11555972078670251770ull, 415748667605121ull}},
{{5555428848194291092ull, 332598934084097ull}},
{{12578034971852776071ull, 532158294534555ull}},
{{10062427977482220857ull, 425726635627644ull}},
{{11739291196727687009ull, 340581308502115ull}},
{{336121841054747598ull, 544930093603385ull}},
{{268897472843798078ull, 435944074882708ull}},
{{7593815607758859109ull, 348755259906166ull}},
{{4771407342930353928ull, 558008415849866ull}},
{{127777059602372819ull, 446406732679893ull}},
{{7480919277165718902ull, 357125386143914ull}},
{{9674084236474485445ull, 285700308915131ull}},
{{8099837148875356065ull, 457120494264210ull}},
{{6479869719100284852ull, 365696395411368ull}},
{{12562593404764048528ull, 292557116329094ull}},
{{9032103003396746675ull, 468091386126551ull}},
{{3536333587975487017ull, 374473108901241ull}},
{{17586462129348030906ull, 299578487120992ull}},
{{13380944147989208158ull, 479325579393588ull}},
{{18083452947875187172ull, 383460463514870ull}},
{{14466762358300149738ull, 306768370811896ull}},
{{15768122143796418934ull, 490829393299034ull}},
{{16303846529779045471ull, 392663514639227ull}},
{{5664379594339415730ull, 314130811711382ull}},
{{12752356165684975491ull, 502609298738211ull}},
{{6512536117806070070ull, 402087438990569ull}},
{{8899377708986766379ull, 321669951192455ull}},
{{14239004334378826207ull, 514671921907928ull}},
{{323157023277329996ull, 411737537526343ull}},
{{7637223248105684643ull, 329390030021074ull}},
{{1151510752743364459ull, 527024048033719ull}},
{{4610557416936601890ull, 421619238426975ull}},
{{3688445933549281512ull, 337295390741580ull}},
{{5901513493678850420ull, 539672625186528ull}},
{{12099908424426900982ull, 431738100149222ull}},
{{2301229110057700139ull, 345390480119378ull}},
{{18439361835059961516ull, 552624768191004ull}},
{{18440838282789879536ull, 442099814552803ull}},
{{3684624182006172659ull, 353679851642243ull}},
{{10326396975088758774ull, 282943881313794ull}},
{{5454188715916283068ull, 452710210102071ull}},
{{674002157991116131ull, 362168168081657ull}},
{{11607248170618623875ull, 289734534465325ull}},
{{124852999280246584ull, 463575255144521ull}},
{{14857277658391838560ull, 370860204115616ull}},
{{8196473311971560524ull, 296688163292493ull}},
{{9425008484412586516ull, 474701061267989ull}},
{{11229355602271979536ull, 379760849014391ull}},
{{5294135667075673305ull, 303808679211513ull}},
{{4781268252579166966ull, 486093886738421ull}},
{{135665787321423249ull, 388875109390737ull}},
{{11176579074082869569ull, 311100087512589ull}},
{{6814480074306860341ull, 497760140020143ull}},
{{12830281688929308919ull, 398208112016114ull}},
{{13953574165885357458ull, 318566489612891ull}},
{{14947021035932751287ull, 509706383380626ull}},
{{8268268014004290707ull, 407765106704501ull}},
{{2925265596461522242ull, 326212085363601ull}},
{{15748471398564166557ull, 521939336581761ull}},
{{8909428304109422922ull, 417551469265409ull}},
{{10816891458029448661ull, 334041175412327ull}},
{{2549631073879476565ull, 534465880659724ull}},
{{5729053673845491575ull, 427572704527779ull}},
{{8272591753818303583ull, 342058163622223ull}},
{{9546797991367375410ull, 547293061795557ull}},
{{258740763610079682ull, 437834449436446ull}},
{{14964387869855705038ull, 350267559549156ull}},
{{16564322962285307415ull, 560428095278650ull}},
{{13251458369828245932ull, 448342476222920ull}},
{{10601166695862596745ull, 358673980978336ull}},
{{4791584541948167073ull, 286939184782669ull}},
{{15045232896600887963ull, 459102695652270ull}},
{{12036186317280710371ull, 367282156521816ull}},
{{5939600239082657973ull, 293825725217453ull}},
{{5814011567790342434ull, 470121160347925ull}},
{{4651209254232273947ull, 376096928278340ull}},
{{3720967403385819158ull, 300877542622672ull}},
{{9642896660159220976ull, 481404068196275ull}},
{{7714317328127376781ull, 385123254557020ull}},
{{6171453862501901424ull, 308098603645616ull}},
{{2495628550519221633ull, 492957765832986ull}},
{{16753898099383018599ull, 394366212666388ull}},
{{2335072035280683910ull, 315492970133111ull}},
{{14804161700674825225ull, 504788752212977ull}},
{{4464631731056039534ull, 403831001770382ull}},
{{14639751829070562596ull, 323064801416305ull}},
{{4976858852803348539ull, 516903682266089ull}},
{{7670835896984589154ull, 413522945812871ull}},
{{2447319902845761000ull, 330818356650297ull}},
{{7605060659295127923ull, 529309370640475ull}},
{{6084048527436102339ull, 423447496512380ull}},
{{4867238821948881871ull, 338757997209904ull}},
{{15166279744602031640ull, 542012795535846ull}},
{{8443674980939714989ull, 433610236428677ull}},
{{17822986428977502960ull, 346888189142941ull}},
{{2691336583170632474ull, 555021102628707ull}},
{{13221115710762236949ull, 444016882102965ull}},
{{10576892568609789559ull, 355213505682372ull}},
{{1082816425404011001ull, 284170804545898ull}},
{{16489901539614058894ull, 454673287273436ull}},
{{9502572416949336792ull, 363738629818749ull}},
{{11291406748301379757ull, 290990903854999ull}},
{{6998204353056476642ull, 465585446167999ull}},
{{9287912297187091636ull, 372468356934399ull}},
{{11119678652491583632ull, 297974685547519ull}},
{{6723439399760802842ull, 476759496876031ull}},
{{1689402705066731951ull, 381407597500825ull}},
{{1351522164053385560ull, 305126078000660ull}},
{{2162435462485416897ull, 488201724801056ull}},
{{16487343628955974810ull, 390561379840844ull}},
{{16879223717906690171ull, 312449103872675ull}},
{{8560013874941152658ull, 499918566196281ull}},
{{3158662285211011803ull, 399934852957025ull}},
{{2526929828168809443ull, 319947882365620ull}},
{{4043087725070095108ull, 511916611784992ull}},
{{14302516624281807056ull, 409533289427993ull}},
{{373966855199714675ull, 327626631542395ull}},
{{598346968319543481ull, 524202610467832ull}},
{{11546724018881365754ull, 419362088374265ull}},
{{9237379215105092603ull, 335489670699412ull}},
{{22411485200506873ull, 536783473119060ull}},
{{17929188160405498ull, 429426778495248ull}},
{{7393040980012145045ull, 343541422796198ull}},
{{8139516753277521749ull, 549666276473917ull}},
{{17579659846847748368ull, 439733021179133ull}},
{{2995681433252467725ull, 351786416943307ull}},
{{8482439107945858684ull, 562858267109291ull}},
{{3096602471614776624ull, 450286613687433ull}},
{{9855979606775641945ull, 360229290949946ull}},
{{4195434870678603233ull, 288183432759957ull}},
{{10402044607827675496ull, 461093492415931ull}},
{{4632286871520230073ull, 368874793932745ull}},
{{3705829497216184059ull, 295099835146196ull}},
{{16997373639771625464ull, 472159736233913ull}},
{{2529852467591569401ull, 377727788987131ull}},
{{16781277233040896814ull, 302182231189704ull}},
{{15781997128639703933ull, 483491569903527ull}},
{{5246900073427942500ull, 386793255922822ull}},
{{15265566502968084969ull, 309434604738257ull}},
{{9667511145781294658ull, 495095367581212ull}},
{{355311287141215080ull, 396076294064970ull}},
{{284249029712972064ull, 316861035251976ull}},
{{11522844891766486272ull, 506977656403161ull}},
{{5528927098671278695ull, 405582125122529ull}},
{{8112490493678933279ull, 324465700098023ull}},
{{9290635975144382923ull, 519145120156837ull}},
{{53811150631685692ull, 415316096125470ull}},
{{43048920505348553ull, 332252876900376ull}},
{{11136924717034288655ull, 531604603040601ull}},
{{5220190958885520601ull, 425283682432481ull}},
{{486803952366506158ull, 340226945945985ull}},
{{778886323786409852ull, 544363113513576ull}},
{{15380504317996769175ull, 435490490810860ull}},
{{12304403454397415340ull, 348392392648688ull}},
{{15997696712293954220ull, 557427828237901ull}},
{{9108808555093253053ull, 445942262590321ull}},
{{3597698029332692119ull, 356753810072257ull}},
{{13946204867691884665ull, 285403048057805ull}},
{{3867183714597463848ull, 456644876892489ull}},
{{6783095786419881402ull, 365315901513991ull}},
{{1737127814393994798ull, 292252721211193ull}},
{{17536799761998032970ull, 467604353937908ull}},
{{2961393365372695406ull, 374083483150327ull}},
{{13437161136523887294ull, 299266786520261ull}},
{{14120760188954399025ull, 478826858432418ull}},
{{228561706937788250ull, 383061486745935ull}},
{{182849365550230600ull, 306449189396748ull}},
{{15049954243848010253ull, 490318703034796ull}},
{{8350614580336497879ull, 392254962427837ull}},
{{17748538108494929273ull, 313803969942269ull}},
{{17329614529366155867ull, 502086351907631ull}},
{{10174342808751014371ull, 401669081526105ull}},
{{8139474247000811496ull, 321335265220884ull}},
{{1955112350975567425ull, 514136424353415ull}},
{{1564089880780453940ull, 411309139482732ull}},
{{12319318348850094121ull, 329047311586185ull}},
{{1264165284450598978ull, 526475698537897ull}},
{{12079378671786210152ull, 421180558830317ull}},
{{2284805307945147475ull, 336944447064254ull}},
{{11034386122196056607ull, 539111115302806ull}},
{{5138160083014934962ull, 431288892242245ull}},
{{4110528066411947970ull, 345031113793796ull}},
{{17644891350484847722ull, 552049782070073ull}},
{{3047866636162147208ull, 441639825656059ull}},
{{6127642123671628089ull, 353311860524847ull}},
{{15970160143163033441ull, 282649488419877ull}},
{{10794860970093212213ull, 452239181471804ull}},
{{12325237590816480093ull, 361791345177443ull}},
{{17238887702137004721ull, 289433076141954ull}},
{{16514173879193476584ull, 463092921827127ull}},
{{5832641473870960621ull, 370474337461702ull}},
{{15734159623322499466ull, 296379469969361ull}},
{{17795957767832178500ull, 474207151950978ull}},
{{3168719770040011830ull, 379365721560783ull}},
{{9913673445515830111ull, 303492577248626ull}},
{{8483179883341507531ull, 485588123597802ull}},
{{17854590350898936994ull, 388470498878241ull}},
{{10594323465977239272ull, 310776399102593ull}},
{{13261568730821672512ull, 497242238564149ull}},
{{14298603799399248333ull, 397793790851319ull}},
{{15128231854261308989ull, 318235032681055ull}},
{{5758426893108542767ull, 509176052289689ull}},
{{8296090329228744537ull, 407340841831751ull}},
{{2947523448641085306ull, 325872673465401ull}},
{{15784083962051467460ull, 521396277544641ull}},
{{8937918354899263645ull, 417117022035713ull}},
{{14529032313403231562ull, 333693617628570ull}},
{{4799707627735618884ull, 533909788205713ull}},
{{11218463731672315753ull, 427127830564570ull}},
{{8974770985337852602ull, 341702264451656ull}},
{{6980935947056743518ull, 546723623122650ull}},
{{5584748757645394814ull, 437378898498120ull}},
{{4467799006116315851ull, 349903118798496ull}},
{{18216524854011836332ull, 559844990077593ull}},
{{3505173438983738096ull, 447875992062075ull}},
{{2804138751186990477ull, 358300793649660ull}},
{{2243311000949592381ull, 286640634919728ull}},
{{18346692860486989103ull, 458625015871564ull}},
{{18366703103131501605ull, 366900012697251ull}},
{{11004013667763290961ull, 293520010157801ull}},
{{10227724238937444892ull, 469632016252482ull}},
{{803481761666135267ull, 375705613001986ull}},
{{15400180668300549506ull, 300564490401588ull}},
{{2504196180829417271ull, 480903184642542ull}},
{{13071403388889264786ull, 384722547714033ull}},
{{17835820340595232475ull, 307778038171226ull}},
{{2711870841758999698ull, 492444861073963ull}},
{{9548194302891020405ull, 393955888859170ull}},
{{7638555442312816324ull, 315164711087336ull}},
{{4842991078216685472ull, 504263537739738ull}},
{{11253090492057169024ull, 403410830191790ull}},
{{9002472393645735219ull, 322728664153432ull}},
{{18093304644575086674ull, 516365862645491ull}},
{{10785294900918159016ull, 413092690116393ull}},
{{16006933550218347859ull, 330474152093114ull}},
{{14543047236123625605ull, 528758643348983ull}},
{{566391344673169514ull, 423006914679187ull}},
{{11521159519964266581ull, 338405531743349ull}},
{{7365808787717095560ull, 541448850789359ull}},
{{9581995844915586771ull, 433159080631487ull}},
{{286899046448648771ull, 346527264505190ull}},
{{459038474317838033ull, 554443623208304ull}},
{{4056579594196180750ull, 443554898566643ull}},
{{10623961304840765246ull, 354843918853314ull}},
{{12188517858614522520ull, 283875135082651ull}},
{{12122930944299415386ull, 454200216132242ull}},
{{2319647125955711662ull, 363360172905794ull}},
{{5545066515506479653ull, 290688138324635ull}},
{{8872106424810367445ull, 465101021319416ull}},
{{3408336325106383633ull, 372080817055533ull}},
{{10105366689568927552ull, 297664653644426ull}},
{{8789889073826463438ull, 476263445831082ull}},
{{18099957703286901720ull, 381010756664865ull}},
{{14479966162629521376ull, 304808605331892ull}},
{{8410550601239592908ull, 487693768531028ull}},
{{14107138110475494973ull, 390155014824822ull}},
{{3907012858896575332ull, 312124011859858ull}},
{{2561871759492610208ull, 499398418975773ull}},
{{9428195037077908813ull, 399518735180618ull}},
{{14921253659146147697ull, 319614988144494ull}},
{{12805959410408105345ull, 511383981031191ull}},
{{6555418713584573953ull, 409107184824953ull}},
{{12623032600351479809ull, 327285747859962ull}},
{{5439456901594726401ull, 523657196575940ull}},
{{4351565521275781121ull, 418925757260752ull}},
{{14549298861246355866ull, 335140605808601ull}},
{{15900180548510348740ull, 536224969293762ull}},
{{5341446809324458345ull, 428979975435010ull}},
{{4273157447459566676ull, 343183980348008ull}},
{{3147703101193396359ull, 549094368556813ull}},
{{9896860110438537734ull, 439275494845450ull}},
{{7917488088350830187ull, 351420395876360ull}},
{{12667980941361328299ull, 562272633402176ull}},
{{6445035938347152316ull, 449818106721741ull}},
{{1466679935935811529ull, 359854485377393ull}},
{{8552041578232469870ull, 287883588301914ull}},
{{2615220080946220823ull, 460613741283063ull}},
{{9470873694240797304ull, 368490993026450ull}},
{{7576698955392637843ull, 294792794421160ull}},
{{12122718328628220550ull, 471668471073856ull}},
{{6008825848160666116ull, 377334776859085ull}},
{{4807060678528532893ull, 301867821487268ull}},
{{4001948270903742306ull, 482988514379629ull}},
{{6890907431464904168ull, 386390811503703ull}},
{{12891423574655743981ull, 309112649202962ull}},
{{5868882460481549076ull, 494580238724740ull}},
{{4695105968385239261ull, 395664190979792ull}},
{{14824131218933922378ull, 316531352783833ull}},
{{1582517061842813866ull, 506450164454134ull}},
{{4955362464216161416ull, 405160131563307ull}},
{{15032336415598660103ull, 324128105250645ull}},
{{5604994191248304548ull, 518604968401033ull}},
{{11862692982482464285ull, 414883974720826ull}},
{{5800805571244061105ull, 331907179776661ull}},
{{1902591284506677121ull, 531051487642658ull}},
{{8900770657089162343ull, 424841190114126ull}},
{{3431267710929419551ull, 339872952091301ull}},
{{16558074781712802252ull, 543796723346081ull}},
{{9557111010628331478ull, 435037378676865ull}},
{{7645688808502665183ull, 348029902941492ull}},
{{15922450908346174616ull, 556847844706387ull}},
{{5359263097193119046ull, 445478275765110ull}},
{{4287410477754495237ull, 356382620612088ull}},
{{10808626011687416836ull, 285106096489670ull}},
{{17293801618699866937ull, 456169754383472ull}},
{{6456343665476072903ull, 364935803506778ull}},
{{12543772561864678969ull, 291948642805422ull}},
{{5312640840015845058ull, 467117828488676ull}},
{{560763857270765723ull, 373694262790941ull}},
{{15206006344784253871ull, 298955410232752ull}},
{{9572214892687164901ull, 478328656372404ull}},
{{11347120728891642244ull, 382662925097923ull}},
{{16456394212597134442ull, 306130340078338ull}},
{{4194137851703953168ull, 489808544125342ull}},
{{14423356725588893504ull, 391846835300273ull}},
{{470638936245383833ull, 313477468240219ull}},
{{8131719927476434780ull, 501563949184350ull}},
{{6505375941981147824ull, 401251159347480ull}},
{{5204300753584918259ull, 321000927477984ull}},
{{15705578835219689861ull, 513601483964774ull}},
{{16253811882917662212ull, 410881187171819ull}},
{{16692398321076040093ull, 328704949737455ull}},
{{8261093240012112533ull, 525927919579929ull}},
{{10298223406751600349ull, 420742335663943ull}},
{{15617276354885100926ull, 336593868531154ull}},
{{13919595723590430512ull, 538550189649847ull}},
{{3756978949388523763ull, 430840151719878ull}},
{{10384280788994639657ull, 344672121375902ull}},
{{1857454003423782158ull, 551475394201444ull}},
{{5175312017480936050ull, 441180315361155ull}},
{{4140249613984748840ull, 352944252288924ull}},
{{7001548505929709395ull, 282355401831139ull}},
{{134431165261804062ull, 451768642929823ull}},
{{7486242561693263896ull, 361414914343858ull}},
{{13367691678838431763ull, 289131931475086ull}},
{{14009609056657670175ull, 462611090360138ull}},
{{139640801100405170ull, 370088872288111ull}},
{{14869107899847965429ull, 296071097830488ull}},
{{1654479751305282747ull, 473713756528782ull}},
{{12391630245269957167ull, 378971005223025ull}},
{{9913304196215965734ull, 303176804178420ull}},
{{15861286713945545174ull, 485082886685472ull}},
{{5310331741672615493ull, 388066309348378ull}},
{{11626963022821913041ull, 310453047478702ull}},
{{3845745577547419573ull, 496724875965924ull}},
{{6765945276779845981ull, 397379900772739ull}},
{{9102105036165787108ull, 317903920618191ull}},
{{7184670428381438727ull, 508646272989106ull}},
{{2058387527963240658ull, 406917018391285ull}},
{{1646710022370592526ull, 325533614713028ull}},
{{17392131294760589335ull, 520853783540844ull}},
{{17603053850550381791ull, 416683026832675ull}},
{{14082443080440305433ull, 333346421466140ull}},
{{4085164854994937077ull, 533354274345825ull}},
{{3268131883995949662ull, 426683419476660ull}},
{{2614505507196759729ull, 341346735581328ull}},
{{493859996772905244ull, 546154776930125ull}},
{{395087997418324195ull, 436923821544100ull}},
{{316070397934659356ull, 349539057235280ull}},
{{505712636695454970ull, 559262491576448ull}},
{{7783267738840184622ull, 447409993261158ull}},
{{13605311820555968344ull, 357927994608926ull}},
{{7194900641702864352ull, 286342395687141ull}},
{{4133143397240762317ull, 458147833099426ull}},
{{18063909976760251146ull, 366518266479540ull}},
{{14451127981408200917ull, 293214613183632ull}},
{{8364409511285480174ull, 469143381093812ull}},
{{17759574053254115109ull, 375314704875049ull}},
{{17897008057345202410ull, 300251763900039ull}},
{{17567166447526592887ull, 480402822240063ull}},
{{2985686713795543340ull, 384322257792051ull}},
{{17145944630004075965ull, 307457806233640ull}},
{{8986767334296969928ull, 491932489973825ull}},
{{7189413867437575942ull, 393545991979060ull}},
{{5751531093950060754ull, 314836793583248ull}},
{{5513100935578186883ull, 503738869733197ull}},
{{15478527192688280476ull, 402991095786557ull}},
{{5004124124666803734ull, 322392876629246ull}},
{{627900969983065329ull, 515828602606794ull}},
{{4191669590728362586ull, 412662882085435ull}},
{{3353335672582690069ull, 330130305668348ull}},
{{1675988261390393787ull, 528208489069357ull}},
{{12408837053338045999ull, 422566791255485ull}},
{{9927069642670436799ull, 338053433004388ull}},
{{12193962613530788556ull, 540885492807021ull}},
{{6065821276082720521ull, 432708394245617ull}},
{{15920703465091907387ull, 346166715396493ull}},
{{3337032655695589880ull, 553866744634390ull}},
{{2669626124556471904ull, 443093395707512ull}},
{{13203747343870908492ull, 354474716566009ull}},
{{14252346689838637117ull, 283579773252807ull}},
{{8046359444774178095ull, 453727637204492ull}},
{{17505134000045073445ull, 362982109763593ull}},
{{2936060755810327787ull, 290385687810875ull}},
{{4697697209296524459ull, 464617100497400ull}},
{{3758157767437219567ull, 371693680397920ull}},
{{3006526213949775653ull, 297354944318336ull}},
{{15878488386545372015ull, 475767910909337ull}},
{{5324093079752476966ull, 380614328727470ull}},
{{4259274463801981573ull, 304491462981976ull}},
{{17882885586308901486ull, 487186340771161ull}},
{{10616959654305210865ull, 389749072616929ull}},
{{12182916538186079015ull, 311799258093543ull}},
{{15803317646355816102ull, 498878812949669ull}},
{{16332002931826563205ull, 399103050359735ull}},
{{13065602345461250564ull, 319282440287788ull}},
{{17215614937996090579ull, 510851904460461ull}},
{{10083143135654962140ull, 408681523568369ull}},
{{11755863323265880035ull, 326945218854695ull}},
{{362637243515856440ull, 523112350167513ull}},
{{7668807424296505798ull, 418489880134010ull}},
{{6135045939437204639ull, 334791904107208ull}},
{{6126724688357617099ull, 535667046571533ull}},
{{12280077380169914325ull, 428533637257226ull}},
{{6134713089394021137ull, 342826909805781ull}},
{{2436843313546613173ull, 548523055689250ull}},
{{1949474650837290538ull, 438818444551400ull}},
{{1559579720669832431ull, 351054755641120ull}},
{{2495327553071731889ull, 561687609025792ull}},
{{13064308486683116481ull, 449350087220633ull}},
{{17830144418830313831ull, 359480069776506ull}},
{{10574766720322340742ull, 287584055821205ull}},
{{16919626752515745187ull, 460134489313928ull}},
{{2467654957786865180ull, 368107591451143ull}},
{{9352821595713312790ull, 294486073160914ull}},
{{3896468108915569495ull, 471177717057463ull}},
{{10495872116616276242ull, 376942173645970ull}},
{{8396697693293020994ull, 301553738916776ull}},
{{6056018679785012944ull, 482485982266842ull}},
{{15912861388053741325ull, 385988785813473ull}},
{{1662242666217262090ull, 308791028650779ull}},
{{10038285895431439991ull, 494065645841246ull}},
{{4341279901603241669ull, 395252516672997ull}},
{{14541070365508324305ull, 316202013338397ull}},
{{8508317325845677595ull, 505923221341436ull}},
{{3117305045934631753ull, 404738577073149ull}},
{{6183192851489615725ull, 323790861658519ull}},
{{17271806191867205807ull, 518065378653630ull}},
{{13817444953493764646ull, 414452302922904ull}},
{{14743304777536922040ull, 331561842338323ull}},
{{1453194755607613325ull, 530498947741318ull}},
{{8541253433969911306ull, 424399158193054ull}},
{{10522351561917839368ull, 339519326554443ull}},
{{13146413684326632666ull, 543230922487109ull}},
{{14206479762203216456ull, 434584737989687ull}},
{{3986486180278752518ull, 347667790391750ull}},
{{6378377888446004029ull, 556268464626800ull}},
{{5102702310756803223ull, 445014771701440ull}},
{{4082161848605442578ull, 356011817361152ull}},
{{14333775923110085032ull, 284809453888921ull}},
{{15555343847492315406ull, 455695126222274ull}},
{{16133623892735762648ull, 364556100977819ull}},
{{16596247928930520441ull, 291644880782255ull}},
{{8107252612579281090ull, 466631809251609ull}},
{{10175150904805335195ull, 373305447401287ull}},
{{761423094360447510ull, 298644357921030ull}},
{{1218276950976716016ull, 477830972673648ull}},
{{8353319190265193459ull, 382264778138918ull}},
{{14061352981695975413ull, 305811822511134ull}},
{{11430118326487829692ull, 489298916017815ull}},
{{9144094661190263754ull, 391439132814252ull}},
{{18383322173177941972ull, 313151306251401ull}},
{{3587873773891334894ull, 501042090002243ull}},
{{10248996648596888561ull, 400833672001794ull}},
{{11888546133619421172ull, 320666937601435ull}},
{{574929740081522260ull, 513067100162297ull}},
{{11527990236290948777ull, 410453680129837ull}},
{{1843694559548938375ull, 328362944103870ull}},
{{2949911295278301401ull, 525380710566192ull}},
{{13427975480448372090ull, 420304568452953ull}},
{{18121078013842518318ull, 336243654762362ull}},
{{14236329563180388017ull, 537989847619780ull}},
{{11389063650544310414ull, 430391878095824ull}},
{{12800599735177358654ull, 344313502476659ull}},
{{9412913132058042877ull, 550901603962655ull}},
{{7530330505646434301ull, 440721283170124ull}},
{{9713613219259057764ull, 352577026536099ull}},
{{11460239390149156535ull, 282061621228879ull}},
{{7268336580012919486ull, 451298593966207ull}},
{{16882715708236066558ull, 361038875172965ull}},
{{13506172566588853246ull, 288831100138372ull}},
{{6852480847574523902ull, 462129760221396ull}},
{{1792635863317708798ull, 369703808177117ull}},
{{12502155134879898008ull, 295763046541693ull}},
{{16314099401065926490ull, 473220874466709ull}},
{{16740628335594651515ull, 378576699573367ull}},
{{6013805038991900566ull, 302861359658694ull}},
{{17000785691870861552ull, 484578175453910ull}},
{{13600628553496689241ull, 387662540363128ull}},
{{18259200472281172039ull, 310130032290502ull}},
{{14457325496682233970ull, 496208051664804ull}},
{{15255209212087697499ull, 396966441331843ull}},
{{1136120925444427030ull, 317573153065475ull}},
{{1817793480711083248ull, 508117044904760ull}},
{{1454234784568866598ull, 406493635923808ull}},
{{8542085457138913925ull, 325194908739046ull}},
{{6288639101938441634ull, 520311853982474ull}},
{{8720260096292663630ull, 416249483185979ull}},
{{10665556891776041227ull, 332999586548783ull}},
{{13375542212099755641ull, 532799338478053ull}},
{{18079131399163625159ull, 426239470782442ull}},
{{7084607489847079481ull, 340991576625954ull}},
{{267325539529596200ull, 545586522601527ull}},
{{11281906875849407929ull, 436469218081221ull}},
{{5336176685937616020ull, 349175374464977ull}},
{{12227231512242095956ull, 558680599143963ull}},
{{17160482839277497411ull, 446944479315170ull}},
{{13728386271421997928ull, 357555583452136ull}},
{{7293360202395688019ull, 286044466761709ull}},
{{601329879607369862ull, 457671146818735ull}},
{{481063903685895889ull, 366136917454988ull}},
{{7763548752432537358ull, 292909533963990ull}},
{{12421678003892059773ull, 468655254342384ull}},
{{13626691217855558141ull, 374924203473907ull}},
{{3522655344800625867ull, 299939362779126ull}},
{{16704294995906732356ull, 479902980446601ull}},
{{9674087181983475562ull, 383922384357281ull}},
{{4049920930844870126ull, 307137907485825ull}},
{{6479873489351792202ull, 491420651977320ull}},
{{5183898791481433762ull, 393136521581856ull}},
{{457770218443236686ull, 314509217265485ull}},
{{732432349509178698ull, 503214747624776ull}},
{{15343341138574984251ull, 402571798099820ull}},
{{12274672910859987401ull, 322057438479856ull}},
{{12260779027892159195ull, 515291901567770ull}},
{{9808623222313727356ull, 412233521254216ull}},
{{4157549763109071561ull, 329786817003373ull}},
{{2962730806232604175ull, 527658907205397ull}},
{{13438231089211814310ull, 422127125764317ull}},
{{3371887241885630801ull, 337701700611454ull}},
{{12773717216500829929ull, 540322720978326ull}},
{{6529624958458753620ull, 432258176782661ull}},
{{1534351152025092573ull, 345806541426129ull}},
{{9833659472723968763ull, 553290466281806ull}},
{{4177578763437264687ull, 442632373025445ull}},
{{3342063010749811749ull, 354105898420356ull}},
{{17431045667567490692ull, 283284718736284ull}},
{{16821626623882254138ull, 453255549978055ull}},
{{13457301299105803311ull, 362604439982444ull}},
{{14455189854026552972ull, 290083551985955ull}},
{{4681559692732933139ull, 464133683177529ull}},
{{7434596568928256834ull, 371306946542023ull}},
{{13326374884626426114ull, 297045557233618ull}},
{{17632851000660371459ull, 475272891573789ull}},
{{17795629615270207490ull, 380218313259031ull}},
{{10547154877474255669ull, 304174650607225ull}},
{{16875447803958809070ull, 486679440971560ull}},
{{13500358243167047256ull, 389343552777248ull}},
{{18178984224017458451ull, 311474842221798ull}},
{{6950281869976471583ull, 498359747554878ull}},
{{12938923125464997913ull, 398687798043902ull}},
{{2972440870888177684ull, 318950238435122ull}},
{{8445254208162994618ull, 510320381496195ull}},
{{6756203366530395694ull, 408256305196956ull}},
{{1715613878482406232ull, 326605044157565ull}},
{{2744982205571849971ull, 522568070652104ull}},
{{5885334579199390300ull, 418054456521683ull}},
{{12086965292843332886ull, 334443565217346ull}},
{{11960446839065511972ull, 535109704347754ull}},
{{13257706285994319901ull, 428087763478203ull}},
{{17984862658279276567ull, 342470210782562ull}},
{{14018384994279201215ull, 547952337252100ull}},
{{11214707995423360972ull, 438361869801680ull}},
{{8971766396338688777ull, 350689495841344ull}},
{{3286779789916171074ull, 561103193346151ull}},
{{17386819090900578152ull, 448882554676920ull}},
{{13909455272720462522ull, 359106043741536ull}},
{{7438215403434459694ull, 287284834993229ull}},
{{833098201269404541ull, 459655735989167ull}},
{{11734525005241254602ull, 367724588791333ull}},
{{16766317633676824328ull, 294179671033066ull}},
{{1000666510689546663ull, 470687473652907ull}},
{{11868579652777368300ull, 376549978922325ull}},
{{9494863722221894640ull, 301239983137860ull}},
{{15191781955555031424ull, 481983973020576ull}},
{{8464076749702114816ull, 385587178416461ull}},
{{3081912585019781529ull, 308469742733169ull}},
{{12309757765515471094ull, 493551588373070ull}},
{{9847806212412376875ull, 394841270698456ull}},
{{4188896155187991177ull, 315873016558765ull}},
{{6702233848300785883ull, 505396826494024ull}},
{{9051135893382539029ull, 404317461195219ull}},
{{10930257529447941547ull, 323453968956175ull}},
{{17488412047116706475ull, 517526350329880ull}},
{{13990729637693365180ull, 414021080263904ull}},
{{14881932524896602467ull, 331216864211123ull}},
{{1674999151383102008ull, 529946982737798ull}},
{{8718696950590302253ull, 423957586190238ull}},
{{14353655189956062449ull, 339166068952190ull}},
{{4519104230220148302ull, 542665710323505ull}},
{{3615283384176118641ull, 434132568258804ull}},
{{6581575522082805236ull, 347306054607043ull}},
{{6841172020590578055ull, 555689687371269ull}},
{{9162286431214372767ull, 444551749897015ull}},
{{7329829144971498214ull, 355641399917612ull}},
{{16931909760202929540ull, 284513119934089ull}},
{{16023009172098956295ull, 455220991894543ull}},
{{1750360893453434067ull, 364176793515635ull}},
{{1400288714762747253ull, 291341434812508ull}},
{{16997857202588036898ull, 466146295700012ull}},
{{6219588132586608872ull, 372917036560010ull}},
{{4975670506069287098ull, 298333629248008ull}},
{{4271723994968949033ull, 477333806796813ull}},
{{10796076825458979873ull, 381867045437450ull}},
{{8636861460367183898ull, 305493636349960ull}},
{{13818978336587494237ull, 488789818159936ull}},
{{7365833854528085067ull, 391031854527949ull}},
{{9582015898364378376ull, 312825483622359ull}},
{{4263178993157274433ull, 500520773795775ull}},
{{3410543194525819546ull, 400416619036620ull}},
{{2728434555620655637ull, 320333295229296ull}},
{{15433541733218779989ull, 512533272366873ull}},
{{1278786942349293021ull, 410026617893499ull}},
{{4712378368621344740ull, 328021294314799ull}},
{{14918503019277972231ull, 524834070903678ull}},
{{866755971196646815ull, 419867256722943ull}},
{{8072102406441138098ull, 335893805378354ull}},
{{1847317406080089988ull, 537430088605367ull}},
{{12545900369089802960ull, 429944070884293ull}},
{{17415417924755663014ull, 343955256707434ull}},
{{16796622235383329854ull, 550328410731895ull}},
{{13437297788306663883ull, 440262728585516ull}},
{{7060489415903420783ull, 352210182868413ull}},
{{13027089162206557273ull, 281768146294730ull}},
{{2396598585820940021ull, 450829034071569ull}},
{{5606627683398662340ull, 360663227257255ull}},
{{4485302146718929872ull, 288530581805804ull}},
{{14555181064234108441ull, 461648930889286ull}},
{{7954796036645376430ull, 369319144711429ull}},
{{10053185644058211467ull, 295455315769143ull}},
{{12395748215751228024ull, 472728505230629ull}},
{{13605947387342892742ull, 378182804184503ull}},
{{18263455539358134840ull, 302546243347602ull}},
{{14464133604005374452ull, 484073989356164ull}},
{{15260655697946209884ull, 387259191484931ull}},
{{8519175743615057584ull, 309807353187945ull}},
{{13630681189784092135ull, 495691765100712ull}},
{{3525847322343453062ull, 396553412080570ull}},
{{2820677857874762449ull, 317242729664456ull}},
{{15581131016825350889ull, 507588367463129ull}},
{{16154253628202191034ull, 406070693970503ull}},
{{1855356458336021858ull, 324856555176403ull}},
{{17725965592305276265ull, 519770488282244ull}},
{{17870121288586131335ull, 415816390625795ull}},
{{14296097030868905068ull, 332653112500636ull}},
{{15495057619906427463ull, 532244980001018ull}},
{{1327999651699411001ull, 425795984000815ull}},
{{1062399721359528800ull, 340636787200652ull}},
{{5389188368917156404ull, 545018859521043ull}},
{{11690048324617545770ull, 436015087616834ull}},
{{13041387474435946939ull, 348812070093467ull}},
{{6108824700129873809ull, 558099312149548ull}},
{{12265757389587719694ull, 446479449719638ull}},
{{17191303541153996401ull, 357183559775710ull}},
{{13753042832923197121ull, 285746847820568ull}},
{{18315519717935205071ull, 457194956512909ull}},
{{18341764589090074380ull, 365755965210327ull}},
{{7294714041788238857ull, 292604772168262ull}},
{{15360891281603092495ull, 468167635469219ull}},
{{15978061840024384319ull, 374534108375375ull}},
{{12782449472019507455ull, 299627286700300ull}},
{{2005175081521660313ull, 479403658720481ull}},
{{16361535324184969543ull, 383522926976384ull}},
{{16778577074089885957ull, 306818341581107ull}},
{{12088328059576176239ull, 490909346529772ull}},
{{2291964818177120345ull, 392727477223818ull}},
{{9212269484025516922ull, 314181981779054ull}},
{{3671584730215096106ull, 502691170846487ull}},
{{14005314228397807855ull, 402152936677189ull}},
{{14893600197460156607ull, 321722349341751ull}},
{{16451062686452429925ull, 514755758946802ull}},
{{5782152519678123293ull, 411804607157442ull}},
{{15693768459968229604ull, 329443685725953ull}},
{{2973936647497705428ull, 527109897161526ull}},
{{17136544576965805635ull, 421687917729220ull}},
{{13709235661572644508ull, 337350334183376ull}},
{{14556079429032410566ull, 539760534693402ull}},
{{4266165913742107807ull, 431808427754722ull}},
{{14480979175219417215ull, 345446742203777ull}},
{{8412171421383426251ull, 552714787526044ull}},
{{10419085951848651324ull, 442171830020835ull}},
{{8335268761478921059ull, 353737464016668ull}},
{{14046912638666957494ull, 282989971213334ull}},
{{11407013777641401020ull, 452783953941335ull}},
{{9125611022113120816ull, 362227163153068ull}},
{{14679186447174317299ull, 289781730522454ull}},
{{12418651871253176710ull, 463650768835927ull}},
{{2556223867518720721ull, 370920615068742ull}},
{{13113025538240707546ull, 296736492054993ull}},
{{17291492046443221751ull, 474778387287989ull}},
{{17522542451896487724ull, 379822709830391ull}},
{{10328685146775279856ull, 303858167864313ull}},
{{12836547420098537447ull, 486173068582901ull}},
{{6579889121336919634ull, 388938454866321ull}},
{{1574562482327625384ull, 311150763893057ull}},
{{6208648786466110938ull, 497841222228891ull}},
{{1277570214430978427ull, 398272977783113ull}},
{{8400753801028603388ull, 318618382226490ull}},
{{13441206081645765421ull, 509789411562384ull}},
{{14442313680058522660ull, 407831529249907ull}},
{{4175153314562997481ull, 326265223399926ull}},
{{17748291747526526940ull, 522024357439881ull}},
{{10509284583279311229ull, 417619485951905ull}},
{{8407427666623448983ull, 334095588761524ull}},
{{2383837822371787403ull, 534552942018439ull}},
{{5596419072639340246ull, 427642353614751ull}},
{{787786443369561873ull, 342113882891801ull}},
{{12328504753617029967ull, 547382212626881ull}},
{{6173454988151713650ull, 437905770101505ull}},
{{4938763990521370920ull, 350324616081204ull}},
{{15280720014318014119ull, 560519385729926ull}},
{{8535227196712500972ull, 448415508583941ull}},
{{3138832942628090454ull, 358732406867153ull}},
{{9889763983586293010ull, 286985925493722ull}},
{{1066227114770427523ull, 459177480789956ull}},
{{15610376950783983311ull, 367341984631964ull}},
{{16177650375369096972ull, 293873587705571ull}},
{{58798897397182893ull, 470197740328915ull}},
{{47039117917746314ull, 376158192263132ull}},
{{11105677738559928021ull, 300926553810505ull}},
{{17769084381695884834ull, 481482486096808ull}},
{{3147221061130976897ull, 385185988877447ull}},
{{13585823293130512487ull, 308148791101957ull}},
{{6979922010041178687ull, 493038065763132ull}},
{{16651984052258673919ull, 394430452610505ull}},
{{13321587241806939135ull, 315544362088404ull}},
{{10246493142665371647ull, 504870979341447ull}},
{{818496884648476671ull, 403896783473158ull}},
{{8033495137202601983ull, 323117426778526ull}},
{{5474894590040342527ull, 516987882845642ull}},
{{15447962116258004991ull, 413590306276513ull}},
{{1290323248780673023ull, 330872245021211ull}},
{{13132563642274807807ull, 529395592033937ull}},
{{3127353284336025599ull, 423516473627150ull}},
{{2501882627468820479ull, 338813178901720ull}},
{{4003012203950112767ull, 542101086242752ull}},
{{14270456207385821183ull, 433680868994201ull}},
{{7727016151166746623ull, 346944695195361ull}},
{{4984528212382973951ull, 555111512312578ull}},
{{11366320199390199807ull, 444089209850062ull}},
{{1714358530028339199ull, 355271367880050ull}},
{{1371486824022671359ull, 284217094304040ull}},
{{2194378918436274175ull, 454747350886464ull}},
{{5444851949490929663ull, 363797880709171ull}},
{{666532744850833407ull, 291038304567337ull}},
{{4755801206503243775ull, 465661287307739ull}},
{{7493989779944505343ull, 372529029846191ull}},
{{2305843009213693951ull, 298023223876953ull}},
{{18446744073709551615ull, 476837158203124ull}},
{{18446744073709551615ull, 381469726562499ull}},
{{18446744073709551615ull, 305175781249999ull}},
{{18446744073709551615ull, 488281249999999ull}},
{{18446744073709551615ull, 390624999999999ull}},
{{18446744073709551615ull, 312499999999999ull}},
{{18446744073709551615ull, 499999999999999ull}},
{{18446744073709551615ull, 399999999999999ull}},
{{18446744073709551615ull, 319999999999999ull}},
{{18446744073709551615ull, 511999999999999ull}},
{{18446744073709551615ull, 409599999999999ull}},
{{18446744073709551615ull, 327679999999999ull}},
{{18446744073709551615ull, 524287999999999ull}},
{{18446744073709551615ull, 419430399999999ull}},
{{18446744073709551615ull, 335544319999999ull}},
{{18446744073709551615ull, 536870911999999ull}},
{{18446744073709551615ull, 429496729599999ull}},
{{18446744073709551615ull, 343597383679999ull}},
{{18446744073709551615ull, 549755813887999ull}},
{{18446744073709551615ull, 439804651110399ull}},
{{18446744073709551615ull, 351843720888319ull}},
{{18446744073709551615ull, 281474976710655ull}},
{{11068046444225730969ull, 450359962737049ull}},
{{12543785970122495098ull, 360287970189639ull}},
{{13724377590839906402ull, 288230376151711ull}},
{{14580306515860029597ull, 461168601842738ull}},
{{596198768462292708ull, 368934881474191ull}},
{{15234354273737475459ull, 295147905179352ull}},
{{9617571579012319442ull, 472236648286964ull}},
{{11383406077951765876ull, 377789318629571ull}},
{{5417376047619502378ull, 302231454903657ull}},
{{12357150490933114128ull, 483570327845851ull}},
{{6196371578004580979ull, 386856262276681ull}},
{{1267748447661754460ull, 309485009821345ull}},
{{2028397516258807136ull, 495176015714152ull}},
{{12690764457232776679ull, 396140812571321ull}},
{{6463262751044311020ull, 316912650057057ull}},
{{14030569216412807955ull, 507060240091291ull}},
{{7535106558388336041ull, 405648192073033ull}},
{{13406782876194489479ull, 324518553658426ull}},
{{14072154972427362520ull, 519229685853482ull}},
{{3879026348458069369ull, 415383748682786ull}},
{{17860616337734096788ull, 332306998946228ull}},
{{6440893251923092922ull, 531691198313966ull}},
{{1463365786796564015ull, 425352958651173ull}},
{{8549390258921071858ull, 340282366920938ull}},
{{9989675599531804650ull, 544451787073501ull}},
{{4302391664883533397ull, 435561429658801ull}},
{{18199308590874468010ull, 348449143727040ull}},
{{10672149671689597200ull, 557518629963265ull}},
{{8537719737351677760ull, 446014903970612ull}},
{{17898222234107073178ull, 356811923176489ull}},
{{18007926602027568865ull, 285449538541191ull}},
{{2987240860050737922ull, 456719261665907ull}},
{{13457839132266321307ull, 365375409332725ull}},
{{10766271305813057046ull, 292300327466180ull}},
{{17226034089300891273ull, 467680523945888ull}},
{{2712780827214982049ull, 374144419156711ull}},
{{16927619920739626932ull, 299315535325368ull}},
{{4948098984731941152ull, 478904856520590ull}},
{{3958479187785552922ull, 383123885216472ull}},
{{14234829794454173307ull, 306499108173177ull}},
{{8018332412159035998ull, 490398573077084ull}},
{{10104014744469139122ull, 392318858461667ull}},
{{704514166091490651ull, 313855086769334ull}},
{{8505920295230205688ull, 502168138830934ull}},
{{10494085050926074874ull, 401734511064747ull}},
{{1016570411257039252ull, 321387608851798ull}},
{{16383907916978904097ull, 514220174162876ull}},
{{9417777518841212954ull, 411376139330301ull}},
{{3844873200331060040ull, 329100911464241ull}},
{{17219843564755427034ull, 526561458342785ull}},
{{13775874851804341627ull, 421249166674228ull}},
{{18399397510927293948ull, 336999333339382ull}},
{{14681640758516029024ull, 539198933343012ull}},
{{4366614977329002573ull, 431359146674410ull}},
{{3493291981863202058ull, 345087317339528ull}},
{{1899918356239212970ull, 552139707743245ull}},
{{1519934684991370376ull, 441711766194596ull}},
{{15973343006960737594ull, 353369412955676ull}},
{{9089325590826679752ull, 282695530364541ull}},
{{7164223315838866956ull, 452312848583266ull}},
{{2042029837929183242ull, 361850278866613ull}},
{{9012321499827167240ull, 289480223093290ull}},
{{14419714399723467584ull, 463168356949264ull}},
{{15225120334520684390ull, 370534685559411ull}},
{{8490747452874637189ull, 296427748447529ull}},
{{2517149480373688533ull, 474284397516047ull}},
{{13081766028524681796ull, 379427518012837ull}},
{{3086715193335924790ull, 303542014410270ull}},
{{4938744309337479665ull, 485667223056432ull}},
{{15019041891695714701ull, 388533778445145ull}},
{{12015233513356571761ull, 310827022756116ull}},
{{11845675991886694171ull, 497323236409786ull}},
{{5787191978767445014ull, 397858589127829ull}},
{{8319102397755866334ull, 318286871302263ull}},
{{9621215021667475812ull, 509258994083621ull}},
{{4007623202592070326ull, 407407195266897ull}},
{{14274145006299387230ull, 325925756213517ull}},
{{8081236751111378276ull, 521481209941628ull}},
{{13843687030372923267ull, 417184967953302ull}},
{{3696251994814517967ull, 333747974362642ull}},
{{9603352006445139071ull, 533996758980227ull}},
{{303983975672290610ull, 427197407184182ull}},
{{11311233624763563458ull, 341757925747345ull}},
{{18097973799621701533ull, 546812681195752ull}},
{{7099681410213540580ull, 437450144956602ull}},
{{16747791572396563433ull, 349960115965281ull}},
{{971024812641129231ull, 559936185544451ull}},
{{15534215109080544677ull, 447948948435560ull}},
{{12427372087264435742ull, 358359158748448ull}},
{{17320595299295369240ull, 286687326998758ull}},
{{5576859590421128845ull, 458699723198014ull}},
{{8150836487078813399ull, 366959778558411ull}},
{{2831320374921140396ull, 293567822846729ull}},
{{11908810229357645280ull, 469708516554766ull}},
{{5837699368744205901ull, 375766813243813ull}},
{{12048857124479185367ull, 300613450595050ull}},
{{831427325457144971ull, 480981520952081ull}},
{{15422537119333357270ull, 384785216761664ull}},
{{16027378510208596139ull, 307828173409331ull}},
{{18265107986849933176ull, 492525077454930ull}},
{{14612086389479946541ull, 394020061963944ull}},
{{15379017926325867556ull, 315216049571155ull}},
{{6159684608411836474ull, 504345679313849ull}},
{{8617096501471379502ull, 403476543451079ull}},
{{10583026015919013925ull, 322781234760863ull}},
{{13243492810728511957ull, 516449975617381ull}},
{{6905445433840899242ull, 413159980493905ull}},
{{5524356347072719393ull, 330527984395124ull}},
{{16217667784800171676ull, 528844775032198ull}},
{{1906087783614406371ull, 423075820025759ull}},
{{5214219041633435420ull, 338460656020607ull}},
{{12032099281355406996ull, 541537049632971ull}},
{{5936330610342415273ull, 433229639706377ull}},
{{15817110932499663188ull, 346583711765101ull}},
{{17928679862515640455ull, 554533938824162ull}},
{{6964246260528691717ull, 443627151059330ull}},
{{5571397008422953374ull, 354901720847464ull}},
{{8146466421480273022ull, 283921376677971ull}},
{{5655648644884616189ull, 454274202684754ull}},
{{8213867730649603275ull, 363419362147803ull}},
{{13949791814003503266ull, 290735489718242ull}},
{{7562271643437963933ull, 465176783549188ull}},
{{13428514944234191793ull, 372141426839350ull}},
{{10742811955387353434ull, 297713141471480ull}},
{{17188499128619765495ull, 476341026354368ull}},
{{2682752858670081426ull, 381072821083495ull}},
{{2146202286936065141ull, 304858256866796ull}},
{{14501970103323435195ull, 487773210986873ull}},
{{533529638433017186ull, 390218568789499ull}},
{{4116172525488324072ull, 312174855031599ull}},
{{13964573670265139162ull, 499479768050558ull}},
{{103612491986380360ull, 399583814440447ull}},
{{11150936437814835258ull, 319667051552357ull}},
{{3084103041536095120ull, 511467282483772ull}},
{{13535328877454607065ull, 409173825987017ull}},
{{3449565472479865006ull, 327339060789614ull}},
{{12898002385451604656ull, 523742497263382ull}},
{{2939704278877463078ull, 418993997810706ull}},
{{17109158682069611755ull, 335195198248564ull}},
{{16306607447085647839ull, 536312317197703ull}},
{{1977239513442787302ull, 429049853758163ull}},
{{8960489240238050488ull, 343239883006530ull}},
{{14336782784380880780ull, 549183812810448ull}},
{{401379783278973655ull, 439347050248359ull}},
{{4010452641365089247ull, 351477640198687ull}},
{{10106073040926053118ull, 562364224317899ull}},
{{11774207247482752818ull, 449891379454319ull}},
{{13108714612728112577ull, 359913103563455ull}},
{{10486971690182490062ull, 287930482850764ull}},
{{5711108260066253130ull, 460688772561223ull}},
{{11947584237536823150ull, 368551018048978ull}},
{{16936765019513279166ull, 294840814439182ull}},
{{12341428772253605373ull, 471745303102692ull}},
{{2494445388319063652ull, 377396242482154ull}},
{{5684905125397161245ull, 301916993985723ull}},
{{5406499385893547669ull, 483067190377157ull}},
{{15393245952940569105ull, 386453752301725ull}},
{{12314596762352455284ull, 309163001841380ull}},
{{1256610746054376838ull, 494660802946209ull}},
{{4694637411585411794ull, 395728642356967ull}},
{{14823756373494060404ull, 316582913885573ull}},
{{1581917309139034708ull, 506532662216918ull}},
{{8644231476795048413ull, 405226129773534ull}},
{{10604733996177949053ull, 324180903818827ull}},
{{2210179134917077193ull, 518689446110124ull}},
{{5457492122675572077ull, 414951556888099ull}},
{{8055342512882367985ull, 331961245510479ull}},
{{1820501576386057807ull, 531137992816767ull}},
{{12524447705334577215ull, 424910394253413ull}},
{{17398255793751482418ull, 339928315402730ull}},
{{9390465196292820253ull, 543885304644369ull}},
{{11201720971776166526ull, 435108243715495ull}},
{{8961376777420933221ull, 348086594972396ull}},
{{6959505214389672507ull, 556938551955834ull}},
{{9256952986253648329ull, 445550841564667ull}},
{{26864759519098016ull, 356440673251734ull}},
{{3710840622357188736ull, 285152538601387ull}},
{{9626693810513412301ull, 456244061762219ull}},
{{11390703863152640164ull, 364995249409775ull}},
{{9112563090522112131ull, 291996199527820ull}},
{{14580100944835379410ull, 467193919244512ull}},
{{4285383126384482882ull, 373755135395610ull}},
{{3428306501107586305ull, 299004108316488ull}},
{{1795941587030227766ull, 478406573306381ull}},
{{16194148528591823505ull, 382725258645104ull}},
{{16644667637615369127ull, 306180206916083ull}},
{{4495375331733128665ull, 489888331065734ull}},
{{7285649080128413255ull, 391910664852587ull}},
{{16896565708328461573ull, 313528531882069ull}},
{{15966458689099807548ull, 501645651011311ull}},
{{9083818136537935715ull, 401316520809049ull}},
{{10956403323972258895ull, 321053216647239ull}},
{{6462198874129883263ull, 513685146635583ull}},
{{12548456728787727257ull, 410948117308466ull}},
{{6349416568288271482ull, 328758493846773ull}},
{{6469717694519324048ull, 526013590154837ull}},
{{16243820599841190208ull, 420810872123869ull}},
{{16684405294614862490ull, 336648697699095ull}},
{{8248304397674228368ull, 538637916318553ull}},
{{13977341147623203341ull, 430910333054842ull}},
{{3803175288614742026ull, 344728266443874ull}},
{{13463778091267407888ull, 551565226310198ull}},
{{18149720102497746957ull, 441252181048158ull}},
{{3451729637772466596ull, 353001744838527ull}},
{{13829430154443704246ull, 282401395870821ull}},
{{14748390617626106148ull, 451842233393314ull}},
{{15488061308842795241ull, 361473786714651ull}},
{{8701100232332325870ull, 289179029371721ull}},
{{6543062742247900745ull, 462686446994754ull}},
{{8923799008540230919ull, 370149157595803ull}},
{{14517736836316005382ull, 296119326076642ull}},
{{8470983679137967319ull, 473790921722628ull}},
{{14155484572794194501ull, 379032737378102ull}},
{{3945690028751534954ull, 303226189902482ull}},
{{10002452860744366251ull, 485161903843971ull}},
{{4312613473853582677ull, 388129523075177ull}},
{{14518137223308597111ull, 310503618460141ull}},
{{15850321927809934732ull, 496805789536226ull}},
{{8990908727506037462ull, 397444631628981ull}},
{{3503378167262919646ull, 317955705303185ull}},
{{5605405067620671435ull, 508729128485096ull}},
{{794975239354626824ull, 406983302788077ull}},
{{11704026635709432429ull, 325586642230461ull}},
{{11347744987651271240ull, 520938627568738ull}},
{{16456893619604837639ull, 416750902054990ull}},
{{13165514895683870111ull, 333400721643992ull}},
{{6307428574126550885ull, 533441154630388ull}},
{{12424640488785061354ull, 426752923704310ull}},
{{9939712391028049083ull, 341402338963448ull}},
{{12214191010902968210ull, 546243742341517ull}},
{{2392655179238553922ull, 436994993873214ull}},
{{5603472958132753460ull, 349595995098571ull}},
{{1586859103528584890ull, 559353592157714ull}},
{{4958836097564778235ull, 447482873726171ull}},
{{277720063309912265ull, 357986298980937ull}},
{{11290222494873660782ull, 286389039184749ull}},
{{6996309547572126281ull, 458222462695599ull}},
{{9286396452799611348ull, 366577970156479ull}},
{{11118465976981599402ull, 293262376125183ull}},
{{14100196748428648720ull, 469219801800293ull}},
{{212110954517188006ull, 375375841440235ull}},
{{169688763613750405ull, 300300673152188ull}},
{{15028897280749641941ull, 480481077043500ull}},
{{12023117824599713552ull, 384384861634800ull}},
{{9618494259679770842ull, 307507889307840ull}},
{{15389590815487633347ull, 492012622892544ull}},
{{16001021467132017001ull, 393610098314035ull}},
{{12800817173705613601ull, 314888078651228ull}},
{{16791958663187071438ull, 503820925841965ull}},
{{13433566930549657150ull, 403056740673572ull}},
{{3368155914955905074ull, 322445392538858ull}},
{{1699700649187537795ull, 515912628062173ull}},
{{8738458148833850882ull, 412730102449738ull}},
{{14369464148550901352ull, 330184081959790ull}},
{{4544398563971890548ull, 528294531135665ull}},
{{3635518851177512438ull, 422635624908532ull}},
{{13976461525167740920ull, 338108499926825ull}},
{{3915594366558833856ull, 540973599882921ull}},
{{17889870752214708378ull, 432778879906336ull}},
{{10622547787029856379ull, 346223103925069ull}},
{{5928030015022039237ull, 553956966280111ull}},
{{1053075197275721066ull, 443165573024089ull}},
{{4531808972562487176ull, 354532458419271ull}},
{{18382842437017631034ull, 283625966735416ull}},
{{3587106196034837392ull, 453801546776667ull}},
{{13937731401053600883ull, 363041237421333ull}},
{{82138676617149737ull, 290432989937067ull}},
{{3820770697329349902ull, 464692783899307ull}},
{{14124663002089210891ull, 371754227119445ull}},
{{11299730401671368713ull, 297403381695556ull}},
{{10700871013190369294ull, 475845410712890ull}},
{{8560696810552295435ull, 380676328570312ull}},
{{17916603892667567318ull, 304541062856249ull}},
{{17598519784042376739ull, 487265700569999ull}},
{{17768164641975811714ull, 389812560455999ull}},
{{17903880528322559695ull, 311850048364799ull}},
{{17578162401090364542ull, 498960077383679ull}},
{{17751878735614201957ull, 399168061906943ull}},
{{3133456544265630596ull, 319334449525555ull}},
{{5013530470825008953ull, 510935119240888ull}},
{{11389522006143827809ull, 408748095392710ull}},
{{9111617604915062247ull, 326998476314168ull}},
{{10889239353122189273ull, 523197562102669ull}},
{{12400740297239661741ull, 418558049682135ull}},
{{9920592237791729393ull, 334846439745708ull}},
{{12183598765724856706ull, 535754303593133ull}},
{{17125576642063706011ull, 428603442874506ull}},
{{10011112498909054485ull, 342882754299605ull}},
{{16017779998254487177ull, 548612406879368ull}},
{{1746177554377858772ull, 438889925503495ull}},
{{1396942043502287017ull, 351111940402796ull}},
{{13303153713829390198ull, 561779104644473ull}},
{{18021220600547332804ull, 449423283715578ull}},
{{3348930036212135274ull, 359538626972463ull}},
{{10057841658453528865ull, 287630901577970ull}},
{{16092546653525646185ull, 460209442524752ull}},
{{5495339693336696301ull, 368167554019802ull}},
{{15464318198895088011ull, 294534043215841ull}},
{{17364211488748320171ull, 471254469145346ull}},
{{10202020376256745813ull, 377003575316277ull}},
{{782918671521576004ull, 301602860253022ull}},
{{4942018689176431930ull, 482564576404835ull}},
{{3953614951341145544ull, 386051661123868ull}},
{{10541589590556737082ull, 308841328899094ull}},
{{5798496900665048361ull, 494146126238551ull}},
{{949448705790128366ull, 395316900990841ull}},
{{15516954223599743985ull, 316253520792672ull}},
{{10069731498791949084ull, 506005633268276ull}},
{{4366436384291648944ull, 404804506614621ull}},
{{18250544366400960448ull, 323843605291696ull}},
{{3375429283048164454ull, 518149768466715ull}},
{{2700343426438531563ull, 414519814773372ull}},
{{13228321185376556220ull, 331615851818697ull}},
{{6407918637634848660ull, 530585362909916ull}},
{{1436986095365968605ull, 424468290327933ull}},
{{8528286505776595530ull, 339574632262346ull}},
{{6266560779758732202ull, 543319411619754ull}},
{{8702597438548896085ull, 434655529295803ull}},
{{14340775580322937514ull, 347724423436642ull}},
{{8187845669549058730ull, 556359077498628ull}},
{{13928974165123067630ull, 445087261998902ull}},
{{3764481702614633458ull, 356069809599122ull}},
{{14079631806317437736ull, 284855847679297ull}},
{{7770015631140259084ull, 455769356286876ull}},
{{2526663690170296944ull, 364615485029501ull}},
{{16778726211103878848ull, 291692388023600ull}},
{{8399217864056654541ull, 466707820837761ull}},
{{3030025476503413310ull, 373366256670209ull}},
{{6113369195944640971ull, 298693005336167ull}},
{{13470739528253335877ull, 477908808537867ull}},
{{3397893993118848055ull, 382327046830294ull}},
{{6407664009236988767ull, 305861637464235ull}},
{{10252262414779182028ull, 489378619942776ull}},
{{4512461117081435299ull, 391502895954221ull}},
{{18367364152632789532ull, 313202316763376ull}},
{{3562340941019090989ull, 501123706821403ull}},
{{10228570382299093437ull, 400898965457122ull}},
{{804158676355454103ull, 320719172365698ull}},
{{16044049141136367858ull, 513150675785116ull}},
{{9145890498167183963ull, 410520540628093ull}},
{{14695410028017567817ull, 328416432502474ull}},
{{12444609600602377538ull, 525466292003959ull}},
{{13645036495223812353ull, 420373033603167ull}},
{{3537331566695229236ull, 336298426882534ull}},
{{13038428136196187425ull, 538077483012054ull}},
{{14120091323698860263ull, 430461986409643ull}},
{{228026614733357241ull, 344369589127715ull}},
{{364842583573371585ull, 550991342604344ull}},
{{3981222881600607591ull, 440793074083475ull}},
{{3184978305280486073ull, 352634459266780ull}},
{{2547982644224388858ull, 282107567413424ull}},
{{11455469860242842820ull, 451372107861478ull}},
{{16543073517678094902ull, 361097686289182ull}},
{{5855761184658655275ull, 288878149031346ull}},
{{1990520265970027794ull, 462205038450154ull}},
{{5281765027517932559ull, 369764030760123ull}},
{{11604109651498166693ull, 295811224608098ull}},
{{14877226627655156386ull, 473297959372957ull}},
{{4523083672640304462ull, 378638367498366ull}},
{{18375862197079884863ull, 302910693998692ull}},
{{14643984256360174488ull, 484657110397908ull}},
{{647140960862408621ull, 387725688318327ull}},
{{11585759212915657866ull, 310180550654661ull}},
{{11158517111181231939ull, 496288881047458ull}},
{{16305511318428806198ull, 397031104837966ull}},
{{9355060240001134635ull, 317624883870373ull}},
{{11278747569259905093ull, 508199814192597ull}},
{{1644300425924103428ull, 406559851354078ull}},
{{8694137970223103389ull, 325247881083262ull}},
{{17599969567098875745ull, 520396609733219ull}},
{{17769324468421010919ull, 416317287786575ull}},
{{14215459574736808735ull, 333053830229260ull}},
{{4297991245869342361ull, 532886128366817ull}},
{{14506439440921204858ull, 426308902693453ull}},
{{537105108511232917ull, 341047122154763ull}},
{{15616763432585613960ull, 545675395447620ull}},
{{12493410746068491168ull, 436540316358096ull}},
{{6305379782112882611ull, 349232253086477ull}},
{{13777956466122522501ull, 558771604938363ull}},
{{18401062802381838647ull, 447017283950690ull}},
{{14720850241905470918ull, 357613827160552ull}},
{{4397982564040556088ull, 286091061728442ull}},
{{10726120917206800064ull, 457745698765507ull}},
{{1202199104281619405ull, 366196559012406ull}},
{{15719154542392936816ull, 292957247209924ull}},
{{14082600823602967937ull, 468731595535879ull}},
{{14955429473624284673ull, 374985276428703ull}},
{{896297134673696768ull, 299988221142963ull}},
{{16191470674445556122ull, 479981153828740ull}},
{{12953176539556444898ull, 383984923062992ull}},
{{2983843602161335272ull, 307187938450394ull}},
{{12152847392941957082ull, 491500701520630ull}},
{{9722277914353565665ull, 393200561216504ull}},
{{11467171146224762855ull, 314560448973203ull}},
{{14658125019217710245ull, 503296718357125ull}},
{{11726500015374168196ull, 402637374685700ull}},
{{9381200012299334557ull, 322109899748560ull}},
{{15009920019678935291ull, 515375839597696ull}},
{{8318587201001237910ull, 412300671678157ull}},
{{17722916205026721297ull, 329840537342525ull}},
{{9909921854333202460ull, 527744859748041ull}},
{{4238588668724651645ull, 422195887798433ull}},
{{10769568564463541962ull, 337756710238746ull}},
{{9852612073657846493ull, 540410736381994ull}},
{{11571438473668187518ull, 432328589105595ull}},
{{9257150778934550014ull, 345862871284476ull}},
{{7432743616811459376ull, 553380594055162ull}},
{{17014241337674898471ull, 442704475244129ull}},
{{17300741884881829100ull, 354163580195303ull}},
{{2772547063679732310ull, 283330864156243ull}},
{{746726487145661373ull, 453329382649989ull}},
{{4286730004458439422ull, 362663506119991ull}},
{{18186779262534392830ull, 290130804895992ull}},
{{14341451561087387235ull, 464209287833588ull}},
{{405114804644178819ull, 371367430266871ull}},
{{15081487102682984348ull, 297093944213496ull}},
{{16751681734808954310ull, 475350310741594ull}},
{{17090694202589073771ull, 380280248593275ull}},
{{13672555362071259017ull, 304224198874620ull}},
{{3429344505604462811ull, 486758718199393ull}},
{{10122173233967390895ull, 389406974559514ull}},
{{11787087401915823039ull, 311525579647611ull}},
{{11480642213581496217ull, 498440927436178ull}},
{{16563211400349017620ull, 398752741948942ull}},
{{5871871490795393449ull, 319002193559154ull}},
{{16773692014756450166ull, 510403509694646ull}},
{{9729604797063249809ull, 408322807755717ull}},
{{404986208166779201ull, 326658246204574ull}},
{{8026675562550667368ull, 522653193927318ull}},
{{13800038079524354541ull, 418122555141854ull}},
{{14729379278361393956ull, 334498044113483ull}},
{{1430913956926768390ull, 535196870581574ull}},
{{4834079980283325035ull, 428157496465259ull}},
{{7556612798968570351ull, 342525997172207ull}},
{{15779929293091622885ull, 548041595475531ull}},
{{8934594619731387985ull, 438433276380425ull}},
{{7147675695785110388ull, 350746621104340ull}},
{{11436281113256176621ull, 561194593766944ull}},
{{12838373705346851620ull, 448955675013555ull}},
{{10270698964277481296ull, 359164540010844ull}},
{{11905907986163895360ull, 287331632008675ull}},
{{602708704152680960ull, 459730611213881ull}},
{{15239562222289786061ull, 367784488971104ull}},
{{15880998592573739172ull, 294227591176883ull}},
{{3273504859666520736ull, 470764145883014ull}},
{{6308152702475126912ull, 376611316706411ull}},
{{1357173347238191206ull, 301289053365129ull}},
{{9550174985064926576ull, 482062485384206ull}},
{{3950791173310030938ull, 385649988307365ull}},
{{3160632938648024750ull, 308519990645892ull}},
{{8746361516578749924ull, 493631985033427ull}},
{{18065135657488730908ull, 394905588026741ull}},
{{10762759711249074403ull, 315924470421393ull}},
{{13531066723256608723ull, 505479152674229ull}},
{{14514202193347197301ull, 404383322139383ull}},
{{543315310452026871ull, 323506657711507ull}},
{{4558653311465153318ull, 517610652338411ull}},
{{18404317908139763947ull, 414088521870728ull}},
{{3655407882286080188ull, 331270817496583ull}},
{{2159303796915817977ull, 530033307994533ull}},
{{9106140667016475028ull, 424026646395626ull}},
{{3595563718871269699ull, 339221317116501ull}},
{{16820948394419762489ull, 542754107386401ull}},
{{9767409900793899668ull, 434203285909121ull}},
{{4124579105893209411ull, 347362628727297ull}},
{{10288675384171045381ull, 555780205963675ull}},
{{8230940307336836305ull, 444624164770940ull}},
{{6584752245869469044ull, 355699331816752ull}},
{{16335848240921306204ull, 284559465453401ull}},
{{311915482280717665ull, 455295144725443ull}},
{{7628230015308394778ull, 364236115780354ull}},
{{9791932826988626146ull, 291388892624283ull}},
{{11977743708439891510ull, 466222228198853ull}},
{{16960892596235733854ull, 372977782559082ull}},
{{6190016447504766437ull, 298382226047266ull}},
{{2525328686523805653ull, 477411561675626ull}},
{{16777658208186685815ull, 381929249340500ull}},
{{13422126566549348652ull, 305543399472400ull}},
{{3028658432769406228ull, 488869439155841ull}},
{{17180322005183166275ull, 391095551324672ull}},
{{6365559974662712373ull, 312876441059738ull}},
{{6495547144718429474ull, 500602305695581ull}},
{{1507088901032833256ull, 400481844556465ull}},
{{1205671120826266605ull, 320385475645172ull}},
{{5618422608063936891ull, 512616761032275ull}},
{{4494738086451149513ull, 410093408825820ull}},
{{3595790469160919610ull, 328074727060656ull}},
{{16821311194883202346ull, 524919563297049ull}},
{{17146397770648472200ull, 419935650637639ull}},
{{17406467031260688083ull, 335948520510111ull}},
{{2024905546823728671ull, 537517632816179ull}},
{{5309273252200893260ull, 430014106252943ull}},
{{11626116231244535254ull, 344011285002354ull}},
{{7533739525765525438ull, 550418056003767ull}},
{{17095038064838151320ull, 440334444803013ull}},
{{2607984007644790086ull, 352267555842411ull}},
{{16843782465083473361ull, 281814044673928ull}},
{{4813959055682095439ull, 450902471478286ull}},
{{161818429803766028ull, 360721977182629ull}},
{{3818803558584923146ull, 288577581746103ull}},
{{2420736878993966710ull, 461724130793765ull}},
{{1936589503195173368ull, 369379304635012ull}},
{{12617318046781869664ull, 295503443708009ull}},
{{9119662430625260493ull, 472805509932815ull}},
{{7295729944500208394ull, 378244407946252ull}},
{{16904630399825897685ull, 302595526357001ull}},
{{1221966936528064034ull, 484152842171203ull}},
{{8356271178706271873ull, 387322273736962ull}},
{{17753063387190748468ull, 309857818989569ull}},
{{17336854975279466580ull, 495772510383311ull}},
{{10180135165481662941ull, 396618008306649ull}},
{{11833456947127240676ull, 317294406645319ull}},
{{7865484671177854112ull, 507671050632511ull}},
{{2603038922200372966ull, 406136840506009ull}},
{{5771779952502208696ull, 324909472404807ull}},
{{12924196738745444237ull, 519855155847691ull}},
{{6650008576254445066ull, 415884124678153ull}},
{{12698704490487376699ull, 332707299742522ull}},
{{5560531925812161426ull, 532331679588036ull}},
{{759076725907818818ull, 425865343670429ull}},
{{4296610195468165377ull, 340692274936343ull}},
{{3185227498007154281ull, 545107639898149ull}},
{{6237530813147633748ull, 436086111918519ull}},
{{8679373465260017321ull, 348868889534815ull}},
{{13886997544416027714ull, 558190223255704ull}},
{{14798946850274732495ull, 446552178604563ull}},
{{771111035994055026ull, 357241742883651ull}},
{{15374284087762885313ull, 285793394306920ull}},
{{6152110466711064886ull, 457269430891073ull}},
{{12300386002852672555ull, 365815544712858ull}},
{{17219006431765958690ull, 292652435770286ull}},
{{1724968587632161642ull, 468243897232459ull}},
{{5069323684847639637ull, 374595117785967ull}},
{{15123505392103842679ull, 299676094228773ull}},
{{2061515738914686348ull, 479481750766038ull}},
{{9027910220615569724ull, 383585400612830ull}},
{{7222328176492455779ull, 306868320490264ull}},
{{487678638162198278ull, 490989312784423ull}},
{{7768840540013579269ull, 392791450227538ull}},
{{13593770061494684061ull, 314233160182030ull}},
{{3303288024681942882ull, 502773056291249ull}},
{{6331979234487464629ull, 402218445032999ull}},
{{8754932202331882026ull, 321774756026399ull}},
{{2939845079505280272ull, 514839609642239ull}},
{{6041224878346134541ull, 411871687713791ull}},
{{1143631087934997310ull, 329497350171033ull}},
{{16587204999663636988ull, 527195760273652ull}},
{{5891066370247088944ull, 421756608218922ull}},
{{15780899540423402125ull, 337405286575137ull}},
{{10492044005709802107ull, 539848458520220ull}},
{{8393635204567841686ull, 431878766816176ull}},
{{3025559348912363025ull, 345503013452941ull}},
{{15908941402485511810ull, 552804821524705ull}},
{{12727153121988409448ull, 442243857219764ull}},
{{13871071312332637882ull, 353795085775811ull}},
{{7407508235124199982ull, 283036068620649ull}},
{{783966731972989002ull, 452857709793039ull}},
{{4316522200320301525ull, 362286167834431ull}},
{{18210613019223882512ull, 289828934267544ull}},
{{18068934386532481051ull, 463726294828071ull}},
{{10765798694484074517ull, 370981035862457ull}},
{{1233941326103438967ull, 296784828689966ull}},
{{13042352565991233317ull, 474855725903945ull}},
{{10433882052792986654ull, 379884580723156ull}},
{{4657756827492479000ull, 303907664578525ull}},
{{7452410923987966400ull, 486252263325640ull}},
{{5961928739190373120ull, 389001810660512ull}},
{{15837589435578029465ull, 311201448528409ull}},
{{14272096652699116175ull, 497922317645455ull}},
{{11417677322159292940ull, 398337854116364ull}},
{{12823490672469344675ull, 318670283293091ull}},
{{13138887446467130834ull, 509872453268946ull}},
{{6821761142431794344ull, 407897962615157ull}},
{{16525455358171166445ull, 326318370092125ull}},
{{7993984499364314696ull, 522109392147401ull}},
{{2705838784749541434ull, 417687513717921ull}},
{{16922066286767274440ull, 334150010974336ull}},
{{1249864355634266841ull, 534640017558939ull}},
{{4689240299249323796ull, 427712014047151ull}},
{{62043424657548713ull, 342169611237721ull}},
{{11167315923677808911ull, 547471377980353ull}},
{{16312550368426067775ull, 437977102384282ull}},
{{5671342665257033574ull, 350381681907426ull}},
{{1695450634927433072ull, 560610691051882ull}},
{{12424406952167677427ull, 448488552841505ull}},
{{9939525561734141942ull, 358790842273204ull}},
{{11640969264129223876ull, 287032673818563ull}},
{{14936202007864847879ull, 459252278109701ull}},
{{8259612791549967980ull, 367401822487761ull}},
{{2918341418498064061ull, 293921457990209ull}},
{{12048043899080723144ull, 470274332784334ull}},
{{13327783934006488838ull, 376219466227467ull}},
{{3283529517721370424ull, 300975572981974ull}},
{{12632344857838013325ull, 481560916771158ull}},
{{17484573515754231307ull, 385248733416926ull}},
{{10298309997861474722ull, 308198986733541ull}},
{{9098598367094538909ull, 493118378773666ull}},
{{3589529878933720804ull, 394494703018933ull}},
{{10250321532630797289ull, 315595762415146ull}},
{{9021816822725455017ull, 504953219864234ull}},
{{10906802272922274337ull, 403962575891387ull}},
{{1346744188853998823ull, 323170060713110ull}},
{{2154790702166398117ull, 517072097140976ull}},
{{16481227820700759786ull, 413657677712780ull}},
{{13184982256560607829ull, 330926142170224ull}},
{{10027925166271241557ull, 529481827472359ull}},
{{11711688947758903569ull, 423585461977887ull}},
{{1990653528723302208ull, 338868369582310ull}},
{{3185045645957283534ull, 542189391331696ull}},
{{17305431775733468120ull, 433751513065356ull}},
{{10154996605844864172ull, 347001210452285ull}},
{{16247994569351782676ull, 555201936723656ull}},
{{9309046840739515818ull, 444161549378925ull}},
{{7447237472591612654ull, 355329239503140ull}},
{{5957789978073290123ull, 284263391602512ull}},
{{13221812779659174521ull, 454821426564019ull}},
{{14266799038469249940ull, 363857141251215ull}},
{{11413439230775399952ull, 291085713000972ull}},
{{3504107510272998630ull, 465737140801556ull}},
{{17560681267186040197ull, 372589712641244ull}},
{{17737893828490742480ull, 298071770112995ull}},
{{9933886051875636353ull, 476914832180793ull}},
{{15325806470984329729ull, 381531865744634ull}},
{{15949993991529374106ull, 305225492595707ull}},
{{10762595127479357277ull, 488360788153132ull}},
{{1231378472499665175ull, 390688630522506ull}},
{{15742498036967373433ull, 312550904418004ull}},
{{14119950414922066523ull, 500081447068807ull}},
{{3917262702453832572ull, 400065157655046ull}},
{{17891205420930707350ull, 320052126124036ull}},
{{2800486970295759499ull, 512083401798459ull}},
{{5929738390978517922ull, 409666721438767ull}},
{{15811837157008545307ull, 327733377151013ull}},
{{3162846562762210552ull, 524373403441622ull}},
{{13598323694435499411ull, 419498722753297ull}},
{{3499961326064578883ull, 335598978202638ull}},
{{1910589306961415889ull, 536958365124221ull}},
{{16285866704536774004ull, 429566692099376ull}},
{{9339344548887508880ull, 343653353679501ull}},
{{7564253648736193562ull, 549845365887202ull}},
{{17119449363214685819ull, 439876292709761ull}},
{{10006210675829838332ull, 351901034167809ull}},
{{11694317355405780989ull, 281520827334247ull}},
{{3953512509681608289ull, 450433323734796ull}},
{{17920205266712927924ull, 360346658987836ull}},
{{10646815398628432016ull, 288277327190269ull}},
{{5966858193579760256ull, 461243723504431ull}},
{{1084137740121897882ull, 368994978803545ull}},
{{867310192097518305ull, 295195983042836ull}},
{{12455742751581760258ull, 472313572868537ull}},
{{2585896571781587560ull, 377850858294830ull}},
{{2068717257425270048ull, 302280686635864ull}},
{{10688645241364252724ull, 483649098617382ull}},
{{1172218563607581532ull, 386919278893906ull}},
{{15695170109853706519ull, 309535423115124ull}},
{{14044225731540199461ull, 495256676984199ull}},
{{14924729399974069892ull, 396205341587359ull}},
{{15629132334721166236ull, 316964273269887ull}},
{{10249216476586224686ull, 507142837231820ull}},
{{8199373181268979748ull, 405714269785456ull}},
{{2870149730273273475ull, 324571415828365ull}},
{{4592239568437237561ull, 519314265325384ull}},
{{7363140469491700372ull, 415451412260307ull}},
{{16958558819819091267ull, 332361129808245ull}},
{{8686950038000994412ull, 531777807693193ull}},
{{14328257659884616176ull, 425422246154554ull}},
{{15151954942649603264ull, 340337796923643ull}},
{{2107035019787903283ull, 544540475077830ull}},
{{1685628015830322626ull, 435632380062264ull}},
{{5037851227406168424ull, 348505904049811ull}},
{{681864334366048832ull, 557609446479698ull}},
{{7924189096976659712ull, 446087557183758ull}},
{{13718048907065148416ull, 356870045747006ull}},
{{7285090310910208409ull, 285496036597605ull}},
{{11656144497456333455ull, 456793658556168ull}},
{{16703613227448887411ull, 365434926844934ull}},
{{17052239396701020252ull, 292347941475947ull}},
{{12526187775753991110ull, 467756706361516ull}},
{{6331601405861282565ull, 374205365089213ull}},
{{12443978754172846698ull, 299364292071370ull}},
{{1463621932967003101ull, 478982867314193ull}},
{{8549595175857423127ull, 383186293851354ull}},
{{10529024955427848825ull, 306549035081083ull}},
{{13157091113942647797ull, 490478456129733ull}},
{{17904370520637938884ull, 392382764903786ull}},
{{10634147601768440784ull, 313906211923029ull}},
{{5946589718603774285ull, 502249939076847ull}},
{{15825318219108750397ull, 401799951261477ull}},
{{5281556945803179671ull, 321439961009182ull}},
{{12139839928026997798ull, 514303937614691ull}},
{{6022523127679687915ull, 411443150091753ull}},
{{12196716131627570978ull, 329154520073402ull}},
{{4757350551636472273ull, 526647232117444ull}},
{{7495229256051088141ull, 421317785693955ull}},
{{5996183404840870513ull, 337054228555164ull}},
{{16972591077229213467ull, 539286765688262ull}},
{{6199375232299550127ull, 431429412550610ull}},
{{4959500185839640102ull, 345143530040488ull}},
{{4245851482601513840ull, 552229648064781ull}},
{{18154076445048852365ull, 441783718451824ull}},
{{18212609970780992215ull, 353426974761459ull}},
{{18259436791366704095ull, 282741579809167ull}},
{{14457703607219085259ull, 452386527694668ull}},
{{498116441549537238ull, 361909222155735ull}},
{{398493153239629790ull, 289527377724588ull}},
{{15394984304151048957ull, 463243804359340ull}},
{{12315987443320839166ull, 370595043487472ull}},
{{2474092325172850686ull, 296476034789978ull}},
{{269198905534650775ull, 474361655663965ull}},
{{215359124427720620ull, 379489324531172ull}},
{{11240333743767907465ull, 303591459624937ull}},
{{3227138731061010652ull, 485746335399900ull}},
{{2581710984848808522ull, 388597068319920ull}},
{{2065368787879046817ull, 310877654655936ull}},
{{14372636504832205877ull, 497404247449497ull}},
{{4119411574381944055ull, 397923397959598ull}},
{{10674226888989375891ull, 318338718367678ull}},
{{13389414207641091102ull, 509341949388285ull}},
{{10711531366112872882ull, 407473559510628ull}},
{{15947922722374118952ull, 325978847608502ull}},
{{10759281096830949030ull, 521566156173604ull}},
{{12296773692206669547ull, 417252924938883ull}},
{{17216116583249156284ull, 333802339951106ull}},
{{1720344830005277792ull, 534083743921771ull}},
{{16133671122971863527ull, 427266995137416ull}},
{{9217588083635580498ull, 341813596109933ull}},
{{11058792119075018474ull, 546901753775893ull}},
{{16225731324743835425ull, 437521403020714ull}},
{{16669933874536978663ull, 350017122416571ull}},
{{846452496065793599ull, 560027395866515ull}},
{{677161996852634879ull, 448021916693212ull}},
{{11609776041707838873ull, 358417533354569ull}},
{{12977169648108181421ull, 286734026683655ull}},
{{2316727363263538659ull, 458774442693849ull}},
{{5542730705352741250ull, 367019554155079ull}},
{{8123533379024103323ull, 293615643324063ull}},
{{9308304591696654994ull, 469785029318501ull}},
{{3757294858615413672ull, 375828023454801ull}},
{{17763231145859972230ull, 300662418763840ull}},
{{9974425759666403953ull, 481059870022145ull}},
{{7979540607733123162ull, 384847896017716ull}},
{{2694283671444588206ull, 307878316814173ull}},
{{621505059569430807ull, 492605306902677ull}},
{{11565250491881275615ull, 394084245522141ull}},
{{5562851578763110169ull, 315267396417713ull}},
{{5211213711279065947ull, 504427834268341ull}},
{{479622154281342435ull, 403542267414673ull}},
{{7762395352908894594ull, 322833813931738ull}},
{{8730483749912321028ull, 516534102290781ull}},
{{3295038185187946499ull, 413227281832625ull}},
{{2636030548150357199ull, 330581825466100ull}},
{{4217648877040571519ull, 528930920745760ull}},
{{3374119101632457215ull, 423144736596608ull}},
{{10077992910789786418ull, 338515789277286ull}},
{{8746091027779837623ull, 541625262843658ull}},
{{14375570451707690745ull, 433300210274926ull}},
{{7811107546624242272ull, 346640168219941ull}},
{{5119074445114966990ull, 554624269151906ull}},
{{405910741350063268ull, 443699415321525ull}},
{{324728593080050615ull, 354959532257220ull}},
{{259782874464040492ull, 283967625805776ull}},
{{11483699043368195756ull, 454348201289241ull}},
{{5497610419952646282ull, 363478561031393ull}},
{{11776785965445937672ull, 290782848825114ull}},
{{7774811100487769306ull, 465252558120183ull}},
{{13598546509874036091ull, 372202046496146ull}},
{{7189488393157318549ull, 297761637196917ull}},
{{15192530243793620002ull, 476418619515067ull}},
{{4775326565551075355ull, 381134895612054ull}},
{{7509610067182770607ull, 304907916489643ull}},
{{8326027292750522649ull, 487852666383429ull}},
{{10350170648942328442ull, 390282133106743ull}},
{{15658834148637683400ull, 312225706485394ull}},
{{13986088193594562471ull, 499561130376631ull}},
{{7499521740133739653ull, 399648904301305ull}},
{{5999617392106991723ull, 319719123441044ull}},
{{16978085456855007403ull, 511550597505670ull}},
{{13582468365484005922ull, 409240478004536ull}},
{{7176625877645294415ull, 327392382403629ull}},
{{414554960006740094ull, 523827811845807ull}},
{{11399690412231123045ull, 419062249476645ull}},
{{9119752329784898436ull, 335249799581316ull}},
{{7212906098172016851ull, 536399679330106ull}},
{{2080976063795703157ull, 429119743464085ull}},
{{1664780851036562526ull, 343295794771268ull}},
{{17421044620626141334ull, 549273271634028ull}},
{{2868789252275182098ull, 439418617307223ull}},
{{9673729031303966325ull, 351534893845778ull}},
{{11788617635344435796ull, 562455830153245ull}},
{{9430894108275548637ull, 449964664122596ull}},
{{3855366471878528586ull, 359971731298077ull}},
{{14152339621728553839ull, 287977385038461ull}},
{{15265045765281865496ull, 460763816061538ull}},
{{1143990167999761427ull, 368611052849231ull}},
{{15672587393367450434ull, 294888842279384ull}},
{{14008093385162189725ull, 471822147647015ull}},
{{11206474708129751780ull, 377457718117612ull}},
{{1586482137019980778ull, 301966174494090ull}},
{{2538371419231969244ull, 483145879190544ull}},
{{5720045950127485719ull, 386516703352435ull}},
{{4576036760101988575ull, 309213362681948ull}},
{{3632310001421271397ull, 494741380291117ull}},
{{13973894445362748087ull, 395793104232893ull}},
{{111069112064467500ull, 316634483386315ull}},
{{177710579303148000ull, 506615173418104ull}},
{{3831517278184428723ull, 405292138734483ull}},
{{10443911452031363625ull, 324233710987586ull}},
{{9331560693766361154ull, 518773937580138ull}},
{{14843946184496909569ull, 415019150064110ull}},
{{11875156947597527655ull, 332015320051288ull}},
{{15310902301414133926ull, 531224512082061ull}},
{{8559373026389396817ull, 424979609665649ull}},
{{10536847235853427777ull, 339983687732519ull}},
{{5790909133139753474ull, 543973900372031ull}},
{{943378491769892456ull, 435179120297625ull}},
{{754702793415913964ull, 348143296238100ull}},
{{1207524469465462343ull, 557029273980960ull}},
{{966019575572369875ull, 445623419184768ull}},
{{8151513289941716546ull, 356498735347814ull}},
{{10210559446695283560ull, 285198988278251ull}},
{{8958197485228633050ull, 456318381245202ull}},
{{18234604432408637409ull, 365054704996161ull}},
{{10898334731184999604ull, 292043763996929ull}},
{{6369289125670268397ull, 467270022395087ull}},
{{16163477744761945687ull, 373816017916069ull}},
{{16620131010551466873ull, 299052814332855ull}},
{{8145465543172795381ull, 478484502932569ull}},
{{10205721249280146628ull, 382787602346055ull}},
{{8164576999424117302ull, 306230081876844ull}},
{{1995276754852856714ull, 489968131002951ull}},
{{16353616662849926664ull, 391974504802360ull}},
{{13082893330279941331ull, 313579603841888ull}},
{{17243280513705995807ull, 501727366147021ull}},
{{10105275596222886322ull, 401381892917617ull}},
{{705522847494488411ull, 321105514334094ull}},
{{8507534185475002105ull, 513768822934550ull}},
{{6806027348380001684ull, 411015058347640ull}},
{{5444821878704001347ull, 328812046678112ull}},
{{12401063820668312478ull, 526099274684979ull}},
{{13610199871276560306ull, 420879419747983ull}},
{{18266857526505068891ull, 336703535798386ull}},
{{3401530339214737964ull, 538725657277419ull}},
{{6410573086113700694ull, 430980525821935ull}},
{{5128458468890960555ull, 344784420657548ull}},
{{4516184735483626565ull, 551655073052077ull}},
{{14680994232612632222ull, 441324058441661ull}},
{{8055446571348195454ull, 353059246753329ull}},
{{10133706071820466686ull, 282447397402663ull}},
{{12524580900170836375ull, 451915835844261ull}},
{{6330315905394758777ull, 361532668675409ull}},
{{8753601539057717345ull, 289226134940327ull}},
{{17695111277234258075ull, 462761815904523ull}},
{{3088042577561675490ull, 370209452723619ull}},
{{6159782876791250715ull, 296167562178895ull}},
{{9855652602866001145ull, 473868099486232ull}},
{{505824452808980269ull, 379094479588986ull}},
{{15162054821214825508ull, 303275583671188ull}},
{{2123194825492258874ull, 485240933873902ull}},
{{12766602304619538069ull, 388192747099121ull}},
{{6523933028953720132ull, 310554197679297ull}},
{{14127641661067862534ull, 496886716286875ull}},
{{11302113328854290027ull, 397509373029500ull}},
{{9041690663083432022ull, 318007498423600ull}},
{{14466705060933491235ull, 508811997477760ull}},
{{11573364048746792988ull, 407049597982208ull}},
{{16637388868481255037ull, 325639678385766ull}},
{{794380486376635797ull, 521023485417227ull}},
{{11703550833327039607ull, 416818788333781ull}},
{{5673491851919721362ull, 333455030667025ull}},
{{9077586963071554180ull, 533528049067240ull}},
{{7262069570457243344ull, 426822439253792ull}},
{{16877702100591525644ull, 341457951403033ull}},
{{4868230472494979092ull, 546332722244854ull}},
{{7583933192737893597ull, 437066177795883ull}},
{{13445844183674135524ull, 349652942236706ull}},
{{14134653064394796192ull, 559444707578730ull}},
{{11307722451515836953ull, 447555766062984ull}},
{{12735526775954579886ull, 358044612850387ull}},
{{2809723791279843262ull, 286435690280310ull}},
{{4495558066047749220ull, 458297104448496ull}},
{{18353841711805840668ull, 366637683558796ull}},
{{10993724554702762211ull, 293310146847037ull}},
{{2832564028556778246ull, 469296234955260ull}},
{{2266051222845422597ull, 375436987964208ull}},
{{9191538607760158724ull, 300349590371366ull}},
{{7327764142932433312ull, 480559344594186ull}},
{{2172862499604036326ull, 384447475675349ull}},
{{5427638814425139384ull, 307557980540279ull}},
{{16062919732564043661ull, 492092768864446ull}},
{{9160986971309324605ull, 393674215091557ull}},
{{18396836021273190654ull, 314939372073245ull}},
{{10988193560327553430ull, 503902995317193ull}},
{{16169252477745863391ull, 403122396253754ull}},
{{16624750796938601036ull, 322497917003003ull}},
{{4463508386650299718ull, 515996667204806ull}},
{{18328201968287881067ull, 412797333763844ull}},
{{18351910389372215177ull, 330237867011075ull}},
{{10916312549285992667ull, 528380587217721ull}},
{{5043701224686883811ull, 422704469774177ull}},
{{15103007423975238018ull, 338163575819341ull}},
{{16786114248876560183ull, 541061721310946ull}},
{{9739542584359337823ull, 432849377048757ull}},
{{412936438003649612ull, 346279501639006ull}},
{{11728744745031570349ull, 554047202622409ull}},
{{13072344610767166602ull, 443237762097927ull}},
{{3079178059129912635ull, 354590209678342ull}},
{{13531388891529661078ull, 283672167742673ull}},
{{17960873411705547401ull, 453875468388277ull}},
{{6990001099880617274ull, 363100374710622ull}},
{{16660047324130224789ull, 290480299768497ull}},
{{11898680459640718370ull, 464768479629596ull}},
{{5829595552970664373ull, 371814783703677ull}},
{{15731722886602262468ull, 297451826962941ull}},
{{17792058989079799302ull, 475922923140706ull}},
{{10544298376521929118ull, 380738338512565ull}},
{{8435438701217543295ull, 304590670810052ull}},
{{17186050736689979595ull, 487345073296083ull}},
{{2680794145126252706ull, 389876058636867ull}},
{{13212681760326733135ull, 311900846909493ull}},
{{17450942001780862692ull, 499041355055189ull}},
{{17650102416166600477ull, 399233084044151ull}},
{{10430733118191370058ull, 319386467235321ull}},
{{9310475359622371447ull, 511018347576514ull}},
{{11137729102439807481ull, 408814678061211ull}},
{{5220834467209935661ull, 327051742448969ull}},
{{15732032777019717705ull, 523282787918350ull}},
{{12585626221615774164ull, 418626230334680ull}},
{{10068500977292619331ull, 334900984267744ull}},
{{5041555119442459960ull, 535841574828391ull}},
{{343895280812057645ull, 428673259862713ull}},
{{7653813854133466762ull, 342938607890170ull}},
{{12246102166613546820ull, 548701772624272ull}},
{{2418184103807016809ull, 438961418099418ull}},
{{9313244912529434094ull, 351169134479534ull}},
{{3833145415821363581ull, 561870615167255ull}},
{{3066516332657090864ull, 449496492133804ull}},
{{6142561880867583015ull, 359597193707043ull}},
{{12292747134177887058ull, 287677754965634ull}},
{{8600348970458888324ull, 460284407945015ull}},
{{6880279176367110659ull, 368227526356012ull}},
{{16572269785319419497ull, 294582021084809ull}},
{{15447585212285340225ull, 471331233735695ull}},
{{12358068169828272180ull, 377064986988556ull}},
{{6197105721120707421ull, 301651989590845ull}},
{{9915369153793131873ull, 482643183345352ull}},
{{553597693550684852ull, 386114546676282ull}},
{{11510924599066278851ull, 308891637341025ull}},
{{18417479358506046162ull, 494226619745640ull}},
{{14733983486804836930ull, 395381295796512ull}},
{{4408489159960048897ull, 316305036637210ull}},
{{7053582655936078236ull, 506088058619536ull}},
{{1953517310006952266ull, 404870446895629ull}},
{{5252162662747472136ull, 323896357516503ull}},
{{4714111445654045094ull, 518234172026405ull}},
{{3771289156523236075ull, 414587337621124ull}},
{{6706380139960499183ull, 331669870096899ull}},
{{18108905853420619340ull, 530671792155038ull}},
{{3419078238510764502ull, 424537433724031ull}},
{{17492657849776252894ull, 339629946979224ull}},
{{16920206115416273662ull, 543407915166759ull}},
{{17225513707074929252ull, 434726332133407ull}},
{{6401713336176122755ull, 347781065706726ull}},
{{2864043708397975763ull, 556449705130762ull}},
{{13359281410944111580ull, 445159764104609ull}},
{{14376773943497199587ull, 356127811283687ull}},
{{4122721525313939023ull, 284902249026950ull}},
{{6596354440502302437ull, 455843598443120ull}},
{{5277083552401841949ull, 364674878754496ull}},
{{532318027179563236ull, 291739903003597ull}},
{{4541057658229211502ull, 466783844805755ull}},
{{3632846126583369201ull, 373427075844604ull}},
{{6595625716008605684ull, 298741660675683ull}},
{{6863652330871858772ull, 477986657081093ull}},
{{12869619494181307664ull, 382389325664874ull}},
{{13985044410086956454ull, 305911460531899ull}},
{{11308024611913399357ull, 489458336851039ull}},
{{12735768504272629809ull, 391566669480831ull}},
{{6499265988676193524ull, 313253335584665ull}},
{{10398825581881909638ull, 501205336935464ull}},
{{12008409280247438034ull, 400964269548371ull}},
{{5917378609456040104ull, 320771415638697ull}},
{{13157154589871574489ull, 513234265021915ull}},
{{10525723671897259591ull, 410587412017532ull}},
{{1041881308033987027ull, 328469929614026ull}},
{{12735056537080110212ull, 525551887382441ull}},
{{6498696414922177847ull, 420441509905953ull}},
{{12577654761421562924ull, 336353207924762ull}},
{{5366852359306859385ull, 538165132679620ull}},
{{4293481887445487508ull, 430532106143696ull}},
{{18192180768924031299ull, 344425684914956ull}},
{{3282047527085077817ull, 551081095863931ull}},
{{17383033280635703546ull, 440864876691144ull}},
{{17595775439250473160ull, 352691901352915ull}},
{{14076620351400378528ull, 282153521082332ull}},
{{7765197303272964352ull, 451445633731732ull}},
{{17280204286844102451ull, 361156506985385ull}},
{{13824163429475281961ull, 288925205588308ull}},
{{18429312672418540814ull, 462280328941293ull}},
{{3675403693709101682ull, 369824263153035ull}},
{{2940322954967281345ull, 295859410522428ull}},
{{1015167913205739830ull, 473375056835885ull}},
{{812134330564591864ull, 378700045468708ull}},
{{8028405093935494137ull, 302960036374966ull}},
{{5466750520812969973ull, 484736058199946ull}},
{{684051601908465655ull, 387788846559957ull}},
{{11615287725752503494ull, 310231077247965ull}},
{{137716287494453974ull, 496369723596745ull}},
{{110173029995563179ull, 397095778877396ull}},
{{14845533682964091836ull, 317676623101916ull}},
{{16374156263258726292ull, 508282596963066ull}},
{{9409976195865070710ull, 406626077570453ull}},
{{14906678586175877214ull, 325300862056362ull}},
{{9093290478913762251ull, 520481379290180ull}},
{{7274632383131009800ull, 416385103432144ull}},
{{9509054721246718163ull, 333108082745715ull}},
{{15214487553994749062ull, 532972932393144ull}},
{{15860938857937709572ull, 426378345914515ull}},
{{12688751086350167658ull, 341102676731612ull}},
{{5544606479192626960ull, 545764282770580ull}},
{{4435685183354101568ull, 436611426216464ull}},
{{7237896961425191577ull, 349289140973171ull}},
{{4201937508796485878ull, 558862625557074ull}},
{{7050898821779099025ull, 447090100445659ull}},
{{9330067872165189543ull, 357672080356527ull}},
{{85356668248330988ull, 286137664285222ull}},
{{3825919483939239905ull, 457820262856355ull}},
{{3060735587151391924ull, 366256210285084ull}},
{{6137937284463023862ull, 293004968228067ull}},
{{13510048469882748503ull, 468807949164907ull}},
{{3429341146422378156ull, 375046359331926ull}},
{{17500868176105543817ull, 300037087465540ull}},
{{9554645008059318492ull, 480059339944865ull}},
{{7643716006447454793ull, 384047471955892ull}},
{{17183019249383694804ull, 307237977564713ull}},
{{5356737910562449748ull, 491580764103542ull}},
{{15353436772675690768ull, 393264611282833ull}},
{{1214702973914821645ull, 314611689026267ull}},
{{5632873573005624955ull, 503378702442027ull}},
{{15574345302630230933ull, 402702961953621ull}},
{{8770127427362274423ull, 322162369562897ull}},
{{17721552698521549401ull, 515459791300635ull}},
{{14177242158817239521ull, 412367833040508ull}},
{{273747282828060647ull, 329894266432407ull}},
{{4127344467266807358ull, 527830826291851ull}},
{{18059270832781087179ull, 422264661033480ull}},
{{14447416666224869743ull, 337811728826784ull}},
{{12047820221734060620ull, 540498766122855ull}},
{{9638256177387248496ull, 432399012898284ull}},
{{11399953756651709120ull, 345919210318627ull}},
{{3482530751675093299ull, 553470736509804ull}},
{{6475373416081984963ull, 442776589207843ull}},
{{12558996362349408616ull, 354221271366274ull}},
{{13736545904621437216ull, 283377017093019ull}},
{{10910427003168568577ull, 453403227348831ull}},
{{5038992787792944538ull, 362722581879065ull}},
{{4031194230234355630ull, 290178065503252ull}},
{{10139259583116879332ull, 464284904805203ull}},
{{15490105295977324112ull, 371427923844162ull}},
{{5013386607298038643ull, 297142339075330ull}},
{{8021418571676861829ull, 475427742520528ull}},
{{13795832486825310110ull, 380342194016422ull}},
{{3657968359976427441ull, 304273755213138ull}},
{{2163400561220373583ull, 486838008341021ull}},
{{16488115707943940159ull, 389470406672816ull}},
{{9501143751613241804ull, 311576325338253ull}},
{{11512481187839276563ull, 498522120541205ull}},
{{9209984950271421251ull, 398817696432964ull}},
{{11057336774959047324ull, 319054157146371ull}},
{{10313041210450655072ull, 510486651434194ull}},
{{11939781783102434380ull, 408389321147355ull}},
{{9551825426481947504ull, 326711456917884ull}},
{{4214874238145385037ull, 522738331068615ull}},
{{3371899390516308030ull, 418190664854892ull}},
{{13765565956638777393ull, 334552531883913ull}},
{{18335556715880133507ull, 535284051014261ull}},
{{10979096557962196482ull, 428227240811409ull}},
{{12472626061111667509ull, 342581792649127ull}},
{{5198806438811026721ull, 548130868238604ull}},
{{7848393965790731700ull, 438504694590883ull}},
{{13657412802116406006ull, 350803755672706ull}},
{{14473162853902428964ull, 561286009076330ull}},
{{11578530283121943171ull, 449028807261064ull}},
{{12952173041239464860ull, 359223045808851ull}},
{{6672389618249661565ull, 287378436647081ull}},
{{3297125759715637858ull, 459805498635330ull}},
{{2637700607772510286ull, 367844398908264ull}},
{{5799509300959918552ull, 294275519126611ull}},
{{1900517252052049037ull, 470840830602578ull}},
{{8899111431125459876ull, 376672664482062ull}},
{{18187335589126098870ull, 301338131585649ull}},
{{18031690498376027223ull, 482141010537039ull}},
{{18114701213442732101ull, 385712808429631ull}},
{{10802412156012275358ull, 308570246743705ull}},
{{17283859449619640573ull, 493712394789928ull}},
{{2759041115469981489ull, 394969915831943ull}},
{{9585930521859805837ull, 315975932665554ull}},
{{4269442390749958370ull, 505561492264887ull}},
{{14483600356825697666ull, 404449193811909ull}},
{{15276229100202468456ull, 323559355049527ull}},
{{9684571301356308236ull, 517694968079244ull}},
{{11437005855826956912ull, 414155974463395ull}},
{{9149604684661565530ull, 331324779570716ull}},
{{7260669865974684201ull, 530119647313146ull}},
{{2119187078037837038ull, 424095717850517ull}},
{{12763396106656000600ull, 339276574280413ull}},
{{16732084955907690637ull, 542842518848661ull}},
{{9696319149984242186ull, 434274015078929ull}},
{{11446404134729304072ull, 347419212063143ull}},
{{14624897800824976192ull, 555870739301029ull}},
{{15389267055401891277ull, 444696591440823ull}},
{{1243367200095782052ull, 355757273152659ull}},
{{4684042574818535965ull, 284605818522127ull}},
{{11183816934451567867ull, 455369309635403ull}},
{{16325751177045074940ull, 364295447708322ull}},
{{5681903312152239305ull, 291436358166658ull}},
{{5401696484701672566ull, 466298173066653ull}},
{{11700054817245158699ull, 373038538453322ull}},
{{1981346224312306313ull, 298430830762658ull}},
{{17927549217867331393ull, 477489329220252ull}},
{{6963341744810044468ull, 381991463376202ull}},
{{16638719840073766544ull, 305593170700961ull}},
{{796510040924654208ull, 488949073121539ull}},
{{4326556847481633690ull, 391159258497231ull}},
{{18218640736952948244ull, 312927406797784ull}},
{{18081778734898986222ull, 500683850876455ull}},
{{14465422987919188977ull, 400547080701164ull}},
{{15261687205077261505ull, 320437664560931ull}},
{{17040001898639797762ull, 512700263297490ull}},
{{13632001518911838209ull, 410160210637992ull}},
{{3526903585645649921ull, 328128168510394ull}},
{{13021743366516860520ull, 525005069616630ull}},
{{10417394693213488416ull, 420004055693304ull}},
{{12023264569312701056ull, 336003244554643ull}},
{{15547874496158411367ull, 537605191287429ull}},
{{16127648411668639416ull, 430084153029943ull}},
{{1834072285109180563ull, 344067322423955ull}},
{{2934515656174688902ull, 550507715878328ull}},
{{9726310154423571768ull, 440406172702662ull}},
{{402350494055036768ull, 352324938162130ull}},
{{321880395244029414ull, 281859950529704ull}},
{{7893706261874267709ull, 450975920847526ull}},
{{2625616194757503844ull, 360780736678021ull}},
{{16857888214773644368ull, 288624589342416ull}},
{{1147179440444458727ull, 461799342947867ull}},
{{11985789996581297951ull, 369439474358293ull}},
{{16967329626748859007ull, 295551579486634ull}},
{{16079680958572443442ull, 472882527178615ull}},
{{12863744766857954753ull, 378306021742892ull}},
{{2912298184002543156ull, 302644817394314ull}},
{{12038374723887889697ull, 484231707830902ull}},
{{2252002149626491111ull, 387385366264722ull}},
{{12869648163926923858ull, 309908293011777ull}},
{{5834041803315436880ull, 495853268818844ull}},
{{8356582257394259827ull, 396682615055075ull}},
{{6685265805915407862ull, 317346092044060ull}},
{{10696425289464652579ull, 507753747270496ull}},
{{4867791416829811740ull, 406202997816397ull}},
{{14962279577689580362ull, 324962398253117ull}},
{{9182252065335687286ull, 519939837204988ull}},
{{14724499281752370475ull, 415951869763990ull}},
{{11779599425401896380ull, 332761495811192ull}},
{{4089963821675392916ull, 532418393297908ull}},
{{10650668686824134979ull, 425934714638326ull}},
{{4831186134717397660ull, 340747771710661ull}},
{{351200186064015609ull, 545196434737058ull}},
{{7659657778335033134ull, 436157147789646ull}},
{{2438377407926116184ull, 348925718231717ull}},
{{7590752667423696218ull, 558281149170747ull}},
{{17140648578164687944ull, 446624919336597ull}},
{{6333821233047929708ull, 357299935469278ull}},
{{12445754615922164413ull, 285839948375422ull}},
{{5155812126507821768ull, 457343917400676ull}},
{{435300886464347091ull, 365875133920541ull}},
{{15105635968139118966ull, 292700107136432ull}},
{{9411622290054949053ull, 468320171418292ull}},
{{150600202560138596ull, 374656137134634ull}},
{{3809828976790021200ull, 299724909707707ull}},
{{9785075177605944243ull, 479559855532331ull}},
{{4138711327342845071ull, 383647884425865ull}},
{{3310969061874276057ull, 306918307540692ull}},
{{8986899313740752014ull, 491069292065107ull}},
{{18257565895218332581ull, 392855433652085ull}},
{{14606052716174666065ull, 314284346921668ull}},
{{1233591457428003764ull, 502854955074670ull}},
{{986873165942403011ull, 402283964059736ull}},
{{15546893791721563702ull, 321827171247788ull}},
{{2738937178303039984ull, 514923473996462ull}},
{{13259196186868162957ull, 411938779197169ull}},
{{14296705764236440689ull, 329551023357735ull}},
{{4427985149068753486ull, 527281637372377ull}},
{{14610434563480733758ull, 421825309897901ull}},
{{7998998836042676683ull, 337460247918321ull}},
{{5419700508184462047ull, 539936396669314ull}},
{{8025109221289479961ull, 431949117335451ull}},
{{2730738562289673645ull, 345559293868361ull}},
{{15437228143889208802ull, 552894870189377ull}},
{{4971084885627546395ull, 442315896151502ull}},
{{15044914352727768086ull, 353852716921201ull}},
{{8346582667440304145ull, 283082173536961ull}},
{{5975834638420665987ull, 452931477659138ull}},
{{12159365340220353436ull, 362345182127310ull}},
{{9727492272176282748ull, 289876145701848ull}},
{{11874638820740142074ull, 463801833122957ull}},
{{2121013427108293013ull, 371041466498366ull}},
{{16454206000654275703ull, 296833173198692ull}},
{{11569334342079199833ull, 474933077117908ull}},
{{16634165103147180512ull, 379946461694326ull}},
{{9617983267775834087ull, 303957169355461ull}},
{{8010075598957513892ull, 486331470968738ull}},
{{13786758108649831760ull, 389065176774990ull}},
{{11029406486919865408ull, 311252141419992ull}},
{{2889655120104143360ull, 498003426271988ull}},
{{9690421725567135335ull, 398402741017590ull}},
{{7752337380453708268ull, 318722192814072ull}},
{{16093088623467843552ull, 509955508502515ull}},
{{12874470898774274841ull, 407964406802012ull}},
{{2920879089535599226ull, 326371525441610ull}},
{{4673406543256958763ull, 522194440706576ull}},
{{49376419863656687ull, 417755552565261ull}},
{{14796896394858566642ull, 334204442052208ull}},
{{1538941343322244689ull, 534727107283534ull}},
{{4920501889399706074ull, 427781685826827ull}},
{{15004447955745495829ull, 342225348661461ull}},
{{16628419099708972680ull, 547560557858338ull}},
{{2234688835541447174ull, 438048446286671ull}},
{{16545146327400799032ull, 350438757029336ull}},
{{646792420647906189ull, 560702011246939ull}},
{{4206782751260235274ull, 448561608997551ull}},
{{18122821459975829512ull, 358849287198040ull}},
{{14498257167980663610ull, 287079429758432ull}},
{{8439816209801420483ull, 459327087613492ull}},
{{17819899412066867356ull, 367461670090793ull}},
{{3187873085427762915ull, 293969336072635ull}},
{{5100596936684420664ull, 470350937716216ull}},
{{391128734605626208ull, 376280750172973ull}},
{{7691600617168321613ull, 301024600138378ull}},
{{8617212172727404258ull, 481639360221405ull}},
{{6893769738181923406ull, 385311488177124ull}},
{{9204364605287449048ull, 308249190541699ull}},
{{3658936924234187507ull, 493198704866719ull}},
{{6616498354129260329ull, 394558963893375ull}},
{{5293198683303408263ull, 315647171114700ull}},
{{8469117893285453221ull, 505035473783520ull}},
{{6775294314628362577ull, 404028379026816ull}},
{{1730886636960779738ull, 323222703221453ull}},
{{17526813878104888874ull, 517156325154324ull}},
{{17710799917225821422ull, 413725060123459ull}},
{{17857988748522567461ull, 330980048098767ull}},
{{13815386738668466645ull, 529568076958028ull}},
{{18431007020418593962ull, 423654461566422ull}},
{{7366107986851054523ull, 338923569253138ull}},
{{8096423964219776915ull, 542277710805021ull}},
{{2787790356633911208ull, 433822168644017ull}},
{{13298278729532859936ull, 347057734915213ull}},
{{17587897152510665575ull, 555292375864341ull}},
{{10380968907266622137ull, 444233900691473ull}},
{{15683472755297118356ull, 355387120553178ull}},
{{1478731760011963715ull, 284309696442543ull}},
{{17123366074986783237ull, 454895514308068ull}},
{{2630646415763695620ull, 363916411446455ull}},
{{2104517132610956496ull, 291133129157164ull}},
{{10745925041661351040ull, 465813006651462ull}},
{{1218042403845260185ull, 372650405321170ull}},
{{974433923076208148ull, 298120324256936ull}},
{{12627140721147664007ull, 476992518811097ull}},
{{2723014947434310559ull, 381594015048878ull}},
{{9557109587431269094ull, 305275212039102ull}},
{{533980080922389257ull, 488440339262564ull}},
{{4116532879479821729ull, 390752271410051ull}},
{{18050621562551498676ull, 312601817128040ull}},
{{10434250426372846266ull, 500162907404865ull}},
{{8347400341098277012ull, 400130325923892ull}},
{{17745966717104352579ull, 320104260739113ull}},
{{6257453858915502188ull, 512166817182582ull}},
{{16074009531358132720ull, 409733453746065ull}},
{{12859207625086506176ull, 327786762996852ull}},
{{5817336941170768589ull, 524458820794964ull}},
{{8343218367678525194ull, 419567056635971ull}},
{{2985225879400909832ull, 335653645308777ull}},
{{8465710221783366055ull, 537045832494043ull}},
{{14151265806910513490ull, 429636665995234ull}},
{{15010361460270321115ull, 343709332796187ull}},
{{9259183077464872492ull, 549934932473900ull}},
{{7407346461971897993ull, 439947945979120ull}},
{{5925877169577518395ull, 351958356783296ull}},
{{1051352920920104392ull, 281566685426637ull}},
{{5371513488214077351ull, 450506696682619ull}},
{{7986559605313172204ull, 360405357346095ull}},
{{6389247684250537763ull, 288324285876876ull}},
{{2844098665317039775ull, 461318857403002ull}},
{{13343325376479362790ull, 369055085922401ull}},
{{6985311486441579908ull, 295244068737921ull}},
{{3797800748822707207ull, 472390509980674ull}},
{{6727589413800076089ull, 377912407984539ull}},
{{9071420345781971194ull, 302329926387631ull}},
{{7135574923767333265ull, 483727882220210ull}},
{{5708459939013866612ull, 386982305776168ull}},
{{11945465580694913936ull, 309585844620934ull}},
{{8044698484886131328ull, 495337351393495ull}},
{{6435758787908905062ull, 396269881114796ull}},
{{1459258215585213726ull, 317015904891837ull}},
{{6024161959678252286ull, 507225447826939ull}},
{{8508678382484512152ull, 405780358261551ull}},
{{3117593891245699398ull, 324624286609241ull}},
{{16056196670218850007ull, 519398858574785ull}},
{{12844957336175080005ull, 415519086859828ull}},
{{17654663498423884651ull, 332415269487862ull}},
{{13490066338510574148ull, 531864431180580ull}},
{{10792053070808459319ull, 425491544944464ull}},
{{12322991271388677778ull, 340393235955571ull}},
{{12338088404738063799ull, 544629177528914ull}},
{{13559819538532361362ull, 435703342023131ull}},
{{7158506816083978766ull, 348562673618505ull}},
{{11453610905734366026ull, 557700277789608ull}},
{{16541586354071313467ull, 446160222231686ull}},
{{9543920268515140451ull, 356928177785349ull}},
{{11324485029554022684ull, 285542542228279ull}},
{{7051129603060705325ull, 456868067565247ull}},
{{16708950126674295229ull, 365494454052197ull}},
{{5988462471855615537ull, 292395563241758ull}},
{{5892191140227074536ull, 467832901186813ull}},
{{12092450541665480275ull, 374266320949450ull}},
{{9673960433332384220ull, 299413056759560ull}},
{{15478336693331814752ull, 479060890815296ull}},
{{8693320539923541478ull, 383248712652237ull}},
{{18022702876164564152ull, 306598970121789ull}},
{{17768278157637571674ull, 490558352194863ull}},
{{3146576081884326370ull, 392446681755891ull}},
{{17274656124475102389ull, 313957345404712ull}},
{{12882054540192522529ull, 502331752647540ull}},
{{10305643632154018023ull, 401865402118032ull}},
{{865817276239393772ull, 321492321694426ull}},
{{12453354086208761005ull, 514387714711081ull}},
{{6273334454225098481ull, 411510171768865ull}},
{{5018667563380078785ull, 329208137415092ull}},
{{11719216916150036379ull, 526733019864147ull}},
{{1996675903436208457ull, 421386415891318ull}},
{{8976038352232787412ull, 337109132713054ull}},
{{3293614919346728889ull, 539374612340887ull}},
{{13702938379703114081ull, 431499689872709ull}},
{{14651699518504401588ull, 345199751898167ull}},
{{8685323970639401248ull, 552319603037068ull}},
{{14326956805995341645ull, 441855682429654ull}},
{{15150914259538183639ull, 353484545943723ull}},
{{1052684963404815941ull, 282787636754979ull}},
{{9062993570931526153ull, 452460218807966ull}},
{{3561046042003310599ull, 361968175046373ull}},
{{10227534463086469126ull, 289574540037098ull}},
{{12674706326196440278ull, 463319264059357ull}},
{{2761067431473331576ull, 370655411247486ull}},
{{16966249204146306553ull, 296524328997988ull}},
{{5009905838182628546ull, 474438926396782ull}},
{{15075971114771833807ull, 379551141117425ull}},
{{12060776891817467045ull, 303640912893940ull}},
{{850498953198395657ull, 485825460630305ull}},
{{680399162558716525ull, 388660368504244ull}},
{{4233668144788883543ull, 310928294803395ull}},
{{6773869031662213670ull, 497485271685432ull}},
{{16487141669555501905ull, 397988217348345ull}},
{{13189713335644401524ull, 318390573878676ull}},
{{13724843707547221792ull, 509424918205882ull}},
{{3601177336553956787ull, 407539934564706ull}},
{{17638337128210806723ull, 326031947651764ull}},
{{17153292960911559787ull, 521651116242823ull}},
{{2654587924503516860ull, 417320892994259ull}},
{{5813019154344723811ull, 333856714395407ull}},
{{12990179461693468421ull, 534170743032651ull}},
{{6702794754612864414ull, 427336594426121ull}},
{{1672886988948381208ull, 341869275540897ull}},
{{6365967997059320256ull, 546990840865435ull}},
{{5092774397647456204ull, 437592672692348ull}},
{{11452917147601785610ull, 350074138153878ull}},
{{14635318621420946653ull, 560118621046205ull}},
{{11708254897136757322ull, 448094896836964ull}},
{{13055952732451316181ull, 358475917469571ull}},
{{6755413371219142621ull, 286780733975657ull}},
{{14498010208692538518ull, 458849174361051ull}},
{{7909059352212120491ull, 367079339488841ull}},
{{2637898667027786069ull, 293663471591073ull}},
{{531289052502547388ull, 469861554545717ull}},
{{11493077686227768880ull, 375889243636573ull}},
{{16573159778466035750ull, 300711394909258ull}},
{{4380962757094195261ull, 481138231854814ull}},
{{7194119020417266532ull, 384910585483851ull}},
{{2065946401591902903ull, 307928468387081ull}},
{{14373560686772775614ull, 492685549419329ull}},
{{15188197364160130814ull, 394148439535463ull}},
{{1082511447102373682ull, 315318751628371ull}},
{{12800064759589528861ull, 504510002605393ull}},
{{17618749437155443735ull, 403608002084314ull}},
{{17784348364466265311ull, 322886401667451ull}},
{{2629515679952652235ull, 516618242667923ull}},
{{9482310173445942435ull, 413294594134338ull}},
{{14964545768240574594ull, 330635675307470ull}},
{{5496529155475367735ull, 529017080491953ull}},
{{11775920953864114834ull, 423213664393562ull}},
{{2042039133607471221ull, 338570931514850ull}},
{{3267262613771953953ull, 541713490423760ull}},
{{2613810091017563163ull, 433370792339008ull}},
{{9469745702297871176ull, 346696633871206ull}},
{{7772895494192773236ull, 554714614193930ull}},
{{6218316395354218589ull, 443771691355144ull}},
{{8664001931025285194ull, 355017353084115ull}},
{{6931201544820228155ull, 284013882467292ull}},
{{14779271286454275372ull, 454422211947667ull}},
{{4444719399679599651ull, 363537769558134ull}},
{{7245124334485590044ull, 290830215646507ull}},
{{15281547749918854394ull, 465328345034411ull}},
{{8535889385193173192ull, 372262676027529ull}},
{{10518060322896448876ull, 297810140822023ull}},
{{13139547701892407879ull, 476496225315237ull}},
{{3132940532030105657ull, 381196980252190ull}},
{{2506352425624084526ull, 304957584201752ull}},
{{7699512695740445564ull, 487932134722803ull}},
{{13538307786076177098ull, 390345707778242ull}},
{{3451948599377121032ull, 312276566222594ull}},
{{12901815388487214297ull, 499642505956150ull}},
{{10321452310789771438ull, 399714004764920ull}},
{{8257161848631817150ull, 319771203811936ull}},
{{5832761328327086794ull, 511633926099098ull}},
{{12044906692145490082ull, 409307140879278ull}},
{{17014622983200212712ull, 327445712703422ull}},
{{12466001514152699046ull, 523913140325476ull}},
{{6283452396580248914ull, 419130512260381ull}},
{{1337413102522288808ull, 335304409808305ull}},
{{2139860964035662092ull, 536487055693288ull}},
{{9090586400712350320ull, 429189644554630ull}},
{{7272469120569880256ull, 343351715643704ull}},
{{567904148686077440ull, 549362745029927ull}},
{{11522369763174592922ull, 439490196023941ull}},
{{5528546995797764014ull, 351592156819153ull}},
{{5156326378534512100ull, 562547450910645ull}},
{{4125061102827609680ull, 450037960728516ull}},
{{18057444141229729036ull, 360030368582812ull}},
{{7067257683499962583ull, 288024294866250ull}},
{{11307612293599940133ull, 460838871786000ull}},
{{9046089834879952106ull, 368671097428800ull}},
{{7236871867903961685ull, 294936877943040ull}},
{{11578994988646338696ull, 471899004708864ull}},
{{12952544805658981280ull, 377519203767091ull}},
{{6672687029785274700ull, 302015363013673ull}},
{{6986950432914529198ull, 483224580821877ull}},
{{16657606790557354328ull, 386579664657501ull}},
{{9636736617703973139ull, 309263731726001ull}},
{{8040080958842536376ull, 494821970761602ull}},
{{17500111211299760070ull, 395857576609281ull}},
{{10310740154297897733ull, 316686061287425ull}},
{{16497184246876636373ull, 506697698059880ull}},
{{13197747397501309098ull, 405358158447904ull}},
{{14247546732742957602ull, 324286526758323ull}},
{{659981883937270224ull, 518858442813318ull}},
{{7906683136633636826ull, 415086754250654ull}},
{{10014695324048819784ull, 332069403400523ull}},
{{12334163703736201331ull, 531311045440837ull}},
{{2488633333505140418ull, 425048836352670ull}},
{{1990906666804112334ull, 340039069082136ull}},
{{14253497111112310705ull, 544062510531417ull}},
{{4024100059406027917ull, 435250008425134ull}},
{{6908628862266732657ull, 348200006740107ull}},
{{14743154994368682575ull, 557120010784171ull}},
{{8105175180753035737ull, 445696008627337ull}},
{{17552186588828159559ull, 356556806901869ull}},
{{17731098085804437970ull, 285245445521495ull}},
{{9923012863577549136ull, 456392712834393ull}},
{{15317107920345859955ull, 365114170267514ull}},
{{15943035151018598287ull, 292091336214011ull}},
{{18130158612145936614ull, 467346137942418ull}},
{{3436080445491018321ull, 373876910353935ull}},
{{2748864356392814657ull, 299101528283148ull}},
{{708834155486593128ull, 478562445253037ull}},
{{11635113768615005472ull, 382849956202429ull}},
{{12997439829633914701ull, 306279964961943ull}},
{{17106554912672353198ull, 490047943939109ull}},
{{17374592744879792882ull, 392038355151287ull}},
{{6520976566420013659ull, 313630684121030ull}},
{{10433562506272021855ull, 501809094593648ull}},
{{15725547634501438130ull, 401447275674918ull}},
{{1512391663375419534ull, 321157820539935ull}},
{{2419826661400671255ull, 513852512863896ull}},
{{16693256588088178297ull, 411082010291116ull}},
{{9665256455728632314ull, 328865608232893ull}},
{{11775061514423901380ull, 526184973172629ull}},
{{13109398026281031427ull, 420947978538103ull}},
{{17866216050508645788ull, 336758382830482ull}},
{{13828550421846191968ull, 538813412528772ull}},
{{3684142707993132928ull, 431050730023018ull}},
{{10326011795878326989ull, 344840584018414ull}},
{{5453572429179592213ull, 551744934429463ull}},
{{11741555572827494416ull, 441395947543570ull}},
{{9393244458261995533ull, 353116758034856ull}},
{{3825246751867686103ull, 282493406427885ull}},
{{6120394802988297765ull, 451989450284616ull}},
{{1206967027648727889ull, 361591560227693ull}},
{{8344271251602802957ull, 289273248182154ull}},
{{2282787558338753763ull, 462837197091447ull}},
{{12894276490896733980ull, 370269757673157ull}},
{{2936723563233566537ull, 296215806138526ull}},
{{15766804145399437429ull, 473945289821641ull}},
{{8924094501577639620ull, 379156231857313ull}},
{{14517973230745932342ull, 303324985485850ull}},
{{4782013095483940132ull, 485319976777361ull}},
{{136261661645241782ull, 388255981421889ull}},
{{3798358144058103749ull, 310604785137511ull}},
{{17145419474718696968ull, 496967656220017ull}},
{{6337637950291136928ull, 397574124976014ull}},
{{8759459174974819866ull, 318059299980811ull}},
{{6636437050475891139ull, 508894879969298ull}},
{{12687847269864533557ull, 407115903975438ull}},
{{17528975445375447492ull, 325692723180350ull}},
{{9599616638891164372ull, 521108357088561ull}},
{{3990344496371021174ull, 416886685670849ull}},
{{6881624411838727263ull, 333509348536679ull}},
{{18389296688425784267ull, 533614957658686ull}},
{{11022088535998717090ull, 426891966126949ull}},
{{12507019643540883995ull, 341513572901559ull}},
{{8943184985439683423ull, 546421716642495ull}},
{{7154547988351746738ull, 437137373313996ull}},
{{2034289575939487067ull, 349709898651197ull}},
{{6944212136245089631ull, 559535837841915ull}},
{{5555369708996071705ull, 447628670273532ull}},
{{15512342211422588333ull, 358102936218825ull}},
{{12409873769138070667ull, 286482348975060ull}},
{{1409053956911361451ull, 458371758360097ull}},
{{12195289609754820130ull, 366697406688077ull}},
{{2377534058320035458ull, 293357925350462ull}},
{{7493403308053967056ull, 469372680560739ull}},
{{9684071461185083968ull, 375498144448591ull}},
{{4057908354206156851ull, 300398515558873ull}},
{{2803304551987940638ull, 480637624894197ull}},
{{13310690085816083480ull, 384510099915357ull}},
{{3269854439169046138ull, 307608079932286ull}},
{{16299813546896204790ull, 492172927891657ull}},
{{5661153208033143186ull, 393738342313326ull}},
{{839573751684604225ull, 314990673850661ull}},
{{12411364446921097730ull, 503985078161057ull}},
{{2550393928053057538ull, 403188062528846ull}},
{{16797710401410087323ull, 322550450023076ull}},
{{1050894939062767455ull, 516080720036923ull}},
{{8219413580734034610ull, 412864576029538ull}},
{{13954228494071048334ull, 330291660823630ull}},
{{3880021516804125719ull, 528466657317809ull}},
{{6793366028185210898ull, 422773325854247ull}},
{{16502739266773899688ull, 338218660683397ull}},
{{11646987567870598209ull, 541149857093436ull}},
{{5628241239554568244ull, 432919885674749ull}},
{{8191941806385564918ull, 346335908539799ull}},
{{2039060445991172899ull, 554137453663679ull}},
{{5320597171534848643ull, 443309962930943ull}},
{{11635175366711699560ull, 354647970344754ull}},
{{12997489108111269971ull, 283718376275803ull}},
{{17106633758236121631ull, 453949402041285ull}},
{{13685307006588897305ull, 363159521633028ull}},
{{18326943234754938490ull, 290527617306422ull}},
{{14565713916640260292ull, 464844187690276ull}},
{{7963222318570297910ull, 371875350152221ull}},
{{2681229040114328005ull, 297500280121777ull}},
{{7979315278924835131ull, 476000448194843ull}},
{{13762149852623688751ull, 380800358555874ull}},
{{14699068696840861324ull, 304640286844699ull}},
{{12450463470719647150ull, 487424458951519ull}},
{{13649719591317628043ull, 389939567161215ull}},
{{10919775673054102434ull, 311951653728972ull}},
{{2714245817918922602ull, 499122645966356ull}},
{{16928791913302779374ull, 399298116773084ull}},
{{17232382345384133823ull, 319438493418467ull}},
{{12814416493646972824ull, 511101589469548ull}},
{{17630230824401398905ull, 408881271575638ull}},
{{3036138215295388154ull, 327105017260511ull}},
{{15925867588698352017ull, 523368027616817ull}},
{{5361996441474860967ull, 418694422093454ull}},
{{7978945967921799097ull, 334955537674763ull}},
{{9076964733932968232ull, 535928860279621ull}},
{{3572222972404464262ull, 428743088223697ull}},
{{13925824822149302379ull, 342994470578957ull}},
{{7523924456471242514ull, 548791152926332ull}},
{{17087186009402724981ull, 439032922341065ull}},
{{13669748807522179985ull, 351226337872852ull}},
{{7114202833067846683ull, 561962140596564ull}},
{{9380711081196187670ull, 449569712477251ull}},
{{3815220050215039812ull, 359655769981801ull}},
{{17809571299139673143ull, 287724615985440ull}},
{{10048570004913925412ull, 460359385576705ull}},
{{8038856003931140330ull, 368287508461364ull}},
{{10120433617886822587ull, 294630006769091ull}},
{{8813996159135095493ull, 471408010830546ull}},
{{3361848112566166071ull, 377126408664437ull}},
{{13757524934278663826ull, 301701126931549ull}},
{{10943993450620131153ull, 482721803090479ull}},
{{12444543575238015245ull, 386177442472383ull}},
{{17334332489674232843ull, 308941953977906ull}},
{{1909490280285400286ull, 494307126364651ull}},
{{16284987483195961522ull, 395445701091720ull}},
{{13027989986556769217ull, 316356560873376ull}},
{{13466086349007010101ull, 506170497397402ull}},
{{3394171449721787435ull, 404936397917922ull}},
{{13783383604003160917ull, 323949118334337ull}},
{{7296018507437416175ull, 518318589334940ull}},
{{5836814805949932940ull, 414654871467952ull}},
{{15737498288985677321ull, 331723897174361ull}},
{{17801299632893263068ull, 530758235478978ull}},
{{3172993262088879485ull, 424606588383183ull}},
{{9917092239154924234ull, 339685270706546ull}},
{{8488649953164058129ull, 543496433130474ull}},
{{10480268777273156826ull, 434797146504379ull}},
{{12073563836560435784ull, 347837717203503ull}},
{{15628353323754786931ull, 556540347525605ull}},
{{12502682659003829545ull, 445232278020484ull}},
{{13691494941944973959ull, 356185822416387ull}},
{{3574498324072158521ull, 284948657933110ull}},
{{5719197318515453634ull, 455917852692976ull}},
{{886009040070452584ull, 364734282154381ull}},
{{15466202491024003360ull, 291787425723504ull}},
{{13677877541412674406ull, 466859881157607ull}},
{{3563604403646318878ull, 373487904926086ull}},
{{17608278781884696395ull, 298790323940868ull}},
{{6037153162564052294ull, 478064518305390ull}},
{{4829722530051241835ull, 382451614644312ull}},
{{14931824468266724437ull, 305961291715449ull}},
{{12822872705001028130ull, 489538066744719ull}},
{{13947646978742732827ull, 391630453395775ull}},
{{11158117582994186262ull, 313304362716620ull}},
{{17852988132790698019ull, 501286980346592ull}},
{{6903692876748737769ull, 401029584277274ull}},
{{9212303116140900538ull, 320823667421819ull}},
{{3671638541599709892ull, 513317867874911ull}},
{{17694706092247409206ull, 410654294299928ull}},
{{3087718429572196395ull, 328523435439943ull}},
{{1251000672573603909ull, 525637496703909ull}},
{{4690149352800793451ull, 420509997363127ull}},
{{14820165926466365730ull, 336407997890501ull}},
{{16333567852862364522ull, 538252796624802ull}},
{{5688156652806070971ull, 430602237299842ull}},
{{15618571766470587746ull, 344481789839873ull}},
{{2853621937901478455ull, 551170863743798ull}},
{{9661595179805003410ull, 440936690995038ull}},
{{15107973773327823375ull, 352749352796030ull}},
{{12086379018662258700ull, 282199482236824ull}},
{{8270159985633882950ull, 451519171578919ull}},
{{10305476803249016683ull, 361215337263135ull}},
{{8244381442599213346ull, 288972269810508ull}},
{{9501661493416831031ull, 462355631696813ull}},
{{14980026824217285471ull, 369884505357450ull}},
{{11984021459373828377ull, 295907604285960ull}},
{{727690261288573788ull, 473452166857537ull}},
{{11650198653256590000ull, 378761733486029ull}},
{{13009507737347182323ull, 303009386788823ull}},
{{17125863565013581394ull, 484815018862117ull}},
{{6321993222527044468ull, 387852015089694ull}},
{{8746943392763545898ull, 310281612071755ull}},
{{13995109428421673437ull, 496450579314808ull}},
{{128041098511607780ull, 397160463451847ull}},
{{11170479323035017193ull, 317728370761477ull}},
{{3115371657888386217ull, 508365393218364ull}},
{{6181646141052619296ull, 406692314574691ull}},
{{1255968098100185114ull, 325353851659753ull}},
{{16766944215927937475ull, 520566162655604ull}},
{{17102904187484260303ull, 416452930124483ull}},
{{2614276905761677273ull, 333162344099587ull}},
{{7872191863960593960ull, 533059750559339ull}},
{{9987102305910385491ull, 426447800447471ull}},
{{4300333029986398070ull, 341158240357977ull}},
{{10569881662720147235ull, 545853184572763ull}},
{{15834602959659938434ull, 436682547658210ull}},
{{12667682367727950747ull, 349346038126568ull}},
{{16578942973622810873ull, 558953661002509ull}},
{{16952503193640159021ull, 447162928802007ull}},
{{6183304925428306571ull, 357730343041606ull}},
{{1257295125600734933ull, 286184274433285ull}},
{{2011672200961175893ull, 457894839093256ull}},
{{16366733019736582007ull, 366315871274604ull}},
{{16782735230531175929ull, 293052697019683ull}},
{{4716283480398419548ull, 468884315231494ull}},
{{7462375599060645961ull, 375107452185195ull}},
{{5969900479248516769ull, 300085961748156ull}},
{{2173143137313806184ull, 480137538797050ull}},
{{1738514509851044947ull, 384110031037640ull}},
{{1390811607880835958ull, 307288024830112ull}},
{{5914647387351247856ull, 491660839728179ull}},
{{8421066724622908608ull, 393328671782543ull}},
{{14115551009182147532ull, 314662937426034ull}},
{{11516835170465705083ull, 503460699881655ull}},
{{9213468136372564066ull, 402768559905324ull}},
{{11060123323839961576ull, 322214847924259ull}},
{{6628150873918207552ull, 515543756678815ull}},
{{5302520699134566042ull, 412435005343052ull}},
{{15310063003533383803ull, 329948004274441ull}},
{{17117403176169593438ull, 527916806839106ull}},
{{10004573726193764427ull, 422333445471285ull}},
{{8003658980955011542ull, 337866756377028ull}},
{{9116505554786108144ull, 540586810203245ull}},
{{7293204443828886515ull, 432469448162596ull}},
{{2145214740321198889ull, 345975558530077ull}},
{{7121692399255828545ull, 553560893648123ull}},
{{13076051548888483483ull, 442848714918498ull}},
{{17839538868594607432ull, 354278971934798ull}},
{{3203584650649954976ull, 283423177547839ull}},
{{12504433070523748609ull, 453477084076542ull}},
{{2624848826935178240ull, 362781667261234ull}},
{{5789227876290052915ull, 290225333808987ull}},
{{12952113416805994988ull, 464360534094379ull}},
{{14051039548186706314ull, 371488427275503ull}},
{{172785194323634081ull, 297190741820403ull}},
{{15033851569885455823ull, 475505186912644ull}},
{{15716430070650274982ull, 380404149530115ull}},
{{12573144056520219985ull, 304323319624092ull}},
{{5359635231464710684ull, 486917311398548ull}},
{{11666405814655589193ull, 389533849118838ull}},
{{16711822281208292001ull, 311627079295070ull}},
{{8292171576223715586ull, 498603326872113ull}},
{{14012434890462793115ull, 398882661497690ull}},
{{11209947912370234492ull, 319106129198152ull}},
{{3178521400824733895ull, 510569806717044ull}},
{{6232165935401697439ull, 408455845373635ull}},
{{4985732748321357951ull, 326764676298908ull}},
{{4287823582572262398ull, 522823482078253ull}},
{{10808956495541630565ull, 418258785662602ull}},
{{1268467566949483806ull, 334607028530082ull}},
{{5718896921861084412ull, 535371245648131ull}},
{{885768722746957207ull, 428296996518505ull}},
{{708614978197565765ull, 342637597214804ull}},
{{8512481594599925871ull, 548220155543686ull}},
{{3120636460938030374ull, 438576124434949ull}},
{{6185857983492334622ull, 350860899547959ull}},
{{17276070403071556042ull, 561377439276734ull}},
{{17510205137199155157ull, 449101951421387ull}},
{{6629466480275503479ull, 359281561137110ull}},
{{5303573184220402783ull, 287425248909688ull}},
{{4796368280010734130ull, 459880398255501ull}},
{{147745809266676980ull, 367904318604401ull}},
{{14875591906380982877ull, 294323454883520ull}},
{{5354202976500020988ull, 470917527813633ull}},
{{11662060010683837436ull, 376734022250906ull}},
{{5640299193805159626ull, 301387217800725ull}},
{{9024478710088255402ull, 482219548481160ull}},
{{7219582968070604321ull, 385775638784928ull}},
{{13154364003940304103ull, 308620511027942ull}},
{{6289587147336845273ull, 493792817644708ull}},
{{12410367347353296864ull, 395034254115766ull}},
{{6238945063140727168ull, 316027403292613ull}},
{{6292963286283253146ull, 505643845268181ull}},
{{1345021814284692194ull, 404515076214545ull}},
{{1076017451427753755ull, 323612060971636ull}},
{{12789674366510136978ull, 517779297554617ull}},
{{2853041863724288936ull, 414223438043694ull}},
{{5971782305721341472ull, 331378750434955ull}},
{{9554851689154146355ull, 530206000695928ull}},
{{15022578980807137730ull, 424164800556742ull}},
{{4639365555161889538ull, 339331840445394ull}},
{{14801682517742843907ull, 542930944712630ull}},
{{11841346014194275126ull, 434344755770104ull}},
{{13162425626097330424ull, 347475804616083ull}},
{{17370532187013818355ull, 555961287385733ull}},
{{2828379305385323714ull, 444769029908587ull}},
{{13330749888533989941ull, 355815223926869ull}},
{{14353948725569102276ull, 284652179141495ull}},
{{4519573887201012025ull, 455443486626393ull}},
{{10994356739244630267ull, 364354789301114ull}},
{{12484834206137614536ull, 291483831440891ull}},
{{12597037100336362612ull, 466374130305426ull}},
{{6388280865527179766ull, 373099304244341ull}},
{{1421275877679833490ull, 298479443395473ull}},
{{17031436663255374877ull, 477567109432756ull}},
{{9935800515862389578ull, 382053687546205ull}},
{{7948640412689911662ull, 305642950036964ull}},
{{1649778216078127691ull, 489028720059143ull}},
{{8698520202346322799ull, 391222976047314ull}},
{{10648164976618968562ull, 312978380837851ull}},
{{9658366333106529053ull, 500765409340562ull}},
{{347995437001402596ull, 400612327472450ull}},
{{278396349601122077ull, 320489861977960ull}},
{{445434159361795323ull, 512783779164736ull}},
{{15113742586457077551ull, 410227023331788ull}},
{{1022947624939931071ull, 328181618665431ull}},
{{12704762644129620684ull, 525090589864689ull}},
{{13853158930045606870ull, 420072471891751ull}},
{{7393178329294575173ull, 336057977513401ull}},
{{4450387697387499631ull, 537692764021442ull}},
{{14628356602135730674ull, 430154211217153ull}},
{{634638837482853569ull, 344123368973723ull}},
{{15772817398940207004ull, 550597390357956ull}},
{{8928905104410255280ull, 440477912286365ull}},
{{7143124083528204224ull, 352382329829092ull}},
{{16782545711048294349ull, 281905863863273ull}},
{{4715980249225809019ull, 451049382181238ull}},
{{11151481828864467862ull, 360839505744990ull}},
{{8921185463091574289ull, 288671604595992ull}},
{{17963245555688429186ull, 461874567353587ull}},
{{6991898815066922702ull, 369499653882870ull}},
{{5593519052053538162ull, 295599723106296ull}},
{{1570932853801840413ull, 472959556970074ull}},
{{4946095097783382653ull, 378367645576059ull}},
{{7646224892968616446ull, 302694116460847ull}},
{{15923308643491696637ull, 484310586337355ull}},
{{12738646914793357309ull, 387448469069884ull}},
{{13880266346576596171ull, 309958775255907ull}},
{{7451030895554912580ull, 495934040409452ull}},
{{17028871160669661034ull, 396747232327561ull}},
{{9933748113793818504ull, 317397785862049ull}},
{{4825950537844378637ull, 507836457379279ull}},
{{7550109245017413232ull, 406269165903423ull}},
{{13418785025497751232ull, 325015332722738ull}},
{{17780707226054491649ull, 520024532356381ull}},
{{10535216966101682996ull, 416019625885105ull}},
{{8428173572881346396ull, 332815700708084ull}},
{{2417031272384423265ull, 532505121132935ull}},
{{1933625017907538612ull, 426004096906348ull}},
{{8925597643809851536ull, 340803277525078ull}},
{{10591607415353852134ull, 545285244040125ull}},
{{8473285932283081707ull, 436228195232100ull}},
{{6778628745826465366ull, 348982556185680ull}},
{{10845805993322344586ull, 558372089897088ull}},
{{16055342424141696315ull, 446697671917670ull}},
{{12844273939313357052ull, 357358137534136ull}},
{{6586070336708775318ull, 285886510027309ull}},
{{17916410168217861156ull, 457418416043694ull}},
{{18022476949316199248ull, 365934732834955ull}},
{{14417981559452959398ull, 292747786267964ull}},
{{12000724050899004067ull, 468396458028743ull}},
{{16979276870203023900ull, 374717166422994ull}},
{{17272770310904329443ull, 299773733138395ull}},
{{9189688423737375494ull, 479637973021433ull}},
{{14730448368473721041ull, 383710378417146ull}},
{{8095009880037066510ull, 306968302733717ull}},
{{16641364622801216739ull, 491149284373947ull}},
{{5934394068757152745ull, 392919427499158ull}},
{{12126212884489542842ull, 314335541999326ull}},
{{12023242985699447901ull, 502936867198922ull}},
{{2239896759075737674ull, 402349493759138ull}},
{{9170615036744410786ull, 321879595007310ull}},
{{14672984058791057258ull, 515007352011696ull}},
{{8049038432290935483ull, 412005881609357ull}},
{{17507277190058479356ull, 329604705287485ull}},
{{9564899430384015353ull, 527367528459977ull}},
{{273221914823391636ull, 421894022767982ull}},
{{11286623976084444279ull, 337515218214385ull}},
{{18058598361735110846ull, 540024349143016ull}},
{{10757529874646178353ull, 432019479314413ull}},
{{15984721529200763329ull, 345615583451530ull}},
{{7128810373011669711ull, 552984933522449ull}},
{{9392397113151246092ull, 442387946817959ull}},
{{11203266505262907196ull, 353910357454367ull}},
{{1583915574726505111ull, 283128285963494ull}},
{{9912962549046228824ull, 453005257541590ull}},
{{7930370039236983059ull, 362404206033272ull}},
{{17412342475615317417ull, 289923364826617ull}},
{{13102352702016866574ull, 463877383722588ull}},
{{17860579791097313906ull, 371101906978070ull}},
{{14288463832877851124ull, 296881525582456ull}},
{{15482844503120741153ull, 475010440931930ull}},
{{12386275602496592922ull, 380008352745544ull}},
{{13598369296739184661ull, 304006682196435ull}},
{{3310646801073143842ull, 486410691514297ull}},
{{13716563885084246043ull, 389128553211437ull}},
{{3594553478583576188ull, 311302842569150ull}},
{{5751285565733721901ull, 498084548110640ull}},
{{4601028452586977521ull, 398467638488512ull}},
{{14748869206295312986ull, 318774110790809ull}},
{{12530144285846769808ull, 510038577265295ull}},
{{10024115428677415846ull, 408030861812236ull}},
{{4329943528200022354ull, 326424689449789ull}},
{{14306607274603856413ull, 522279503119662ull}},
{{4066588190199264484ull, 417823602495730ull}},
{{3253270552159411587ull, 334258881996584ull}},
{{12583930512938879186ull, 534814211194534ull}},
{{13756493225093013672ull, 427851368955627ull}},
{{3626496950590590291ull, 342281095164502ull}},
{{9491743935686854789ull, 547649752263203ull}},
{{14972092778033304477ull, 438119801810562ull}},
{{4598976592942822935ull, 350495841448450ull}},
{{7358362548708516697ull, 560793346317520ull}},
{{5886690038966813358ull, 448634677054016ull}},
{{1020003216431540363ull, 358907741643213ull}},
{{8194700202629052936ull, 287126193314570ull}},
{{13111520324206484699ull, 459401909303312ull}},
{{3110518629881367112ull, 367521527442650ull}},
{{2488414903905093690ull, 294017221954120ull}},
{{3981463846248149904ull, 470427555126592ull}},
{{14253217521224250893ull, 376342044101273ull}},
{{334527572753669744ull, 301073635281019ull}},
{{7913941745889692238ull, 481717816449630ull}},
{{6331153396711753790ull, 385374253159704ull}},
{{8754271532111313355ull, 308299402527763ull}},
{{10317485636636191046ull, 493279044044421ull}},
{{4564639694567042513ull, 394623235235537ull}},
{{14719758199879364980ull, 315698588188429ull}},
{{12483566675581252999ull, 505117741101487ull}},
{{2608155710981181752ull, 404094192881190ull}},
{{2086524568784945402ull, 323275354304952ull}},
{{7027788124797822966ull, 517240566887923ull}},
{{13000928129322079019ull, 413792453510338ull}},
{{17779440132941483862ull, 331033962808270ull}},
{{10000360138996822563ull, 529654340493233ull}},
{{15378985740681278697ull, 423723472394586ull}},
{{8613839777803112634ull, 338978777915669ull}},
{{2714097200259249246ull, 542366044665071ull}},
{{16928673019175040689ull, 433892835732056ull}},
{{9853589600598122228ull, 347114268585645ull}},
{{15765743360956995565ull, 555382829737032ull}},
{{5233897059281775806ull, 444306263789626ull}},
{{497768832683510321ull, 355445011031701ull}},
{{15155610325114449550ull, 284356008825360ull}},
{{5802232446473567664ull, 454969614120577ull}},
{{15709832401404585100ull, 363975691296461ull}},
{{8878517106381757757ull, 291180553037169ull}},
{{3137580925985081442ull, 465888884859471ull}},
{{17267459999755706446ull, 372711107887576ull}},
{{10124619185062654834ull, 298168886310061ull}},
{{8820693066616427088ull, 477070218096098ull}},
{{14435252082776962317ull, 381656174476878ull}},
{{480155221995838884ull, 305324939581503ull}},
{{15525643614160983507ull, 488519903330404ull}},
{{16109863706070697129ull, 390815922664323ull}},
{{1819844520630826733ull, 312652738131459ull}},
{{10290448862493143420ull, 500244381010334ull}},
{{11921707904736425059ull, 400195504808267ull}},
{{2158668694305319401ull, 320156403846614ull}},
{{10832567540372331688ull, 512250246154582ull}},
{{1287356402814044704ull, 409800196923666ull}},
{{15787280381218877056ull, 327840157538932ull}},
{{10502253350982561997ull, 524544252062292ull}},
{{1023105051302228951ull, 419635401649834ull}},
{{4507832855783693484ull, 335708321319867ull}},
{{10901881383995819897ull, 537133314111787ull}},
{{1342807477712835271ull, 429706651289430ull}},
{{1074245982170268217ull, 343765321031544ull}},
{{9097491200956249794ull, 550024513650470ull}},
{{7277992960764999835ull, 440019610920376ull}},
{{2133045553870089545ull, 352015688736301ull}},
{{16463831702063712928ull, 281612550989040ull}},
{{7895386649592389070ull, 450580081582465ull}},
{{6316309319673911256ull, 360464065265972ull}},
{{16121093899964859974ull, 288371252212777ull}},
{{11036354980976134666ull, 461394003540444ull}},
{{12518432799522818056ull, 369115202832355ull}},
{{10014746239618254445ull, 295292162265884ull}},
{{4955547539163476142ull, 472467459625415ull}},
{{3964438031330780914ull, 377973967700332ull}},
{{14239596869290355700ull, 302379174160265ull}},
{{4336610917155017505ull, 483806678656425ull}},
{{3469288733724014004ull, 387045342925140ull}},
{{2775430986979211203ull, 309636274340112ull}},
{{8130038393908648248ull, 495418038944179ull}},
{{10193379529868828922ull, 396334431155343ull}},
{{15533401253378883784ull, 317067544924274ull}},
{{13785395561180483085ull, 507308071878839ull}},
{{14717665263686296791ull, 405846457503071ull}},
{{8084783396207127109ull, 324677166002457ull}},
{{16625002248673313698ull, 519483465603931ull}},
{{9610652984196740635ull, 415586772483145ull}},
{{7688522387357392508ull, 332469417986516ull}},
{{4922938190288007367ull, 531951068778426ull}},
{{249001737488495570ull, 425560855022741ull}},
{{14956596648958437749ull, 340448684018192ull}},
{{9173159379365859106ull, 544717894429108ull}},
{{14717225132976507931ull, 435774315543286ull}},
{{8084431291639296022ull, 348619452434629ull}},
{{1867043622397142665ull, 557791123895407ull}},
{{12561681342143445102ull, 446232899116325ull}},
{{10049345073714756081ull, 356986319293060ull}},
{{8039476058971804865ull, 285589055434448ull}},
{{9173812879612977461ull, 456942488695117ull}},
{{18407096747916112938ull, 365553990956093ull}},
{{3657630954107159381ull, 292443192764875ull}},
{{5852209526571455010ull, 467909108423800ull}},
{{4681767621257164008ull, 374327286739040ull}},
{{3745414097005731206ull, 299461829391232ull}},
{{9682011369951080253ull, 479138927025971ull}},
{{4056260281218953879ull, 383311141620777ull}},
{{14313054669200894073ull, 306648913296621ull}},
{{15522189841237609870ull, 490638261274594ull}},
{{16107100687731998219ull, 392510609019675ull}},
{{12885680550185598575ull, 314008487215740ull}},
{{2170344806587406105ull, 502413579545185ull}},
{{1736275845269924884ull, 401930863636148ull}},
{{8767718305699760553ull, 321544690908918ull}},
{{10339000474377706563ull, 514471505454269ull}},
{{11960549194244075573ull, 411577204363415ull}},
{{9568439355395260458ull, 329261763490732ull}},
{{552107709664775441ull, 526818821585172ull}},
{{11509732611957551322ull, 421455057268137ull}},
{{1829088460082220411ull, 337164045814510ull}},
{{2926541536131552659ull, 539462473303216ull}},
{{17098628487872883420ull, 431569978642572ull}},
{{6300205160814486089ull, 345255982914058ull}},
{{6390979442561267420ull, 552409572662493ull}},
{{12491481183532834582ull, 441927658129994ull}},
{{13682533761568177989ull, 353542126503995ull}},
{{10946027009254542391ull, 282833701203196ull}},
{{10134945585323447179ull, 452533921925114ull}},
{{11797305283000668067ull, 362027137540091ull}},
{{5748495411658624130ull, 289621710032073ull}},
{{5508243843911888285ull, 463394736051317ull}},
{{15474641519355241598ull, 370715788841053ull}},
{{1311666771258462308ull, 296572631072843ull}},
{{16856062092981180986ull, 474516209716548ull}},
{{2416803230159213819ull, 379612967773239ull}},
{{5622791398869281379ull, 303690374218591ull}},
{{1617768608707029560ull, 485904598749746ull}},
{{16051610145933264940ull, 388723678999796ull}},
{{9151939302004701629ull, 310978943199837ull}},
{{18332451697949432930ull, 497566309119739ull}},
{{18355310173101456667ull, 398053047295791ull}},
{{10994899323739255010ull, 318442437836633ull}},
{{13902490103240897694ull, 509507900538613ull}},
{{53945638366987185ull, 407606320430891ull}},
{{14800551769661231041ull, 326085056344712ull}},
{{8923487572490328373ull, 521736090151540ull}},
{{7138790057992262698ull, 417388872121232ull}},
{{16779078490619541128ull, 333911097696985ull}},
{{8399781511281714189ull, 534257756315177ull}},
{{17787871653251102321ull, 427406205052141ull}},
{{10540948507858971533ull, 341924964041713ull}},
{{13176168797832444131ull, 547079942466741ull}},
{{6851586223524044981ull, 437663953973393ull}},
{{12859966608303056631ull, 350131163178714ull}},
{{9507900129059159641ull, 560209861085943ull}},
{{14985017732731148359ull, 448167888868754ull}},
{{15677363000926829010ull, 358534311095003ull}},
{{1473843956515732238ull, 286827448876003ull}},
{{17115545589392812875ull, 458923918201604ull}},
{{17381785286256160623ull, 367139134561283ull}},
{{2837381784779197529ull, 293711307649027ull}},
{{8229159670388626369ull, 469938092238443ull}},
{{13962025365794721742ull, 375950473790754ull}},
{{14858969107377687716ull, 300760379032603ull}},
{{1638257683352838407ull, 481216606452166ull}},
{{16068001405649912019ull, 384973285161732ull}},
{{5475703495036108968ull, 307978628129386ull}},
{{1382427962573953703ull, 492765805007018ull}},
{{8484639999542983609ull, 394212644005614ull}},
{{10477060814376297210ull, 315370115204491ull}},
{{9384599673518254890ull, 504592184327186ull}},
{{3818330924072693589ull, 403673747461749ull}},
{{6744013554000065194ull, 322938997969399ull}},
{{18169119315883924958ull, 516702396751038ull}},
{{3467249008481408996ull, 413361917400831ull}},
{{17531194465752768490ull, 330689533920664ull}},
{{16981864700978698614ull, 529103254273063ull}},
{{2517445316557227922ull, 423282603418451ull}},
{{16771351512213423630ull, 338626082734760ull}},
{{8387418345831926192ull, 541801732375617ull}},
{{17777981120891271923ull, 433441385900493ull}},
{{3154338452487286569ull, 346753108720395ull}},
{{5046941523979658511ull, 554804973952632ull}},
{{15105599663409457778ull, 443843979162105ull}},
{{12084479730727566222ull, 355075183329684ull}},
{{13356932599323963301ull, 284060146663747ull}},
{{6613696899950699989ull, 454496234661996ull}},
{{1601608705218649668ull, 363596987729597ull}},
{{12349333408400650704ull, 290877590183677ull}},
{{5001538194473399834ull, 465404144293884ull}},
{{7690579370320630190ull, 372323315435107ull}},
{{17220509940482235122ull, 297858652348085ull}},
{{9106071831062024579ull, 476573843756937ull}},
{{18352903909075350633ull, 381259075005549ull}},
{{18371671942002190829ull, 305007260004439ull}},
{{18326628662977774357ull, 488011616007103ull}},
{{3593256486156488516ull, 390409292805683ull}},
{{10253302818409011459ull, 312327434244546ull}},
{{9026586879970597689ull, 499723894791274ull}},
{{10910618318718388474ull, 399779115833019ull}},
{{12417843469716621102ull, 319823292666415ull}},
{{1421805477837042148ull, 511717268266265ull}},
{{1137444382269633718ull, 409373814613012ull}},
{{11978001950041437944ull, 327499051690409ull}},
{{8096756675840569741ull, 523998482704655ull}},
{{6477405340672455793ull, 419198786163724ull}},
{{8871273087279874958ull, 335359028930979ull}},
{{3125990495422068963ull, 536574446289567ull}},
{{13568838840563386140ull, 429259557031653ull}},
{{18233768701934529558ull, 343407645625322ull}},
{{14416634664127606000ull, 549452233000516ull}},
{{7843958916560174477ull, 439561786400413ull}},
{{13653864762731960228ull, 351649429120330ull}},
{{3399439546661584749ull, 562639086592529ull}},
{{6408900452071178122ull, 450111269274023ull}},
{{12505817991140763144ull, 360089015419218ull}},
{{17383352022396431162ull, 288071212335374ull}},
{{16745316791608558889ull, 460913939736599ull}},
{{17085602248028757434ull, 368731151789279ull}},
{{17357830613164916271ull, 294984921431423ull}},
{{5636436092612404094ull, 471975874290278ull}},
{{11887846503573743922ull, 377580699432222ull}},
{{2131579573375174491ull, 302064559545778ull}},
{{18167922576367920478ull, 483303295273244ull}},
{{18223686875836246706ull, 386642636218595ull}},
{{14578949500668997365ull, 309314108974876ull}},
{{15947621571586575137ull, 494902574359802ull}},
{{5379399627785439463ull, 395922059487842ull}},
{{15371566146454082540ull, 316737647590273ull}},
{{2458412945875070125ull, 506780236144438ull}},
{{9345427986183876747ull, 405424188915550ull}},
{{7476342388947101397ull, 324339351132440ull}},
{{11962147822315362236ull, 518942961811904ull}},
{{13259067072594200112ull, 415154369449523ull}},
{{17985951287559180736ull, 332123495559618ull}},
{{6641429171643227238ull, 531397592895390ull}},
{{5313143337314581790ull, 425118074316312ull}},
{{15318561114077396402ull, 340094459453049ull}},
{{13441651338298103274ull, 544151135124879ull}},
{{14442669885380392942ull, 435320908099903ull}},
{{486089464078583384ull, 348256726479923ull}},
{{15535138401493374707ull, 557210762367876ull}},
{{8738761906452789443ull, 445768609894301ull}},
{{3301660710420321231ull, 356614887915441ull}},
{{17398723827303898277ull, 285291910332352ull}},
{{13080562864718595951ull, 456467056531764ull}},
{{14153799106516787084ull, 365173645225411ull}},
{{7633690470471519344ull, 292138916180329ull}},
{{1145858308528699981ull, 467422265888527ull}},
{{11984733091048690954ull, 373937812710821ull}},
{{5898437658097042440ull, 299150250168657ull}},
{{13126849067697178228ull, 478640400269851ull}},
{{6812130439415832259ull, 382912320215881ull}},
{{1760355536790755484ull, 306329856172705ull}},
{{2816568858865208774ull, 490127769876328ull}},
{{9631952716575987666ull, 392102215901062ull}},
{{326864543776969486ull, 313681772720850ull}},
{{522983270043151178ull, 501890836353360ull}},
{{418386616034520942ull, 401512669082688ull}},
{{7713406922311437400ull, 321210135266150ull}},
{{12341451075698299841ull, 513936216425840ull}},
{{9873160860558639872ull, 411148973140672ull}},
{{519831058963091251ull, 328919178512538ull}},
{{15589124953308587295ull, 526270685620060ull}},
{{12471299962646869836ull, 421016548496048ull}},
{{17355737599601316515ull, 336813238796838ull}},
{{5633087270910644485ull, 538901182074942ull}},
{{15574516260954246558ull, 431120945659953ull}},
{{1391566564537666277ull, 344896756527963ull}},
{{16983901762227907336ull, 551834810444740ull}},
{{13587121409782325868ull, 441467848355792ull}},
{{3490999498342040048ull, 353174278684634ull}},
{{6482148413415542362ull, 282539422947707ull}},
{{14060786276206778102ull, 452063076716331ull}},
{{7559280206223512158ull, 361650461373065ull}},
{{6047424164978809727ull, 289320369098452ull}},
{{13365227478708005886ull, 462912590557523ull}},
{{18070879612450225355ull, 370330072446018ull}},
{{3388657245734449315ull, 296264057956815ull}},
{{5421851593175118904ull, 474022492730904ull}},
{{8026830089282005446ull, 379217994184723ull}},
{{13800161700909425003ull, 303374395347778ull}},
{{18390909906713169682ull, 485399032556445ull}},
{{14712727925370535745ull, 388319226045156ull}},
{{8080833525554518273ull, 310655380836125ull}},
{{12929333640887229237ull, 497048609337800ull}},
{{10343466912709783390ull, 397638887470240ull}},
{{8274773530167826712ull, 318111109976192ull}},
{{16928986463010433062ull, 508977775961907ull}},
{{6164491540924525803ull, 407182220769526ull}},
{{1242244417997710319ull, 325745776615621ull}},
{{13055637513022067481ull, 521193242584993ull}},
{{17823207639901474631ull, 416954594067994ull}},
{{17947914926663090028ull, 333563675254395ull}},
{{10269919808951392429ull, 533701880407033ull}},
{{15594633476644934589ull, 426961504325626ull}},
{{8786357966574037348ull, 341569203460501ull}},
{{6679475117034639111ull, 546510725536802ull}},
{{16411626537853442258ull, 437208580429441ull}},
{{9439952415540843483ull, 349766864343553ull}},
{{11414575050123439250ull, 559626982949685ull}},
{{9131660040098751400ull, 447701586359748ull}},
{{14684025661562821766ull, 358161269087798ull}},
{{679174085024526443ull, 286529015270239ull}},
{{8465376165523062956ull, 458446424432382ull}},
{{17840347376644181335ull, 366757139545905ull}},
{{14272277901315345068ull, 293405711636724ull}},
{{11767598197878821139ull, 469449138618759ull}},
{{13103427373044967234ull, 375559310895007ull}},
{{3104044268952153141ull, 300447448716006ull}},
{{16034517274549175995ull, 480715917945609ull}},
{{16516962634381251119ull, 384572734356487ull}},
{{5834872478021180249ull, 307658187485190ull}},
{{9335795964833888398ull, 492253099976304ull}},
{{11157985586609021042ull, 393802479981043ull}},
{{16305086098771037480ull, 315041983984834ull}},
{{15020091313807928998ull, 504067174375735ull}},
{{12016073051046343199ull, 403253739500588ull}},
{{16991556070320895205ull, 322602991600470ull}},
{{8739745638803880713ull, 516164786560753ull}},
{{14370494140526925216ull, 412931829248602ull}},
{{4117697682937719527ull, 330345463398882ull}},
{{10277665107442261566ull, 528552741438211ull}},
{{4532783271211898930ull, 422842193150569ull}},
{{7315575431711429467ull, 338273754520455ull}},
{{11704920690738287147ull, 541238007232728ull}},
{{16742634182074450364ull, 432990405786182ull}},
{{6015409716175739645ull, 346392324628946ull}},
{{2245957916397362785ull, 554227719406314ull}},
{{5486115147859800551ull, 443382175525051ull}},
{{699543303545930118ull, 354705740420041ull}},
{{15317029901804385387ull, 283764592336032ull}},
{{9749852583919375327ull, 454023347737652ull}},
{{421184437651679615ull, 363218678190122ull}},
{{11404993994347074661ull, 290574942552097ull}},
{{3490595131987678166ull, 464919908083356ull}},
{{17549871364557783825ull, 371935926466684ull}},
{{17729245906388137383ull, 297548741173347ull}},
{{13609398191253378521ull, 476077985877356ull}},
{{7198169738260792493ull, 380862388701885ull}},
{{5758535790608633995ull, 304689910961508ull}},
{{5524308450231904068ull, 487503857538413ull}},
{{11798144389669343901ull, 390003086030730ull}},
{{9438515511735475121ull, 312002468824584ull}},
{{4033578374551029224ull, 499203950119335ull}},
{{3226862699640823379ull, 399363160095468ull}},
{{9960187789196479349ull, 319490528076374ull}},
{{4868254018488635990ull, 511184844922199ull}},
{{7583952029532819115ull, 408947875937759ull}},
{{9756510438368165615ull, 327158300750207ull}},
{{853021442421423692ull, 523453281200332ull}},
{{11750463598162869923ull, 418762624960265ull}},
{{9400370878530295938ull, 335010099968212ull}},
{{283198146680832208ull, 536016159949140ull}},
{{226558517344665767ull, 428812927959312ull}},
{{11249293258101463583ull, 343050342367449ull}},
{{6930822768736610763ull, 548880547787919ull}},
{{9234007029731198934ull, 439104438230335ull}},
{{7387205623784959147ull, 351283550584268ull}},
{{8130180183314024312ull, 562053680934829ull}},
{{10193492961393129773ull, 449642944747863ull}},
{{15533491998598324465ull, 359714355798290ull}},
{{12426793598878659572ull, 287771484638632ull}},
{{5125474499238214022ull, 460434375421812ull}},
{{15168426043616302187ull, 368347500337449ull}},
{{15824089649634952073ull, 294678000269959ull}},
{{14250496995190192347ull, 471484800431935ull}},
{{11400397596152153878ull, 377187840345548ull}},
{{16499015706405543748ull, 301750272276438ull}},
{{4262332241797408058ull, 482800435642302ull}},
{{14477912237663657416ull, 386240348513841ull}},
{{7892980975389015610ull, 308992278811073ull}},
{{8939420745880514653ull, 494387646097717ull}},
{{18219583040930142692ull, 395510116878173ull}},
{{3507619988518383184ull, 316408093502539ull}},
{{12990889611113233740ull, 506252949604062ull}},
{{3014014059406766346ull, 405002359683250ull}},
{{2411211247525413077ull, 324001887746600ull}},
{{3857937996040660923ull, 518403020394560ull}},
{{3086350396832528738ull, 414722416315648ull}},
{{9847777946949843637ull, 331777933052518ull}},
{{12067095900377839496ull, 530844692884029ull}},
{{13343025535044181920ull, 424675754307223ull}},
{{18053118057519166182ull, 339740603445778ull}},
{{6748896003579203953ull, 543584965513246ull}},
{{1709767988121452839ull, 434867972410597ull}},
{{12435860834722893241ull, 347894377928477ull}},
{{5139982076588987892ull, 556631004685564ull}},
{{7801334476013100637ull, 445304803748451ull}},
{{2551718766068570186ull, 356243842998761ull}},
{{16798770271822497442ull, 284995074399008ull}},
{{4741939546464533968ull, 455992119038414ull}},
{{7482900451913537497ull, 364793695230731ull}},
{{2296971546788919675ull, 291834956184585ull}},
{{3675154474862271480ull, 466935929895336ull}},
{{17697518838857458476ull, 373548743916268ull}},
{{3089968626860235811ull, 298838995133015ull}},
{{4943949802976377299ull, 478142392212824ull}},
{{7644508657123012162ull, 382513913770259ull}},
{{9804955740440320053ull, 306011131016207ull}},
{{930533925736870792ull, 489617809625932ull}},
{{11812473584815227603ull, 391694247700745ull}},
{{9449978867852182082ull, 313355398160596ull}},
{{7741268559079670686ull, 501368637056954ull}},
{{9882363662005646872ull, 401094909645563ull}},
{{15284588559088338144ull, 320875927716450ull}},
{{6008597620831789414ull, 513401484346321ull}},
{{1117529281923521208ull, 410721187477057ull}},
{{11962069869764547936ull, 328576949981645ull}},
{{692567717913725082ull, 525723119970633ull}},
{{7932751803814800712ull, 420578495976506ull}},
{{2656852628309930246ull, 336462796781205ull}},
{{4250964205295888394ull, 538340474849928ull}},
{{10779468993720531361ull, 430672379879942ull}},
{{1244877565492604443ull, 344537903903954ull}},
{{9370501734271987755ull, 551260646246326ull}},
{{3807052572675679881ull, 441008516997061ull}},
{{17803037317108185197ull, 352806813597648ull}},
{{3174383409460817188ull, 282245450878119ull}},
{{12457711084621128148ull, 451592721404990ull}},
{{9966168867696902518ull, 361274177123992ull}},
{{594237464673701368ull, 289019341699194ull}},
{{8329477572961742835ull, 462430946718710ull}},
{{6663582058369394268ull, 369944757374968ull}},
{{12709563276179336061ull, 295955805899974ull}},
{{9267254797661206728ull, 473529289439959ull}},
{{11103152652870875705ull, 378823431551967ull}},
{{1503824492812879918ull, 303058745241574ull}},
{{9784816817984428515ull, 484893992386518ull}},
{{15206551083871363459ull, 387915193909214ull}},
{{15854589681839001090ull, 310332155127371ull}},
{{17988645861458581098ull, 496531448203794ull}},
{{18080265503908775201ull, 397225158563035ull}},
{{14464212403127020161ull, 317780126850428ull}},
{{1006646956551770319ull, 508448202960686ull}},
{{15562712824209057548ull, 406758562368548ull}},
{{1382123815141515068ull, 325406849894839ull}},
{{9590095733710244756ull, 520650959831742ull}},
{{293378957484375158ull, 416520767865394ull}},
{{3924051980729410450ull, 333216614292315ull}},
{{6278483169167056720ull, 533146582867704ull}},
{{8712135350075555699ull, 426517266294163ull}},
{{14348405909544265206ull, 341213813035330ull}},
{{4510705381561272713ull, 545942100856529ull}},
{{7297913119990928494ull, 436753680685223ull}},
{{13217028125476563441ull, 349402944548178ull}},
{{17457896186020591183ull, 559044711277085ull}},
{{13966316948816472946ull, 447235769021668ull}},
{{105007114827447387ull, 357788615217335ull}},
{{84005691861957910ull, 286230892173868ull}},
{{14891804365946773949ull, 457969427478188ull}},
{{845397048531688189ull, 366375541982551ull}},
{{15433712897792991844ull, 293100433586040ull}},
{{6247196562759235335ull, 468960693737665ull}},
{{4997757250207388268ull, 375168554990132ull}},
{{15066252244391641584ull, 300134843992105ull}},
{{5659259517317074918ull, 480215750387369ull}},
{{8216756428595570258ull, 384172600309895ull}},
{{6573405142876456206ull, 307338080247916ull}},
{{3138750599118509284ull, 491740928396666ull}},
{{17268395738262448720ull, 393392742717332ull}},
{{6436018961126138329ull, 314714194173866ull}},
{{2918932708318000681ull, 503542710678186ull}},
{{17092541425622041837ull, 402834168542548ull}},
{{2605986696271902500ull, 322267334834039ull}},
{{11548276343518864647ull, 515627735734462ull}},
{{1859923445331271071ull, 412502188587570ull}},
{{1487938756265016857ull, 330001750870056ull}},
{{13448748454249757941ull, 528002801392089ull}},
{{14448347578141716676ull, 422402241113671ull}},
{{7869329247771463017ull, 337921792890937ull}},
{{16280275611176251151ull, 540674868625499ull}},
{{16713569303682911244ull, 432539894900399ull}},
{{17060204257688239318ull, 346031915920319ull}},
{{16228280368075451940ull, 553651065472511ull}},
{{9293275479718451229ull, 442920852378009ull}},
{{11123969198516671306ull, 354336681902407ull}},
{{1520477729329516398ull, 283469345521926ull}},
{{13500810811152957207ull, 453550952835081ull}},
{{7111299834180455442ull, 362840762268065ull}},
{{5689039867344364354ull, 290272609814452ull}},
{{12791812602492893290ull, 464436175703123ull}},
{{17612147711478135278ull, 371548940562498ull}},
{{3021671724956777253ull, 297239152449999ull}},
{{12213372389414664251ull, 475582643919998ull}},
{{17149395541015552047ull, 380466115135998ull}},
{{2651469988586710668ull, 304372892108799ull}},
{{11621049611222557716ull, 486996627374078ull}},
{{16675537318461866819ull, 389597301899262ull}},
{{5961732225285672808ull, 311677841519410ull}},
{{9538771560457076494ull, 498684546431056ull}},
{{3941668433623750872ull, 398947637144845ull}},
{{3153334746899000697ull, 319158109715876ull}},
{{16113382039264132086ull, 510652975545401ull}},
{{9201356816669395345ull, 408522380436321ull}},
{{3671736638593605953ull, 326817904349057ull}},
{{9564127436491679848ull, 522908646958491ull}},
{{3961953134451433555ull, 418326917566793ull}},
{{10548260137044967490ull, 334661534053434ull}},
{{5809169775046217015ull, 535458454485495ull}},
{{4647335820036973612ull, 428366763588396ull}},
{{28519841287668566ull, 342693410870717ull}},
{{3734980560802180030ull, 548309457393147ull}},
{{14056030892867474993ull, 438647565914517ull}},
{{3866127084810159348ull, 350918052731614ull}},
{{13564500965180075604ull, 561468884370582ull}},
{{3472903142660239837ull, 449175107496466ull}},
{{17535717773095833162ull, 359340085997172ull}},
{{6649876588992845883ull, 287472068797738ull}},
{{6950453727646643090ull, 459955310076381ull}},
{{1871014167375404149ull, 367964248061105ull}},
{{1496811333900323319ull, 294371398448884ull}},
{{9773595763724337957ull, 470994237518214ull}},
{{11508225425721380689ull, 376795390014571ull}},
{{5517231525835194228ull, 301436312011657ull}},
{{12516919256078221088ull, 482298099218651ull}},
{{6324186590120666547ull, 385838479374921ull}},
{{1370000457354622914ull, 308670783499937ull}},
{{5881349546509306986ull, 493873253599899ull}},
{{8394428451949355912ull, 395098602879919ull}},
{{10404891576301395053ull, 316078882303935ull}},
{{16647826522082232085ull, 505726211686296ull}},
{{9628912402923875344ull, 404580969349037ull}},
{{324432292855279629ull, 323664775479230ull}},
{{519091668568447407ull, 517863640766768ull}},
{{7793970964338578572ull, 414290912613414ull}},
{{9924525586212773180ull, 331432730090731ull}},
{{8500543308456616443ull, 530292368145170ull}},
{{6800434646765293154ull, 424233894516136ull}},
{{1750998902670324200ull, 339387115612909ull}},
{{10180295873756339367ull, 543019384980654ull}},
{{11833585513746981816ull, 434415507984523ull}},
{{16845566040481406099ull, 347532406387618ull}},
{{4816812776318787820ull, 556051850220190ull}},
{{3853450221055030256ull, 444841480176152ull}},
{{14150806621069755174ull, 355873184140921ull}},
{{7631296482113893816ull, 284698547312737ull}},
{{15899423186124140429ull, 455517675700379ull}},
{{16408887363641222667ull, 364414140560303ull}},
{{2059063446687247164ull, 291531312448243ull}},
{{18051896773667236755ull, 466450099917188ull}},
{{3373470974708058434ull, 373160079933751ull}},
{{17456172038734088040ull, 298528063947000ull}},
{{9483131188264989248ull, 477644902315201ull}},
{{3897156135870081075ull, 382115921852161ull}},
{{17875120167663706153ull, 305692737481728ull}},
{{6464099379810467906ull, 489108379970766ull}},
{{1481930689106464001ull, 391286703976613ull}},
{{8564242180768991847ull, 313029363181290ull}},
{{13702787489230386956ull, 500846981090064ull}},
{{14651578806126219888ull, 400677584872051ull}},
{{8031914230159065587ull, 320542067897641ull}},
{{5472365138770684293ull, 512867308636226ull}},
{{688543296274637111ull, 410293846908981ull}},
{{15308229895987350982ull, 328235077527184ull}},
{{13425121389354030601ull, 525176124043495ull}},
{{10740097111483224481ull, 420140899234796ull}},
{{4902728874444669262ull, 336112719387837ull}},
{{11533715013853381142ull, 537780351020539ull}},
{{12916320825824615237ull, 430224280816431ull}},
{{6643707845917781866ull, 344179424653145ull}},
{{10629932553468450986ull, 550687079445032ull}},
{{1125248413290940142ull, 440549663556026ull}},
{{15657593989600393407ull, 352439730844820ull}},
{{12526075191680314725ull, 281951784675856ull}},
{{12663022677204682914ull, 451122855481370ull}},
{{10130418141763746331ull, 360898284385096ull}},
{{4414985698669086742ull, 288718627508077ull}},
{{10753325932612449110ull, 461949804012923ull}},
{{15981358375573779934ull, 369559843210338ull}},
{{1717040256233292978ull, 295647874568271ull}},
{{13815310854198999734ull, 473036599309233ull}},
{{18430946312843020434ull, 378429279447386ull}},
{{11055408235532506024ull, 302743423557909ull}},
{{6620606732626278669ull, 484389477692655ull}},
{{5296485386101022935ull, 387511582154124ull}},
{{7926537123622728671ull, 310009265723299ull}},
{{1614412953570634904ull, 496014825157279ull}},
{{4980879177598418247ull, 396811860125823ull}},
{{11363400971562555244ull, 317449488100658ull}},
{{14492092739758178067ull, 507919180961053ull}},
{{525627747580811484ull, 406335344768843ull}},
{{7799199827548469833ull, 325068275815074ull}},
{{1410673279851820764ull, 520109241304119ull}},
{{4817887438623366934ull, 416087393043295ull}},
{{3854309950898693547ull, 332869914434636ull}},
{{17234942365663640646ull, 532591863095417ull}},
{{6409256263047091870ull, 426073490476334ull}},
{{8816753825179583819ull, 340858792381067ull}},
{{17796154935029244434ull, 545374067809707ull}},
{{6858226318539574901ull, 436299254247766ull}},
{{1797232240089749597ull, 349039403398213ull}},
{{17632966843111240649ull, 558463045437140ull}},
{{14106373474488992519ull, 446770436349712ull}},
{{3906401150107373369ull, 357416349079770ull}},
{{3125120920085898695ull, 285933079263816ull}},
{{16068239916363168882ull, 457492926822105ull}},
{{12854591933090535105ull, 365994341457684ull}},
{{13973022361214338407ull, 292795473166147ull}},
{{7599440518975300159ull, 468472757065836ull}},
{{2390203600438329804ull, 374778205652669ull}},
{{5601511695092574166ull, 299822564522135ull}},
{{8962418712148118666ull, 479716103235416ull}},
{{3480586154976584610ull, 383772882588333ull}},
{{10163166553465088334ull, 307018306070666ull}},
{{8882368856060320688ull, 491229289713066ull}},
{{3416546270106346227ull, 392983431770453ull}},
{{10111934645568897628ull, 314386745416362ull}},
{{1421700173942594913ull, 503018792666180ull}},
{{1137360139154075930ull, 402415034132944ull}},
{{4599236926065171067ull, 321932027306355ull}},
{{7358779081704273708ull, 515091243690168ull}},
{{13265720894847239612ull, 412072994952134ull}},
{{14301925530619702013ull, 329658395961707ull}},
{{8125685590023881928ull, 527453433538732ull}},
{{17568594916244836512ull, 421962746830985ull}},
{{14054875932995869210ull, 337570197464788ull}},
{{351708604341928797ull, 540112315943662ull}},
{{11349413327699274007ull, 432089852754929ull}},
{{12768879476901329529ull, 345671882203943ull}},
{{16740858348300216923ull, 553075011526309ull}},
{{17082035493382083861ull, 442460009221047ull}},
{{6286930765221846443ull, 353968007376838ull}},
{{12408242241661297800ull, 283174405901470ull}},
{{1406443512948524865ull, 453079049442353ull}},
{{8503852439842640538ull, 362463239553882ull}},
{{17871128396099843400ull, 289970591643105ull}},
{{10147061360050197824ull, 463952946628969ull}},
{{11806997902782068583ull, 371162357303175ull}},
{{9445598322225654866ull, 296929885842540ull}},
{{15112957315561047786ull, 475087817348064ull}},
{{15779714667190748552ull, 380070253878451ull}},
{{8934422919010688518ull, 304056203102761ull}},
{{6916379040933280983ull, 486489924964418ull}},
{{12911800862230445433ull, 389191939971534ull}},
{{14018789504526266669ull, 311353551977227ull}},
{{7672667948274385378ull, 498165683163564ull}},
{{9827483173361418626ull, 398532546530851ull}},
{{4172637723947224577ull, 318826037224681ull}},
{{17744266802541290293ull, 510121659559489ull}},
{{17884762256774942558ull, 408097327647591ull}},
{{10618460990678043723ull, 326477862118073ull}},
{{13300188770342959634ull, 522364579388917ull}},
{{3261453386790547061ull, 417891663511134ull}},
{{6298511524174347972ull, 334313330808907ull}},
{{13766967253420867078ull, 534901329294251ull}},
{{7324224987994783339ull, 427921063435401ull}},
{{2170031175653916348ull, 342336850748321ull}},
{{14540096325271997127ull, 547738961197313ull}},
{{564030615991866732ull, 438191168957851ull}},
{{15208619751761134678ull, 350552935166280ull}},
{{5887047529108263869ull, 560884696266049ull}},
{{8398986838028521418ull, 448707757012839ull}},
{{10408538285164727458ull, 358966205610271ull}},
{{4637481813389871643ull, 287172964488217ull}},
{{11109319716165704952ull, 459476743181147ull}},
{{1508758143448743315ull, 367581394544918ull}},
{{8585704144242815299ull, 294065115635934ull}},
{{2669080186562773508ull, 470504185017495ull}},
{{2135264149250218807ull, 376403348013996ull}},
{{16465606578367816338ull, 301122678411196ull}},
{{519528822195133879ull, 481796285457915ull}},
{